(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     25904,        654]
NotebookOptionsPosition[     24829,        615]
NotebookOutlinePosition[     25468,        639]
CellTagsIndexPosition[     25425,        636]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Fitness Model for Gene Frequency in Populations", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "freqs", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"w2", "\[Equal]", "w1", "\[Equal]", "w0", "\[Equal]", "0"}], 
        ",", 
        RowBox[{"w0", "=", ".001"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"w2", "\[Equal]", "0"}], "&&", 
         RowBox[{"p0", "\[Equal]", "1"}]}], ",", 
        RowBox[{"w2", "=", ".001"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"freqs", "=", 
       RowBox[{"NestList", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{"p", ",", 
           FractionBox[
            RowBox[{
             RowBox[{"w2", "*", 
              SuperscriptBox["p", "2"]}], "+", 
             RowBox[{"w1", "*", "p", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "p"}], ")"}]}]}], 
            RowBox[{
             RowBox[{"w2", "*", 
              SuperscriptBox["p", "2"]}], "+", 
             RowBox[{"w1", "*", "2", "p", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "p"}], ")"}]}], "+", 
             RowBox[{"w0", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "p"}], ")"}], "2"]}]}]]}], "]"}], ",", "p0",
          ",", "generations"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Grid", "[", 
       RowBox[{"{", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"0", ",", "generations"}], "]"}], ",", "freqs"}], 
              "}"}], "]"}], ",", 
            RowBox[{"AspectRatio", "\[Rule]", ".6"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "350"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", ".01"}], "*", "generations"}], ",", 
                 RowBox[{"1.1", "*", "generations"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", ".02"}], ",", "1.02"}], "}"}]}], "}"}]}], ",", 
            RowBox[{"PlotLabel", "\[Rule]", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Subscript", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<p\>\"", ",", "Italic"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}]}], "]"}], 
                  ",", "\"\< = frequency of allele \>\"", ",", "\"\<A\>\"", 
                  ",", "\"\< in the population in generation \>\"", ",", 
                  RowBox[{"Style", "[", 
                   RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}]}], "}"}], 
                "]"}], ",", "Bold"}], "]"}]}], ",", 
            RowBox[{"Epilog", "\[Rule]", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"White", ",", 
                 RowBox[{"Rectangle", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1.01", "*", "generations"}], ",", 
                    RowBox[{"-", ".01"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1.1", "*", "generations"}], ",", ".02"}], 
                    "}"}]}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"Black", ",", 
                 RowBox[{"Text", "[", 
                  RowBox[{
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1.04", "*", "generations"}], ",", "0"}], "}"}]}],
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"Which", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}], "\[Equal]", 
                   "0"}], "||", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["w1", "2"], "-", 
                    RowBox[{"w0", "*", "w2"}]}], "\[Equal]", "0"}]}], ",", 
                 RowBox[{"{", "}"}], ",", 
                 RowBox[{"0", "<", 
                  FractionBox[
                   RowBox[{"w1", "-", "w0"}], 
                   RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}]], "<", "1"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"w0", 
                    RowBox[{"(", 
                    RowBox[{"w1", "-", "w2"}], ")"}]}], "+", 
                    RowBox[{"w2", 
                    RowBox[{"(", 
                    RowBox[{"w1", "-", "w0"}], ")"}]}]}], 
                    RowBox[{
                    SuperscriptBox["w1", "2"], "-", 
                    RowBox[{"w0", "*", "w2"}]}]], "]"}], "<", "1"}], ",", 
                    RowBox[{"Darker", "@", "Green"}], ",", 
                    RowBox[{"Darker", "@", "Pink"}]}], "]"}], ",", 
                   RowBox[{"Line", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    FractionBox[
                    RowBox[{"w1", "-", "w0"}], 
                    RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}]]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"generations", ",", 
                    FractionBox[
                    RowBox[{"w1", "-", "w0"}], 
                    RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}]]}], "}"}]}], 
                    "}"}], "]"}], ",", 
                   RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"w1", "-", "w0"}], 
                    RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}]], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "3"}], "}"}], ",", 
                    RowBox[{"ExponentFunction", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{"Null", "&"}], ")"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"generations", ",", 
                    FractionBox[
                    RowBox[{"w1", "-", "w0"}], 
                    RowBox[{
                    RowBox[{"2", "w1"}], "-", "w0", "-", "w2"}]]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1.5"}], ",", "0"}], "}"}]}], "]"}]}], "}"}],
                  ",", "True", ",", 
                 RowBox[{"{", "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"PointSize", "[", ".015", "]"}], ",", 
                 RowBox[{"Point", "[", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "p0"}], "}"}], "]"}]}], "}"}]}], 
              "\[IndentingNewLine]", "]"}]}]}], "]"}], ",", 
          RowBox[{"Text", "@", 
           RowBox[{"Grid", "[", 
            RowBox[{
             RowBox[{"Prepend", "[", 
              RowBox[{
               RowBox[{"Transpose", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Range", "[", 
                   RowBox[{"0", ",", "generations", ",", 
                    RowBox[{"generations", "/", "10"}]}], "]"}], ",", 
                  RowBox[{"MapAt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{"#", ",", "Red"}], "]"}], "&"}], ",", 
                    RowBox[{"Map", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "3"}], "}"}], ",", 
                    RowBox[{"ExponentFunction", "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{"Null", "&"}], ")"}]}]}], "]"}], "&"}], ",", 
                    RowBox[{"freqs", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ";;", 
                    RowBox[{"generations", "+", "1"}], ";;", 
                    RowBox[{"generations", "/", "10"}]}], 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", "1"}], "]"}]}], 
                 "}"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Row", "[", 
                  RowBox[{"{", 
                   RowBox[{"\"\<generation \>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}]}], "}"}], 
                  "]"}], ",", 
                 RowBox[{"Subscript", "[", 
                  RowBox[{
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<p\>\"", ",", "Italic"}], "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<k\>\"", ",", "Italic"}], "]"}]}], "]"}]}], 
                "}"}]}], "]"}], ",", 
             RowBox[{"Dividers", "\[Rule]", "Gray"}], ",", 
             RowBox[{"ItemSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"Automatic", ",", "4"}], "}"}], ",", "Automatic"}], 
               "}"}]}]}], "]"}]}]}], "}"}], "}"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"generations", ",", "100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "20", ",", "50", ",", "100"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p0", ",", ".45", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(p\), \(0\)]\)\>\"", ",", "Red"}], 
        "]"}]}], "}"}], ",", "0.001", ",", ".999", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "VerticalSlider"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w2", ",", "1.", ",", "\"\<fitness of AA\>\""}], "}"}], ",", 
     "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w1", ",", ".93", ",", "\"\<fitness of Aa\>\""}], "}"}], ",", 
     "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w0", ",", ".97", ",", "\"\<fitness of aa\>\""}], "}"}], ",", 
     "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.413879817332931*^9, {3.4138798855522633`*^9, 
   3.413879899382256*^9}, {3.4138799900989037`*^9, 3.413879990763886*^9}, {
   3.413969823721362*^9, 3.413969846081072*^9}, 3.413972287174608*^9, {
   3.4139723325144777`*^9, 3.413972348266386*^9}, {3.4139724030573673`*^9, 
   3.413972413496883*^9}, {3.413972447453247*^9, 3.4139724580365458`*^9}, {
   3.4141458997932577`*^9, 3.4141461146526327`*^9}, {3.4141461604807577`*^9, 
   3.4141462117307577`*^9}, {3.414158251449812*^9, 3.414158257885784*^9}, {
   3.4141728784182577`*^9, 3.4141729221995077`*^9}, {3.4142731262831707`*^9, 
   3.414273131803516*^9}, {3.4144286434740677`*^9, 3.4144286633958154`*^9}, {
   3.414495092406048*^9, 3.4144950952029047`*^9}}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`generations$$ = 100, $CellContext`p0$$ = 
    0.45, $CellContext`w0$$ = 0.97, $CellContext`w1$$ = 
    0.93, $CellContext`w2$$ = 1., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`generations$$], 100}, {10, 20, 50, 100}}, {{
       Hold[$CellContext`p0$$], 0.45, 
       Style["\!\(\*SubscriptBox[\(p\), \(0\)]\)", 
        RGBColor[1, 0, 0]]}, 0.001, 0.999}, {{
       Hold[$CellContext`w2$$], 1., "fitness of AA"}, 0, 1}, {{
       Hold[$CellContext`w1$$], 0.93, "fitness of Aa"}, 0, 1}, {{
       Hold[$CellContext`w0$$], 0.97, "fitness of aa"}, 0, 1}}, 
    Typeset`size$$ = {483., {114., 119.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`generations$13146$$ = 0, $CellContext`p0$13147$$ = 
    0, $CellContext`w2$13148$$ = 0, $CellContext`w1$13149$$ = 
    0, $CellContext`w0$13150$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`generations$$ = 100, $CellContext`p0$$ = 
        0.45, $CellContext`w0$$ = 0.97, $CellContext`w1$$ = 
        0.93, $CellContext`w2$$ = 1.}, "ControllerVariables" :> {
        Hold[$CellContext`generations$$, $CellContext`generations$13146$$, 0],
         
        Hold[$CellContext`p0$$, $CellContext`p0$13147$$, 0], 
        Hold[$CellContext`w2$$, $CellContext`w2$13148$$, 0], 
        Hold[$CellContext`w1$$, $CellContext`w1$13149$$, 0], 
        Hold[$CellContext`w0$$, $CellContext`w0$13150$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`freqs$}, 
        If[$CellContext`w2$$ == $CellContext`w1$$ == $CellContext`w0$$ == 
          0, $CellContext`w0$$ = 0.001]; If[
          
          And[$CellContext`w2$$ == 0, $CellContext`p0$$ == 
           1], $CellContext`w2$$ = 0.001]; $CellContext`freqs$ = NestList[
           
           Function[$CellContext`p$, ($CellContext`w2$$ $CellContext`p$^2 + \
$CellContext`w1$$ $CellContext`p$ (
               1 - $CellContext`p$))/($CellContext`w2$$ $CellContext`p$^2 + \
$CellContext`w1$$ 
             2 $CellContext`p$ (
              1 - $CellContext`p$) + $CellContext`w0$$ (
               1 - $CellContext`p$)^2)], $CellContext`p0$$, \
$CellContext`generations$$]; Grid[{{
            ListPlot[
             Transpose[{
               Range[0, $CellContext`generations$$], $CellContext`freqs$}], 
             AspectRatio -> 0.6, ImageSize -> 350, 
             PlotRange -> {{(-0.01) $CellContext`generations$$, 
                1.1 $CellContext`generations$$}, {-0.02, 1.02}}, PlotLabel -> 
             Style[
               Row[{
                 Subscript[
                  Style["p", Italic], 
                  Style["k", Italic]], " = frequency of allele ", "A", 
                 " in the population in generation ", 
                 Style["k", Italic]}], Bold], Epilog -> Join[{White, 
                
                Rectangle[{1.01 $CellContext`generations$$, -0.01}, {
                 1.1 $CellContext`generations$$, 0.02}]}, {Black, 
                Text[
                 Style["k", Italic], {1.04 $CellContext`generations$$, 0}]}, 
               Which[
                Or[
                2 $CellContext`w1$$ - $CellContext`w0$$ - $CellContext`w2$$ == 
                 0, $CellContext`w1$$^2 - $CellContext`w0$$ $CellContext`w2$$ == 
                 0], {}, 
                0 < ($CellContext`w1$$ - $CellContext`w0$$)/(
                 2 $CellContext`w1$$ - $CellContext`w0$$ - $CellContext`w2$$) < 
                1, {
                 If[
                 Abs[($CellContext`w0$$ ($CellContext`w1$$ - \
$CellContext`w2$$) + $CellContext`w2$$ ($CellContext`w1$$ - \
$CellContext`w0$$))/($CellContext`w1$$^2 - $CellContext`w0$$ \
$CellContext`w2$$)] < 1, 
                  Darker[Green], 
                  Darker[Pink]], 
                 
                 Line[{{0, ($CellContext`w1$$ - $CellContext`w0$$)/(
                    2 $CellContext`w1$$ - $CellContext`w0$$ - \
$CellContext`w2$$)}, {$CellContext`generations$$, ($CellContext`w1$$ - \
$CellContext`w0$$)/(
                    2 $CellContext`w1$$ - $CellContext`w0$$ - \
$CellContext`w2$$)}}], 
                 Text[
                  
                  NumberForm[($CellContext`w1$$ - $CellContext`w0$$)/(
                   2 $CellContext`w1$$ - $CellContext`w0$$ - \
$CellContext`w2$$), {4, 3}, 
                   ExponentFunction -> (
                    Null& )], {$CellContext`generations$$, ($CellContext`w1$$ - \
$CellContext`w0$$)/(
                   2 $CellContext`w1$$ - $CellContext`w0$$ - \
$CellContext`w2$$)}, {-1.5, 0}]}, True, {}], {Red, 
                PointSize[0.015], 
                Point[{0, $CellContext`p0$$}]}]], 
            Text[
             Grid[
              Prepend[
               Transpose[{
                 Range[
                 0, $CellContext`generations$$, $CellContext`generations$$/
                  10], 
                 MapAt[Style[#, Red]& , 
                  Map[NumberForm[#, {4, 3}, ExponentFunction -> (Null& )]& , 
                   Part[$CellContext`freqs$, 
                    Span[
                    1, $CellContext`generations$$ + 
                    1, $CellContext`generations$$/10]]], 1]}], {
                Row[{"generation ", 
                  Style["k", Italic]}], 
                Subscript[
                 Style["p", Italic], 
                 Style["k", Italic]]}], Dividers -> Gray, 
              ItemSize -> {{Automatic, 4}, Automatic}]]}}]], 
      "Specifications" :> {{{$CellContext`generations$$, 100}, {10, 20, 50, 
         100}}, {{$CellContext`p0$$, 0.45, 
          Style["\!\(\*SubscriptBox[\(p\), \(0\)]\)", 
           RGBColor[1, 0, 0]]}, 0.001, 0.999, ControlPlacement -> Left, 
         ControlType -> 
         VerticalSlider}, {{$CellContext`w2$$, 1., "fitness of AA"}, 0, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`w1$$, 0.93, "fitness of Aa"}, 0, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`w0$$, 0.97, "fitness of aa"}, 0, 1, 
         Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{571., {197., 202.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->376394509],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Fitness Model for Gene Frequency in Populations",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
FitnessModelForGeneFrequencyInPopulations/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
FitnessModelForGeneFrequencyInPopulations/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
FitnessModelForGeneFrequencyInPopulations/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
FitnessModelForGeneFrequencyInPopulations/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
FitnessModelForGeneFrequencyInPopulations/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]],

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "Contributed by: ",
 ButtonBox["Bruce Torrence",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/author.html?author=Bruce+Torrence"]\
, None},
  ButtonNote->
   "http://demonstrations.wolfram.com/author.html?author=Bruce+Torrence"]
}], "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6]],

Cell[CellGroupData[{

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 system is required to edit this notebook.\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA 6 \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
FitnessModelForGeneFrequencyInPopulations"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{751, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Fitness Model for Gene Frequency in Populations - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (February 7, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 239, 4, 70, "Section"],
Cell[832, 29, 12670, 298, 70, "Input"]
}, Open  ]],
Cell[13517, 330, 6983, 145, 70, "Output",
 CellID->376394509],
Cell[CellGroupData[{
Cell[20525, 479, 373, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[20901, 490, 1047, 31, 70, "Text"],
Cell[21951, 523, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[22291, 534, 436, 14, 70, "Text"],
Cell[CellGroupData[{
Cell[22752, 552, 829, 24, 70, "Text"],
Cell[23584, 578, 1217, 33, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
(* NotebookSignature HRjPlhij4B7JcADIm6@X86ll *)
