(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2782145,      54578]
NotebookOptionsPosition[   2781106,      54539]
NotebookOutlinePosition[   2781471,      54555]
CellTagsIndexPosition[   2781428,      54552]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Free Trade Economy", "Title"],

Cell[TextData[{
 "Hayes, Brian, ",
 StyleBox["Follow the Money",
  FontSlant->"Italic"],
 ", American Scientist, vol. 90 (5), Sept.-Oct. 2002, p. 400. Available \
online at ",
 Cell[BoxData[
  FormBox[
   ButtonBox[
    RowBox[{
     RowBox[{"http", ":"}], "//", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"www", ".", "americanscientist", ".", "org"}], "/", 
         "issues"}], "/", "pub"}], "/", "follow"}], "-", "the", "-", 
      "money"}]}],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://www.americanscientist.org/issues/pub/follow-the-money"], 
      None}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["Inits", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "step", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"step", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"state_List", ",", "leftX_List", ",", "log__"}], "}"}], ",", 
    RowBox[{"maxProportion_:", "1"}], ",", 
    RowBox[{"space_:", "1"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "si", ",", "sj", ",", "transfer"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "=", 
      RowBox[{"RandomSample", "[", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "state", "]"}], "]"}], ",", "2"}], "]"}]}], 
     ";", 
     RowBox[{"(*", " ", 
      RowBox[{
      "wealth", " ", "flows", " ", "from", " ", "i", " ", "to", " ", "j"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"si", ",", "sj"}], "}"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
        "state", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
        
        RowBox[{
        "state", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"transfer", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{"maxProportion", "*", 
        RowBox[{"Min", "[", 
         RowBox[{"si", ",", "sj"}], "]"}]}], "]"}]}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{"amt", " ", "transferred"}], " ", "*)"}], "\[IndentingNewLine]",
      
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReplacePart", "[", 
        RowBox[{"state", ",", 
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"si", ",", "sj"}], "}"}], "+", 
             RowBox[{"transfer", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], ")"}]}], "]"}]}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ReplacePart", "[", 
        RowBox[{"leftX", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "<", "j"}], ",", 
           RowBox[{"Thread", "[", 
            RowBox[{"j", "\[Rule]", 
             RowBox[{
              RowBox[{
              "leftX", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}],
               "-", "transfer"}]}], "]"}], ",", 
           RowBox[{"Thread", "[", 
            RowBox[{"i", "\[Rule]", 
             RowBox[{
              RowBox[{
              "leftX", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
               "+", "transfer"}]}], "]"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "transfer", ",", "i", ",", "j", ",", 
       RowBox[{
        RowBox[{"Last", "[", 
         RowBox[{"{", "log", "}"}], "]"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "space"}], ")"}], "transfer"}]}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "shadedRectangle", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shadedRectangle", "[", 
   RowBox[{
   "p1_", ",", "p2_", ",", "leftColor_", ",", "rightColor_", ",", 
    "opacity_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Opacity", "[", "opacity", "]"}], ",", 
    RowBox[{"Polygon", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "p2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "p1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "}"}], ",", "p2", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "p1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
          RowBox[{
          "p2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         "}"}]}], "}"}], ",", 
      RowBox[{"VertexColors", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "leftColor", ",", "rightColor", ",", "rightColor", ",", "leftColor"}],
         "}"}]}]}], "]"}]}], "}"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "sliceElements", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sliceElements", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "st_List", ",", "lx_List", ",", "tr_", ",", "i_", ",", "j_", ",", 
       "y_"}], "}"}], ",", "c_List", ",", "op_", ",", "sp_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Note", ":", " ", 
     RowBox[{
     "current", " ", "transaction", " ", "transfers", " ", "tr", " ", 
      "dollars", " ", "from", " ", "individual", " ", "i", " ", "to", " ", 
      "individual", " ", 
      RowBox[{"j", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "Here", " ", "are", " ", "the", " ", "polygons", " ", "for", " ", 
       "individuals", " ", "unaffected", " ", "by", " ", "current", " ", 
       "transaction"}], ",", " ", "and"}], " ", "*)"}], "\[IndentingNewLine]",
     
    RowBox[{"(*", " ", 
     RowBox[{
     "the", " ", "top", " ", "to", " ", "bottom", " ", "portion", " ", "of", 
      " ", "polygon", " ", "for", " ", "individual", " ", "i"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Opacity", "[", "op", "]"}], ",", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"#3", ",", 
            RowBox[{"Polygon", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#1", ",", "y"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"#2", ",", "y"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"#2", ",", 
                 RowBox[{"y", "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"#1", ",", 
                 RowBox[{"y", "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}]}], 
              "}"}], "]"}]}], "}"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{"lx", ",", "j"}], "]"}], ",", 
           RowBox[{
            RowBox[{"Delete", "[", 
             RowBox[{"lx", ",", "j"}], "]"}], "+", 
            RowBox[{"Delete", "[", 
             RowBox[{"st", ",", "j"}], "]"}]}], ",", 
           RowBox[{"Delete", "[", 
            RowBox[{"c", ",", "j"}], "]"}]}], "}"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Here", " ", "is", " ", "the", " ", "top", " ", "to", " ", "bottom", 
       " ", "portion", " ", "of", " ", "polygon", " ", "for", " ", 
       "individual", " ", "j"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"Opacity", "[", "op", "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "<", 
          RowBox[{
          "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
         "*)"}], 
        RowBox[{
         RowBox[{"i", "<", "j"}], ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", "tr"}], ",", "y"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}],
               ",", "y"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}],
               ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", "tr"}], ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}]}], "}"}], 
          "]"}], ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              ",", "y"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "-", "tr"}], ",", "y"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "-", "tr"}], ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}]}], "}"}], 
          "]"}]}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Here", " ", "is", " ", "the", " ", "tube", " ", "from", " ", "i", " ", 
       "to", " ", "j"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
        "<", 
        RowBox[{
        "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}], 
       "*)"}], 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "+", "tr"}], ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}]}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "+", "tr"}], ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
             "tr", ",", 
             RowBox[{"\[Pi]", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1.5"}], "}"}]}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"shadedRectangle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               "+", "tr"}], ",", 
              RowBox[{"y", "+", 
               RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
            RowBox[{
            "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
            "op"}], "]"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{"y", "+", 
                RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}], ",", "tr", ",", 
             RowBox[{"\[Pi]", 
              RowBox[{"{", 
               RowBox[{"0", ",", ".5"}], "}"}]}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               ",", "y"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                "+", "tr"}], ",", 
               RowBox[{"y", "+", 
                RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}]}], "]"}]}], 
          "}"}]}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "-", "tr"}], ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "sp"}], ")"}], "tr"}]}]}], "}"}]}], 
            "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                "-", "tr"}], ",", 
               RowBox[{"y", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
             "tr", ",", 
             RowBox[{"\[Pi]", 
              RowBox[{"{", 
               RowBox[{"1.5", ",", "2"}], "}"}]}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"shadedRectangle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
               "+", 
               RowBox[{
               "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}]}],
               ",", 
              RowBox[{"y", "+", 
               RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "lx", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               "-", "tr"}], ",", 
              RowBox[{"y", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{".5", "sp"}]}], ")"}], "tr"}]}]}], "}"}], ",", 
            RowBox[{
            "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "c", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], ",", 
            "op"}], "]"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "j", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"y", "+", 
                RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}], ",", "tr", ",", 
             RowBox[{"\[Pi]", 
              RowBox[{"{", 
               RowBox[{".5", ",", "1"}], "}"}]}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "c", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Opacity", "[", "op", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                "-", "tr"}], ",", "y"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                "lx", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "st", "\[LeftDoubleBracket]", "j", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"y", "+", 
                RowBox[{".5", "sp", "*", "tr"}]}]}], "}"}]}], "]"}]}], 
          "}"}]}], "\[IndentingNewLine]", "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "renderTrades", "]"}], ":=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"colorList", "\[Rule]", 
      RowBox[{"ColorData", "[", 
       RowBox[{"3", ",", "\"\<ColorList\>\""}], "]"}]}], ",", 
     RowBox[{"transparancy", "\[Rule]", ".7"}], ",", " ", 
     RowBox[{"width", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"space", "\[Rule]", "1"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "renderTrades", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"renderTrades", "[", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "_List", ",", "_List", ",", "_", ",", "_", ",", "_", ",", "_"}], 
        "}"}], ".."}], "}"}]}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "op", ",", "sp", ",", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", "x", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"c", ",", "op", ",", "sp"}], "}"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"colorList", ",", "transparancy", ",", "space"}], "}"}], "/.",
         
        RowBox[{"{", "opts", "}"}]}], "/.", 
       RowBox[{"Options", "[", "renderTrades", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "cycle", " ", "color", " ", "list", " ", "if", " ", "there", " ", 
        "are", " ", "more", " ", "individuals", " ", "than", " ", "colors"}], 
       ",", " ", 
       RowBox[{"or", " ", "vice", " ", "versa"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"c", "=", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{"c", ",", 
           RowBox[{"{", 
            RowBox[{"Ceiling", "[", 
             RowBox[{
              RowBox[{"Length", "@", 
               RowBox[{"x", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "/", 
              RowBox[{"Length", "[", "c", "]"}]}], "]"}], "}"}]}], "]"}], 
         "]"}], ",", 
        RowBox[{"Length", "@", 
         RowBox[{"x", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"sliceElements", "[", 
          RowBox[{"#", ",", "c", ",", "op", ",", "sp"}], "]"}], "&"}], "/@", 
        "x"}], ",", 
       RowBox[{"FilterRules", "[", 
        RowBox[{
         RowBox[{"{", "opts", "}"}], ",", " ", 
         RowBox[{"Options", "[", "Graphics", "]"}]}], "]"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Play:", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"initial", " ", "state", " ", "and", " ", "leftX", " ", "values"}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"st", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"100", ",", 
       RowBox[{"{", "10", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lx", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"500", "k"}], "+", "100"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "9"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"NestList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"step", "[", 
         RowBox[{"#", ",", "1", ",", "1"}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"st", ",", "lx", ",", "0", ",", "0", ",", "0", ",", "0"}], 
        "}"}], ",", "600"}], "]"}]}], ";"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"renderTrades", "[", 
  RowBox[{
   RowBox[{"Rest", "@", "data"}], ",", 
   RowBox[{"transparancy", "\[Rule]", ".9"}], ",", 
   RowBox[{"Background", "\[Rule]", "Gray"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -28.83458803629813}, {200, -28.83458803629813}, {
        200, 0.}, {100, 0.}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -28.83458803629813}, {700, -28.83458803629813}, {
        700, 0.}, {600, 0.}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -28.83458803629813}, {1200, -28.83458803629813}, {
        1200, 0.}, {1100, 0.}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -28.83458803629813}, {1700, -28.83458803629813}, {
        1700, 0.}, {1600, 0.}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -28.83458803629813}, {2200, -28.83458803629813}, {
        2200, 0.}, {2100, 0.}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2600, -28.83458803629813}, {2700, -28.83458803629813}, {
        2700, 0.}, {2600, 0.}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3100, -28.83458803629813}, {3200, -28.83458803629813}, {
        3200, 0.}, {3100, 0.}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -28.83458803629813}, {4200, -28.83458803629813}, {
        4200, 0.}, {4100, 0.}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4614.417294018149, -28.83458803629813}, {
       4700., -28.83458803629813}, {4700., 0.}, {4614.417294018149, 0.}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3600, -28.83458803629813}, {3700., -28.83458803629813}, {
       3700., 0.}, {3600, 0.}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4600., -7.208647009074532}, {4614.417294018149, 0.}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4600., -7.208647009074532}, 14.417294018149065`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3714.4172940181493`, -21.625941027223597`}, {
       4600., -21.625941027223597`}, {4600., -7.208647009074532}, {
       3714.4172940181493`, -7.208647009074532}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3714.4172940181493`, -21.625941027223597`}, 
       14.417294018149065`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3700., -28.83458803629813}, \
{3714.4172940181493`, -21.625941027223597`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -179.9410593581542}, {
        124.44676433907196`, -179.9410593581542}, {
        124.44676433907196`, -28.83458803629813}, {
        100, -28.83458803629813}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -179.9410593581542}, {700, -179.9410593581542}, {
        700, -28.83458803629813}, {600, -28.83458803629813}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -179.9410593581542}, {1200, -179.9410593581542}, {
        1200, -28.83458803629813}, {1100, -28.83458803629813}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -179.9410593581542}, {1700, -179.9410593581542}, {
        1700, -28.83458803629813}, {1600, -28.83458803629813}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -179.9410593581542}, {2200, -179.9410593581542}, {
        2200, -28.83458803629813}, {2100, -28.83458803629813}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3100, -179.9410593581542}, {3200, -179.9410593581542}, {
        3200, -28.83458803629813}, {3100, -28.83458803629813}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3600, -179.9410593581542}, {
        3714.4172940181493`, -179.9410593581542}, {
        3714.4172940181493`, -28.83458803629813}, {
        3600, -28.83458803629813}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -179.9410593581542}, {4200, -179.9410593581542}, {
        4200, -28.83458803629813}, {4100, -28.83458803629813}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4614.417294018149, -179.9410593581542}, {
       4700., -179.9410593581542}, {4700., -28.83458803629813}, {
       4614.417294018149, -28.83458803629813}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2600., -179.9410593581542}, {2700., -179.9410593581542}, {
      2700., -28.83458803629813}, {2600., -28.83458803629813}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{124.44676433907196`, -66.61120586676215}, \
{200., -28.83458803629813}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{200., -66.61120586676215}, 75.55323566092804, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{200., -142.1644415276902}, {
       2524.446764339072, -142.1644415276902}, {
       2524.446764339072, -66.61120586676215}, {200., -66.61120586676215}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2524.446764339072, -142.1644415276902}, 75.55323566092804, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2524.446764339072, -179.9410593581542}, \
{2600., -142.1644415276902}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -219.56591988537147`}, {
        104.63433407546333`, -219.56591988537147`}, {
        104.63433407546333`, -179.9410593581542}, {
        100, -179.9410593581542}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -219.56591988537147`}, {700, -219.56591988537147`}, {
        700, -179.9410593581542}, {600, -179.9410593581542}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -219.56591988537147`}, {
        1200, -219.56591988537147`}, {1200, -179.9410593581542}, {
        1100, -179.9410593581542}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -219.56591988537147`}, {
        1700, -219.56591988537147`}, {1700, -179.9410593581542}, {
        1600, -179.9410593581542}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -219.56591988537147`}, {
        2200, -219.56591988537147`}, {2200, -179.9410593581542}, {
        2100, -179.9410593581542}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -219.56591988537147`}, {
       2700., -219.56591988537147`}, {2700., -179.9410593581542}, {
       2524.446764339072, -179.9410593581542}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3100, -219.56591988537147`}, {
        3200, -219.56591988537147`}, {3200, -179.9410593581542}, {
        3100, -179.9410593581542}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3600, -219.56591988537147`}, {
        3714.4172940181493`, -219.56591988537147`}, {
        3714.4172940181493`, -179.9410593581542}, {
        3600, -179.9410593581542}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -219.56591988537147`}, {
        4200, -219.56591988537147`}, {4200, -179.9410593581542}, {
        4100, -179.9410593581542}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4614.417294018149, -219.56591988537147`}, {
      4700., -219.56591988537147`}, {4700., -179.9410593581542}, {
      4614.417294018149, -179.9410593581542}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{104.63433407546333`, -189.84727448995852`}, \
{124.44676433907196`, -179.9410593581542}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{124.44676433907196`, -189.84727448995852`}, 
       19.812430263608633`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{124.44676433907196`, -209.65970475356715`}, {
       4594.60486375454, -209.65970475356715`}, {
       4594.60486375454, -189.84727448995852`}, {
       124.44676433907196`, -189.84727448995852`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4594.60486375454, -209.65970475356715`}, 19.812430263608633`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4594.60486375454, -219.56591988537147`}, \
{4614.417294018149, -209.65970475356715`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -385.9410612024835}, {
        104.63433407546333`, -385.9410612024835}, {
        104.63433407546333`, -219.5659198853715}, {
        100, -219.5659198853715}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -385.9410612024835}, {700, -385.9410612024835}, {
        700, -219.5659198853715}, {600, -219.5659198853715}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -385.9410612024835}, {1200, -385.9410612024835}, {
        1200, -219.5659198853715}, {1100, -219.5659198853715}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -385.9410612024835}, {
        1616.812429341444, -385.9410612024835}, {
        1616.812429341444, -219.5659198853715}, {
        1600, -219.5659198853715}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -385.9410612024835}, {2200, -385.9410612024835}, {
        2200, -219.5659198853715}, {2100, -219.5659198853715}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -385.9410612024835}, {
       2700., -385.9410612024835}, {2700., -219.5659198853715}, {
       2524.446764339072, -219.5659198853715}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3600, -385.9410612024835}, {
        3714.4172940181493`, -385.9410612024835}, {
        3714.4172940181493`, -219.5659198853715}, {
        3600, -219.5659198853715}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -385.9410612024835}, {4200, -385.9410612024835}, {
        4200, -219.5659198853715}, {4100, -219.5659198853715}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4594.60486375454, -385.9410612024835}, {
       4700., -385.9410612024835}, {4700., -219.5659198853715}, {
       4594.60486375454, -219.5659198853715}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3100., -385.9410612024835}, {3200., -385.9410612024835}, {
      3200., -219.5659198853715}, {3100., -219.5659198853715}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1616.812429341444, -261.15970521464953`}, \
{1700., -219.5659198853715}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1700., -261.15970521464953`}, 83.18757065855601, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1700., -344.3472758732055}, {
       3016.812429341444, -344.3472758732055}, {
       3016.812429341444, -261.15970521464953`}, {
       1700., -261.15970521464953`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3016.812429341444, -344.3472758732055}, 83.18757065855601, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3016.812429341444, -385.9410612024835}, \
{3100., -344.3472758732055}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -457.6593595665385}, {
        104.63433407546333`, -457.6593595665385}, {
        104.63433407546333`, -385.9410612024835}, {
        100, -385.9410612024835}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -457.6593595665385}, {700, -457.6593595665385}, {
        700, -385.9410612024835}, {600, -385.9410612024835}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -457.6593595665385}, {
        1164.1408508179725`, -457.6593595665385}, {
        1164.1408508179725`, -385.9410612024835}, {
        1100, -385.9410612024835}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -457.6593595665385}, {
        1616.812429341444, -457.6593595665385}, {
        1616.812429341444, -385.9410612024835}, {
        1600, -385.9410612024835}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -457.6593595665385}, {2200, -457.6593595665385}, {
        2200, -385.9410612024835}, {2100, -385.9410612024835}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -457.6593595665385}, {
       2700., -457.6593595665385}, {2700., -385.9410612024835}, {
       2524.446764339072, -385.9410612024835}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -457.6593595665385}, {
       3200., -457.6593595665385}, {3200., -385.9410612024835}, {
       3016.812429341444, -385.9410612024835}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3600, -457.6593595665385}, {
        3714.4172940181493`, -457.6593595665385}, {
        3714.4172940181493`, -385.9410612024835}, {
        3600, -385.9410612024835}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -457.6593595665385}, {4200, -457.6593595665385}, {
        4200, -385.9410612024835}, {4100, -385.9410612024835}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4594.60486375454, -457.6593595665385}, {
      4700., -457.6593595665385}, {4700., -385.9410612024835}, {
      4594.60486375454, -385.9410612024835}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1164.1408508179725`, -403.8706357934973}, \
{1200., -385.9410612024835}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1200., -403.8706357934973}, 35.859149182027494`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1200., -439.72978497552475`}, {
       4558.745714572513, -439.72978497552475`}, {
       4558.745714572513, -403.8706357934973}, {1200., -403.8706357934973}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4558.745714572513, -439.72978497552475`}, 
       35.859149182027494`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4558.745714572513, -457.6593595665385}, \
{4594.60486375454, -439.72978497552475`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -656.97459471646}, {
        104.63433407546333`, -656.97459471646}, {
        104.63433407546333`, -457.65935956653846`}, {
        100, -457.65935956653846`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600, -656.97459471646}, {700, -656.97459471646}, {
        700, -457.65935956653846`}, {600, -457.65935956653846`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -656.97459471646}, {
        1164.1408508179725`, -656.97459471646}, {
        1164.1408508179725`, -457.65935956653846`}, {
        1100, -457.65935956653846`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -656.97459471646}, {
        1616.812429341444, -656.97459471646}, {
        1616.812429341444, -457.65935956653846`}, {
        1600, -457.65935956653846`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -656.97459471646}, {2200, -656.97459471646}, {
        2200, -457.65935956653846`}, {2100, -457.65935956653846`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -656.97459471646}, {
       2600.3423824250394`, -656.97459471646}, {
       2600.3423824250394`, -457.65935956653846`}, {
       2524.446764339072, -457.65935956653846`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -656.97459471646}, {
       3200., -656.97459471646}, {3200., -457.65935956653846`}, {
       3016.812429341444, -457.65935956653846`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -656.97459471646}, {4200, -656.97459471646}, {
        4200, -457.65935956653846`}, {4100, -457.65935956653846`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4558.745714572513, -656.97459471646}, {
       4700., -656.97459471646}, {4700., -457.65935956653846`}, {
       4558.745714572513, -457.65935956653846`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3600., -656.97459471646}, {
      3714.4172940181493`, -656.97459471646}, {
      3714.4172940181493`, -457.65935956653846`}, {
      3600., -457.65935956653846`}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2600.3423824250394`, -507.48816835401885`}, \
{2700., -457.65935956653846`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2700., -507.48816835401885`}, 99.65761757496078, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2700., -607.1457859289796}, {
       3500.3423824250394`, -607.1457859289796}, {
       3500.3423824250394`, -507.48816835401885`}, {
       2700., -507.48816835401885`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3500.3423824250394`, -607.1457859289796}, 99.65761757496078, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3500.3423824250394`, -656.97459471646}, \
{3600., -607.1457859289796}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -665.3291414936209}, {
       700., -665.3291414936209}, {700., -656.97459471646}, {
       604.1772733885804, -656.97459471646}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -665.3291414936209}, {
        1164.1408508179725`, -665.3291414936209}, {
        1164.1408508179725`, -656.97459471646}, {1100, -656.97459471646}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -665.3291414936209}, {
        1616.812429341444, -665.3291414936209}, {
        1616.812429341444, -656.97459471646}, {1600, -656.97459471646}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -665.3291414936209}, {2200, -665.3291414936209}, {
        2200, -656.97459471646}, {2100, -656.97459471646}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -665.3291414936209}, {
       2600.3423824250394`, -665.3291414936209}, {
       2600.3423824250394`, -656.97459471646}, {
       2524.446764339072, -656.97459471646}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -665.3291414936209}, {
       3200., -665.3291414936209}, {3200., -656.97459471646}, {
       3016.812429341444, -656.97459471646}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -665.3291414936209}, {
       3714.4172940181493`, -665.3291414936209}, {
       3714.4172940181493`, -656.97459471646}, {
       3500.3423824250394`, -656.97459471646}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -665.3291414936209}, {4200, -665.3291414936209}, {
        4200, -656.97459471646}, {4100, -656.97459471646}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4558.745714572513, -665.3291414936209}, {
       4700., -665.3291414936209}, {4700., -656.97459471646}, {
       4558.745714572513, -656.97459471646}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -665.3291414936209}, {
       104.63433407546333`, -665.3291414936209}, {
       104.63433407546333`, -656.97459471646}, {100, -656.97459471646}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600., -659.0632314107503}, \
{604.1772733885804, -656.97459471646}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600., -659.0632314107503}, 4.1772733885804225`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{108.81160746404375`, -663.2405047993307}, {
       600., -663.2405047993307}, {600., -659.0632314107503}, {
       108.81160746404375`, -659.0632314107503}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{108.81160746404375`, -663.2405047993307}, 4.1772733885804225`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{104.63433407546333`, -665.3291414936209}, \
{108.81160746404375`, -663.2405047993307}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -782.3428544061425}, {
        108.81160746404375`, -782.3428544061425}, {
        108.81160746404375`, -665.3291414936209}, {
        100, -665.3291414936209}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -782.3428544061425}, {
       700., -782.3428544061425}, {700., -665.3291414936209}, {
       604.1772733885804, -665.3291414936209}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -782.3428544061425}, {
        1164.1408508179725`, -782.3428544061425}, {
        1164.1408508179725`, -665.3291414936209}, {
        1100, -665.3291414936209}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -782.3428544061425}, {
        1616.812429341444, -782.3428544061425}, {
        1616.812429341444, -665.3291414936209}, {
        1600, -665.3291414936209}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -782.3428544061425}, {2200, -782.3428544061425}, {
        2200, -665.3291414936209}, {2100, -665.3291414936209}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -782.3428544061425}, {
       2600.3423824250394`, -782.3428544061425}, {
       2600.3423824250394`, -665.3291414936209}, {
       2524.446764339072, -665.3291414936209}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -782.3428544061425}, {
       3200., -782.3428544061425}, {3200., -665.3291414936209}, {
       3016.812429341444, -665.3291414936209}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -782.3428544061425}, {
       3714.4172940181493`, -782.3428544061425}, {
       3714.4172940181493`, -665.3291414936209}, {
       3500.3423824250394`, -665.3291414936209}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -782.3428544061425}, {
        4141.493143543739, -782.3428544061425}, {
        4141.493143543739, -665.3291414936209}, {
        4100, -665.3291414936209}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4558.745714572513, -782.3428544061425}, {
      4700., -782.3428544061425}, {4700., -665.3291414936209}, {
      4558.745714572513, -665.3291414936209}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4141.493143543739, -694.5825697217513}, \
{4200., -665.3291414936209}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4200., -694.5825697217513}, 58.50685645626078, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4200., -753.0894261780121}, {
       4500.238858116252, -753.0894261780121}, {
       4500.238858116252, -694.5825697217513}, {4200., -694.5825697217513}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4500.238858116252, -753.0894261780121}, 58.50685645626078, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4500.238858116252, -782.3428544061425}, \
{4558.745714572513, -753.0894261780121}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -833.9794228938996}, {
        108.81160746404375`, -833.9794228938996}, {
        108.81160746404375`, -782.3428544061425}, {
        100, -782.3428544061425}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -833.9794228938996}, {
        1164.1408508179725`, -833.9794228938996}, {
        1164.1408508179725`, -782.3428544061425}, {
        1100, -782.3428544061425}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -833.9794228938996}, {
        1616.812429341444, -833.9794228938996}, {
        1616.812429341444, -782.3428544061425}, {
        1600, -782.3428544061425}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -833.9794228938996}, {2200, -833.9794228938996}, {
        2200, -782.3428544061425}, {2100, -782.3428544061425}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2524.446764339072, -833.9794228938996}, {
       2600.3423824250394`, -833.9794228938996}, {
       2600.3423824250394`, -782.3428544061425}, {
       2524.446764339072, -782.3428544061425}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -833.9794228938996}, {
       3200., -833.9794228938996}, {3200., -782.3428544061425}, {
       3016.812429341444, -782.3428544061425}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -833.9794228938996}, {
       3714.4172940181493`, -833.9794228938996}, {
       3714.4172940181493`, -782.3428544061425}, {
       3500.3423824250394`, -782.3428544061425}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -833.9794228938996}, {
        4141.493143543739, -833.9794228938996}, {
        4141.493143543739, -782.3428544061425}, {
        4100, -782.3428544061425}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -833.9794228938996}, {
       4700., -833.9794228938996}, {4700., -782.3428544061425}, {
       4526.0571423601305`, -782.3428544061425}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -833.9794228938996}, {
      700., -833.9794228938996}, {700., -782.3428544061425}, {
      604.1772733885804, -782.3428544061425}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4500.238858116252, -795.2519965280818}, \
{4526.0571423601305`, -782.3428544061425}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4500.238858116252, -795.2519965280818}, 25.81828424387855, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{725.8182842438785, -821.0702807719604}, {
       4500.238858116252, -821.0702807719604}, {
       4500.238858116252, -795.2519965280818}, {
       725.8182842438785, -795.2519965280818}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{725.8182842438785, -821.0702807719604}, 25.81828424387855, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{700., -833.9794228938996}, \
{725.8182842438785, -821.0702807719604}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -862.213871321922}, {
        108.81160746404375`, -862.213871321922}, {
        108.81160746404375`, -833.9794228938996}, {
        100, -833.9794228938996}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -862.213871321922}, {
       725.8182842438785, -862.213871321922}, {
       725.8182842438785, -833.9794228938996}, {
       604.1772733885804, -833.9794228938996}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -862.213871321922}, {
        1164.1408508179725`, -862.213871321922}, {
        1164.1408508179725`, -833.9794228938996}, {
        1100, -833.9794228938996}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -862.213871321922}, {
        1602.6952051274327`, -862.213871321922}, {
        1602.6952051274327`, -833.9794228938996}, {
        1600, -833.9794228938996}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -862.213871321922}, {2200, -862.213871321922}, {
        2200, -833.9794228938996}, {2100, -833.9794228938996}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -862.213871321922}, {
       3200., -862.213871321922}, {3200., -833.9794228938996}, {
       3016.812429341444, -833.9794228938996}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -862.213871321922}, {
       3714.4172940181493`, -862.213871321922}, {
       3714.4172940181493`, -833.9794228938996}, {
       3500.3423824250394`, -833.9794228938996}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -862.213871321922}, {
        4141.493143543739, -862.213871321922}, {
        4141.493143543739, -833.9794228938996}, {
        4100, -833.9794228938996}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -862.213871321922}, {
       4700., -862.213871321922}, {4700., -833.9794228938996}, {
       4526.0571423601305`, -833.9794228938996}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2524.446764339072, -862.213871321922}, {
      2600.3423824250394`, -862.213871321922}, {
      2600.3423824250394`, -833.9794228938996}, {
      2524.446764339072, -833.9794228938996}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1602.6952051274327`, -841.0380350009052}, \
{1616.812429341444, -833.9794228938996}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1616.812429341444, -841.0380350009052}, 14.117224214011241`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1616.812429341444, -855.1552592149164}, {
       2510.3295401250607`, -855.1552592149164}, {
       2510.3295401250607`, -841.0380350009052}, {
       1616.812429341444, -841.0380350009052}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2510.3295401250607`, -855.1552592149164}, 
       14.117224214011241`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2510.3295401250607`, -862.213871321922}, \
{2524.446764339072, -855.1552592149164}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -864.5854564509692}, {
        108.81160746404375`, -864.5854564509692}, {
        108.81160746404375`, -862.213871321922}, {
        100, -862.213871321922}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -864.5854564509692}, {
       725.8182842438785, -864.5854564509692}, {
       725.8182842438785, -862.213871321922}, {
       604.1772733885804, -862.213871321922}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -864.5854564509692}, {
        1164.1408508179725`, -864.5854564509692}, {
        1164.1408508179725`, -862.213871321922}, {
        1100, -862.213871321922}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -864.5854564509692}, {
        1601.5094125629091`, -864.5854564509692}, {
        1601.5094125629091`, -862.213871321922}, {
        1600, -862.213871321922}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -864.5854564509692}, {2200, -864.5854564509692}, {
        2200, -862.213871321922}, {2100, -862.213871321922}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -864.5854564509692}, {
       3200., -864.5854564509692}, {3200., -862.213871321922}, {
       3016.812429341444, -862.213871321922}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -864.5854564509692}, {
       3714.4172940181493`, -864.5854564509692}, {
       3714.4172940181493`, -862.213871321922}, {
       3500.3423824250394`, -862.213871321922}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4100, -864.5854564509692}, {
        4141.493143543739, -864.5854564509692}, {
        4141.493143543739, -862.213871321922}, {4100, -862.213871321922}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -864.5854564509692}, {
       4700., -864.5854564509692}, {4700., -862.213871321922}, {
       4526.0571423601305`, -862.213871321922}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2510.3295401250607`, -864.5854564509692}, {
      2600.3423824250394`, -864.5854564509692}, {
      2600.3423824250394`, -862.213871321922}, {
      2510.3295401250607`, -862.213871321922}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.5094125629091`, -862.8067676041838}, \
{1602.6952051274327`, -862.213871321922}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1602.6952051274327`, -862.8067676041838}, 1.1857925645235872`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1602.6952051274327`, -863.9925601687074}, {
       2509.143747560537, -863.9925601687074}, {
       2509.143747560537, -862.8067676041838}, {
       1602.6952051274327`, -862.8067676041838}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2509.143747560537, -863.9925601687074}, 1.1857925645235872`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2509.143747560537, -864.5854564509692}, \
{2510.3295401250607`, -863.9925601687074}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -896.6309578616131}, {
        108.81160746404375`, -896.6309578616131}, {
        108.81160746404375`, -864.5854564509692}, {
        100, -864.5854564509692}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -896.6309578616131}, {
       725.8182842438785, -896.6309578616131}, {
       725.8182842438785, -864.5854564509692}, {
       604.1772733885804, -864.5854564509692}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -896.6309578616131}, {
        1164.1408508179725`, -896.6309578616131}, {
        1164.1408508179725`, -864.5854564509692}, {
        1100, -864.5854564509692}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -896.6309578616131}, {
        1601.5094125629091`, -896.6309578616131}, {
        1601.5094125629091`, -864.5854564509692}, {
        1600, -864.5854564509692}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -896.6309578616131}, {2200, -896.6309578616131}, {
        2200, -864.5854564509692}, {2100, -864.5854564509692}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3016.812429341444, -896.6309578616131}, {
       3200., -896.6309578616131}, {3200., -864.5854564509692}, {
       3016.812429341444, -864.5854564509692}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -896.6309578616131}, {
       3714.4172940181493`, -896.6309578616131}, {
       3714.4172940181493`, -864.5854564509692}, {
       3500.3423824250394`, -864.5854564509692}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -896.6309578616131}, {
       4141.493143543739, -896.6309578616131}, {
       4141.493143543739, -864.5854564509692}, {
       4116.022750705322, -864.5854564509692}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -896.6309578616131}, {
       4700., -896.6309578616131}, {4700., -864.5854564509692}, {
       4526.0571423601305`, -864.5854564509692}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2509.143747560537, -896.6309578616131}, {
      2600.3423824250394`, -896.6309578616131}, {
      2600.3423824250394`, -864.5854564509692}, {
      2509.143747560537, -864.5854564509692}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4100., -872.5968318036302}, \
{4116.022750705322, -864.5854564509692}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4100., -872.5968318036302}, 16.022750705321926`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2616.3651331303613`, -888.6195825089521}, {
       4100., -888.6195825089521}, {4100., -872.5968318036302}, {
       2616.3651331303613`, -872.5968318036302}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2616.3651331303613`, -888.6195825089521}, 16.022750705321926`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2600.3423824250394`, -896.6309578616131}, \
{2616.3651331303613`, -888.6195825089521}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -897.8500700563396}, {
        108.81160746404375`, -897.8500700563396}, {
        108.81160746404375`, -896.6309578616131}, {
        100, -896.6309578616131}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -897.8500700563396}, {
       725.8182842438785, -897.8500700563396}, {
       725.8182842438785, -896.6309578616131}, {
       604.1772733885804, -896.6309578616131}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -897.8500700563396}, {
        1164.1408508179725`, -897.8500700563396}, {
        1164.1408508179725`, -896.6309578616131}, {
        1100, -896.6309578616131}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -897.8500700563396}, {
        1600.8998564655458`, -897.8500700563396}, {
        1600.8998564655458`, -896.6309578616131}, {
        1600, -896.6309578616131}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -897.8500700563396}, {2200, -897.8500700563396}, {
        2200, -896.6309578616131}, {2100, -896.6309578616131}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2509.143747560537, -897.8500700563396}, {
       2616.3651331303613`, -897.8500700563396}, {
       2616.3651331303613`, -896.6309578616131}, {
       2509.143747560537, -896.6309578616131}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -897.8500700563396}, {
       3714.4172940181493`, -897.8500700563396}, {
       3714.4172940181493`, -896.6309578616131}, {
       3500.3423824250394`, -896.6309578616131}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -897.8500700563396}, {
       4141.493143543739, -897.8500700563396}, {
       4141.493143543739, -896.6309578616131}, {
       4116.022750705322, -896.6309578616131}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -897.8500700563396}, {
       4700., -897.8500700563396}, {4700., -896.6309578616131}, {
       4526.0571423601305`, -896.6309578616131}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3016.812429341444, -897.8500700563396}, {
      3200., -897.8500700563396}, {3200., -896.6309578616131}, {
      3016.812429341444, -896.6309578616131}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.8998564655458`, -896.9357359102947}, \
{1601.5094125629091`, -896.6309578616131}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.5094125629091`, -896.9357359102947}, 0.6095560973632974, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.5094125629091`, -897.545292007658}, {
       3016.202873244081, -897.545292007658}, {
       3016.202873244081, -896.9357359102947}, {
       1601.5094125629091`, -896.9357359102947}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3016.202873244081, -897.545292007658}, 0.6095560973632974, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3016.202873244081, -897.8500700563396}, \
{3016.812429341444, -897.545292007658}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -918.8908730209967}, {
        108.81160746404375`, -918.8908730209967}, {
        108.81160746404375`, -897.8500700563396}, {
        100, -897.8500700563396}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -918.8908730209967}, {
       725.8182842438785, -918.8908730209967}, {
       725.8182842438785, -897.8500700563396}, {
       604.1772733885804, -897.8500700563396}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -918.8908730209967}, {
        1600.8998564655458`, -918.8908730209967}, {
        1600.8998564655458`, -897.8500700563396}, {
        1600, -897.8500700563396}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -918.8908730209967}, {2200, -918.8908730209967}, {
        2200, -897.8500700563396}, {2100, -897.8500700563396}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2509.143747560537, -918.8908730209967}, {
       2616.3651331303613`, -918.8908730209967}, {
       2616.3651331303613`, -897.8500700563396}, {
       2509.143747560537, -897.8500700563396}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -918.8908730209967}, {
       3200., -918.8908730209967}, {3200., -897.8500700563396}, {
       3026.7232747264093`, -897.8500700563396}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3500.3423824250394`, -918.8908730209967}, {
       3714.4172940181493`, -918.8908730209967}, {
       3714.4172940181493`, -897.8500700563396}, {
       3500.3423824250394`, -897.8500700563396}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -918.8908730209967}, {
       4141.493143543739, -918.8908730209967}, {
       4141.493143543739, -897.8500700563396}, {
       4116.022750705322, -897.8500700563396}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -918.8908730209967}, {
       4700., -918.8908730209967}, {4700., -897.8500700563396}, {
       4526.0571423601305`, -897.8500700563396}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1100, -918.8908730209967}, {
       1164.1408508179725`, -918.8908730209967}, {
       1164.1408508179725`, -897.8500700563396}, {
       1100, -897.8500700563396}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3016.202873244081, -903.1102707975039}, \
{3026.7232747264093`, -897.8500700563396}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3016.202873244081, -903.1102707975039}, 10.52040148232851, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1174.661252300301, -913.6306722798324}, {
       3016.202873244081, -913.6306722798324}, {
       3016.202873244081, -903.1102707975039}, {
       1174.661252300301, -903.1102707975039}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1174.661252300301, -913.6306722798324}, 10.52040148232851, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1164.1408508179725`, -918.8908730209967}, \
{1174.661252300301, -913.6306722798324}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -936.7530213972792}, {
        108.81160746404375`, -936.7530213972792}, {
        108.81160746404375`, -918.8908730209967}, {
        100, -918.8908730209967}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -936.7530213972792}, {
       725.8182842438785, -936.7530213972792}, {
       725.8182842438785, -918.8908730209967}, {
       604.1772733885804, -918.8908730209967}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -936.7530213972792}, {
        1174.661252300301, -936.7530213972792}, {
        1174.661252300301, -918.8908730209967}, {
        1100, -918.8908730209967}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -936.7530213972792}, {
        1600.8998564655458`, -936.7530213972792}, {
        1600.8998564655458`, -918.8908730209967}, {
        1600, -918.8908730209967}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -936.7530213972792}, {2200, -936.7530213972792}, {
        2200, -918.8908730209967}, {2100, -918.8908730209967}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2509.143747560537, -936.7530213972792}, {
       2607.43405894222, -936.7530213972792}, {
       2607.43405894222, -918.8908730209967}, {
       2509.143747560537, -918.8908730209967}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -936.7530213972792}, {
       3200., -936.7530213972792}, {3200., -918.8908730209967}, {
       3026.7232747264093`, -918.8908730209967}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -936.7530213972792}, {
       4141.493143543739, -936.7530213972792}, {
       4141.493143543739, -918.8908730209967}, {
       4116.022750705322, -918.8908730209967}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -936.7530213972792}, {
       4700., -936.7530213972792}, {4700., -918.8908730209967}, {
       4526.0571423601305`, -918.8908730209967}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3500.3423824250394`, -936.7530213972792}, {
      3714.4172940181493`, -936.7530213972792}, {
      3714.4172940181493`, -918.8908730209967}, {
      3500.3423824250394`, -918.8908730209967}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2607.43405894222, -923.3564101150673}, \
{2616.3651331303613`, -918.8908730209967}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2616.3651331303613`, -923.3564101150673}, 8.931074188141281, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2616.3651331303613`, -932.2874843032085}, {
       3491.411308236898, -932.2874843032085}, {
       3491.411308236898, -923.3564101150673}, {
       2616.3651331303613`, -923.3564101150673}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3491.411308236898, -932.2874843032085}, 8.931074188141281, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3491.411308236898, -936.7530213972792}, \
{3500.3423824250394`, -932.2874843032085}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1072.4678963563667`}, {
        108.81160746404375`, -1072.4678963563667`}, {
        108.81160746404375`, -936.7530213972793}, {
        100, -936.7530213972793}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1072.4678963563667`}, {
       725.8182842438785, -1072.4678963563667`}, {
       725.8182842438785, -936.7530213972793}, {
       604.1772733885804, -936.7530213972793}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1072.4678963563667`}, {
        1600.8998564655458`, -1072.4678963563667`}, {
        1600.8998564655458`, -936.7530213972793}, {
        1600, -936.7530213972793}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1072.4678963563667`}, {
        2200, -1072.4678963563667`}, {2200, -936.7530213972793}, {
        2100, -936.7530213972793}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2509.143747560537, -1072.4678963563667`}, {
       2607.43405894222, -1072.4678963563667`}, {
       2607.43405894222, -936.7530213972793}, {
       2509.143747560537, -936.7530213972793}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1072.4678963563667`}, {
       3200., -1072.4678963563667`}, {3200., -936.7530213972793}, {
       3026.7232747264093`, -936.7530213972793}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3559.268745716442, -1072.4678963563667`}, {
       3714.4172940181493`, -1072.4678963563667`}, {
       3714.4172940181493`, -936.7530213972793}, {
       3559.268745716442, -936.7530213972793}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -1072.4678963563667`}, {
       4141.493143543739, -1072.4678963563667`}, {
       4141.493143543739, -936.7530213972793}, {
       4116.022750705322, -936.7530213972793}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -1072.4678963563667`}, {
       4700., -1072.4678963563667`}, {4700., -936.7530213972793}, {
       4526.0571423601305`, -936.7530213972793}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1100, -1072.4678963563667`}, {
       1174.661252300301, -1072.4678963563667`}, {
       1174.661252300301, -936.7530213972793}, {
       1100, -936.7530213972793}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3491.411308236898, -970.6817401370512}, \
{3559.268745716442, -936.7530213972793}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3491.411308236898, -970.6817401370512}, 67.85743747954373, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1242.5186897798449`, -1038.5391776165948`}, {
       3491.411308236898, -1038.5391776165948`}, {
       3491.411308236898, -970.6817401370512}, {
       1242.5186897798449`, -970.6817401370512}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1242.5186897798449`, -1038.5391776165948`}, 67.85743747954373, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1174.661252300301, -1072.4678963563667`}, \
{1242.5186897798449`, -1038.5391776165948`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1210.5223097773016`}, {
        108.81160746404375`, -1210.5223097773016`}, {
        108.81160746404375`, -1072.4678963563667`}, {
        100, -1072.4678963563667`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1210.5223097773016`}, {
        1242.5186897798449`, -1210.5223097773016`}, {
        1242.5186897798449`, -1072.4678963563667`}, {
        1100, -1072.4678963563667`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1210.5223097773016`}, {
        1600.8998564655458`, -1210.5223097773016`}, {
        1600.8998564655458`, -1072.4678963563667`}, {
        1600, -1072.4678963563667`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1210.5223097773016`}, {
        2200, -1210.5223097773016`}, {2200, -1072.4678963563667`}, {
        2100, -1072.4678963563667`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1210.5223097773016`}, {
       2607.43405894222, -1210.5223097773016`}, {
       2607.43405894222, -1072.4678963563667`}, {
       2578.1709542710046`, -1072.4678963563667`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1210.5223097773016`}, {
       3200., -1210.5223097773016`}, {3200., -1072.4678963563667`}, {
       3026.7232747264093`, -1072.4678963563667`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3559.268745716442, -1210.5223097773016`}, {
       3714.4172940181493`, -1210.5223097773016`}, {
       3714.4172940181493`, -1072.4678963563667`}, {
       3559.268745716442, -1072.4678963563667`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -1210.5223097773016`}, {
       4141.493143543739, -1210.5223097773016`}, {
       4141.493143543739, -1072.4678963563667`}, {
       4116.022750705322, -1072.4678963563667`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -1210.5223097773016`}, {
       4700., -1210.5223097773016`}, {4700., -1072.4678963563667`}, {
       4526.0571423601305`, -1072.4678963563667`}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -1210.5223097773016`}, {
      725.8182842438785, -1210.5223097773016`}, {
      725.8182842438785, -1072.4678963563667`}, {
      604.1772733885804, -1072.4678963563667`}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2509.143747560537, -1106.9814997116005`}, \
{2578.1709542710046`, -1072.4678963563667`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2509.143747560537, -1106.9814997116005`}, 69.02720671046745, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{794.8454909543459, -1176.008706422068}, {
       2509.143747560537, -1176.008706422068}, {
       2509.143747560537, -1106.9814997116005`}, {
       794.8454909543459, -1106.9814997116005`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{794.8454909543459, -1176.008706422068}, 69.02720671046745, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{725.8182842438785, -1210.5223097773016`}, \
{794.8454909543459, -1176.008706422068}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1324.196879902766}, {
        108.81160746404375`, -1324.196879902766}, {
        108.81160746404375`, -1210.5223097773016`}, {
        100, -1210.5223097773016`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1324.196879902766}, {
       794.8454909543459, -1324.196879902766}, {
       794.8454909543459, -1210.5223097773016`}, {
       604.1772733885804, -1210.5223097773016`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1324.196879902766}, {
        1242.5186897798449`, -1324.196879902766}, {
        1242.5186897798449`, -1210.5223097773016`}, {
        1100, -1210.5223097773016`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1324.196879902766}, {
        1600.8998564655458`, -1324.196879902766}, {
        1600.8998564655458`, -1210.5223097773016`}, {
        1600, -1210.5223097773016`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1324.196879902766}, {2200, -1324.196879902766}, {
        2200, -1210.5223097773016`}, {2100, -1210.5223097773016`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1324.196879902766}, {
       2607.43405894222, -1324.196879902766}, {
       2607.43405894222, -1210.5223097773016`}, {
       2578.1709542710046`, -1210.5223097773016`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1324.196879902766}, {
       3143.162714937268, -1324.196879902766}, {
       3143.162714937268, -1210.5223097773016`}, {
       3026.7232747264093`, -1210.5223097773016`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -1324.196879902766}, {
       4141.493143543739, -1324.196879902766}, {
       4141.493143543739, -1210.5223097773016`}, {
       4116.022750705322, -1210.5223097773016`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4526.0571423601305`, -1324.196879902766}, {
       4700., -1324.196879902766}, {4700., -1210.5223097773016`}, {
       4526.0571423601305`, -1210.5223097773016`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3559.268745716442, -1324.196879902766}, {
      3714.4172940181493`, -1324.196879902766}, {
      3714.4172940181493`, -1210.5223097773016`}, {
      3559.268745716442, -1210.5223097773016`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3143.162714937268, -1238.9409523086676`}, \
{3200., -1210.5223097773016`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3200., -1238.9409523086676`}, 56.83728506273226, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3200., -1295.7782373713999`}, {
       3502.4314606537096`, -1295.7782373713999`}, {
       3502.4314606537096`, -1238.9409523086676`}, {
       3200., -1238.9409523086676`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3502.4314606537096`, -1295.7782373713999`}, 
       56.83728506273226, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3502.4314606537096`, -1324.196879902766}, \
{3559.268745716442, -1295.7782373713999`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1408.6234081907876`}, {
        108.81160746404375`, -1408.6234081907876`}, {
        108.81160746404375`, -1324.196879902766}, {
        100, -1324.196879902766}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1408.6234081907876`}, {
       794.8454909543459, -1408.6234081907876`}, {
       794.8454909543459, -1324.196879902766}, {
       604.1772733885804, -1324.196879902766}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1408.6234081907876`}, {
        1242.5186897798449`, -1408.6234081907876`}, {
        1242.5186897798449`, -1324.196879902766}, {
        1100, -1324.196879902766}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1408.6234081907876`}, {
        1600.8998564655458`, -1408.6234081907876`}, {
        1600.8998564655458`, -1324.196879902766}, {
        1600, -1324.196879902766}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1408.6234081907876`}, {
       2607.43405894222, -1408.6234081907876`}, {
       2607.43405894222, -1324.196879902766}, {
       2578.1709542710046`, -1324.196879902766}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1408.6234081907876`}, {
       3143.162714937268, -1408.6234081907876`}, {
       3143.162714937268, -1324.196879902766}, {
       3026.7232747264093`, -1324.196879902766}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3502.4314606537096`, -1408.6234081907876`}, {
       3714.4172940181493`, -1408.6234081907876`}, {
       3714.4172940181493`, -1324.196879902766}, {
       3502.4314606537096`, -1324.196879902766}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.022750705322, -1408.6234081907876`}, {
       4141.493143543739, -1408.6234081907876`}, {
       4141.493143543739, -1324.196879902766}, {
       4116.022750705322, -1324.196879902766}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4568.270406504142, -1408.6234081907876`}, {
       4700., -1408.6234081907876`}, {4700., -1324.196879902766}, {
       4568.270406504142, -1324.196879902766}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2100, -1408.6234081907876`}, {
       2200., -1408.6234081907876`}, {2200., -1324.196879902766}, {
       2100, -1324.196879902766}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4526.0571423601305`, -1345.3035119747715`}, \
{4568.270406504142, -1324.196879902766}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4526.0571423601305`, -1345.3035119747715`}, 
       42.213264144010765`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2242.2132641440107`, -1387.5167761187822`}, {
       4526.0571423601305`, -1387.5167761187822`}, {
       4526.0571423601305`, -1345.3035119747715`}, {
       2242.2132641440107`, -1345.3035119747715`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2242.2132641440107`, -1387.5167761187822`}, 
       42.213264144010765`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2200., -1408.6234081907876`}, \
{2242.2132641440107`, -1387.5167761187822`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1422.9973357373021`}, {
       794.8454909543459, -1422.9973357373021`}, {
       794.8454909543459, -1408.6234081907876`}, {
       604.1772733885804, -1408.6234081907876`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1422.9973357373021`}, {
        1242.5186897798449`, -1422.9973357373021`}, {
        1242.5186897798449`, -1408.6234081907876`}, {
        1100, -1408.6234081907876`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1422.9973357373021`}, {
        1600.8998564655458`, -1422.9973357373021`}, {
        1600.8998564655458`, -1408.6234081907876`}, {
        1600, -1408.6234081907876`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1422.9973357373021`}, {
        2242.2132641440107`, -1422.9973357373021`}, {
        2242.2132641440107`, -1408.6234081907876`}, {
        2100, -1408.6234081907876`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1422.9973357373021`}, {
       2607.43405894222, -1422.9973357373021`}, {
       2607.43405894222, -1408.6234081907876`}, {
       2578.1709542710046`, -1408.6234081907876`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1422.9973357373021`}, {
       3143.162714937268, -1422.9973357373021`}, {
       3143.162714937268, -1408.6234081907876`}, {
       3026.7232747264093`, -1408.6234081907876`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3502.4314606537096`, -1422.9973357373021`}, {
       3714.4172940181493`, -1422.9973357373021`}, {
       3714.4172940181493`, -1408.6234081907876`}, {
       3502.4314606537096`, -1408.6234081907876`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.209714478579, -1422.9973357373021`}, {
       4141.493143543739, -1422.9973357373021`}, {
       4141.493143543739, -1408.6234081907876`}, {
       4123.209714478579, -1408.6234081907876`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4568.270406504142, -1422.9973357373021`}, {
       4700., -1422.9973357373021`}, {4700., -1408.6234081907876`}, {
       4568.270406504142, -1408.6234081907876`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -1422.9973357373021`}, {
       108.81160746404375`, -1422.9973357373021`}, {
       108.81160746404375`, -1408.6234081907876`}, {
       100, -1408.6234081907876`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4116.022750705322, -1412.2168900774163`}, \
{4123.209714478579, -1408.6234081907876`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4116.022750705322, -1412.2168900774163`}, 7.186963773257222, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{115.99857123730098`, -1419.4038538506736`}, {
       4116.022750705322, -1419.4038538506736`}, {
       4116.022750705322, -1412.2168900774163`}, {
       115.99857123730098`, -1412.2168900774163`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{115.99857123730098`, -1419.4038538506736`}, 7.186963773257222, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{108.81160746404375`, -1422.9973357373021`}, \
{115.99857123730098`, -1419.4038538506736`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1657.3421843593285`}, {
        115.99857123730098`, -1657.3421843593285`}, {
        115.99857123730098`, -1422.9973357373021`}, {
        100, -1422.9973357373021`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1657.3421843593285`}, {
       794.8454909543459, -1657.3421843593285`}, {
       794.8454909543459, -1422.9973357373021`}, {
       604.1772733885804, -1422.9973357373021`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1657.3421843593285`}, {
        1242.5186897798449`, -1657.3421843593285`}, {
        1242.5186897798449`, -1422.9973357373021`}, {
        1100, -1422.9973357373021`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1657.3421843593285`}, {
        1600.8998564655458`, -1657.3421843593285`}, {
        1600.8998564655458`, -1422.9973357373021`}, {
        1600, -1422.9973357373021`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1657.3421843593285`}, {
        2125.040839832998, -1657.3421843593285`}, {
        2125.040839832998, -1422.9973357373021`}, {
        2100, -1422.9973357373021`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1657.3421843593285`}, {
       2607.43405894222, -1657.3421843593285`}, {
       2607.43405894222, -1422.9973357373021`}, {
       2578.1709542710046`, -1422.9973357373021`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1657.3421843593285`}, {
       3143.162714937268, -1657.3421843593285`}, {
       3143.162714937268, -1422.9973357373021`}, {
       3026.7232747264093`, -1422.9973357373021`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.209714478579, -1657.3421843593285`}, {
       4141.493143543739, -1657.3421843593285`}, {
       4141.493143543739, -1422.9973357373021`}, {
       4123.209714478579, -1422.9973357373021`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4568.270406504142, -1657.3421843593285`}, {
       4700., -1657.3421843593285`}, {4700., -1422.9973357373021`}, {
       4568.270406504142, -1422.9973357373021`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3502.4314606537096`, -1657.3421843593285`}, {
      3714.4172940181493`, -1657.3421843593285`}, {
      3714.4172940181493`, -1422.9973357373021`}, {
      3502.4314606537096`, -1422.9973357373021`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2125.040839832998, -1481.5835478928088`}, \
{2242.2132641440107`, -1422.9973357373021`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2242.2132641440107`, -1481.5835478928088`}, 
       117.17242431101315`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2242.2132641440107`, -1598.755972203822}, {
       3385.2590363426966`, -1598.755972203822}, {
       3385.2590363426966`, -1481.5835478928088`}, {
       2242.2132641440107`, -1481.5835478928088`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3385.2590363426966`, -1598.755972203822}, 
       117.17242431101315`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3385.2590363426966`, -1657.3421843593285`}, \
{3502.4314606537096`, -1598.755972203822}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1674.564227614779}, {
        115.99857123730098`, -1674.564227614779}, {
        115.99857123730098`, -1657.3421843593285`}, {
        100, -1657.3421843593285`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1674.564227614779}, {
       794.8454909543459, -1674.564227614779}, {
       794.8454909543459, -1657.3421843593285`}, {
       604.1772733885804, -1657.3421843593285`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1674.564227614779}, {
        1242.5186897798449`, -1674.564227614779}, {
        1242.5186897798449`, -1657.3421843593285`}, {
        1100, -1657.3421843593285`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1674.564227614779}, {
        1600.8998564655458`, -1674.564227614779}, {
        1600.8998564655458`, -1657.3421843593285`}, {
        1600, -1657.3421843593285`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1674.564227614779}, {
        2125.040839832998, -1674.564227614779}, {
        2125.040839832998, -1657.3421843593285`}, {
        2100, -1657.3421843593285`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1674.564227614779}, {
       3143.162714937268, -1674.564227614779}, {
       3143.162714937268, -1657.3421843593285`}, {
       3026.7232747264093`, -1657.3421843593285`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3385.2590363426966`, -1674.564227614779}, {
       3714.4172940181493`, -1674.564227614779}, {
       3714.4172940181493`, -1657.3421843593285`}, {
       3385.2590363426966`, -1657.3421843593285`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.820736106304, -1674.564227614779}, {
       4141.493143543739, -1674.564227614779}, {
       4141.493143543739, -1657.3421843593285`}, {
       4131.820736106304, -1657.3421843593285`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4568.270406504142, -1674.564227614779}, {
       4700., -1674.564227614779}, {4700., -1657.3421843593285`}, {
       4568.270406504142, -1657.3421843593285`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2578.1709542710046`, -1674.564227614779}, {
      2607.43405894222, -1674.564227614779}, {
      2607.43405894222, -1657.3421843593285`}, {
      2578.1709542710046`, -1657.3421843593285`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4123.209714478579, -1661.647695173191}, \
{4131.820736106304, -1657.3421843593285`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4123.209714478579, -1661.647695173191}, 8.611021627725215, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2616.045080569945, -1670.2587168009163`}, {
       4123.209714478579, -1670.2587168009163`}, {
       4123.209714478579, -1661.647695173191}, {
       2616.045080569945, -1661.647695173191}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2616.045080569945, -1670.2587168009163`}, 8.611021627725215, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2607.43405894222, -1674.564227614779}, \
{2616.045080569945, -1670.2587168009163`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1690.2945677115474`}, {
        108.13340118891672`, -1690.2945677115474`}, {
        108.13340118891672`, -1674.564227614779}, {
        100, -1674.564227614779}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1690.2945677115474`}, {
       794.8454909543459, -1690.2945677115474`}, {
       794.8454909543459, -1674.564227614779}, {
       604.1772733885804, -1674.564227614779}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1690.2945677115474`}, {
        1242.5186897798449`, -1690.2945677115474`}, {
        1242.5186897798449`, -1674.564227614779}, {
        1100, -1674.564227614779}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1690.2945677115474`}, {
        1600.8998564655458`, -1690.2945677115474`}, {
        1600.8998564655458`, -1674.564227614779}, {
        1600, -1674.564227614779}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1690.2945677115474`}, {
        2125.040839832998, -1690.2945677115474`}, {
        2125.040839832998, -1674.564227614779}, {
        2100, -1674.564227614779}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1690.2945677115474`}, {
       2616.045080569945, -1690.2945677115474`}, {
       2616.045080569945, -1674.564227614779}, {
       2578.1709542710046`, -1674.564227614779}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1690.2945677115474`}, {
       3143.162714937268, -1690.2945677115474`}, {
       3143.162714937268, -1674.564227614779}, {
       3026.7232747264093`, -1674.564227614779}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3385.2590363426966`, -1690.2945677115474`}, {
       3714.4172940181493`, -1690.2945677115474`}, {
       3714.4172940181493`, -1674.564227614779}, {
       3385.2590363426966`, -1674.564227614779}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4568.270406504142, -1690.2945677115474`}, {
       4700., -1690.2945677115474`}, {4700., -1674.564227614779}, {
       4568.270406504142, -1674.564227614779}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4131.820736106304, -1690.2945677115474`}, {
      4141.493143543739, -1690.2945677115474`}, {
      4141.493143543739, -1674.564227614779}, {
      4131.820736106304, -1674.564227614779}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{108.13340118891672`, -1678.496812638971}, \
{115.99857123730098`, -1674.564227614779}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{115.99857123730098`, -1678.496812638971}, 7.8651700483842575`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{115.99857123730098`, -1686.3619826873553`}, {
       4123.95556605792, -1686.3619826873553`}, {
       4123.95556605792, -1678.496812638971}, {
       115.99857123730098`, -1678.496812638971}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4123.95556605792, -1686.3619826873553`}, 7.8651700483842575`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4123.95556605792, -1690.2945677115474`}, \
{4131.820736106304, -1686.3619826873553`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1705.9289173632437`}, {
       794.8454909543459, -1705.9289173632437`}, {
       794.8454909543459, -1690.2945677115474`}, {
       604.1772733885804, -1690.2945677115474`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1705.9289173632437`}, {
        1242.5186897798449`, -1705.9289173632437`}, {
        1242.5186897798449`, -1690.2945677115474`}, {
        1100, -1690.2945677115474`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1705.9289173632437`}, {
        1600.8998564655458`, -1705.9289173632437`}, {
        1600.8998564655458`, -1690.2945677115474`}, {
        1600, -1690.2945677115474`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1705.9289173632437`}, {
        2125.040839832998, -1705.9289173632437`}, {
        2125.040839832998, -1690.2945677115474`}, {
        2100, -1690.2945677115474`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2578.1709542710046`, -1705.9289173632437`}, {
       2616.045080569945, -1705.9289173632437`}, {
       2616.045080569945, -1690.2945677115474`}, {
       2578.1709542710046`, -1690.2945677115474`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1705.9289173632437`}, {
       3143.162714937268, -1705.9289173632437`}, {
       3143.162714937268, -1690.2945677115474`}, {
       3026.7232747264093`, -1690.2945677115474`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3385.2590363426966`, -1705.9289173632437`}, {
       3714.4172940181493`, -1705.9289173632437`}, {
       3714.4172940181493`, -1690.2945677115474`}, {
       3385.2590363426966`, -1690.2945677115474`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1705.9289173632437`}, {
       4141.493143543739, -1705.9289173632437`}, {
       4141.493143543739, -1690.2945677115474`}, {
       4123.95556605792, -1690.2945677115474`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1705.9289173632437`}, {
       4700., -1705.9289173632437`}, {4700., -1690.2945677115474`}, {
       4576.08758132999, -1690.2945677115474`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -1705.9289173632437`}, {
       108.13340118891672`, -1705.9289173632437`}, {
       108.13340118891672`, -1690.2945677115474`}, {
       100, -1690.2945677115474`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4568.270406504142, -1694.2031551244716`}, \
{4576.08758132999, -1690.2945677115474`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4568.270406504142, -1694.2031551244716`}, 7.817174825848113, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{115.95057601476483`, -1702.0203299503196`}, {
       4568.270406504142, -1702.0203299503196`}, {
       4568.270406504142, -1694.2031551244716`}, {
       115.95057601476483`, -1694.2031551244716`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{115.95057601476483`, -1702.0203299503196`}, 7.817174825848113, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{108.13340118891672`, -1705.9289173632437`}, \
{115.95057601476483`, -1702.0203299503196`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1716.5680651662021`}, {
        115.95057601476483`, -1716.5680651662021`}, {
        115.95057601476483`, -1705.9289173632437`}, {
        100, -1705.9289173632437`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1716.5680651662021`}, {
       794.8454909543459, -1716.5680651662021`}, {
       794.8454909543459, -1705.9289173632437`}, {
       604.1772733885804, -1705.9289173632437`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1716.5680651662021`}, {
        1242.5186897798449`, -1716.5680651662021`}, {
        1242.5186897798449`, -1705.9289173632437`}, {
        1100, -1705.9289173632437`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1716.5680651662021`}, {
        1600.8998564655458`, -1716.5680651662021`}, {
        1600.8998564655458`, -1705.9289173632437`}, {
        1600, -1705.9289173632437`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1716.5680651662021`}, {
        2119.7212659315182`, -1716.5680651662021`}, {
        2119.7212659315182`, -1705.9289173632437`}, {
        2100, -1705.9289173632437`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1716.5680651662021`}, {
       3143.162714937268, -1716.5680651662021`}, {
       3143.162714937268, -1705.9289173632437`}, {
       3026.7232747264093`, -1705.9289173632437`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3385.2590363426966`, -1716.5680651662021`}, {
       3714.4172940181493`, -1716.5680651662021`}, {
       3714.4172940181493`, -1705.9289173632437`}, {
       3385.2590363426966`, -1705.9289173632437`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1716.5680651662021`}, {
       4141.493143543739, -1716.5680651662021`}, {
       4141.493143543739, -1705.9289173632437`}, {
       4123.95556605792, -1705.9289173632437`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1716.5680651662021`}, {
       4700., -1716.5680651662021`}, {4700., -1705.9289173632437`}, {
       4576.08758132999, -1705.9289173632437`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2578.1709542710046`, -1716.5680651662021`}, {
      2616.045080569945, -1716.5680651662021`}, {
      2616.045080569945, -1705.9289173632437`}, {
      2578.1709542710046`, -1705.9289173632437`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2119.7212659315182`, -1708.5887043139833`}, \
{2125.040839832998, -1705.9289173632437`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2125.040839832998, -1708.5887043139833`}, 5.319573901479231, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2125.040839832998, -1713.9082782154626`}, {
       2572.8513803695255`, -1713.9082782154626`}, {
       2572.8513803695255`, -1708.5887043139833`}, {
       2125.040839832998, -1708.5887043139833`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2572.8513803695255`, -1713.9082782154626`}, 
       5.319573901479231, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2572.8513803695255`, -1716.5680651662021`}, \
{2578.1709542710046`, -1713.9082782154626`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1752.2245181701403`}, {
        115.95057601476483`, -1752.2245181701403`}, {
        115.95057601476483`, -1716.5680651662021`}, {
        100, -1716.5680651662021`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1752.2245181701403`}, {
       794.8454909543459, -1752.2245181701403`}, {
       794.8454909543459, -1716.5680651662021`}, {
       604.1772733885804, -1716.5680651662021`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1752.2245181701403`}, {
        1242.5186897798449`, -1752.2245181701403`}, {
        1242.5186897798449`, -1716.5680651662021`}, {
        1100, -1716.5680651662021`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600, -1752.2245181701403`}, {
        1600.8998564655458`, -1752.2245181701403`}, {
        1600.8998564655458`, -1716.5680651662021`}, {
        1600, -1716.5680651662021`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1752.2245181701403`}, {
       2616.045080569945, -1752.2245181701403`}, {
       2616.045080569945, -1716.5680651662021`}, {
       2572.8513803695255`, -1716.5680651662021`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1752.2245181701403`}, {
       3143.162714937268, -1752.2245181701403`}, {
       3143.162714937268, -1716.5680651662021`}, {
       3026.7232747264093`, -1716.5680651662021`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3403.0872628446655`, -1752.2245181701403`}, {
       3714.4172940181493`, -1752.2245181701403`}, {
       3714.4172940181493`, -1716.5680651662021`}, {
       3403.0872628446655`, -1716.5680651662021`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1752.2245181701403`}, {
       4141.493143543739, -1752.2245181701403`}, {
       4141.493143543739, -1716.5680651662021`}, {
       4123.95556605792, -1716.5680651662021`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1752.2245181701403`}, {
       4700., -1752.2245181701403`}, {4700., -1716.5680651662021`}, {
       4576.08758132999, -1716.5680651662021`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2100, -1752.2245181701403`}, {
       2119.7212659315182`, -1752.2245181701403`}, {
       2119.7212659315182`, -1716.5680651662021`}, {
       2100, -1716.5680651662021`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3385.2590363426966`, -1725.4821784171868`}, \
{3403.0872628446655`, -1716.5680651662021`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3385.2590363426966`, -1725.4821784171868`}, 
       17.828226501969034`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2137.5494924334876`, -1743.3104049191559`}, {
       3385.2590363426966`, -1743.3104049191559`}, {
       3385.2590363426966`, -1725.4821784171868`}, {
       2137.5494924334876`, -1725.4821784171868`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2137.5494924334876`, -1743.3104049191559`}, 
       17.828226501969034`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2119.7212659315182`, -1752.2245181701403`}, \
{2137.5494924334876`, -1743.3104049191559`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1753.7123073718674`}, {
        115.20668141390126`, -1753.7123073718674`}, {
        115.20668141390126`, -1752.2245181701403`}, {
        100, -1752.2245181701403`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1753.7123073718674`}, {
       794.8454909543459, -1753.7123073718674`}, {
       794.8454909543459, -1752.2245181701403`}, {
       604.1772733885804, -1752.2245181701403`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1753.7123073718674`}, {
        1242.5186897798449`, -1753.7123073718674`}, {
        1242.5186897798449`, -1752.2245181701403`}, {
        1100, -1752.2245181701403`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1753.7123073718674`}, {
        2137.5494924334876`, -1753.7123073718674`}, {
        2137.5494924334876`, -1752.2245181701403`}, {
        2100, -1752.2245181701403`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1753.7123073718674`}, {
       2616.045080569945, -1753.7123073718674`}, {
       2616.045080569945, -1752.2245181701403`}, {
       2572.8513803695255`, -1752.2245181701403`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1753.7123073718674`}, {
       3143.162714937268, -1753.7123073718674`}, {
       3143.162714937268, -1752.2245181701403`}, {
       3026.7232747264093`, -1752.2245181701403`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3403.0872628446655`, -1753.7123073718674`}, {
       3714.4172940181493`, -1753.7123073718674`}, {
       3714.4172940181493`, -1752.2245181701403`}, {
       3403.0872628446655`, -1752.2245181701403`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1753.7123073718674`}, {
       4141.493143543739, -1753.7123073718674`}, {
       4141.493143543739, -1752.2245181701403`}, {
       4123.95556605792, -1752.2245181701403`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1753.7123073718674`}, {
       4700., -1753.7123073718674`}, {4700., -1752.2245181701403`}, {
       4576.08758132999, -1752.2245181701403`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1600., -1753.7123073718674`}, {
      1600.8998564655458`, -1753.7123073718674`}, {
      1600.8998564655458`, -1752.2245181701403`}, {
      1600., -1752.2245181701403`}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{115.20668141390126`, -1752.596465470572}, \
{115.95057601476483`, -1752.2245181701403`}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{115.95057601476483`, -1752.596465470572}, 0.7438946008635645, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{115.95057601476483`, -1753.3403600714355`}, {
       1599.2561053991365`, -1753.3403600714355`}, {
       1599.2561053991365`, -1752.596465470572}, {
       115.95057601476483`, -1752.596465470572}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1599.2561053991365`, -1753.3403600714355`}, 
       0.7438946008635645, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1599.2561053991365`, -1753.7123073718674`}, \
{1600., -1753.3403600714355`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1766.2633931410326`}, {
        108.93113852931872`, -1766.2633931410326`}, {
        108.93113852931872`, -1753.7123073718674`}, {
        100, -1753.7123073718674`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1766.2633931410326`}, {
       794.8454909543459, -1766.2633931410326`}, {
       794.8454909543459, -1753.7123073718674`}, {
       604.1772733885804, -1753.7123073718674`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1766.2633931410326`}, {
        1242.5186897798449`, -1766.2633931410326`}, {
        1242.5186897798449`, -1753.7123073718674`}, {
        1100, -1753.7123073718674`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1766.2633931410326`}, {
       1600.8998564655458`, -1766.2633931410326`}, {
       1600.8998564655458`, -1753.7123073718674`}, {
       1599.2561053991365`, -1753.7123073718674`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1766.2633931410326`}, {
        2137.5494924334876`, -1766.2633931410326`}, {
        2137.5494924334876`, -1753.7123073718674`}, {
        2100, -1753.7123073718674`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1766.2633931410326`}, {
       2616.045080569945, -1766.2633931410326`}, {
       2616.045080569945, -1753.7123073718674`}, {
       2572.8513803695255`, -1753.7123073718674`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1766.2633931410326`}, {
       3143.162714937268, -1766.2633931410326`}, {
       3143.162714937268, -1753.7123073718674`}, {
       3026.7232747264093`, -1753.7123073718674`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1766.2633931410326`}, {
       4141.493143543739, -1766.2633931410326`}, {
       4141.493143543739, -1753.7123073718674`}, {
       4123.95556605792, -1753.7123073718674`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1766.2633931410326`}, {
       4700., -1766.2633931410326`}, {4700., -1753.7123073718674`}, {
       4576.08758132999, -1753.7123073718674`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3403.0872628446655`, -1766.2633931410326`}, {
      3714.4172940181493`, -1766.2633931410326`}, {
      3714.4172940181493`, -1753.7123073718674`}, {
      3403.0872628446655`, -1753.7123073718674`}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{108.93113852931872`, -1756.8500788141587`}, \
{115.20668141390126`, -1753.7123073718674`}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{115.20668141390126`, -1756.8500788141587`}, 6.275542884582546, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{115.20668141390126`, -1763.1256216987413`}, {
       3396.811719960083, -1763.1256216987413`}, {
       3396.811719960083, -1756.8500788141587`}, {
       115.20668141390126`, -1756.8500788141587`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3396.811719960083, -1763.1256216987413`}, 6.275542884582546, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3396.811719960083, -1766.2633931410326`}, \
{3403.0872628446655`, -1763.1256216987413`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1815.4661999358334`}, {
        108.93113852931872`, -1815.4661999358334`}, {
        108.93113852931872`, -1766.2633931410326`}, {
        100, -1766.2633931410326`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1815.4661999358334`}, {
       794.8454909543459, -1815.4661999358334`}, {
       794.8454909543459, -1766.2633931410326`}, {
       604.1772733885804, -1766.2633931410326`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1815.4661999358334`}, {
        1242.5186897798449`, -1815.4661999358334`}, {
        1242.5186897798449`, -1766.2633931410326`}, {
        1100, -1766.2633931410326`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1815.4661999358334`}, {
       1600.8998564655458`, -1815.4661999358334`}, {
       1600.8998564655458`, -1766.2633931410326`}, {
       1599.2561053991365`, -1766.2633931410326`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1815.4661999358334`}, {
        2137.5494924334876`, -1815.4661999358334`}, {
        2137.5494924334876`, -1766.2633931410326`}, {
        2100, -1766.2633931410326`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1815.4661999358334`}, {
       2591.443677172545, -1815.4661999358334`}, {
       2591.443677172545, -1766.2633931410326`}, {
       2572.8513803695255`, -1766.2633931410326`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1815.4661999358334`}, {
       3143.162714937268, -1815.4661999358334`}, {
       3143.162714937268, -1766.2633931410326`}, {
       3026.7232747264093`, -1766.2633931410326`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.95556605792, -1815.4661999358334`}, {
       4141.493143543739, -1815.4661999358334`}, {
       4141.493143543739, -1766.2633931410326`}, {
       4123.95556605792, -1766.2633931410326`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1815.4661999358334`}, {
       4700., -1815.4661999358334`}, {4700., -1766.2633931410326`}, {
       4576.08758132999, -1766.2633931410326`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3396.811719960083, -1815.4661999358334`}, {
      3714.4172940181493`, -1815.4661999358334`}, {
      3714.4172940181493`, -1766.2633931410326`}, {
      3396.811719960083, -1766.2633931410326`}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2591.443677172545, -1778.564094839733}, \
{2616.045080569945, -1766.2633931410326`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2616.045080569945, -1778.564094839733}, 24.601403397400368`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2616.045080569945, -1803.1654982371333`}, {
       3372.2103165626827`, -1803.1654982371333`}, {
       3372.2103165626827`, -1778.564094839733}, {
       2616.045080569945, -1778.564094839733}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3372.2103165626827`, -1803.1654982371333`}, 
       24.601403397400368`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3372.2103165626827`, -1815.4661999358334`}, \
{3396.811719960083, -1803.1654982371333`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1840.9058713026375`}, {
        108.93113852931872`, -1840.9058713026375`}, {
        108.93113852931872`, -1815.4661999358334`}, {
        100, -1815.4661999358334`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1840.9058713026375`}, {
       794.8454909543459, -1840.9058713026375`}, {
       794.8454909543459, -1815.4661999358334`}, {
       604.1772733885804, -1815.4661999358334`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1840.9058713026375`}, {
        1242.5186897798449`, -1840.9058713026375`}, {
        1242.5186897798449`, -1815.4661999358334`}, {
        1100, -1815.4661999358334`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1840.9058713026375`}, {
       1600.8998564655458`, -1840.9058713026375`}, {
       1600.8998564655458`, -1815.4661999358334`}, {
       1599.2561053991365`, -1815.4661999358334`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1840.9058713026375`}, {
        2137.5494924334876`, -1840.9058713026375`}, {
        2137.5494924334876`, -1815.4661999358334`}, {
        2100, -1815.4661999358334`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1840.9058713026375`}, {
       2591.443677172545, -1840.9058713026375`}, {
       2591.443677172545, -1815.4661999358334`}, {
       2572.8513803695255`, -1815.4661999358334`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1840.9058713026375`}, {
       3130.4428792538656`, -1840.9058713026375`}, {
       3130.4428792538656`, -1815.4661999358334`}, {
       3026.7232747264093`, -1815.4661999358334`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1840.9058713026375`}, {
       3714.4172940181493`, -1840.9058713026375`}, {
       3714.4172940181493`, -1815.4661999358334`}, {
       3372.2103165626827`, -1815.4661999358334`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1840.9058713026375`}, {
       4700., -1840.9058713026375`}, {4700., -1815.4661999358334`}, {
       4576.08758132999, -1815.4661999358334`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4123.95556605792, -1840.9058713026375`}, {
      4141.493143543738, -1840.9058713026375`}, {
      4141.493143543738, -1815.4661999358334`}, {
      4123.95556605792, -1815.4661999358334`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3130.4428792538656`, -1821.8261177775344`}, \
{3143.162714937268, -1815.4661999358334`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3143.162714937268, -1821.8261177775344`}, 12.719835683402074`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3143.162714937268, -1834.5459534609365`}, {
       4111.2357303745175`, -1834.5459534609365`}, {
       4111.2357303745175`, -1821.8261177775344`}, {
       3143.162714937268, -1821.8261177775344`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4111.2357303745175`, -1834.5459534609365`}, 
       12.719835683402074`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4111.2357303745175`, -1840.9058713026375`}, \
{4123.95556605792, -1834.5459534609365`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1851.0816666505757`}, {
        108.93113852931872`, -1851.0816666505757`}, {
        108.93113852931872`, -1840.9058713026375`}, {
        100, -1840.9058713026375`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1851.0816666505757`}, {
       794.8454909543459, -1851.0816666505757`}, {
       794.8454909543459, -1840.9058713026375`}, {
       604.1772733885804, -1840.9058713026375`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1100, -1851.0816666505757`}, {
        1242.5186897798449`, -1851.0816666505757`}, {
        1242.5186897798449`, -1840.9058713026375`}, {
        1100, -1840.9058713026375`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1851.0816666505757`}, {
       1600.8998564655458`, -1851.0816666505757`}, {
       1600.8998564655458`, -1840.9058713026375`}, {
       1599.2561053991365`, -1840.9058713026375`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1851.0816666505757`}, {
        2137.5494924334876`, -1851.0816666505757`}, {
        2137.5494924334876`, -1840.9058713026375`}, {
        2100, -1840.9058713026375`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1851.0816666505757`}, {
       3130.4428792538656`, -1851.0816666505757`}, {
       3130.4428792538656`, -1840.9058713026375`}, {
       3026.7232747264093`, -1840.9058713026375`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1851.0816666505757`}, {
       3714.4172940181493`, -1851.0816666505757`}, {
       3714.4172940181493`, -1840.9058713026375`}, {
       3372.2103165626827`, -1840.9058713026375`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -1851.0816666505757`}, {
       4141.493143543739, -1851.0816666505757`}, {
       4141.493143543739, -1840.9058713026375`}, {
       4116.323628048487, -1840.9058713026375`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1851.0816666505757`}, {
       4700., -1851.0816666505757`}, {4700., -1840.9058713026375`}, {
       4576.08758132999, -1840.9058713026375`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2572.8513803695255`, -1851.0816666505757`}, {
      2591.443677172545, -1851.0816666505757`}, {
      2591.443677172545, -1840.9058713026375`}, {
      2572.8513803695255`, -1840.9058713026375`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4111.2357303745175`, -1843.449820139622}, \
{4116.323628048487, -1840.9058713026375`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4111.2357303745175`, -1843.449820139622}, 5.087897673969149, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2596.531574846514, -1848.5377178135911`}, {
       4111.2357303745175`, -1848.5377178135911`}, {
       4111.2357303745175`, -1843.449820139622}, {
       2596.531574846514, -1843.449820139622}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2596.531574846514, -1848.5377178135911`}, 5.087897673969149, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2591.443677172545, -1851.0816666505757`}, \
{2596.531574846514, -1848.5377178135911`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1866.5343507416217`}, {
       794.8454909543459, -1866.5343507416217`}, {
       794.8454909543459, -1851.0816666505757`}, {
       604.1772733885804, -1851.0816666505757`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1107.726342045523, -1866.5343507416217`}, {
       1242.5186897798449`, -1866.5343507416217`}, {
       1242.5186897798449`, -1851.0816666505757`}, {
       1107.726342045523, -1851.0816666505757`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1866.5343507416217`}, {
       1600.8998564655458`, -1866.5343507416217`}, {
       1600.8998564655458`, -1851.0816666505757`}, {
       1599.2561053991365`, -1851.0816666505757`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2100, -1866.5343507416217`}, {
        2137.5494924334876`, -1866.5343507416217`}, {
        2137.5494924334876`, -1851.0816666505757`}, {
        2100, -1851.0816666505757`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1866.5343507416217`}, {
       2596.531574846514, -1866.5343507416217`}, {
       2596.531574846514, -1851.0816666505757`}, {
       2572.8513803695255`, -1851.0816666505757`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1866.5343507416217`}, {
       3130.4428792538656`, -1866.5343507416217`}, {
       3130.4428792538656`, -1851.0816666505757`}, {
       3026.7232747264093`, -1851.0816666505757`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1866.5343507416217`}, {
       3714.4172940181493`, -1866.5343507416217`}, {
       3714.4172940181493`, -1851.0816666505757`}, {
       3372.2103165626827`, -1851.0816666505757`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -1866.5343507416217`}, {
       4141.493143543739, -1866.5343507416217`}, {
       4141.493143543739, -1851.0816666505757`}, {
       4116.323628048487, -1851.0816666505757`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4576.08758132999, -1866.5343507416217`}, {
       4700., -1866.5343507416217`}, {4700., -1851.0816666505757`}, {
       4576.08758132999, -1851.0816666505757`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -1866.5343507416217`}, {
       108.93113852931872`, -1866.5343507416217`}, {
       108.93113852931872`, -1851.0816666505757`}, {
       100, -1851.0816666505757`}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1100., -1854.9448376733371`}, \
{1107.726342045523, -1851.0816666505757`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1100., -1854.9448376733371`}, 7.72634204552303, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{116.65748057484174`, -1862.6711797188602`}, {
       1100., -1862.6711797188602`}, {1100., -1854.9448376733371`}, {
       116.65748057484174`, -1854.9448376733371`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{116.65748057484174`, -1862.6711797188602`}, 7.72634204552303, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{108.93113852931872`, -1866.5343507416217`}, \
{116.65748057484174`, -1862.6711797188602`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1895.415587749647}, {
        116.65748057484174`, -1895.415587749647}, {
        116.65748057484174`, -1866.5343507416217`}, {
        100, -1866.5343507416217`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1895.415587749647}, {
       794.8454909543459, -1895.415587749647}, {
       794.8454909543459, -1866.5343507416217`}, {
       604.1772733885804, -1866.5343507416217`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1107.726342045523, -1895.415587749647}, {
       1242.5186897798449`, -1895.415587749647}, {
       1242.5186897798449`, -1866.5343507416217`}, {
       1107.726342045523, -1866.5343507416217`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1895.415587749647}, {
       1600.8998564655458`, -1895.415587749647}, {
       1600.8998564655458`, -1866.5343507416217`}, {
       1599.2561053991365`, -1866.5343507416217`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1895.415587749647}, {
       2596.531574846514, -1895.415587749647}, {
       2596.531574846514, -1866.5343507416217`}, {
       2572.8513803695255`, -1866.5343507416217`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1895.415587749647}, {
       3130.4428792538656`, -1895.415587749647}, {
       3130.4428792538656`, -1866.5343507416217`}, {
       3026.7232747264093`, -1866.5343507416217`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1895.415587749647}, {
       3714.4172940181493`, -1895.415587749647}, {
       3714.4172940181493`, -1866.5343507416217`}, {
       3372.2103165626827`, -1866.5343507416217`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -1895.415587749647}, {
       4141.493143543739, -1895.415587749647}, {
       4141.493143543739, -1866.5343507416217`}, {
       4116.323628048487, -1866.5343507416217`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4590.528199834002, -1895.415587749647}, {
       4700., -1895.415587749647}, {4700., -1866.5343507416217`}, {
       4590.528199834002, -1866.5343507416217`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2100, -1895.415587749647}, {
       2137.5494924334876`, -1895.415587749647}, {
       2137.5494924334876`, -1866.5343507416217`}, {
       2100, -1866.5343507416217`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4576.08758132999, -1873.7546599936281`}, \
{4590.528199834002, -1866.5343507416217`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4576.08758132999, -1873.7546599936281`}, 14.440618504012697`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2151.9901109375, -1888.1952784976409`}, {
       4576.08758132999, -1888.1952784976409`}, {
       4576.08758132999, -1873.7546599936281`}, {
       2151.9901109375, -1873.7546599936281`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2151.9901109375, -1888.1952784976409`}, 14.440618504012697`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2137.5494924334876`, -1895.415587749647}, \
{2151.9901109375, -1888.1952784976409`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -1917.5320722403744`}, {
        116.65748057484174`, -1917.5320722403744`}, {
        116.65748057484174`, -1895.415587749647}, {
        100, -1895.415587749647}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1917.5320722403744`}, {
       794.8454909543459, -1917.5320722403744`}, {
       794.8454909543459, -1895.415587749647}, {
       604.1772733885804, -1895.415587749647}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1107.726342045523, -1917.5320722403744`}, {
       1231.4604475344813`, -1917.5320722403744`}, {
       1231.4604475344813`, -1895.415587749647}, {
       1107.726342045523, -1895.415587749647}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1917.5320722403744`}, {
       1600.8998564655458`, -1917.5320722403744`}, {
       1600.8998564655458`, -1895.415587749647}, {
       1599.2561053991365`, -1895.415587749647}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1917.5320722403744`}, {
       2596.531574846514, -1917.5320722403744`}, {
       2596.531574846514, -1895.415587749647}, {
       2572.8513803695255`, -1895.415587749647}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1917.5320722403744`}, {
       3130.4428792538656`, -1917.5320722403744`}, {
       3130.4428792538656`, -1895.415587749647}, {
       3026.7232747264093`, -1895.415587749647}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1917.5320722403744`}, {
       3714.4172940181493`, -1917.5320722403744`}, {
       3714.4172940181493`, -1895.415587749647}, {
       3372.2103165626827`, -1895.415587749647}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -1917.5320722403744`}, {
       4141.493143543739, -1917.5320722403744`}, {
       4141.493143543739, -1895.415587749647}, {
       4116.323628048487, -1895.415587749647}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4590.528199834002, -1917.5320722403744`}, {
       4700., -1917.5320722403744`}, {4700., -1895.415587749647}, {
       4590.528199834002, -1895.415587749647}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2100., -1917.5320722403744`}, {
      2151.9901109375, -1917.5320722403744`}, {
      2151.9901109375, -1895.415587749647}, {2100., -1895.415587749647}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1231.4604475344813`, -1900.944708872329}, \
{1242.5186897798449`, -1895.415587749647}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1242.5186897798449`, -1900.944708872329}, 11.058242245363608`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1242.5186897798449`, -1912.0029511176926`}, {
       2088.9417577546365`, -1912.0029511176926`}, {
       2088.9417577546365`, -1900.944708872329}, {
       1242.5186897798449`, -1900.944708872329}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2088.9417577546365`, -1912.0029511176926`}, 
       11.058242245363608`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2088.9417577546365`, -1917.5320722403744`}, \
{2100., -1912.0029511176926`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -1921.4992313770758`}, {
       794.8454909543459, -1921.4992313770758`}, {
       794.8454909543459, -1917.5320722403744`}, {
       604.1772733885804, -1917.5320722403744`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1107.726342045523, -1921.4992313770758`}, {
       1231.4604475344813`, -1921.4992313770758`}, {
       1231.4604475344813`, -1917.5320722403744`}, {
       1107.726342045523, -1917.5320722403744`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -1921.4992313770758`}, {
       1600.8998564655458`, -1921.4992313770758`}, {
       1600.8998564655458`, -1917.5320722403744`}, {
       1599.2561053991365`, -1917.5320722403744`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2088.9417577546365`, -1921.4992313770758`}, {
       2151.9901109375, -1921.4992313770758`}, {
       2151.9901109375, -1917.5320722403744`}, {
       2088.9417577546365`, -1917.5320722403744`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -1921.4992313770758`}, {
       2596.531574846514, -1921.4992313770758`}, {
       2596.531574846514, -1917.5320722403744`}, {
       2572.8513803695255`, -1917.5320722403744`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -1921.4992313770758`}, {
       3130.4428792538656`, -1921.4992313770758`}, {
       3130.4428792538656`, -1917.5320722403744`}, {
       3026.7232747264093`, -1917.5320722403744`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -1921.4992313770758`}, {
       3714.4172940181493`, -1921.4992313770758`}, {
       3714.4172940181493`, -1917.5320722403744`}, {
       3372.2103165626827`, -1917.5320722403744`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -1921.4992313770758`}, {
       4141.493143543739, -1921.4992313770758`}, {
       4141.493143543739, -1917.5320722403744`}, {
       4116.323628048487, -1917.5320722403744`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4592.511779402354, -1921.4992313770758`}, {
       4700.000000000001, -1921.4992313770758`}, {
       4700.000000000001, -1917.5320722403744`}, {
       4592.511779402354, -1917.5320722403744`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -1921.4992313770758`}, {
       116.65748057484174`, -1921.4992313770758`}, {
       116.65748057484174`, -1917.5320722403744`}, {
       100, -1917.5320722403744`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4590.528199834002, -1918.5238620245498`}, \
{4592.511779402354, -1917.5320722403744`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4590.528199834002, -1918.5238620245498`}, 1.9835795683507094`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{118.64106014319246`, -1920.5074415929005`}, {
       4590.528199834002, -1920.5074415929005`}, {
       4590.528199834002, -1918.5238620245498`}, {
       118.64106014319246`, -1918.5238620245498`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{118.64106014319246`, -1920.5074415929005`}, 
       1.9835795683507094`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{116.65748057484174`, -1921.4992313770758`}, \
{118.64106014319246`, -1920.5074415929005`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2094.7210857510568`}, {
        118.64106014319246`, -2094.7210857510568`}, {
        118.64106014319246`, -1921.499231377076}, {
        100, -1921.499231377076}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2094.7210857510568`}, {
       1231.4604475344813`, -2094.7210857510568`}, {
       1231.4604475344813`, -1921.499231377076}, {
       1194.3372692325136`, -1921.499231377076}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2094.7210857510568`}, {
       1600.8998564655458`, -2094.7210857510568`}, {
       1600.8998564655458`, -1921.499231377076}, {
       1599.2561053991365`, -1921.499231377076}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2088.9417577546365`, -2094.7210857510568`}, {
       2151.9901109375, -2094.7210857510568`}, {
       2151.9901109375, -1921.499231377076}, {
       2088.9417577546365`, -1921.499231377076}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2094.7210857510568`}, {
       2596.531574846514, -2094.7210857510568`}, {
       2596.531574846514, -1921.499231377076}, {
       2572.8513803695255`, -1921.499231377076}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -2094.7210857510568`}, {
       3130.4428792538656`, -2094.7210857510568`}, {
       3130.4428792538656`, -1921.499231377076}, {
       3026.7232747264093`, -1921.499231377076}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2094.7210857510568`}, {
       3714.4172940181493`, -2094.7210857510568`}, {
       3714.4172940181493`, -1921.499231377076}, {
       3372.2103165626827`, -1921.499231377076}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -2094.7210857510568`}, {
       4141.493143543739, -2094.7210857510568`}, {
       4141.493143543739, -1921.499231377076}, {
       4116.323628048487, -1921.499231377076}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4592.511779402354, -2094.7210857510568`}, {
       4700.000000000001, -2094.7210857510568`}, {
       4700.000000000001, -1921.499231377076}, {
       4592.511779402354, -1921.499231377076}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -2094.7210857510568`}, {
      794.845490954346, -2094.7210857510568`}, {
      794.845490954346, -1921.499231377076}, {
      604.1772733885804, -1921.499231377076}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1107.726342045523, -1964.8046949705713`}, \
{1194.3372692325136`, -1921.499231377076}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1107.726342045523, -1964.8046949705713`}, 86.61092718699038, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{881.4564181413364, -2051.4156221575618`}, {
       1107.726342045523, -2051.4156221575618`}, {
       1107.726342045523, -1964.8046949705713`}, {
       881.4564181413364, -1964.8046949705713`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{881.4564181413364, -2051.4156221575618`}, 86.61092718699038, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{794.845490954346, -2094.7210857510568`}, \
{881.4564181413364, -2051.4156221575618`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2184.5777212048743`}, {
        118.64106014319246`, -2184.5777212048743`}, {
        118.64106014319246`, -2094.7210857510568`}, {
        100, -2094.7210857510568`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2184.5777212048743`}, {
       836.5281004144276, -2184.5777212048743`}, {
       836.5281004144276, -2094.7210857510568`}, {
       604.1772733885804, -2094.7210857510568`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2184.5777212048743`}, {
       1231.4604475344813`, -2184.5777212048743`}, {
       1231.4604475344813`, -2094.7210857510568`}, {
       1194.3372692325136`, -2094.7210857510568`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2184.5777212048743`}, {
       1600.8998564655458`, -2184.5777212048743`}, {
       1600.8998564655458`, -2094.7210857510568`}, {
       1599.2561053991365`, -2094.7210857510568`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2184.5777212048743`}, {
       2596.531574846514, -2184.5777212048743`}, {
       2596.531574846514, -2094.7210857510568`}, {
       2572.8513803695255`, -2094.7210857510568`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -2184.5777212048743`}, {
       3130.4428792538656`, -2184.5777212048743`}, {
       3130.4428792538656`, -2094.7210857510568`}, {
       3026.7232747264093`, -2094.7210857510568`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2184.5777212048743`}, {
       3714.4172940181493`, -2184.5777212048743`}, {
       3714.4172940181493`, -2094.7210857510568`}, {
       3372.2103165626827`, -2094.7210857510568`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -2184.5777212048743`}, {
       4141.493143543739, -2184.5777212048743`}, {
       4141.493143543739, -2094.7210857510568`}, {
       4116.323628048487, -2094.7210857510568`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4592.511779402354, -2184.5777212048743`}, {
       4700.000000000001, -2184.5777212048743`}, {
       4700.000000000001, -2094.7210857510568`}, {
       4592.511779402354, -2094.7210857510568`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2088.9417577546365`, -2184.5777212048743`}, {
      2151.9901109375, -2184.5777212048743`}, {
      2151.9901109375, -2094.7210857510568`}, {
      2088.9417577546365`, -2094.7210857510568`}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{836.5281004144276, -2117.1852446145112`}, \
{881.4564181413364, -2094.7210857510568`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{881.4564181413364, -2117.1852446145112`}, 44.92831772690874, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{881.4564181413364, -2162.1135623414198`}, {
       2044.0134400277277`, -2162.1135623414198`}, {
       2044.0134400277277`, -2117.1852446145112`}, {
       881.4564181413364, -2117.1852446145112`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2044.0134400277277`, -2162.1135623414198`}, 
       44.92831772690874, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2044.0134400277277`, -2184.5777212048743`}, \
{2088.9417577546365`, -2162.1135623414198`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2247.752671288168}, {
        118.64106014319246`, -2247.752671288168}, {
        118.64106014319246`, -2184.5777212048743`}, {
        100, -2184.5777212048743`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2247.752671288168}, {
       804.9406253727807, -2247.752671288168}, {
       804.9406253727807, -2184.5777212048743`}, {
       604.1772733885804, -2184.5777212048743`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2247.752671288168}, {
       1231.4604475344813`, -2247.752671288168}, {
       1231.4604475344813`, -2184.5777212048743`}, {
       1194.3372692325136`, -2184.5777212048743`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2247.752671288168}, {
       1600.8998564655458`, -2247.752671288168}, {
       1600.8998564655458`, -2184.5777212048743`}, {
       1599.2561053991365`, -2184.5777212048743`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2247.752671288168}, {
       2151.9901109375, -2247.752671288168}, {
       2151.9901109375, -2184.5777212048743`}, {
       2044.0134400277277`, -2184.5777212048743`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2247.752671288168}, {
       2596.531574846514, -2247.752671288168}, {
       2596.531574846514, -2184.5777212048743`}, {
       2572.8513803695255`, -2184.5777212048743`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -2247.752671288168}, {
       3130.4428792538656`, -2247.752671288168}, {
       3130.4428792538656`, -2184.5777212048743`}, {
       3026.7232747264093`, -2184.5777212048743`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2247.752671288168}, {
       3714.4172940181493`, -2247.752671288168}, {
       3714.4172940181493`, -2184.5777212048743`}, {
       3372.2103165626827`, -2184.5777212048743`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.323628048487, -2247.752671288168}, {
       4141.493143543739, -2247.752671288168}, {
       4141.493143543739, -2184.5777212048743`}, {
       4116.323628048487, -2184.5777212048743`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4592.511779402354, -2247.752671288168}, {
      4700.000000000001, -2247.752671288168}, {
      4700.000000000001, -2184.5777212048743`}, {
      4592.511779402354, -2184.5777212048743`}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{804.9406253727807, -2200.3714587256977`}, \
{836.5281004144276, -2184.5777212048743`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{836.5281004144276, -2200.3714587256977`}, 31.587475041646968`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{836.5281004144276, -2231.9589337673447`}, {
       4560.924304360707, -2231.9589337673447`}, {
       4560.924304360707, -2200.3714587256977`}, {
       836.5281004144276, -2200.3714587256977`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4560.924304360707, -2231.9589337673447`}, 
       31.587475041646968`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4560.924304360707, -2247.752671288168}, \
{4592.511779402354, -2231.9589337673447`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2249.492645029124}, {
        117.77107327271447`, -2249.492645029124}, {
        117.77107327271447`, -2247.752671288168}, {
        100, -2247.752671288168}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2249.492645029124}, {
       804.9406253727807, -2249.492645029124}, {
       804.9406253727807, -2247.752671288168}, {
       604.1772733885804, -2247.752671288168}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2249.492645029124}, {
       1231.4604475344813`, -2249.492645029124}, {
       1231.4604475344813`, -2247.752671288168}, {
       1194.3372692325136`, -2247.752671288168}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2249.492645029124}, {
       1600.8998564655458`, -2249.492645029124}, {
       1600.8998564655458`, -2247.752671288168}, {
       1599.2561053991365`, -2247.752671288168}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2249.492645029124}, {
       2151.9901109375, -2249.492645029124}, {
       2151.9901109375, -2247.752671288168}, {
       2044.0134400277277`, -2247.752671288168}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2249.492645029124}, {
       2596.531574846514, -2249.492645029124}, {
       2596.531574846514, -2247.752671288168}, {
       2572.8513803695255`, -2247.752671288168}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -2249.492645029124}, {
       3130.4428792538656`, -2249.492645029124}, {
       3130.4428792538656`, -2247.752671288168}, {
       3026.7232747264093`, -2247.752671288168}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2249.492645029124}, {
       3714.4172940181493`, -2249.492645029124}, {
       3714.4172940181493`, -2247.752671288168}, {
       3372.2103165626827`, -2247.752671288168}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4560.924304360707, -2249.492645029124}, {
       4700.000000000001, -2249.492645029124}, {
       4700.000000000001, -2247.752671288168}, {
       4560.924304360707, -2247.752671288168}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4116.323628048487, -2249.492645029124}, {
      4141.493143543739, -2249.492645029124}, {
      4141.493143543739, -2247.752671288168}, {
      4116.323628048487, -2247.752671288168}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{117.77107327271447`, -2248.187664723407}, \
{118.64106014319246`, -2247.752671288168}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{118.64106014319246`, -2248.187664723407}, 0.8699868704779838, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{118.64106014319246`, -2249.057651593885}, {
       4115.453641178009, -2249.057651593885}, {
       4115.453641178009, -2248.187664723407}, {
       118.64106014319246`, -2248.187664723407}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4115.453641178009, -2249.057651593885}, 0.8699868704779838, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4115.453641178009, -2249.492645029124}, \
{4116.323628048487, -2249.057651593885}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2284.5494254950872`}, {
        117.77107327271447`, -2284.5494254950872`}, {
        117.77107327271447`, -2249.492645029124}, {
        100, -2249.492645029124}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2284.5494254950872`}, {
       804.9406253727807, -2284.5494254950872`}, {
       804.9406253727807, -2249.492645029124}, {
       604.1772733885804, -2249.492645029124}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2284.5494254950872`}, {
       1231.4604475344813`, -2284.5494254950872`}, {
       1231.4604475344813`, -2249.492645029124}, {
       1194.3372692325136`, -2249.492645029124}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2284.5494254950872`}, {
       1600.8998564655458`, -2284.5494254950872`}, {
       1600.8998564655458`, -2249.492645029124}, {
       1599.2561053991365`, -2249.492645029124}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2284.5494254950872`}, {
       2151.9901109375, -2284.5494254950872`}, {
       2151.9901109375, -2249.492645029124}, {
       2044.0134400277277`, -2249.492645029124}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2284.5494254950872`}, {
       2579.0031846135325`, -2284.5494254950872`}, {
       2579.0031846135325`, -2249.492645029124}, {
       2572.8513803695255`, -2249.492645029124}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3026.7232747264093`, -2284.5494254950872`}, {
       3130.4428792538656`, -2284.5494254950872`}, {
       3130.4428792538656`, -2249.492645029124}, {
       3026.7232747264093`, -2249.492645029124}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2284.5494254950872`}, {
       3714.4172940181493`, -2284.5494254950872`}, {
       3714.4172940181493`, -2249.492645029124}, {
       3372.2103165626827`, -2249.492645029124}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4560.924304360707, -2284.5494254950872`}, {
       4700.000000000001, -2284.5494254950872`}, {
       4700.000000000001, -2249.492645029124}, {
       4560.924304360707, -2249.492645029124}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4115.453641178009, -2284.5494254950872`}, {
      4141.493143543739, -2284.5494254950872`}, {
      4141.493143543739, -2249.492645029124}, {
      4115.453641178009, -2249.492645029124}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2579.0031846135325`, -2258.256840145615}, \
{2596.531574846514, -2249.492645029124}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2596.531574846514, -2258.256840145615}, 17.52839023298149, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2596.531574846514, -2275.7852303785967`}, {
       4097.925250945028, -2275.7852303785967`}, {
       4097.925250945028, -2258.256840145615}, {
       2596.531574846514, -2258.256840145615}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4097.925250945028, -2275.7852303785967`}, 17.52839023298149, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4097.925250945028, -2284.5494254950872`}, \
{4115.453641178009, -2275.7852303785967`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2390.490258650994}, {
        117.77107327271447`, -2390.490258650994}, {
        117.77107327271447`, -2284.5494254950872`}, {
        100, -2284.5494254950872`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2390.490258650994}, {
       804.9406253727807, -2390.490258650994}, {
       804.9406253727807, -2284.5494254950872`}, {
       604.1772733885804, -2284.5494254950872`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2390.490258650994}, {
       1231.4604475344813`, -2390.490258650994}, {
       1231.4604475344813`, -2284.5494254950872`}, {
       1194.3372692325136`, -2284.5494254950872`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2390.490258650994}, {
       1600.8998564655458`, -2390.490258650994}, {
       1600.8998564655458`, -2284.5494254950872`}, {
       1599.2561053991365`, -2284.5494254950872`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2390.490258650994}, {
       2579.0031846135325`, -2390.490258650994}, {
       2579.0031846135325`, -2284.5494254950872`}, {
       2572.8513803695255`, -2284.5494254950872`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3079.693691304363, -2390.490258650994}, {
       3130.442879253866, -2390.490258650994}, {
       3130.442879253866, -2284.5494254950872`}, {
       3079.693691304363, -2284.5494254950872`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2390.490258650994}, {
       3714.4172940181493`, -2390.490258650994}, {
       3714.4172940181493`, -2284.5494254950872`}, {
       3372.2103165626827`, -2284.5494254950872`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2390.490258650994}, {
       4141.493143543739, -2390.490258650994}, {
       4141.493143543739, -2284.5494254950872`}, {
       4097.925250945028, -2284.5494254950872`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4560.924304360707, -2390.490258650994}, {
       4700.000000000001, -2390.490258650994}, {
       4700.000000000001, -2284.5494254950872`}, {
       4560.924304360707, -2284.5494254950872`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.0134400277277`, -2390.490258650994}, {
      2151.9901109375, -2390.490258650994}, {
      2151.9901109375, -2284.5494254950872`}, {
      2044.0134400277277`, -2284.5494254950872`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3026.7232747264093`, -2311.0346337840638`}, \
{3079.693691304363, -2284.5494254950872`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3026.7232747264093`, -2311.0346337840638`}, 52.97041657795333, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2204.9605275154536`, -2364.0050503620173`}, {
       3026.7232747264093`, -2364.0050503620173`}, {
       3026.7232747264093`, -2311.0346337840638`}, {
       2204.9605275154536`, -2311.0346337840638`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2204.9605275154536`, -2364.0050503620173`}, 52.97041657795333, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2151.9901109375, -2390.490258650994}, \
{2204.9605275154536`, -2364.0050503620173`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2454.621441501929}, {
        117.77107327271447`, -2454.621441501929}, {
        117.77107327271447`, -2390.490258650994}, {
        100, -2390.490258650994}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2454.621441501929}, {
       804.9406253727807, -2454.621441501929}, {
       804.9406253727807, -2390.490258650994}, {
       604.1772733885804, -2390.490258650994}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2454.621441501929}, {
       1600.8998564655458`, -2454.621441501929}, {
       1600.8998564655458`, -2390.490258650994}, {
       1599.2561053991365`, -2390.490258650994}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2454.621441501929}, {
       2204.9605275154536`, -2454.621441501929}, {
       2204.9605275154536`, -2390.490258650994}, {
       2044.0134400277277`, -2390.490258650994}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2454.621441501929}, {
       2579.0031846135325`, -2454.621441501929}, {
       2579.0031846135325`, -2390.490258650994}, {
       2572.8513803695255`, -2390.490258650994}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.7592827298304`, -2454.621441501929}, {
       3130.442879253866, -2454.621441501929}, {
       3130.442879253866, -2390.490258650994}, {
       3111.7592827298304`, -2390.490258650994}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2454.621441501929}, {
       3714.4172940181493`, -2454.621441501929}, {
       3714.4172940181493`, -2390.490258650994}, {
       3372.2103165626827`, -2390.490258650994}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2454.621441501929}, {
       4141.493143543739, -2454.621441501929}, {
       4141.493143543739, -2390.490258650994}, {
       4097.925250945028, -2390.490258650994}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4560.924304360707, -2454.621441501929}, {
       4700.000000000001, -2454.621441501929}, {
       4700.000000000001, -2390.490258650994}, {
       4560.924304360707, -2390.490258650994}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1194.3372692325136`, -2454.621441501929}, {
      1231.4604475344813`, -2454.621441501929}, {
      1231.4604475344813`, -2390.490258650994}, {
      1194.3372692325136`, -2390.490258650994}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3079.693691304363, -2406.5230543637276`}, \
{3111.7592827298304`, -2390.490258650994}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3079.693691304363, -2406.5230543637276`}, 32.0655914254675, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1263.526038959949, -2438.588645789195}, {
       3079.693691304363, -2438.588645789195}, {
       3079.693691304363, -2406.5230543637276`}, {
       1263.526038959949, -2406.5230543637276`}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1263.526038959949, -2438.588645789195}, 32.0655914254675, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1231.4604475344813`, -2454.621441501929}, \
{1263.526038959949, -2438.588645789195}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2456.365424637313}, {
        117.77107327271447`, -2456.365424637313}, {
        117.77107327271447`, -2454.621441501929}, {
        100, -2454.621441501929}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2456.365424637313}, {
       804.9406253727807, -2456.365424637313}, {
       804.9406253727807, -2454.621441501929}, {
       604.1772733885804, -2454.621441501929}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2456.365424637313}, {
       1262.6540473922569`, -2456.365424637313}, {
       1262.6540473922569`, -2454.621441501929}, {
       1194.3372692325136`, -2454.621441501929}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2456.365424637313}, {
       1600.8998564655458`, -2456.365424637313}, {
       1600.8998564655458`, -2454.621441501929}, {
       1599.2561053991365`, -2454.621441501929}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2456.365424637313}, {
       2204.9605275154536`, -2456.365424637313}, {
       2204.9605275154536`, -2454.621441501929}, {
       2044.0134400277277`, -2454.621441501929}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2456.365424637313}, {
       2579.0031846135325`, -2456.365424637313}, {
       2579.0031846135325`, -2454.621441501929}, {
       2572.8513803695255`, -2454.621441501929}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.7592827298304`, -2456.365424637313}, {
       3130.442879253866, -2456.365424637313}, {
       3130.442879253866, -2454.621441501929}, {
       3111.7592827298304`, -2454.621441501929}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2456.365424637313}, {
       3714.4172940181493`, -2456.365424637313}, {
       3714.4172940181493`, -2454.621441501929}, {
       3372.2103165626827`, -2454.621441501929}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2456.365424637313}, {
       4141.493143543739, -2456.365424637313}, {
       4141.493143543739, -2454.621441501929}, {
       4097.925250945028, -2454.621441501929}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4560.924304360707, -2456.365424637313}, {
      4700.000000000001, -2456.365424637313}, {
      4700.000000000001, -2454.621441501929}, {
      4560.924304360707, -2454.621441501929}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1262.6540473922569`, -2455.057437285775}, \
{1263.526038959949, -2454.621441501929}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1263.526038959949, -2455.057437285775}, 0.8719915676919499, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1263.526038959949, -2455.929428853467}, {
       4560.052312793015, -2455.929428853467}, {
       4560.052312793015, -2455.057437285775}, {
       1263.526038959949, -2455.057437285775}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4560.052312793015, -2455.929428853467}, 0.8719915676919499, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4560.052312793015, -2456.365424637313}, \
{4560.924304360707, -2455.929428853467}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2463.267999512606}, {
       804.9406253727807, -2463.267999512606}, {
       804.9406253727807, -2456.365424637313}, {
       604.1772733885804, -2456.365424637313}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2463.267999512606}, {
       1262.6540473922569`, -2463.267999512606}, {
       1262.6540473922569`, -2456.365424637313}, {
       1194.3372692325136`, -2456.365424637313}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2463.267999512606}, {
       1600.8998564655458`, -2463.267999512606}, {
       1600.8998564655458`, -2456.365424637313}, {
       1599.2561053991365`, -2456.365424637313}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2463.267999512606}, {
       2204.9605275154536`, -2463.267999512606}, {
       2204.9605275154536`, -2456.365424637313}, {
       2044.0134400277277`, -2456.365424637313}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2463.267999512606}, {
       2579.0031846135325`, -2463.267999512606}, {
       2579.0031846135325`, -2456.365424637313}, {
       2572.8513803695255`, -2456.365424637313}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.7592827298304`, -2463.267999512606}, {
       3130.442879253866, -2463.267999512606}, {
       3130.442879253866, -2456.365424637313}, {
       3111.7592827298304`, -2456.365424637313}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2463.267999512606}, {
       3714.4172940181493`, -2463.267999512606}, {
       3714.4172940181493`, -2456.365424637313}, {
       3372.2103165626827`, -2456.365424637313}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2463.267999512606}, {
       4141.493143543739, -2463.267999512606}, {
       4141.493143543739, -2456.365424637313}, {
       4097.925250945028, -2456.365424637313}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2463.267999512606}, {
       4700.000000000001, -2463.267999512606}, {
       4700.000000000001, -2456.365424637313}, {
       4563.5036002306615`, -2456.365424637313}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -2463.267999512606}, {
       117.77107327271447`, -2463.267999512606}, {
       117.77107327271447`, -2456.365424637313}, {
       100, -2456.365424637313}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4560.052312793015, -2458.091068356136}, \
{4563.5036002306615`, -2456.365424637313}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4560.052312793015, -2458.091068356136}, 3.4512874376465135`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{121.22236071036099`, -2461.5423557937825`}, {
       4560.052312793015, -2461.5423557937825`}, {
       4560.052312793015, -2458.091068356136}, {
       121.22236071036099`, -2458.091068356136}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{121.22236071036099`, -2461.5423557937825`}, 
       3.4512874376465135`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{117.77107327271447`, -2463.267999512606}, \
{121.22236071036099`, -2461.5423557937825`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2463.3670127645155`}, {
        121.22236071036099`, -2463.3670127645155`}, {
        121.22236071036099`, -2463.267999512606}, {
        100, -2463.267999512606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2463.3670127645155`}, {
       804.9406253727807, -2463.3670127645155`}, {
       804.9406253727807, -2463.267999512606}, {
       604.1772733885804, -2463.267999512606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2463.3670127645155`}, {
       1262.6540473922569`, -2463.3670127645155`}, {
       1262.6540473922569`, -2463.267999512606}, {
       1194.3372692325136`, -2463.267999512606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.0134400277277`, -2463.3670127645155`}, {
       2204.9605275154536`, -2463.3670127645155`}, {
       2204.9605275154536`, -2463.267999512606}, {
       2044.0134400277277`, -2463.267999512606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2463.3670127645155`}, {
       2579.0031846135325`, -2463.3670127645155`}, {
       2579.0031846135325`, -2463.267999512606}, {
       2572.8513803695255`, -2463.267999512606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.8087893557854`, -2463.3670127645155`}, {
       3130.442879253866, -2463.3670127645155`}, {
       3130.442879253866, -2463.267999512606}, {
       3111.8087893557854`, -2463.267999512606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2463.3670127645155`}, {
       3714.4172940181493`, -2463.3670127645155`}, {
       3714.4172940181493`, -2463.267999512606}, {
       3372.2103165626827`, -2463.267999512606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2463.3670127645155`}, {
       4141.493143543739, -2463.3670127645155`}, {
       4141.493143543739, -2463.267999512606}, {
       4097.925250945028, -2463.267999512606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2463.3670127645155`}, {
       4700.000000000001, -2463.3670127645155`}, {
       4700.000000000001, -2463.267999512606}, {
       4563.5036002306615`, -2463.267999512606}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1599.2561053991365`, -2463.3670127645155`}, {
      1600.8998564655458`, -2463.3670127645155`}, {
      1600.8998564655458`, -2463.267999512606}, {
      1599.2561053991365`, -2463.267999512606}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3111.7592827298304`, -2463.292752825583}, \
{3111.8087893557854`, -2463.267999512606}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3111.7592827298304`, -2463.292752825583}, 0.04950662595486266, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1600.9493630915008`, -2463.342259451538}, {
       3111.7592827298304`, -2463.342259451538}, {
       3111.7592827298304`, -2463.292752825583}, {
       1600.9493630915008`, -2463.292752825583}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1600.9493630915008`, -2463.342259451538}, 0.04950662595486266, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.8998564655458`, -2463.3670127645155`}, \
{1600.9493630915008`, -2463.342259451538}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2465.177801034779}, {
        121.22236071036099`, -2465.177801034779}, {
        121.22236071036099`, -2463.3670127645155`}, {
        100, -2463.3670127645155`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2465.177801034779}, {
       804.9406253727807, -2465.177801034779}, {
       804.9406253727807, -2463.3670127645155`}, {
       604.1772733885804, -2463.3670127645155`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2465.177801034779}, {
       1262.6540473922569`, -2465.177801034779}, {
       1262.6540473922569`, -2463.3670127645155`}, {
       1194.3372692325136`, -2463.3670127645155`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -2465.177801034779}, {
       2204.9605275154536`, -2465.177801034779}, {
       2204.9605275154536`, -2463.3670127645155`}, {
       2044.9188341628594`, -2463.3670127645155`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2465.177801034779}, {
       2579.0031846135325`, -2465.177801034779}, {
       2579.0031846135325`, -2463.3670127645155`}, {
       2572.8513803695255`, -2463.3670127645155`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.8087893557854`, -2465.177801034779}, {
       3130.442879253866, -2465.177801034779}, {
       3130.442879253866, -2463.3670127645155`}, {
       3111.8087893557854`, -2463.3670127645155`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3372.2103165626827`, -2465.177801034779}, {
       3714.4172940181493`, -2465.177801034779}, {
       3714.4172940181493`, -2463.3670127645155`}, {
       3372.2103165626827`, -2463.3670127645155`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2465.177801034779}, {
       4141.493143543739, -2465.177801034779}, {
       4141.493143543739, -2463.3670127645155`}, {
       4097.925250945028, -2463.3670127645155`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2465.177801034779}, {
       4700.000000000001, -2465.177801034779}, {
       4700.000000000001, -2463.3670127645155`}, {
       4563.5036002306615`, -2463.3670127645155`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1599.2561053991365`, -2465.177801034779}, {
      1600.9493630915008`, -2465.177801034779}, {
      1600.9493630915008`, -2463.3670127645155`}, {
      1599.2561053991365`, -2463.3670127645155`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2044.0134400277277`, -2463.819709832081}, \
{2044.9188341628594`, -2463.3670127645155`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2044.0134400277277`, -2463.819709832081}, 0.9053941351317578, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.8547572266325`, -2464.725103967213}, {
       2044.0134400277277`, -2464.725103967213}, {
       2044.0134400277277`, -2463.819709832081}, {
       1601.8547572266325`, -2463.819709832081}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.8547572266325`, -2464.725103967213}, 0.9053941351317578, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.9493630915008`, -2465.177801034779}, \
{1601.8547572266325`, -2464.725103967213}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2688.983607509631}, {
        121.22236071036099`, -2688.983607509631}, {
        121.22236071036099`, -2465.177801034779}, {
        100, -2465.177801034779}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2688.983607509631}, {
       693.0377221353546, -2688.983607509631}, {
       693.0377221353546, -2465.177801034779}, {
       604.1772733885804, -2465.177801034779}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2688.983607509631}, {
       1262.6540473922569`, -2688.983607509631}, {
       1262.6540473922569`, -2465.177801034779}, {
       1194.3372692325136`, -2465.177801034779}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2688.983607509631}, {
       1601.8547572266325`, -2688.983607509631}, {
       1601.8547572266325`, -2465.177801034779}, {
       1599.2561053991365`, -2465.177801034779}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -2688.983607509631}, {
       2204.9605275154536`, -2688.983607509631}, {
       2204.9605275154536`, -2465.177801034779}, {
       2044.9188341628594`, -2465.177801034779}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2688.983607509631}, {
       2579.0031846135325`, -2688.983607509631}, {
       2579.0031846135325`, -2465.177801034779}, {
       2572.8513803695255`, -2465.177801034779}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3111.8087893557854`, -2688.983607509631}, {
       3130.442879253866, -2688.983607509631}, {
       3130.442879253866, -2465.177801034779}, {
       3111.8087893557854`, -2465.177801034779}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2688.983607509631}, {
       4141.493143543739, -2688.983607509631}, {
       4141.493143543739, -2465.177801034779}, {
       4097.925250945028, -2465.177801034779}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2688.983607509631}, {
       4700.000000000001, -2688.983607509631}, {
       4700.000000000001, -2465.177801034779}, {
       4563.5036002306615`, -2465.177801034779}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3372.2103165626827`, -2688.983607509631}, {
      3714.4172940181493`, -2688.983607509631}, {
      3714.4172940181493`, -2465.177801034779}, {
      3372.2103165626827`, -2465.177801034779}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{693.0377221353546, -2521.1292526534917`}, \
{804.9406253727807, -2465.177801034779}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{804.9406253727807, -2521.1292526534917`}, 111.9029032374261, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{804.9406253727807, -2633.0321558909177`}, {
       3260.3074133252567`, -2633.0321558909177`}, {
       3260.3074133252567`, -2521.1292526534917`}, {
       804.9406253727807, -2521.1292526534917`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3260.3074133252567`, -2633.0321558909177`}, 
       111.9029032374261, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3260.3074133252567`, -2688.983607509631}, \
{3372.2103165626827`, -2633.0321558909177`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2711.5271181450325`}, {
        121.22236071036099`, -2711.5271181450325`}, {
        121.22236071036099`, -2688.983607509631}, {
        100, -2688.983607509631}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2711.5271181450325`}, {
       693.0377221353546, -2711.5271181450325`}, {
       693.0377221353546, -2688.983607509631}, {
       604.1772733885804, -2688.983607509631}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2711.5271181450325`}, {
       1262.6540473922569`, -2711.5271181450325`}, {
       1262.6540473922569`, -2688.983607509631}, {
       1194.3372692325136`, -2688.983607509631}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1599.2561053991365`, -2711.5271181450325`}, {
       1601.8547572266325`, -2711.5271181450325`}, {
       1601.8547572266325`, -2688.983607509631}, {
       1599.2561053991365`, -2688.983607509631}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2711.5271181450325`}, {
       2579.0031846135325`, -2711.5271181450325`}, {
       2579.0031846135325`, -2688.983607509631}, {
       2572.8513803695255`, -2688.983607509631}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -2711.5271181450325`}, {
       3130.442879253866, -2711.5271181450325`}, {
       3130.442879253866, -2688.983607509631}, {
       3123.080544673486, -2688.983607509631}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3260.3074133252567`, -2711.5271181450325`}, {
       3714.4172940181493`, -2711.5271181450325`}, {
       3714.4172940181493`, -2688.983607509631}, {
       3260.3074133252567`, -2688.983607509631}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2711.5271181450325`}, {
       4141.493143543739, -2711.5271181450325`}, {
       4141.493143543739, -2688.983607509631}, {
       4097.925250945028, -2688.983607509631}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2711.5271181450325`}, {
       4700.000000000001, -2711.5271181450325`}, {
       4700.000000000001, -2688.983607509631}, {
       4563.5036002306615`, -2688.983607509631}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.9188341628594`, -2711.5271181450325`}, {
      2204.9605275154536`, -2711.5271181450325`}, {
      2204.9605275154536`, -2688.983607509631}, {
      2044.9188341628594`, -2688.983607509631}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3111.8087893557854`, -2694.6194851684813`}, \
{3123.080544673486, -2688.983607509631}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3111.8087893557854`, -2694.6194851684813`}, 
       11.271755317700816`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2216.2322828331544`, -2705.891240486182}, {
       3111.8087893557854`, -2705.891240486182}, {
       3111.8087893557854`, -2694.6194851684813`}, {
       2216.2322828331544`, -2694.6194851684813`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2216.2322828331544`, -2705.891240486182}, 11.271755317700816`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2204.9605275154536`, -2711.5271181450325`}, \
{2216.2322828331544`, -2705.891240486182}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2713.4694186189927`}, {
       693.0377221353546, -2713.4694186189927`}, {
       693.0377221353546, -2711.5271181450325`}, {
       604.1772733885804, -2711.5271181450325`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2713.4694186189927`}, {
       1262.6540473922569`, -2713.4694186189927`}, {
       1262.6540473922569`, -2711.5271181450325`}, {
       1194.3372692325136`, -2711.5271181450325`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -2713.4694186189927`}, {
       1601.8547572266325`, -2713.4694186189927`}, {
       1601.8547572266325`, -2711.5271181450325`}, {
       1600.2272556361165`, -2711.5271181450325`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -2713.4694186189927`}, {
       2216.2322828331544`, -2713.4694186189927`}, {
       2216.2322828331544`, -2711.5271181450325`}, {
       2044.9188341628594`, -2711.5271181450325`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.8513803695255`, -2713.4694186189927`}, {
       2579.0031846135325`, -2713.4694186189927`}, {
       2579.0031846135325`, -2711.5271181450325`}, {
       2572.8513803695255`, -2711.5271181450325`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -2713.4694186189927`}, {
       3130.442879253866, -2713.4694186189927`}, {
       3130.442879253866, -2711.5271181450325`}, {
       3123.080544673486, -2711.5271181450325`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3260.3074133252567`, -2713.4694186189927`}, {
       3714.4172940181493`, -2713.4694186189927`}, {
       3714.4172940181493`, -2711.5271181450325`}, {
       3260.3074133252567`, -2711.5271181450325`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2713.4694186189927`}, {
       4141.493143543739, -2713.4694186189927`}, {
       4141.493143543739, -2711.5271181450325`}, {
       4097.925250945028, -2711.5271181450325`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2713.4694186189927`}, {
       4700.000000000001, -2713.4694186189927`}, {
       4700.000000000001, -2711.5271181450325`}, {
       4563.5036002306615`, -2711.5271181450325`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -2713.4694186189927`}, {
       121.22236071036099`, -2713.4694186189927`}, {
       121.22236071036099`, -2711.5271181450325`}, {
       100, -2711.5271181450325`}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1599.2561053991365`, -2712.0126932635226`}, \
{1600.2272556361165`, -2711.5271181450325`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1599.2561053991365`, -2712.0126932635226`}, 0.9711502369800127,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{122.193510947341, -2712.9838435005026`}, {
       1599.2561053991365`, -2712.9838435005026`}, {
       1599.2561053991365`, -2712.0126932635226`}, {
       122.193510947341, -2712.0126932635226`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{122.193510947341, -2712.9838435005026`}, 0.9711502369800127, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{121.22236071036099`, -2713.4694186189927`}, \
{122.193510947341, -2712.9838435005026`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2714.2130940961674`}, {
        122.193510947341, -2714.2130940961674`}, {
        122.193510947341, -2713.4694186189927`}, {
        100, -2713.4694186189927`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2714.2130940961674`}, {
       693.0377221353546, -2714.2130940961674`}, {
       693.0377221353546, -2713.4694186189927`}, {
       604.1772733885804, -2713.4694186189927`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2714.2130940961674`}, {
       1262.6540473922569`, -2714.2130940961674`}, {
       1262.6540473922569`, -2713.4694186189927`}, {
       1194.3372692325136`, -2713.4694186189927`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -2714.2130940961674`}, {
       1601.4829194880454`, -2714.2130940961674`}, {
       1601.4829194880454`, -2713.4694186189927`}, {
       1600.2272556361165`, -2713.4694186189927`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -2714.2130940961674`}, {
       2216.2322828331544`, -2714.2130940961674`}, {
       2216.2322828331544`, -2713.4694186189927`}, {
       2044.9188341628594`, -2713.4694186189927`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -2714.2130940961674`}, {
       3130.442879253866, -2714.2130940961674`}, {
       3130.442879253866, -2713.4694186189927`}, {
       3123.080544673486, -2713.4694186189927`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3260.3074133252567`, -2714.2130940961674`}, {
       3714.4172940181493`, -2714.2130940961674`}, {
       3714.4172940181493`, -2713.4694186189927`}, {
       3260.3074133252567`, -2713.4694186189927`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2714.2130940961674`}, {
       4141.493143543739, -2714.2130940961674`}, {
       4141.493143543739, -2713.4694186189927`}, {
       4097.925250945028, -2713.4694186189927`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4563.5036002306615`, -2714.2130940961674`}, {
       4700.000000000001, -2714.2130940961674`}, {
       4700.000000000001, -2713.4694186189927`}, {
       4563.5036002306615`, -2713.4694186189927`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2572.8513803695255`, -2714.2130940961674`}, {
      2579.0031846135325`, -2714.2130940961674`}, {
      2579.0031846135325`, -2713.4694186189927`}, {
      2572.8513803695255`, -2713.4694186189927`}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.4829194880454`, -2713.6553374882865`}, \
{1601.8547572266325`, -2713.4694186189927`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.8547572266325`, -2713.6553374882865`}, 
       0.37183773858730085`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.8547572266325`, -2714.0271752268736`}, {
       2572.4795426309383`, -2714.0271752268736`}, {
       2572.4795426309383`, -2713.6553374882865`}, {
       1601.8547572266325`, -2713.6553374882865`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2572.4795426309383`, -2714.0271752268736`}, 
       0.37183773858730085`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2572.4795426309383`, -2714.2130940961674`}, \
{2572.8513803695255`, -2714.0271752268736`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -2972.0498253593014`}, {
        122.193510947341, -2972.0498253593014`}, {
        122.193510947341, -2714.2130940961674`}, {
        100, -2714.2130940961674`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -2972.0498253593014`}, {
       693.0377221353546, -2972.0498253593014`}, {
       693.0377221353546, -2714.2130940961674`}, {
       604.1772733885804, -2714.2130940961674`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -2972.0498253593014`}, {
       1262.6540473922569`, -2972.0498253593014`}, {
       1262.6540473922569`, -2714.2130940961674`}, {
       1194.3372692325136`, -2714.2130940961674`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -2972.0498253593014`}, {
       1601.4829194880454`, -2972.0498253593014`}, {
       1601.4829194880454`, -2714.2130940961674`}, {
       1600.2272556361165`, -2714.2130940961674`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.4795426309383`, -2972.0498253593014`}, {
       2579.0031846135325`, -2972.0498253593014`}, {
       2579.0031846135325`, -2714.2130940961674`}, {
       2572.4795426309383`, -2714.2130940961674`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -2972.0498253593014`}, {
       3130.442879253866, -2972.0498253593014`}, {
       3130.442879253866, -2714.2130940961674`}, {
       3123.080544673486, -2714.2130940961674`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3260.3074133252567`, -2972.0498253593014`}, {
       3714.4172940181493`, -2972.0498253593014`}, {
       3714.4172940181493`, -2714.2130940961674`}, {
       3260.3074133252567`, -2714.2130940961674`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -2972.0498253593014`}, {
       4141.493143543739, -2972.0498253593014`}, {
       4141.493143543739, -2714.2130940961674`}, {
       4097.925250945028, -2714.2130940961674`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4692.421965862229, -2972.0498253593014`}, {
       4700.000000000001, -2972.0498253593014`}, {
       4700.000000000001, -2714.2130940961674`}, {
       4692.421965862229, -2714.2130940961674`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.9188341628594`, -2972.0498253593014`}, {
      2216.2322828331544`, -2972.0498253593014`}, {
      2216.2322828331544`, -2714.2130940961674`}, {
      2044.9188341628594`, -2714.2130940961674`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4563.5036002306615`, -2778.672276911951}, \
{4692.421965862229, -2714.2130940961674`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4563.5036002306615`, -2778.672276911951}, 128.91836563156699`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2345.150648464721, -2907.590642543518}, {
       4563.5036002306615`, -2907.590642543518}, {
       4563.5036002306615`, -2778.672276911951}, {
       2345.150648464721, -2778.672276911951}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2345.150648464721, -2907.590642543518}, 128.91836563156699`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2216.2322828331544`, -2972.0498253593014`}, \
{2345.150648464721, -2907.590642543518}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3042.9556190737203`}, {
        122.193510947341, -3042.9556190737203`}, {
        122.193510947341, -2972.0498253593014`}, {
        100, -2972.0498253593014`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3042.9556190737203`}, {
       693.0377221353546, -3042.9556190737203`}, {
       693.0377221353546, -2972.0498253593014`}, {
       604.1772733885804, -2972.0498253593014`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3042.9556190737203`}, {
       1601.4829194880454`, -3042.9556190737203`}, {
       1601.4829194880454`, -2972.0498253593014`}, {
       1600.2272556361165`, -2972.0498253593014`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3042.9556190737203`}, {
       2345.150648464721, -3042.9556190737203`}, {
       2345.150648464721, -2972.0498253593014`}, {
       2044.9188341628594`, -2972.0498253593014`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2572.4795426309383`, -3042.9556190737203`}, {
       2579.0031846135325`, -3042.9556190737203`}, {
       2579.0031846135325`, -2972.0498253593014`}, {
       2572.4795426309383`, -2972.0498253593014`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3042.9556190737203`}, {
       3130.442879253866, -3042.9556190737203`}, {
       3130.442879253866, -2972.0498253593014`}, {
       3123.080544673486, -2972.0498253593014`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3295.760310182466, -3042.9556190737203`}, {
       3714.4172940181493`, -3042.9556190737203`}, {
       3714.4172940181493`, -2972.0498253593014`}, {
       3295.760310182466, -2972.0498253593014`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3042.9556190737203`}, {
       4141.493143543739, -3042.9556190737203`}, {
       4141.493143543739, -2972.0498253593014`}, {
       4097.925250945028, -2972.0498253593014`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4692.421965862229, -3042.9556190737203`}, {
       4700.000000000001, -3042.9556190737203`}, {
       4700.000000000001, -2972.0498253593014`}, {
       4692.421965862229, -2972.0498253593014`}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1194.3372692325136`, -3042.9556190737203`}, {
      1262.6540473922569`, -3042.9556190737203`}, {
      1262.6540473922569`, -2972.0498253593014`}, {
      1194.3372692325136`, -2972.0498253593014`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3260.3074133252567`, -2989.776273787906}, \
{3295.760310182466, -2972.0498253593014`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3260.3074133252567`, -2989.776273787906}, 35.45289685720954, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1298.1069442494663`, -3025.2291706451156`}, {
       3260.3074133252567`, -3025.2291706451156`}, {
       3260.3074133252567`, -2989.776273787906}, {
       1298.1069442494663`, -2989.776273787906}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1298.1069442494663`, -3025.2291706451156`}, 35.45289685720954, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1262.6540473922569`, -3042.9556190737203`}, \
{1298.1069442494663`, -3025.2291706451156`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3046.6687267520538`}, {
        122.193510947341, -3046.6687267520538`}, {
        122.193510947341, -3042.9556190737203`}, {
        100, -3042.9556190737203`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3046.6687267520538`}, {
       693.0377221353546, -3046.6687267520538`}, {
       693.0377221353546, -3042.9556190737203`}, {
       604.1772733885804, -3042.9556190737203`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3046.6687267520538`}, {
       1298.1069442494663`, -3046.6687267520538`}, {
       1298.1069442494663`, -3042.9556190737203`}, {
       1194.3372692325136`, -3042.9556190737203`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3046.6687267520538`}, {
       1601.4829194880454`, -3046.6687267520538`}, {
       1601.4829194880454`, -3042.9556190737203`}, {
       1600.2272556361165`, -3042.9556190737203`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3046.6687267520538`}, {
       2343.2940946255544`, -3046.6687267520538`}, {
       2343.2940946255544`, -3042.9556190737203`}, {
       2044.9188341628594`, -3042.9556190737203`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3046.6687267520538`}, {
       3130.442879253866, -3046.6687267520538`}, {
       3130.442879253866, -3042.9556190737203`}, {
       3123.080544673486, -3042.9556190737203`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3295.760310182466, -3046.6687267520538`}, {
       3714.4172940181493`, -3046.6687267520538`}, {
       3714.4172940181493`, -3042.9556190737203`}, {
       3295.760310182466, -3042.9556190737203`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3046.6687267520538`}, {
       4141.493143543739, -3046.6687267520538`}, {
       4141.493143543739, -3042.9556190737203`}, {
       4097.925250945028, -3042.9556190737203`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4692.421965862229, -3046.6687267520538`}, {
       4700.000000000001, -3046.6687267520538`}, {
       4700.000000000001, -3042.9556190737203`}, {
       4692.421965862229, -3042.9556190737203`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2572.4795426309383`, -3046.6687267520538`}, {
      2579.0031846135325`, -3046.6687267520538`}, {
      2579.0031846135325`, -3042.9556190737203`}, {
      2572.4795426309383`, -3042.9556190737203`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2343.2940946255544`, -3043.8838959933037`}, \
{2345.150648464721, -3042.9556190737203`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2345.150648464721, -3043.8838959933037`}, 1.8565538391666756`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2345.150648464721, -3045.7404498324704`}, {
       2570.6229887917716`, -3045.7404498324704`}, {
       2570.6229887917716`, -3043.8838959933037`}, {
       2345.150648464721, -3043.8838959933037`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2570.6229887917716`, -3045.7404498324704`}, 
       1.8565538391666756`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2570.6229887917716`, -3046.6687267520538`}, \
{2572.4795426309383`, -3045.7404498324704`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3057.1275423217185`}, {
        122.193510947341, -3057.1275423217185`}, {
        122.193510947341, -3046.6687267520538`}, {
        100, -3046.6687267520538`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3057.1275423217185`}, {
       693.0377221353546, -3057.1275423217185`}, {
       693.0377221353546, -3046.6687267520538`}, {
       604.1772733885804, -3046.6687267520538`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3057.1275423217185`}, {
       1298.1069442494663`, -3057.1275423217185`}, {
       1298.1069442494663`, -3046.6687267520538`}, {
       1194.3372692325136`, -3046.6687267520538`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3057.1275423217185`}, {
       1601.4829194880454`, -3057.1275423217185`}, {
       1601.4829194880454`, -3046.6687267520538`}, {
       1600.2272556361165`, -3046.6687267520538`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3057.1275423217185`}, {
       2343.2940946255544`, -3057.1275423217185`}, {
       2343.2940946255544`, -3046.6687267520538`}, {
       2044.9188341628594`, -3046.6687267520538`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3057.1275423217185`}, {
       2579.0031846135325`, -3057.1275423217185`}, {
       2579.0031846135325`, -3046.6687267520538`}, {
       2570.6229887917716`, -3046.6687267520538`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3295.760310182466, -3057.1275423217185`}, {
       3714.4172940181493`, -3057.1275423217185`}, {
       3714.4172940181493`, -3046.6687267520538`}, {
       3295.760310182466, -3046.6687267520538`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3057.1275423217185`}, {
       4141.493143543739, -3057.1275423217185`}, {
       4141.493143543739, -3046.6687267520538`}, {
       4097.925250945028, -3046.6687267520538`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4697.6513736470615`, -3057.1275423217185`}, {
       4700.000000000002, -3057.1275423217185`}, {
       4700.000000000002, -3046.6687267520538`}, {
       4697.6513736470615`, -3046.6687267520538`}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3123.080544673486, -3057.1275423217185`}, {
      3130.442879253866, -3057.1275423217185`}, {
      3130.442879253866, -3046.6687267520538`}, {
      3123.080544673486, -3046.6687267520538`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4692.421965862229, -3049.2834306444697`}, \
{4697.6513736470615`, -3046.6687267520538`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4692.421965862229, -3049.2834306444697`}, 5.229407784832423, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3135.6722870386984`, -3054.512838429302}, {
       4692.421965862229, -3054.512838429302}, {
       4692.421965862229, -3049.2834306444697`}, {
       3135.6722870386984`, -3049.2834306444697`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3135.6722870386984`, -3054.512838429302}, 5.229407784832423, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3130.442879253866, -3057.1275423217185`}, \
{3135.6722870386984`, -3054.512838429302}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3158.825963187583}, {
        122.193510947341, -3158.825963187583}, {
        122.193510947341, -3057.1275423217185`}, {
        100, -3057.1275423217185`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3158.825963187583}, {
       1298.1069442494663`, -3158.825963187583}, {
       1298.1069442494663`, -3057.1275423217185`}, {
       1194.3372692325136`, -3057.1275423217185`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3158.825963187583}, {
       1601.4829194880454`, -3158.825963187583}, {
       1601.4829194880454`, -3057.1275423217185`}, {
       1600.2272556361165`, -3057.1275423217185`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3158.825963187583}, {
       2343.2940946255544`, -3158.825963187583}, {
       2343.2940946255544`, -3057.1275423217185`}, {
       2044.9188341628594`, -3057.1275423217185`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3158.825963187583}, {
       2579.0031846135325`, -3158.825963187583}, {
       2579.0031846135325`, -3057.1275423217185`}, {
       2570.6229887917716`, -3057.1275423217185`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3158.825963187583}, {
       3135.6722870386984`, -3158.825963187583}, {
       3135.6722870386984`, -3057.1275423217185`}, {
       3123.080544673486, -3057.1275423217185`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3346.609520615398, -3158.825963187583}, {
       3714.4172940181493`, -3158.825963187583}, {
       3714.4172940181493`, -3057.1275423217185`}, {
       3346.609520615398, -3057.1275423217185`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3158.825963187583}, {
       4141.493143543739, -3158.825963187583}, {
       4141.493143543739, -3057.1275423217185`}, {
       4097.925250945028, -3057.1275423217185`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4697.6513736470615`, -3158.825963187583}, {
       4700.000000000002, -3158.825963187583}, {
       4700.000000000002, -3057.1275423217185`}, {
       4697.6513736470615`, -3057.1275423217185`}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -3158.825963187583}, {
      693.0377221353546, -3158.825963187583}, {
      693.0377221353546, -3057.1275423217185`}, {
      604.1772733885804, -3057.1275423217185`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3295.760310182466, -3082.5521475381847`}, \
{3346.609520615398, -3057.1275423217185`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3295.760310182466, -3082.5521475381847`}, 50.84921043293221, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{743.8869325682867, -3133.401357971117}, {
       3295.760310182466, -3133.401357971117}, {
       3295.760310182466, -3082.5521475381847`}, {
       743.8869325682867, -3082.5521475381847`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{743.8869325682867, -3133.401357971117}, 50.84921043293221, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{693.0377221353546, -3158.825963187583}, \
{743.8869325682867, -3133.401357971117}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3162.945065286028}, {
        122.193510947341, -3162.945065286028}, {
        122.193510947341, -3158.825963187583}, {100, -3158.825963187583}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3162.945065286028}, {
       743.8869325682867, -3162.945065286028}, {
       743.8869325682867, -3158.825963187583}, {
       604.1772733885804, -3158.825963187583}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3162.945065286028}, {
       1298.1069442494663`, -3162.945065286028}, {
       1298.1069442494663`, -3158.825963187583}, {
       1194.3372692325136`, -3158.825963187583}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3162.945065286028}, {
       1601.4829194880454`, -3162.945065286028}, {
       1601.4829194880454`, -3158.825963187583}, {
       1600.2272556361165`, -3158.825963187583}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3162.945065286028}, {
       2579.0031846135325`, -3162.945065286028}, {
       2579.0031846135325`, -3158.825963187583}, {
       2570.6229887917716`, -3158.825963187583}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3162.945065286028}, {
       3135.6722870386984`, -3162.945065286028}, {
       3135.6722870386984`, -3158.825963187583}, {
       3123.080544673486, -3158.825963187583}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3346.609520615398, -3162.945065286028}, {
       3714.4172940181493`, -3162.945065286028}, {
       3714.4172940181493`, -3158.825963187583}, {
       3346.609520615398, -3158.825963187583}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3162.945065286028}, {
       4141.493143543739, -3162.945065286028}, {
       4141.493143543739, -3158.825963187583}, {
       4097.925250945028, -3158.825963187583}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.710924696284, -3162.945065286028}, {
       4700.000000000001, -3162.945065286028}, {
       4700.000000000001, -3158.825963187583}, {
       4699.710924696284, -3158.825963187583}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.9188341628594`, -3162.945065286028}, {
      2343.2940946255544`, -3162.945065286028}, {
      2343.2940946255544`, -3158.825963187583}, {
      2044.9188341628594`, -3158.825963187583}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4697.6513736470615`, -3159.855738712194}, \
{4699.710924696284, -3158.825963187583}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4697.6513736470615`, -3159.855738712194}, 2.0595510492224305`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2345.353645674777, -3161.9152897614167`}, {
       4697.6513736470615`, -3161.9152897614167`}, {
       4697.6513736470615`, -3159.855738712194}, {
       2345.353645674777, -3159.855738712194}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2345.353645674777, -3161.9152897614167`}, 2.0595510492224305`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2343.2940946255544`, -3162.945065286028}, \
{2345.353645674777, -3161.9152897614167`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3163.0605957897387`}, {
        122.193510947341, -3163.0605957897387`}, {
        122.193510947341, -3162.945065286028}, {100, -3162.945065286028}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3163.0605957897387`}, {
       743.8869325682867, -3163.0605957897387`}, {
       743.8869325682867, -3162.945065286028}, {
       604.1772733885804, -3162.945065286028}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3163.0605957897387`}, {
       1298.1069442494663`, -3163.0605957897387`}, {
       1298.1069442494663`, -3162.945065286028}, {
       1194.3372692325136`, -3162.945065286028}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3163.0605957897387`}, {
       1601.4829194880454`, -3163.0605957897387`}, {
       1601.4829194880454`, -3162.945065286028}, {
       1600.2272556361165`, -3162.945065286028}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3163.0605957897387`}, {
       2345.2958804229215`, -3163.0605957897387`}, {
       2345.2958804229215`, -3162.945065286028}, {
       2044.9188341628594`, -3162.945065286028}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3163.0605957897387`}, {
       2579.0031846135325`, -3163.0605957897387`}, {
       2579.0031846135325`, -3162.945065286028}, {
       2570.6229887917716`, -3162.945065286028}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3163.0605957897387`}, {
       3135.6722870386984`, -3163.0605957897387`}, {
       3135.6722870386984`, -3162.945065286028}, {
       3123.080544673486, -3162.945065286028}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3346.609520615398, -3163.0605957897387`}, {
       3714.4172940181493`, -3163.0605957897387`}, {
       3714.4172940181493`, -3162.945065286028}, {
       3346.609520615398, -3162.945065286028}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3163.0605957897387`}, {
       4141.493143543739, -3163.0605957897387`}, {
       4141.493143543739, -3162.945065286028}, {
       4097.925250945028, -3162.945065286028}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.710924696284, -3163.0605957897387`}, {
      4700.000000000001, -3163.0605957897387`}, {
      4700.000000000001, -3162.945065286028}, {
      4699.710924696284, -3162.945065286028}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2345.2958804229215`, -3162.9739479119553`}, \
{2345.353645674777, -3162.945065286028}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2345.353645674777, -3162.9739479119553`}, 
       0.057765251855517064`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2345.353645674777, -3163.0317131638108`}, {
       4699.653159444428, -3163.0317131638108`}, {
       4699.653159444428, -3162.9739479119553`}, {
       2345.353645674777, -3162.9739479119553`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.653159444428, -3163.0317131638108`}, 
       0.057765251855517064`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.653159444428, -3163.0605957897387`}, \
{4699.710924696284, -3163.0317131638108`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3172.009610006205}, {
        122.193510947341, -3172.009610006205}, {
        122.193510947341, -3163.0605957897387`}, {
        100, -3163.0605957897387`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3172.009610006205}, {
       743.8869325682867, -3172.009610006205}, {
       743.8869325682867, -3163.0605957897387`}, {
       604.1772733885804, -3163.0605957897387`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3172.009610006205}, {
       1298.1069442494663`, -3172.009610006205}, {
       1298.1069442494663`, -3163.0605957897387`}, {
       1194.3372692325136`, -3163.0605957897387`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3172.009610006205}, {
       1601.4829194880454`, -3172.009610006205}, {
       1601.4829194880454`, -3163.0605957897387`}, {
       1600.2272556361165`, -3163.0605957897387`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3172.009610006205}, {
       2345.2958804229215`, -3172.009610006205}, {
       2345.2958804229215`, -3163.0605957897387`}, {
       2044.9188341628594`, -3163.0605957897387`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3172.009610006205}, {
       3135.6722870386984`, -3172.009610006205}, {
       3135.6722870386984`, -3163.0605957897387`}, {
       3123.080544673486, -3163.0605957897387`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3351.0840277236316`, -3172.009610006205}, {
       3714.4172940181493`, -3172.009610006205}, {
       3714.4172940181493`, -3163.0605957897387`}, {
       3351.0840277236316`, -3163.0605957897387`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3172.009610006205}, {
       4141.493143543739, -3172.009610006205}, {
       4141.493143543739, -3163.0605957897387`}, {
       4097.925250945028, -3163.0605957897387`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.653159444428, -3172.009610006205}, {
       4700.000000000001, -3172.009610006205}, {
       4700.000000000001, -3163.0605957897387`}, {
       4699.653159444428, -3163.0605957897387`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2570.6229887917716`, -3172.009610006205}, {
      2579.0031846135325`, -3172.009610006205}, {
      2579.0031846135325`, -3163.0605957897387`}, {
      2570.6229887917716`, -3163.0605957897387`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3346.609520615398, -3165.2978493438554`}, \
{3351.0840277236316`, -3163.0605957897387`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3346.609520615398, -3165.2978493438554`}, 4.474507108233189, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2583.477691721766, -3169.7723564520884`}, {
       3346.609520615398, -3169.7723564520884`}, {
       3346.609520615398, -3165.2978493438554`}, {
       2583.477691721766, -3165.2978493438554`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2583.477691721766, -3169.7723564520884`}, 4.474507108233189, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2579.0031846135325`, -3172.009610006205}, \
{2583.477691721766, -3169.7723564520884`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3193.785363903332}, {
        111.30563399877767`, -3193.785363903332}, {
        111.30563399877767`, -3172.009610006205}, {
        100, -3172.009610006205}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3193.785363903332}, {
       743.8869325682867, -3193.785363903332}, {
       743.8869325682867, -3172.009610006205}, {
       604.1772733885804, -3172.009610006205}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3193.785363903332}, {
       1298.1069442494663`, -3193.785363903332}, {
       1298.1069442494663`, -3172.009610006205}, {
       1194.3372692325136`, -3172.009610006205}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3193.785363903332}, {
       1601.4829194880454`, -3193.785363903332}, {
       1601.4829194880454`, -3172.009610006205}, {
       1600.2272556361165`, -3172.009610006205}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3193.785363903332}, {
       2345.2958804229215`, -3193.785363903332}, {
       2345.2958804229215`, -3172.009610006205}, {
       2044.9188341628594`, -3172.009610006205}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3193.785363903332}, {
       2583.477691721766, -3193.785363903332}, {
       2583.477691721766, -3172.009610006205}, {
       2570.6229887917716`, -3172.009610006205}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3193.785363903332}, {
       3135.6722870386984`, -3193.785363903332}, {
       3135.6722870386984`, -3172.009610006205}, {
       3123.080544673486, -3172.009610006205}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3193.785363903332}, {
       4141.493143543739, -3193.785363903332}, {
       4141.493143543739, -3172.009610006205}, {
       4097.925250945028, -3172.009610006205}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.653159444428, -3193.785363903332}, {
       4700.000000000001, -3193.785363903332}, {
       4700.000000000001, -3172.009610006205}, {
       4699.653159444428, -3172.009610006205}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3351.0840277236316`, -3193.785363903332}, {
      3714.4172940181497`, -3193.785363903332}, {
      3714.4172940181497`, -3172.009610006205}, {
      3351.0840277236316`, -3172.009610006205}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{111.30563399877767`, -3177.453548480487}, \
{122.193510947341, -3172.009610006205}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{122.193510947341, -3177.453548480487}, 10.887876948563342`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{122.193510947341, -3188.34142542905}, {
       3340.1961507750684`, -3188.34142542905}, {
       3340.1961507750684`, -3177.453548480487}, {
       122.193510947341, -3177.453548480487}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3340.1961507750684`, -3188.34142542905}, 10.887876948563342`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3340.1961507750684`, -3193.785363903332}, \
{3351.0840277236316`, -3188.34142542905}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3194.094632491546}, {
        111.15099970467064`, -3194.094632491546}, {
        111.15099970467064`, -3193.785363903332}, {
        100, -3193.785363903332}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3194.094632491546}, {
       743.8869325682867, -3194.094632491546}, {
       743.8869325682867, -3193.785363903332}, {
       604.1772733885804, -3193.785363903332}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3194.094632491546}, {
       1298.1069442494663`, -3194.094632491546}, {
       1298.1069442494663`, -3193.785363903332}, {
       1194.3372692325136`, -3193.785363903332}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3194.094632491546}, {
       1601.4829194880454`, -3194.094632491546}, {
       1601.4829194880454`, -3193.785363903332}, {
       1600.2272556361165`, -3193.785363903332}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3194.094632491546}, {
       2345.2958804229215`, -3194.094632491546}, {
       2345.2958804229215`, -3193.785363903332}, {
       2044.9188341628594`, -3193.785363903332}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3194.094632491546}, {
       2583.477691721766, -3194.094632491546}, {
       2583.477691721766, -3193.785363903332}, {
       2570.6229887917716`, -3193.785363903332}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3194.094632491546}, {
       3135.6722870386984`, -3194.094632491546}, {
       3135.6722870386984`, -3193.785363903332}, {
       3123.080544673486, -3193.785363903332}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3340.1961507750684`, -3194.094632491546}, {
       3714.4172940181497`, -3194.094632491546}, {
       3714.4172940181497`, -3193.785363903332}, {
       3340.1961507750684`, -3193.785363903332}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4097.925250945028, -3194.094632491546}, {
       4141.493143543739, -3194.094632491546}, {
       4141.493143543739, -3193.785363903332}, {
       4097.925250945028, -3193.785363903332}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.653159444428, -3194.094632491546}, {
      4700., -3194.094632491546}, {4700., -3193.785363903332}, {
      4699.653159444428, -3193.785363903332}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{111.15099970467064`, -3193.862681050385}, \
{111.30563399877767`, -3193.785363903332}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{111.30563399877767`, -3193.862681050385}, 0.15463429410701923`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{111.30563399877767`, -3194.017315344492}, {
       4699.49852515032, -3194.017315344492}, {
       4699.49852515032, -3193.862681050385}, {
       111.30563399877767`, -3193.862681050385}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.49852515032, -3194.017315344492}, 0.15463429410701923`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.49852515032, -3194.094632491546}, \
{4699.653159444428, -3194.017315344492}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3196.3407008363783`}, {
       743.8869325682867, -3196.3407008363783`}, {
       743.8869325682867, -3194.094632491546}, {
       604.1772733885804, -3194.094632491546}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3196.3407008363783`}, {
       1298.1069442494663`, -3196.3407008363783`}, {
       1298.1069442494663`, -3194.094632491546}, {
       1194.3372692325136`, -3194.094632491546}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3196.3407008363783`}, {
       1601.4829194880454`, -3196.3407008363783`}, {
       1601.4829194880454`, -3194.094632491546}, {
       1600.2272556361165`, -3194.094632491546}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3196.3407008363783`}, {
       2345.2958804229215`, -3196.3407008363783`}, {
       2345.2958804229215`, -3194.094632491546}, {
       2044.9188341628594`, -3194.094632491546}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3196.3407008363783`}, {
       2583.477691721766, -3196.3407008363783`}, {
       2583.477691721766, -3194.094632491546}, {
       2570.6229887917716`, -3194.094632491546}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3196.3407008363783`}, {
       3135.6722870386984`, -3196.3407008363783`}, {
       3135.6722870386984`, -3194.094632491546}, {
       3123.080544673486, -3194.094632491546}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3340.1961507750684`, -3196.3407008363783`}, {
       3714.4172940181497`, -3196.3407008363783`}, {
       3714.4172940181497`, -3194.094632491546}, {
       3340.1961507750684`, -3194.094632491546}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4099.048285117444, -3196.3407008363783`}, {
       4141.493143543739, -3196.3407008363783`}, {
       4141.493143543739, -3194.094632491546}, {
       4099.048285117444, -3194.094632491546}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.49852515032, -3196.3407008363783`}, {
       4700., -3196.3407008363783`}, {4700., -3194.094632491546}, {
       4699.49852515032, -3194.094632491546}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -3196.3407008363783`}, {
       111.15099970467064`, -3196.3407008363783`}, {
       111.15099970467064`, -3194.094632491546}, {
       100, -3194.094632491546}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4097.925250945028, -3194.656149577754}, \
{4099.048285117444, -3194.094632491546}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4097.925250945028, -3194.656149577754}, 1.1230341724162098`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{112.27403387708685`, -3195.7791837501704`}, {
       4097.925250945028, -3195.7791837501704`}, {
       4097.925250945028, -3194.656149577754}, {
       112.27403387708685`, -3194.656149577754}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{112.27403387708685`, -3195.7791837501704`}, 
       1.1230341724162098`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{111.15099970467064`, -3196.3407008363783`}, 
       {112.27403387708685`, -3195.7791837501704`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3208.95354217854}, {
        112.27403387708685`, -3208.95354217854}, {
        112.27403387708685`, -3196.3407008363783`}, {
        100, -3196.3407008363783`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3208.95354217854}, {
       743.8869325682867, -3208.95354217854}, {
       743.8869325682867, -3196.3407008363783`}, {
       604.1772733885804, -3196.3407008363783`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3208.95354217854}, {
       1298.1069442494663`, -3208.95354217854}, {
       1298.1069442494663`, -3196.3407008363783`}, {
       1194.3372692325136`, -3196.3407008363783`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3208.95354217854}, {
       1601.4829194880454`, -3208.95354217854}, {
       1601.4829194880454`, -3196.3407008363783`}, {
       1600.2272556361165`, -3196.3407008363783`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3208.95354217854}, {
       2345.2958804229215`, -3208.95354217854}, {
       2345.2958804229215`, -3196.3407008363783`}, {
       2044.9188341628594`, -3196.3407008363783`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3208.95354217854}, {
       3135.6722870386984`, -3208.95354217854}, {
       3135.6722870386984`, -3196.3407008363783`}, {
       3123.080544673486, -3196.3407008363783`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3340.1961507750684`, -3208.95354217854}, {
       3714.4172940181497`, -3208.95354217854}, {
       3714.4172940181497`, -3196.3407008363783`}, {
       3340.1961507750684`, -3196.3407008363783`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.354705788524, -3208.95354217854}, {
       4141.493143543739, -3208.95354217854}, {
       4141.493143543739, -3196.3407008363783`}, {
       4105.354705788524, -3196.3407008363783`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.49852515032, -3208.95354217854}, {
       4700., -3208.95354217854}, {4700., -3196.3407008363783`}, {
       4699.49852515032, -3196.3407008363783`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2570.6229887917716`, -3208.95354217854}, {
      2583.477691721766, -3208.95354217854}, {
      2583.477691721766, -3196.3407008363783`}, {
      2570.6229887917716`, -3196.3407008363783`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4099.048285117444, -3199.4939111719186`}, \
{4105.354705788524, -3196.3407008363783`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4099.048285117444, -3199.4939111719186`}, 6.306420671080762, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2589.7841123928465`, -3205.8003318429996`}, {
       4099.048285117444, -3205.8003318429996`}, {
       4099.048285117444, -3199.4939111719186`}, {
       2589.7841123928465`, -3199.4939111719186`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2589.7841123928465`, -3205.8003318429996`}, 6.306420671080762, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.477691721766, -3208.95354217854}, \
{2589.7841123928465`, -3205.8003318429996`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3209.989304186924}, {
        112.27403387708685`, -3209.989304186924}, {
        112.27403387708685`, -3208.95354217854}, {
        100, -3208.95354217854}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3209.989304186924}, {
       743.8869325682867, -3209.989304186924}, {
       743.8869325682867, -3208.95354217854}, {
       604.1772733885804, -3208.95354217854}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3209.989304186924}, {
       1298.1069442494663`, -3209.989304186924}, {
       1298.1069442494663`, -3208.95354217854}, {
       1194.3372692325136`, -3208.95354217854}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3209.989304186924}, {
       2345.2958804229215`, -3209.989304186924}, {
       2345.2958804229215`, -3208.95354217854}, {
       2044.9188341628594`, -3208.95354217854}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3209.989304186924}, {
       2589.7841123928465`, -3209.989304186924}, {
       2589.7841123928465`, -3208.95354217854}, {
       2570.6229887917716`, -3208.95354217854}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3123.080544673486, -3209.989304186924}, {
       3135.6722870386984`, -3209.989304186924}, {
       3135.6722870386984`, -3208.95354217854}, {
       3123.080544673486, -3208.95354217854}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3340.1961507750684`, -3209.989304186924}, {
       3714.4172940181497`, -3209.989304186924}, {
       3714.4172940181497`, -3208.95354217854}, {
       3340.1961507750684`, -3208.95354217854}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3209.989304186924}, {
       4141.493143543738, -3209.989304186924}, {
       4141.493143543738, -3208.95354217854}, {
       4105.872586792716, -3208.95354217854}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.49852515032, -3209.989304186924}, {
       4700., -3209.989304186924}, {4700., -3208.95354217854}, {
       4699.49852515032, -3208.95354217854}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1600.2272556361165`, -3209.989304186924}, {
      1601.4829194880454`, -3209.989304186924}, {
      1601.4829194880454`, -3208.95354217854}, {
      1600.2272556361165`, -3208.95354217854}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4105.354705788524, -3209.212482680636}, \
{4105.872586792716, -3208.95354217854}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4105.354705788524, -3209.212482680636}, 0.5178810041920152, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1602.0008004922372`, -3209.7303636848283`}, {
       4105.354705788524, -3209.7303636848283`}, {
       4105.354705788524, -3209.212482680636}, {
       1602.0008004922372`, -3209.212482680636}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1602.0008004922372`, -3209.7303636848283`}, 0.5178810041920152,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.4829194880454`, -3209.989304186924}, \
{1602.0008004922372`, -3209.7303636848283`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3229.267329197281}, {
        112.27403387708685`, -3229.267329197281}, {
        112.27403387708685`, -3209.989304186924}, {
        100, -3209.989304186924}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3229.267329197281}, {
       743.8869325682867, -3229.267329197281}, {
       743.8869325682867, -3209.989304186924}, {
       604.1772733885804, -3209.989304186924}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3229.267329197281}, {
       1298.1069442494663`, -3229.267329197281}, {
       1298.1069442494663`, -3209.989304186924}, {
       1194.3372692325136`, -3209.989304186924}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3229.267329197281}, {
       1602.0008004922372`, -3229.267329197281}, {
       1602.0008004922372`, -3209.989304186924}, {
       1600.2272556361165`, -3209.989304186924}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3229.267329197281}, {
       2589.7841123928465`, -3229.267329197281}, {
       2589.7841123928465`, -3209.989304186924}, {
       2570.6229887917716`, -3209.989304186924}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7195571786647`, -3229.267329197281}, {
       3135.6722870386984`, -3229.267329197281}, {
       3135.6722870386984`, -3209.989304186924}, {
       3132.7195571786647`, -3209.989304186924}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3340.1961507750684`, -3229.267329197281}, {
       3714.4172940181497`, -3229.267329197281}, {
       3714.4172940181497`, -3209.989304186924}, {
       3340.1961507750684`, -3209.989304186924}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3229.267329197281}, {
       4141.493143543738, -3229.267329197281}, {
       4141.493143543738, -3209.989304186924}, {
       4105.872586792716, -3209.989304186924}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.49852515032, -3229.267329197281}, {
       4700., -3229.267329197281}, {4700., -3209.989304186924}, {
       4699.49852515032, -3209.989304186924}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.9188341628594`, -3229.267329197281}, {
      2345.2958804229215`, -3229.267329197281}, {
      2345.2958804229215`, -3209.989304186924}, {
      2044.9188341628594`, -3209.989304186924}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3123.080544673486, -3214.8088104395133`}, \
{3132.7195571786647`, -3209.989304186924}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3123.080544673486, -3214.8088104395133`}, 9.639012505178572, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2354.9348929281, -3224.447822944692}, {
       3123.080544673486, -3224.447822944692}, {
       3123.080544673486, -3214.8088104395133`}, {
       2354.9348929281, -3214.8088104395133`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2354.9348929281, -3224.447822944692}, 9.639012505178572, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2345.2958804229215`, -3229.267329197281}, \
{2354.9348929281, -3224.447822944692}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3263.8508825352646`}, {
        112.27403387708685`, -3263.8508825352646`}, {
        112.27403387708685`, -3229.267329197281}, {
        100, -3229.267329197281}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3263.8508825352646`}, {
       743.8869325682867, -3263.8508825352646`}, {
       743.8869325682867, -3229.267329197281}, {
       604.1772733885804, -3229.267329197281}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3263.8508825352646`}, {
       1280.8151675804745`, -3263.8508825352646`}, {
       1280.8151675804745`, -3229.267329197281}, {
       1194.3372692325136`, -3229.267329197281}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3263.8508825352646`}, {
       1602.0008004922372`, -3263.8508825352646`}, {
       1602.0008004922372`, -3229.267329197281}, {
       1600.2272556361165`, -3229.267329197281}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3263.8508825352646`}, {
       2354.9348929281, -3263.8508825352646`}, {
       2354.9348929281, -3229.267329197281}, {
       2044.9188341628594`, -3229.267329197281}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3263.8508825352646`}, {
       2589.7841123928465`, -3263.8508825352646`}, {
       2589.7841123928465`, -3229.267329197281}, {
       2570.6229887917716`, -3229.267329197281}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7195571786647`, -3263.8508825352646`}, {
       3135.6722870386984`, -3263.8508825352646`}, {
       3135.6722870386984`, -3229.267329197281}, {
       3132.7195571786647`, -3229.267329197281}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3263.8508825352646`}, {
       4141.493143543738, -3263.8508825352646`}, {
       4141.493143543738, -3229.267329197281}, {
       4105.872586792716, -3229.267329197281}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.49852515032, -3263.8508825352646`}, {
       4700., -3263.8508825352646`}, {4700., -3229.267329197281}, {
       4699.49852515032, -3229.267329197281}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3340.1961507750684`, -3263.8508825352646`}, {
      3714.4172940181493`, -3263.8508825352646`}, {
      3714.4172940181493`, -3229.267329197281}, {
      3340.1961507750684`, -3229.267329197281}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1280.8151675804745`, -3237.913217531777}, \
{1298.1069442494663`, -3229.267329197281}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1298.1069442494663`, -3237.913217531777}, 17.291776668991886`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1298.1069442494663`, -3255.204994200769}, {
       3322.9043741060764`, -3255.204994200769}, {
       3322.9043741060764`, -3237.913217531777}, {
       1298.1069442494663`, -3237.913217531777}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3322.9043741060764`, -3255.204994200769}, 
       17.291776668991886`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3322.9043741060764`, -3263.8508825352646`}, \
{3340.1961507750684`, -3255.204994200769}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3264.4218997182315`}, {
        112.27403387708685`, -3264.4218997182315`}, {
        112.27403387708685`, -3263.8508825352646`}, {
        100, -3263.8508825352646`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3264.4218997182315`}, {
       743.8869325682867, -3264.4218997182315`}, {
       743.8869325682867, -3263.8508825352646`}, {
       604.1772733885804, -3263.8508825352646`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3264.4218997182315`}, {
       1280.8151675804745`, -3264.4218997182315`}, {
       1280.8151675804745`, -3263.8508825352646`}, {
       1194.3372692325136`, -3263.8508825352646`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3264.4218997182315`}, {
       1602.0008004922372`, -3264.4218997182315`}, {
       1602.0008004922372`, -3263.8508825352646`}, {
       1600.2272556361165`, -3263.8508825352646`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3264.4218997182315`}, {
       2354.9348929281, -3264.4218997182315`}, {
       2354.9348929281, -3263.8508825352646`}, {
       2044.9188341628594`, -3263.8508825352646`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3264.4218997182315`}, {
       2589.498603801363, -3264.4218997182315`}, {
       2589.498603801363, -3263.8508825352646`}, {
       2570.6229887917716`, -3263.8508825352646`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7195571786647`, -3264.4218997182315`}, {
       3135.6722870386984`, -3264.4218997182315`}, {
       3135.6722870386984`, -3263.8508825352646`}, {
       3132.7195571786647`, -3263.8508825352646`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.9043741060764`, -3264.4218997182315`}, {
       3714.4172940181493`, -3264.4218997182315`}, {
       3714.4172940181493`, -3263.8508825352646`}, {
       3322.9043741060764`, -3263.8508825352646`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3264.4218997182315`}, {
       4141.493143543738, -3264.4218997182315`}, {
       4141.493143543738, -3263.8508825352646`}, {
       4105.872586792716, -3263.8508825352646`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.49852515032, -3264.4218997182315`}, {
      4700.000000000001, -3264.4218997182315`}, {
      4700.000000000001, -3263.8508825352646`}, {
      4699.49852515032, -3263.8508825352646`}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2589.498603801363, -3263.9936368310064`}, \
{2589.7841123928465`, -3263.8508825352646`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2589.7841123928465`, -3263.9936368310064`}, 0.2855085914834573,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2589.7841123928465`, -3264.27914542249}, {
       4699.213016558837, -3264.27914542249}, {
       4699.213016558837, -3263.9936368310064`}, {
       2589.7841123928465`, -3263.9936368310064`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.213016558837, -3264.27914542249}, 0.2855085914834573, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.213016558837, -3264.4218997182315`}, \
{4699.49852515032, -3264.27914542249}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3267.855916129197}, {
       743.8869325682867, -3267.855916129197}, {
       743.8869325682867, -3264.4218997182315`}, {
       604.1772733885804, -3264.4218997182315`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3267.855916129197}, {
       1280.8151675804745`, -3267.855916129197}, {
       1280.8151675804745`, -3264.4218997182315`}, {
       1194.3372692325136`, -3264.4218997182315`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3267.855916129197}, {
       1602.0008004922372`, -3267.855916129197}, {
       1602.0008004922372`, -3264.4218997182315`}, {
       1600.2272556361165`, -3264.4218997182315`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3267.855916129197}, {
       2354.9348929281, -3267.855916129197}, {
       2354.9348929281, -3264.4218997182315`}, {
       2044.9188341628594`, -3264.4218997182315`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3267.855916129197}, {
       2589.498603801363, -3267.855916129197}, {
       2589.498603801363, -3264.4218997182315`}, {
       2570.6229887917716`, -3264.4218997182315`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4365653841473`, -3267.855916129197}, {
       3135.6722870386984`, -3267.855916129197}, {
       3135.6722870386984`, -3264.4218997182315`}, {
       3134.4365653841473`, -3264.4218997182315`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.9043741060764`, -3267.855916129197}, {
       3714.4172940181493`, -3267.855916129197}, {
       3714.4172940181493`, -3264.4218997182315`}, {
       3322.9043741060764`, -3264.4218997182315`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3267.855916129197}, {
       4141.493143543738, -3267.855916129197}, {
       4141.493143543738, -3264.4218997182315`}, {
       4105.872586792716, -3264.4218997182315`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.213016558837, -3267.855916129197}, {
       4700.000000000001, -3267.855916129197}, {
       4700.000000000001, -3264.4218997182315`}, {
       4699.213016558837, -3264.4218997182315`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -3267.855916129197}, {
       112.27403387708685`, -3267.855916129197}, {
       112.27403387708685`, -3264.4218997182315`}, {
       100, -3264.4218997182315`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3132.7195571786647`, -3265.280403820973}, \
{3134.4365653841473`, -3264.4218997182315`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3132.7195571786647`, -3265.280403820973}, 1.7170082054826823`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.99104208256954`, -3266.9974120264555`}, {
       3132.7195571786647`, -3266.9974120264555`}, {
       3132.7195571786647`, -3265.280403820973}, {
       113.99104208256954`, -3265.280403820973}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.99104208256954`, -3266.9974120264555`}, 
       1.7170082054826823`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{112.27403387708685`, -3267.855916129197}, \
{113.99104208256954`, -3266.9974120264555`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3268.9803191643177`}, {
        113.99104208256954`, -3268.9803191643177`}, {
        113.99104208256954`, -3267.855916129197}, {
        100, -3267.855916129197}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3268.9803191643177`}, {
       743.8869325682867, -3268.9803191643177`}, {
       743.8869325682867, -3267.855916129197}, {
       604.1772733885804, -3267.855916129197}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3268.9803191643177`}, {
       1280.8151675804745`, -3268.9803191643177`}, {
       1280.8151675804745`, -3267.855916129197}, {
       1194.3372692325136`, -3267.855916129197}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3268.9803191643177`}, {
       1601.4385989746768`, -3268.9803191643177`}, {
       1601.4385989746768`, -3267.855916129197}, {
       1600.2272556361165`, -3267.855916129197}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3268.9803191643177`}, {
       2354.9348929281, -3268.9803191643177`}, {
       2354.9348929281, -3267.855916129197}, {
       2044.9188341628594`, -3267.855916129197}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3268.9803191643177`}, {
       2589.498603801363, -3268.9803191643177`}, {
       2589.498603801363, -3267.855916129197}, {
       2570.6229887917716`, -3267.855916129197}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4365653841473`, -3268.9803191643177`}, {
       3135.6722870386984`, -3268.9803191643177`}, {
       3135.6722870386984`, -3267.855916129197}, {
       3134.4365653841473`, -3267.855916129197}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3268.9803191643177`}, {
       4141.493143543738, -3268.9803191643177`}, {
       4141.493143543738, -3267.855916129197}, {
       4105.872586792716, -3267.855916129197}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.213016558837, -3268.9803191643177`}, {
       4700.000000000001, -3268.9803191643177`}, {
       4700.000000000001, -3267.855916129197}, {
       4699.213016558837, -3267.855916129197}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3322.9043741060764`, -3268.9803191643177`}, {
      3714.4172940181493`, -3268.9803191643177`}, {
      3714.4172940181493`, -3267.855916129197}, {
      3322.9043741060764`, -3267.855916129197}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.4385989746768`, -3268.137016887977}, \
{1602.0008004922372`, -3267.855916129197}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1602.0008004922372`, -3268.137016887977}, 0.5622015175604256, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1602.0008004922372`, -3268.6992184055375`}, {
       3322.342172588516, -3268.6992184055375`}, {
       3322.342172588516, -3268.137016887977}, {
       1602.0008004922372`, -3268.137016887977}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3322.342172588516, -3268.6992184055375`}, 0.5622015175604256, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3322.342172588516, -3268.9803191643177`}, \
{3322.9043741060764`, -3268.6992184055375`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3269.0854379308107`}, {
       743.8869325682867, -3269.0854379308107`}, {
       743.8869325682867, -3268.9803191643177`}, {
       604.1772733885804, -3268.9803191643177`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3269.0854379308107`}, {
       1280.8151675804745`, -3269.0854379308107`}, {
       1280.8151675804745`, -3268.9803191643177`}, {
       1194.3372692325136`, -3268.9803191643177`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3269.0854379308107`}, {
       1601.4385989746768`, -3269.0854379308107`}, {
       1601.4385989746768`, -3268.9803191643177`}, {
       1600.2272556361165`, -3268.9803191643177`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3269.0854379308107`}, {
       2354.9348929281, -3269.0854379308107`}, {
       2354.9348929281, -3268.9803191643177`}, {
       2044.9188341628594`, -3268.9803191643177`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3269.0854379308107`}, {
       2589.498603801363, -3269.0854379308107`}, {
       2589.498603801363, -3268.9803191643177`}, {
       2570.6229887917716`, -3268.9803191643177`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3269.0854379308107`}, {
       3135.6722870386984`, -3269.0854379308107`}, {
       3135.6722870386984`, -3268.9803191643177`}, {
       3134.4891247673936`, -3268.9803191643177`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.342172588516, -3269.0854379308107`}, {
       3714.4172940181493`, -3269.0854379308107`}, {
       3714.4172940181493`, -3268.9803191643177`}, {
       3322.342172588516, -3268.9803191643177`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3269.0854379308107`}, {
       4141.493143543738, -3269.0854379308107`}, {
       4141.493143543738, -3268.9803191643177`}, {
       4105.872586792716, -3268.9803191643177`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.213016558837, -3269.0854379308107`}, {
       4700.000000000001, -3269.0854379308107`}, {
       4700.000000000001, -3268.9803191643177`}, {
       4699.213016558837, -3268.9803191643177`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -3269.0854379308107`}, {
       113.99104208256954`, -3269.0854379308107`}, {
       113.99104208256954`, -3268.9803191643177`}, {
       100, -3268.9803191643177`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3134.4365653841473`, -3269.006598855941}, \
{3134.4891247673936`, -3268.9803191643177`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3134.4365653841473`, -3269.006598855941}, 
       0.052559383246466584`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{114.043601465816, -3269.0591582391876`}, {
       3134.4365653841473`, -3269.0591582391876`}, {
       3134.4365653841473`, -3269.006598855941}, {
       114.043601465816, -3269.006598855941}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{114.043601465816, -3269.0591582391876`}, 0.052559383246466584`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{113.99104208256954`, -3269.0854379308107`}, \
{114.043601465816, -3269.0591582391876`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3269.6428609006193`}, {
        114.043601465816, -3269.6428609006193`}, {
        114.043601465816, -3269.0854379308107`}, {
        100, -3269.0854379308107`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3269.6428609006193`}, {
       743.8869325682867, -3269.6428609006193`}, {
       743.8869325682867, -3269.0854379308107`}, {
       604.1772733885804, -3269.0854379308107`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3269.6428609006193`}, {
       1280.8151675804745`, -3269.6428609006193`}, {
       1280.8151675804745`, -3269.0854379308107`}, {
       1194.3372692325136`, -3269.0854379308107`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3269.6428609006193`}, {
       1601.4385989746768`, -3269.6428609006193`}, {
       1601.4385989746768`, -3269.0854379308107`}, {
       1600.2272556361165`, -3269.0854379308107`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3269.6428609006193`}, {
       2354.9348929281, -3269.6428609006193`}, {
       2354.9348929281, -3269.0854379308107`}, {
       2044.9188341628594`, -3269.0854379308107`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3269.6428609006193`}, {
       2589.498603801363, -3269.6428609006193`}, {
       2589.498603801363, -3269.0854379308107`}, {
       2570.6229887917716`, -3269.0854379308107`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3269.6428609006193`}, {
       3135.6722870386984`, -3269.6428609006193`}, {
       3135.6722870386984`, -3269.0854379308107`}, {
       3134.4891247673936`, -3269.0854379308107`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.342172588516, -3269.6428609006193`}, {
       3714.4172940181493`, -3269.6428609006193`}, {
       3714.4172940181493`, -3269.0854379308107`}, {
       3322.342172588516, -3269.0854379308107`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.491728043741, -3269.6428609006193`}, {
       4700.000000000001, -3269.6428609006193`}, {
       4700.000000000001, -3269.0854379308107`}, {
       4699.491728043741, -3269.0854379308107`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4105.872586792716, -3269.6428609006193`}, {
      4141.493143543738, -3269.6428609006193`}, {
      4141.493143543738, -3269.0854379308107`}, {
      4105.872586792716, -3269.0854379308107`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.213016558837, -3269.224793673263}, \
{4699.491728043741, -3269.0854379308107`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.213016558837, -3269.224793673263}, 0.27871148490421305`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4141.771855028643, -3269.503505158167}, {
       4699.213016558837, -3269.503505158167}, {
       4699.213016558837, -3269.224793673263}, {
       4141.771855028643, -3269.224793673263}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4141.771855028643, -3269.503505158167}, 0.27871148490421305`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4141.493143543738, -3269.6428609006193`}, \
{4141.771855028643, -3269.503505158167}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3270.2350982753314`}, {
        114.043601465816, -3270.2350982753314`}, {
        114.043601465816, -3269.6428609006193`}, {
        100, -3269.6428609006193`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3270.2350982753314`}, {
       743.5908138809307, -3270.2350982753314`}, {
       743.5908138809307, -3269.6428609006193`}, {
       604.1772733885804, -3269.6428609006193`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3270.2350982753314`}, {
       1280.8151675804745`, -3270.2350982753314`}, {
       1280.8151675804745`, -3269.6428609006193`}, {
       1194.3372692325136`, -3269.6428609006193`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3270.2350982753314`}, {
       1601.4385989746768`, -3270.2350982753314`}, {
       1601.4385989746768`, -3269.6428609006193`}, {
       1600.2272556361165`, -3269.6428609006193`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3270.2350982753314`}, {
       2354.9348929281, -3270.2350982753314`}, {
       2354.9348929281, -3269.6428609006193`}, {
       2044.9188341628594`, -3269.6428609006193`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3270.2350982753314`}, {
       2589.498603801363, -3270.2350982753314`}, {
       2589.498603801363, -3269.6428609006193`}, {
       2570.6229887917716`, -3269.6428609006193`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3270.2350982753314`}, {
       3135.6722870386984`, -3270.2350982753314`}, {
       3135.6722870386984`, -3269.6428609006193`}, {
       3134.4891247673936`, -3269.6428609006193`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.342172588516, -3270.2350982753314`}, {
       3714.4172940181493`, -3270.2350982753314`}, {
       3714.4172940181493`, -3269.6428609006193`}, {
       3322.342172588516, -3269.6428609006193`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3270.2350982753314`}, {
       4141.771855028643, -3270.2350982753314`}, {
       4141.771855028643, -3269.6428609006193`}, {
       4105.872586792716, -3269.6428609006193`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.491728043741, -3270.2350982753314`}, {
      4700., -3270.2350982753314`}, {4700., -3269.6428609006193`}, {
      4699.491728043741, -3269.6428609006193`}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{743.5908138809307, -3269.7909202442975`}, \
{743.8869325682867, -3269.6428609006193`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{743.8869325682867, -3269.7909202442975`}, 0.2961186873560555, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{743.8869325682867, -3270.0870389316533`}, {
       4699.195609356385, -3270.0870389316533`}, {
       4699.195609356385, -3269.7909202442975`}, {
       743.8869325682867, -3269.7909202442975`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.195609356385, -3270.0870389316533`}, 0.2961186873560555, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.195609356385, -3270.2350982753314`}, \
{4699.491728043741, -3270.0870389316533`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3270.9738961351}, {
        114.043601465816, -3270.9738961351}, {
        114.043601465816, -3270.2350982753314`}, {
        100, -3270.2350982753314`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3270.9738961351}, {
       743.5908138809307, -3270.9738961351}, {
       743.5908138809307, -3270.2350982753314`}, {
       604.1772733885804, -3270.2350982753314`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3270.9738961351}, {
       1280.8151675804745`, -3270.9738961351}, {
       1280.8151675804745`, -3270.2350982753314`}, {
       1194.3372692325136`, -3270.2350982753314`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3270.9738961351}, {
       1601.4385989746768`, -3270.9738961351}, {
       1601.4385989746768`, -3270.2350982753314`}, {
       1600.2272556361165`, -3270.2350982753314`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3270.9738961351}, {
       2354.565493998216, -3270.9738961351}, {
       2354.565493998216, -3270.2350982753314`}, {
       2044.9188341628594`, -3270.2350982753314`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3270.9738961351}, {
       2589.498603801363, -3270.9738961351}, {
       2589.498603801363, -3270.2350982753314`}, {
       2570.6229887917716`, -3270.2350982753314`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3270.9738961351}, {
       3135.6722870386984`, -3270.9738961351}, {
       3135.6722870386984`, -3270.2350982753314`}, {
       3134.4891247673936`, -3270.2350982753314`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3322.342172588516, -3270.9738961351}, {
       3714.4172940181493`, -3270.9738961351}, {
       3714.4172940181493`, -3270.2350982753314`}, {
       3322.342172588516, -3270.2350982753314`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3270.9738961351}, {
       4141.771855028643, -3270.9738961351}, {
       4141.771855028643, -3270.2350982753314`}, {
       4105.872586792716, -3270.2350982753314`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.195609356385, -3270.9738961351}, {
      4700., -3270.9738961351}, {4700., -3270.2350982753314`}, {
      4699.195609356385, -3270.2350982753314`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2354.565493998216, -3270.4197977402737`}, \
{2354.9348929281, -3270.2350982753314`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2354.9348929281, -3270.4197977402737`}, 0.3693989298842639, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2354.9348929281, -3270.7891966701577`}, {
       4698.8262104265, -3270.7891966701577`}, {
       4698.8262104265, -3270.4197977402737`}, {
       2354.9348929281, -3270.4197977402737`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4698.8262104265, -3270.7891966701577`}, 0.3693989298842639, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4698.8262104265, -3270.9738961351}, \
{4699.195609356385, -3270.7891966701577`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3283.442912509853}, {
        114.043601465816, -3283.442912509853}, {
        114.043601465816, -3270.9738961351}, {100, -3270.9738961351}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3283.442912509853}, {
       743.5908138809307, -3283.442912509853}, {
       743.5908138809307, -3270.9738961351}, {
       604.1772733885804, -3270.9738961351}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3283.442912509853}, {
       1280.8151675804745`, -3283.442912509853}, {
       1280.8151675804745`, -3270.9738961351}, {
       1194.3372692325136`, -3270.9738961351}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3283.442912509853}, {
       1601.4385989746768`, -3283.442912509853}, {
       1601.4385989746768`, -3270.9738961351}, {
       1600.2272556361165`, -3270.9738961351}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2044.9188341628594`, -3283.442912509853}, {
       2354.565493998216, -3283.442912509853}, {
       2354.565493998216, -3270.9738961351}, {
       2044.9188341628594`, -3270.9738961351}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3283.442912509853}, {
       2583.2640956139862`, -3283.442912509853}, {
       2583.2640956139862`, -3270.9738961351}, {
       2570.6229887917716`, -3270.9738961351}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3283.442912509853}, {
       3135.6722870386984`, -3283.442912509853}, {
       3135.6722870386984`, -3270.9738961351}, {
       3134.4891247673936`, -3270.9738961351}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3283.442912509853}, {
       4141.771855028643, -3283.442912509853}, {
       4141.771855028643, -3270.9738961351}, {
       4105.872586792716, -3270.9738961351}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.8262104265, -3283.442912509853}, {
       4700., -3283.442912509853}, {4700., -3270.9738961351}, {
       4698.8262104265, -3270.9738961351}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3322.342172588516, -3283.442912509853}, {
      3714.4172940181493`, -3283.442912509853}, {
      3714.4172940181493`, -3270.9738961351}, {
      3322.342172588516, -3270.9738961351}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.2640956139862`, -3274.091150228788}, \
{2589.498603801363, -3270.9738961351}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2589.498603801363, -3274.091150228788}, 6.234508187376704, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2589.498603801363, -3280.325658416165}, {
       3316.107664401139, -3280.325658416165}, {
       3316.107664401139, -3274.091150228788}, {
       2589.498603801363, -3274.091150228788}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3316.107664401139, -3280.325658416165}, 6.234508187376704, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3316.107664401139, -3283.442912509853}, \
{3322.342172588516, -3280.325658416165}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3288.771110290719}, {
        111.37950257538292`, -3288.771110290719}, {
        111.37950257538292`, -3283.442912509853}, {
        100, -3283.442912509853}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3288.771110290719}, {
       743.5908138809307, -3288.771110290719}, {
       743.5908138809307, -3283.442912509853}, {
       604.1772733885804, -3283.442912509853}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3288.771110290719}, {
       1280.8151675804745`, -3288.771110290719}, {
       1280.8151675804745`, -3283.442912509853}, {
       1194.3372692325136`, -3283.442912509853}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3288.771110290719}, {
       1601.4385989746768`, -3288.771110290719}, {
       1601.4385989746768`, -3283.442912509853}, {
       1600.2272556361165`, -3283.442912509853}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3288.771110290719}, {
       2583.2640956139862`, -3288.771110290719}, {
       2583.2640956139862`, -3283.442912509853}, {
       2570.6229887917716`, -3283.442912509853}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3288.771110290719}, {
       3135.6722870386984`, -3288.771110290719}, {
       3135.6722870386984`, -3283.442912509853}, {
       3134.4891247673936`, -3283.442912509853}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3316.107664401139, -3288.771110290719}, {
       3714.4172940181493`, -3288.771110290719}, {
       3714.4172940181493`, -3283.442912509853}, {
       3316.107664401139, -3283.442912509853}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3288.771110290719}, {
       4141.771855028643, -3288.771110290719}, {
       4141.771855028643, -3283.442912509853}, {
       4105.872586792716, -3283.442912509853}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.8262104265, -3288.771110290719}, {
       4700., -3288.771110290719}, {4700., -3283.442912509853}, {
       4698.8262104265, -3283.442912509853}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2044.9188341628594`, -3288.771110290719}, {
      2354.565493998216, -3288.771110290719}, {
      2354.565493998216, -3283.442912509853}, {
      2044.9188341628594`, -3283.442912509853}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{111.37950257538292`, -3284.7749619550696`}, \
{114.043601465816, -3283.442912509853}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{114.043601465816, -3284.7749619550696`}, 2.664098890433083, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{114.043601465816, -3287.439060845503}, {
       2042.2547352724264`, -3287.439060845503}, {
       2042.2547352724264`, -3284.7749619550696`}, {
       114.043601465816, -3284.7749619550696`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2042.2547352724264`, -3287.439060845503}, 2.664098890433083, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2042.2547352724264`, -3288.771110290719}, \
{2044.9188341628594`, -3287.439060845503}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3460.3183006267677`}, {
        111.37950257538292`, -3460.3183006267677`}, {
        111.37950257538292`, -3288.771110290719}, {
        100, -3288.771110290719}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3460.3183006267677`}, {
       1280.8151675804745`, -3460.3183006267677`}, {
       1280.8151675804745`, -3288.771110290719}, {
       1194.3372692325136`, -3288.771110290719}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3460.3183006267677`}, {
       1601.4385989746768`, -3460.3183006267677`}, {
       1601.4385989746768`, -3288.771110290719}, {
       1600.2272556361165`, -3288.771110290719}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2042.2547352724264`, -3460.3183006267677`}, {
       2354.565493998216, -3460.3183006267677`}, {
       2354.565493998216, -3288.771110290719}, {
       2042.2547352724264`, -3288.771110290719}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3460.3183006267677`}, {
       2583.2640956139862`, -3460.3183006267677`}, {
       2583.2640956139862`, -3288.771110290719}, {
       2570.6229887917716`, -3288.771110290719}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3460.3183006267677`}, {
       3135.6722870386984`, -3460.3183006267677`}, {
       3135.6722870386984`, -3288.771110290719}, {
       3134.4891247673936`, -3288.771110290719}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3460.3183006267677`}, {
       3714.4172940181493`, -3460.3183006267677`}, {
       3714.4172940181493`, -3288.771110290719}, {
       3401.8812595691634`, -3288.771110290719}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4105.872586792716, -3460.3183006267677`}, {
       4141.771855028643, -3460.3183006267677`}, {
       4141.771855028643, -3288.771110290719}, {
       4105.872586792716, -3288.771110290719}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.8262104265, -3460.3183006267677`}, {
       4700., -3460.3183006267677`}, {4700., -3288.771110290719}, {
       4698.8262104265, -3288.771110290719}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -3460.3183006267677`}, {
      743.5908138809307, -3460.3183006267677`}, {
      743.5908138809307, -3288.771110290719}, {
      604.1772733885804, -3288.771110290719}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3316.107664401139, -3331.6579078747313`}, \
{3401.8812595691634`, -3288.771110290719}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3316.107664401139, -3331.6579078747313`}, 85.77359516802434, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{829.364409048955, -3417.4315030427556`}, {
       3316.107664401139, -3417.4315030427556`}, {
       3316.107664401139, -3331.6579078747313`}, {
       829.364409048955, -3331.6579078747313`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{829.364409048955, -3417.4315030427556`}, 85.77359516802434, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{743.5908138809307, -3460.3183006267677`}, \
{829.364409048955, -3417.4315030427556`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3470.9514232083275`}, {
        111.37950257538292`, -3470.9514232083275`}, {
        111.37950257538292`, -3460.3183006267673`}, {
        100, -3460.3183006267673`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3470.9514232083275`}, {
       829.364409048955, -3470.9514232083275`}, {
       829.364409048955, -3460.3183006267673`}, {
       604.1772733885804, -3460.3183006267673`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3470.9514232083275`}, {
       1280.8151675804745`, -3470.9514232083275`}, {
       1280.8151675804745`, -3460.3183006267673`}, {
       1194.3372692325136`, -3460.3183006267673`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3470.9514232083275`}, {
       1601.4385989746768`, -3470.9514232083275`}, {
       1601.4385989746768`, -3460.3183006267673`}, {
       1600.2272556361165`, -3460.3183006267673`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2042.2547352724264`, -3470.9514232083275`}, {
       2354.565493998216, -3470.9514232083275`}, {
       2354.565493998216, -3460.3183006267673`}, {
       2042.2547352724264`, -3460.3183006267673`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3470.9514232083275`}, {
       2583.2640956139862`, -3470.9514232083275`}, {
       2583.2640956139862`, -3460.3183006267673`}, {
       2570.6229887917716`, -3460.3183006267673`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3470.9514232083275`}, {
       3135.6722870386984`, -3470.9514232083275`}, {
       3135.6722870386984`, -3460.3183006267673`}, {
       3134.4891247673936`, -3460.3183006267673`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4111.189148083496, -3470.9514232083275`}, {
       4141.771855028643, -3470.9514232083275`}, {
       4141.771855028643, -3460.3183006267673`}, {
       4111.189148083496, -3460.3183006267673`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.8262104265, -3470.9514232083275`}, {
       4700., -3470.9514232083275`}, {4700., -3460.3183006267673`}, {
       4698.8262104265, -3460.3183006267673`}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3401.8812595691634`, -3470.9514232083275`}, {
      3714.4172940181493`, -3470.9514232083275`}, {
      3714.4172940181493`, -3460.3183006267673`}, {
      3401.8812595691634`, -3460.3183006267673`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4105.872586792716, -3462.9765812721575`}, \
{4111.189148083496, -3460.3183006267673`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4105.872586792716, -3462.9765812721575`}, 5.316561290779987, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3719.7338553089294`, -3468.2931425629376`}, {
       4105.872586792716, -3468.2931425629376`}, {
       4105.872586792716, -3462.9765812721575`}, {
       3719.7338553089294`, -3462.9765812721575`}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3719.7338553089294`, -3468.2931425629376`}, 5.316561290779987, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3714.4172940181493`, -3470.9514232083275`}, \
{3719.7338553089294`, -3468.2931425629376`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3471.269654294162}, {
        111.37950257538292`, -3471.269654294162}, {
        111.37950257538292`, -3470.9514232083275`}, {
        100, -3470.9514232083275`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3471.269654294162}, {
       829.364409048955, -3471.269654294162}, {
       829.364409048955, -3470.9514232083275`}, {
       604.1772733885804, -3470.9514232083275`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3471.269654294162}, {
       1280.8151675804745`, -3471.269654294162}, {
       1280.8151675804745`, -3470.9514232083275`}, {
       1194.3372692325136`, -3470.9514232083275`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2042.2547352724264`, -3471.269654294162}, {
       2354.565493998216, -3471.269654294162}, {
       2354.565493998216, -3470.9514232083275`}, {
       2042.2547352724264`, -3470.9514232083275`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3471.269654294162}, {
       2583.2640956139862`, -3471.269654294162}, {
       2583.2640956139862`, -3470.9514232083275`}, {
       2570.6229887917716`, -3470.9514232083275`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3471.269654294162}, {
       3135.6722870386984`, -3471.269654294162}, {
       3135.6722870386984`, -3470.9514232083275`}, {
       3134.4891247673936`, -3470.9514232083275`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3471.269654294162}, {
       3719.7338553089294`, -3471.269654294162}, {
       3719.7338553089294`, -3470.9514232083275`}, {
       3401.8812595691634`, -3470.9514232083275`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4111.189148083496, -3471.269654294162}, {
       4141.771855028643, -3471.269654294162}, {
       4141.771855028643, -3470.9514232083275`}, {
       4111.189148083496, -3470.9514232083275`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.985325969417, -3471.269654294162}, {
       4700., -3471.269654294162}, {4700., -3470.9514232083275`}, {
       4698.985325969417, -3470.9514232083275`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1600.2272556361165`, -3471.269654294162}, {
      1601.4385989746768`, -3471.269654294162}, {
      1601.4385989746768`, -3470.9514232083275`}, {
      1600.2272556361165`, -3470.9514232083275`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4698.8262104265, -3471.0309809797864`}, \
{4698.985325969417, -3470.9514232083275`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4698.8262104265, -3471.0309809797864`}, 0.15911554291728236`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.597714517594, -3471.1900965227037`}, {
       4698.8262104265, -3471.1900965227037`}, {
       4698.8262104265, -3471.0309809797864`}, {
       1601.597714517594, -3471.0309809797864`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.597714517594, -3471.1900965227037`}, 0.15911554291728236`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.4385989746768`, -3471.269654294162}, \
{1601.597714517594, -3471.1900965227037`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3472.85487588704}, {
        111.37950257538292`, -3472.85487588704}, {
        111.37950257538292`, -3471.269654294162}, {
        100, -3471.269654294162}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3472.85487588704}, {
       829.364409048955, -3472.85487588704}, {
       829.364409048955, -3471.269654294162}, {
       604.1772733885804, -3471.269654294162}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3472.85487588704}, {
       1280.8151675804745`, -3472.85487588704}, {
       1280.8151675804745`, -3471.269654294162}, {
       1194.3372692325136`, -3471.269654294162}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3472.85487588704}, {
       1600.805103721155, -3472.85487588704}, {
       1600.805103721155, -3471.269654294162}, {
       1600.2272556361165`, -3471.269654294162}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3472.85487588704}, {
       2583.2640956139862`, -3472.85487588704}, {
       2583.2640956139862`, -3471.269654294162}, {
       2570.6229887917716`, -3471.269654294162}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3472.85487588704}, {
       3135.6722870386984`, -3472.85487588704}, {
       3135.6722870386984`, -3471.269654294162}, {
       3134.4891247673936`, -3471.269654294162}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3472.85487588704}, {
       3719.7338553089294`, -3472.85487588704}, {
       3719.7338553089294`, -3471.269654294162}, {
       3401.8812595691634`, -3471.269654294162}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4111.189148083496, -3472.85487588704}, {
       4141.771855028643, -3472.85487588704}, {
       4141.771855028643, -3471.269654294162}, {
       4111.189148083496, -3471.269654294162}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.985325969417, -3472.85487588704}, {
       4700., -3472.85487588704}, {4700., -3471.269654294162}, {
       4698.985325969417, -3471.269654294162}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2042.2547352724264`, -3472.85487588704}, {
      2354.565493998216, -3472.85487588704}, {
      2354.565493998216, -3471.269654294162}, {
      2042.2547352724264`, -3471.269654294162}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.805103721155, -3471.6659596923814`}, \
{1601.597714517594, -3471.269654294162}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.597714517594, -3471.6659596923814`}, 0.7926107964391258, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.597714517594, -3472.4585704888204`}, {
       2041.4621244759874`, -3472.4585704888204`}, {
       2041.4621244759874`, -3471.6659596923814`}, {
       1601.597714517594, -3471.6659596923814`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2041.4621244759874`, -3472.4585704888204`}, 
       0.7926107964391258, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2041.4621244759874`, -3472.85487588704}, \
{2042.2547352724264`, -3472.4585704888204`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3521.2838424640854`}, {
        111.37950257538292`, -3521.2838424640854`}, {
        111.37950257538292`, -3472.85487588704}, {
        100, -3472.85487588704}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3521.2838424640854`}, {
       1280.8151675804745`, -3521.2838424640854`}, {
       1280.8151675804745`, -3472.85487588704}, {
       1194.3372692325136`, -3472.85487588704}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3521.2838424640854`}, {
       1600.805103721155, -3521.2838424640854`}, {
       1600.805103721155, -3472.85487588704}, {
       1600.2272556361165`, -3472.85487588704}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2041.4621244759874`, -3521.2838424640854`}, {
       2354.565493998216, -3521.2838424640854`}, {
       2354.565493998216, -3472.85487588704}, {
       2041.4621244759874`, -3472.85487588704}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3521.2838424640854`}, {
       2583.2640956139862`, -3521.2838424640854`}, {
       2583.2640956139862`, -3472.85487588704}, {
       2570.6229887917716`, -3472.85487588704}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3521.2838424640854`}, {
       3135.6722870386984`, -3521.2838424640854`}, {
       3135.6722870386984`, -3472.85487588704}, {
       3134.4891247673936`, -3472.85487588704}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3521.2838424640854`}, {
       3719.7338553089294`, -3521.2838424640854`}, {
       3719.7338553089294`, -3472.85487588704}, {
       3401.8812595691634`, -3472.85487588704}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3521.2838424640854`}, {
       4141.771855028642, -3521.2838424640854`}, {
       4141.771855028642, -3472.85487588704}, {
       4135.403631372018, -3472.85487588704}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.985325969417, -3521.2838424640854`}, {
       4700., -3521.2838424640854`}, {4700., -3472.85487588704}, {
       4698.985325969417, -3472.85487588704}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -3521.2838424640854`}, {
      829.364409048955, -3521.2838424640854`}, {
      829.364409048955, -3472.85487588704}, {
      604.1772733885804, -3472.85487588704}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4111.189148083496, -3484.9621175313014`}, \
{4135.403631372018, -3472.85487588704}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4111.189148083496, -3484.9621175313014`}, 24.214483288522608`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{853.5788923374777, -3509.176600819824}, {
       4111.189148083496, -3509.176600819824}, {
       4111.189148083496, -3484.9621175313014`}, {
       853.5788923374777, -3484.9621175313014`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{853.5788923374777, -3509.176600819824}, 24.214483288522608`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{829.364409048955, -3521.2838424640854`}, \
{853.5788923374777, -3509.176600819824}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3521.6153832277428`}, {
        111.37950257538292`, -3521.6153832277428`}, {
        111.37950257538292`, -3521.2838424640854`}, {
        100, -3521.2838424640854`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3521.6153832277428`}, {
       853.5788923374777, -3521.6153832277428`}, {
       853.5788923374777, -3521.2838424640854`}, {
       604.1772733885804, -3521.2838424640854`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1194.3372692325136`, -3521.6153832277428`}, {
       1280.8151675804745`, -3521.6153832277428`}, {
       1280.8151675804745`, -3521.2838424640854`}, {
       1194.3372692325136`, -3521.2838424640854`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3521.6153832277428`}, {
       1600.805103721155, -3521.6153832277428`}, {
       1600.805103721155, -3521.2838424640854`}, {
       1600.2272556361165`, -3521.2838424640854`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2041.4621244759874`, -3521.6153832277428`}, {
       2354.565493998216, -3521.6153832277428`}, {
       2354.565493998216, -3521.2838424640854`}, {
       2041.4621244759874`, -3521.2838424640854`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3521.6153832277428`}, {
       2583.0983252321575`, -3521.6153832277428`}, {
       2583.0983252321575`, -3521.2838424640854`}, {
       2570.6229887917716`, -3521.2838424640854`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3521.6153832277428`}, {
       3135.6722870386984`, -3521.6153832277428`}, {
       3135.6722870386984`, -3521.2838424640854`}, {
       3134.4891247673936`, -3521.2838424640854`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3521.6153832277428`}, {
       3719.7338553089294`, -3521.6153832277428`}, {
       3719.7338553089294`, -3521.2838424640854`}, {
       3401.8812595691634`, -3521.2838424640854`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3521.6153832277428`}, {
       4141.771855028642, -3521.6153832277428`}, {
       4141.771855028642, -3521.2838424640854`}, {
       4135.403631372018, -3521.2838424640854`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4698.985325969417, -3521.6153832277428`}, {
      4699.999999999999, -3521.6153832277428`}, {
      4699.999999999999, -3521.2838424640854`}, {
      4698.985325969417, -3521.2838424640854`}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.0983252321575`, -3521.3667276549995`}, \
{2583.2640956139862`, -3521.2838424640854`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2583.2640956139862`, -3521.3667276549995`}, 
       0.16577038182869597`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2583.2640956139862`, -3521.532498036828}, {
       4698.819555587588, -3521.532498036828}, {
       4698.819555587588, -3521.3667276549995`}, {
       2583.2640956139862`, -3521.3667276549995`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4698.819555587588, -3521.532498036828}, 0.16577038182869597`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4698.819555587588, -3521.6153832277428`}, \
{4698.985325969417, -3521.532498036828}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3527.4775855232533`}, {
       853.5788923374777, -3527.4775855232533`}, {
       853.5788923374777, -3521.6153832277428`}, {
       604.1772733885804, -3521.6153832277428`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -3527.4775855232533`}, {
       1280.8151675804745`, -3527.4775855232533`}, {
       1280.8151675804745`, -3521.6153832277428`}, {
       1197.2683703802688`, -3521.6153832277428`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.2272556361165`, -3527.4775855232533`}, {
       1600.805103721155, -3527.4775855232533`}, {
       1600.805103721155, -3521.6153832277428`}, {
       1600.2272556361165`, -3521.6153832277428`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2041.4621244759874`, -3527.4775855232533`}, {
       2354.565493998216, -3527.4775855232533`}, {
       2354.565493998216, -3521.6153832277428`}, {
       2041.4621244759874`, -3521.6153832277428`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3527.4775855232533`}, {
       2583.0983252321575`, -3527.4775855232533`}, {
       2583.0983252321575`, -3521.6153832277428`}, {
       2570.6229887917716`, -3521.6153832277428`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3527.4775855232533`}, {
       3135.6722870386984`, -3527.4775855232533`}, {
       3135.6722870386984`, -3521.6153832277428`}, {
       3134.4891247673936`, -3521.6153832277428`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3527.4775855232533`}, {
       3719.7338553089294`, -3527.4775855232533`}, {
       3719.7338553089294`, -3521.6153832277428`}, {
       3401.8812595691634`, -3521.6153832277428`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3527.4775855232533`}, {
       4141.771855028642, -3527.4775855232533`}, {
       4141.771855028642, -3521.6153832277428`}, {
       4135.403631372018, -3521.6153832277428`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.819555587588, -3527.4775855232533`}, {
       4699.999999999999, -3527.4775855232533`}, {
       4699.999999999999, -3521.6153832277428`}, {
       4698.819555587588, -3521.6153832277428`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -3527.4775855232533`}, {
       111.37950257538292`, -3527.4775855232533`}, {
       111.37950257538292`, -3521.6153832277428`}, {
       100, -3521.6153832277428`}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1194.3372692325136`, -3523.08093380162}, \
{1197.2683703802688`, -3521.6153832277428`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1194.3372692325136`, -3523.08093380162}, 2.931101147755353, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{114.31060372313827`, -3526.0120349493754`}, {
       1194.3372692325136`, -3526.0120349493754`}, {
       1194.3372692325136`, -3523.08093380162}, {
       114.31060372313827`, -3523.08093380162}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{114.31060372313827`, -3526.0120349493754`}, 2.931101147755353, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{111.37950257538292`, -3527.4775855232533`}, \
{114.31060372313827`, -3526.0120349493754`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3527.5847802906137`}, {
        114.31060372313827`, -3527.5847802906137`}, {
        114.31060372313827`, -3527.4775855232533`}, {
        100, -3527.4775855232533`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3527.5847802906137`}, {
       853.5788923374777, -3527.5847802906137`}, {
       853.5788923374777, -3527.4775855232533`}, {
       604.1772733885804, -3527.4775855232533`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -3527.5847802906137`}, {
       1280.7615701967943`, -3527.5847802906137`}, {
       1280.7615701967943`, -3527.4775855232533`}, {
       1197.2683703802688`, -3527.4775855232533`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2041.4621244759874`, -3527.5847802906137`}, {
       2354.565493998216, -3527.5847802906137`}, {
       2354.565493998216, -3527.4775855232533`}, {
       2041.4621244759874`, -3527.4775855232533`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3527.5847802906137`}, {
       2583.0983252321575`, -3527.5847802906137`}, {
       2583.0983252321575`, -3527.4775855232533`}, {
       2570.6229887917716`, -3527.4775855232533`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3527.5847802906137`}, {
       3135.6722870386984`, -3527.5847802906137`}, {
       3135.6722870386984`, -3527.4775855232533`}, {
       3134.4891247673936`, -3527.4775855232533`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3527.5847802906137`}, {
       3719.7338553089294`, -3527.5847802906137`}, {
       3719.7338553089294`, -3527.4775855232533`}, {
       3401.8812595691634`, -3527.4775855232533`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3527.5847802906137`}, {
       4141.771855028642, -3527.5847802906137`}, {
       4141.771855028642, -3527.4775855232533`}, {
       4135.403631372018, -3527.4775855232533`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.819555587588, -3527.5847802906137`}, {
       4699.999999999999, -3527.5847802906137`}, {
       4699.999999999999, -3527.4775855232533`}, {
       4698.819555587588, -3527.4775855232533`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1600.2272556361165`, -3527.5847802906137`}, {
      1600.805103721155, -3527.5847802906137`}, {
      1600.805103721155, -3527.4775855232533`}, {
      1600.2272556361165`, -3527.4775855232533`}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1280.7615701967943`, -3527.5043842150935`}, \
{1280.8151675804745`, -3527.4775855232533`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1280.8151675804745`, -3527.5043842150935`}, 0.0535973836801914,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1280.8151675804745`, -3527.5579815987735`}, {
       1600.1736582524363`, -3527.5579815987735`}, {
       1600.1736582524363`, -3527.5043842150935`}, {
       1280.8151675804745`, -3527.5043842150935`}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1600.1736582524363`, -3527.5579815987735`}, 
       0.0535973836801914, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.1736582524363`, -3527.5847802906137`}, \
{1600.2272556361165`, -3527.5579815987735`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3529.5905745611913`}, {
        113.30770658784944`, -3529.5905745611913`}, {
        113.30770658784944`, -3527.5847802906137`}, {
        100, -3527.5847802906137`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3529.5905745611913`}, {
       853.5788923374777, -3529.5905745611913`}, {
       853.5788923374777, -3527.5847802906137`}, {
       604.1772733885804, -3527.5847802906137`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -3529.5905745611913`}, {
       1280.7615701967943`, -3529.5905745611913`}, {
       1280.7615701967943`, -3527.5847802906137`}, {
       1197.2683703802688`, -3527.5847802906137`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -3529.5905745611913`}, {
       1600.805103721155, -3529.5905745611913`}, {
       1600.805103721155, -3527.5847802906137`}, {
       1600.1736582524363`, -3527.5847802906137`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2041.4621244759874`, -3529.5905745611913`}, {
       2354.565493998216, -3529.5905745611913`}, {
       2354.565493998216, -3527.5847802906137`}, {
       2041.4621244759874`, -3527.5847802906137`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3529.5905745611913`}, {
       2583.0983252321575`, -3529.5905745611913`}, {
       2583.0983252321575`, -3527.5847802906137`}, {
       2570.6229887917716`, -3527.5847802906137`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3529.5905745611913`}, {
       3135.6722870386984`, -3529.5905745611913`}, {
       3135.6722870386984`, -3527.5847802906137`}, {
       3134.4891247673936`, -3527.5847802906137`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3529.5905745611913`}, {
       3719.7338553089294`, -3529.5905745611913`}, {
       3719.7338553089294`, -3527.5847802906137`}, {
       3401.8812595691634`, -3527.5847802906137`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3529.5905745611913`}, {
       4141.771855028642, -3529.5905745611913`}, {
       4141.771855028642, -3527.5847802906137`}, {
       4135.403631372018, -3527.5847802906137`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4698.819555587588, -3529.5905745611913`}, {
      4699.999999999999, -3529.5905745611913`}, {
      4699.999999999999, -3527.5847802906137`}, {
      4698.819555587588, -3527.5847802906137`}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{113.30770658784944`, -3528.086228858258}, \
{114.31060372313827`, -3527.5847802906137`}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{114.31060372313827`, -3528.086228858258}, 1.0028971352888274`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{114.31060372313827`, -3529.089125993547}, {
       4697.8166584523, -3529.089125993547}, {
       4697.8166584523, -3528.086228858258}, {
       114.31060372313827`, -3528.086228858258}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4697.8166584523, -3529.089125993547}, 1.0028971352888274`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4697.8166584523, -3529.5905745611913`}, \
{4698.819555587588, -3529.089125993547}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3580.722056802327}, {
        113.30770658784944`, -3580.722056802327}, {
        113.30770658784944`, -3529.5905745611913`}, {
        100, -3529.5905745611913`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3580.722056802327}, {
       853.5788923374777, -3580.722056802327}, {
       853.5788923374777, -3529.5905745611913`}, {
       604.1772733885804, -3529.5905745611913`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -3580.722056802327}, {
       1600.805103721155, -3580.722056802327}, {
       1600.805103721155, -3529.5905745611913`}, {
       1600.1736582524363`, -3529.5905745611913`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2067.0278655965553`, -3580.722056802327}, {
       2354.565493998216, -3580.722056802327}, {
       2354.565493998216, -3529.5905745611913`}, {
       2067.0278655965553`, -3529.5905745611913`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3580.722056802327}, {
       2583.0983252321575`, -3580.722056802327}, {
       2583.0983252321575`, -3529.5905745611913`}, {
       2570.6229887917716`, -3529.5905745611913`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3580.722056802327}, {
       3135.6722870386984`, -3580.722056802327}, {
       3135.6722870386984`, -3529.5905745611913`}, {
       3134.4891247673936`, -3529.5905745611913`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3580.722056802327}, {
       3719.7338553089294`, -3580.722056802327}, {
       3719.7338553089294`, -3529.5905745611913`}, {
       3401.8812595691634`, -3529.5905745611913`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3580.722056802327}, {
       4141.771855028642, -3580.722056802327}, {
       4141.771855028642, -3529.5905745611913`}, {
       4135.403631372018, -3529.5905745611913`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4697.8166584523, -3580.722056802327}, {
       4699.999999999999, -3580.722056802327}, {
       4699.999999999999, -3529.5905745611913`}, {
       4697.8166584523, -3529.5905745611913`}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1197.2683703802688`, -3580.722056802327}, {
      1280.7615701967943`, -3580.722056802327}, {
      1280.7615701967943`, -3529.5905745611913`}, {
      1197.2683703802688`, -3529.5905745611913`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2041.4621244759874`, -3542.3734451214755`}, \
{2067.0278655965553`, -3529.5905745611913`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2041.4621244759874`, -3542.3734451214755`}, 
       25.565741120567864`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1306.327311317362, -3567.9391862420434`}, {
       2041.4621244759874`, -3567.9391862420434`}, {
       2041.4621244759874`, -3542.3734451214755`}, {
       1306.327311317362, -3542.3734451214755`}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1306.327311317362, -3567.9391862420434`}, 25.565741120567864`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1280.7615701967943`, -3580.722056802327}, \
{1306.327311317362, -3567.9391862420434`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3582.4770165926575`}, {
        113.30770658784944`, -3582.4770165926575`}, {
        113.30770658784944`, -3580.722056802327}, {
        100, -3580.722056802327}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3582.4770165926575`}, {
       853.5788923374777, -3582.4770165926575`}, {
       853.5788923374777, -3580.722056802327}, {
       604.1772733885804, -3580.722056802327}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -3582.4770165926575`}, {
       1306.327311317362, -3582.4770165926575`}, {
       1306.327311317362, -3580.722056802327}, {
       1197.2683703802688`, -3580.722056802327}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -3582.4770165926575`}, {
       1600.805103721155, -3582.4770165926575`}, {
       1600.805103721155, -3580.722056802327}, {
       1600.1736582524363`, -3580.722056802327}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2067.0278655965553`, -3582.4770165926575`}, {
       2354.565493998216, -3582.4770165926575`}, {
       2354.565493998216, -3580.722056802327}, {
       2067.0278655965553`, -3580.722056802327}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -3582.4770165926575`}, {
       2583.0983252321575`, -3582.4770165926575`}, {
       2583.0983252321575`, -3580.722056802327}, {
       2570.6229887917716`, -3580.722056802327}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3582.4770165926575`}, {
       3135.6722870386984`, -3582.4770165926575`}, {
       3135.6722870386984`, -3580.722056802327}, {
       3134.4891247673936`, -3580.722056802327}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3582.4770165926575`}, {
       3719.7338553089294`, -3582.4770165926575`}, {
       3719.7338553089294`, -3580.722056802327}, {
       3401.8812595691634`, -3580.722056802327}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4698.694138347465, -3582.4770165926575`}, {
       4700., -3582.4770165926575`}, {4700., -3580.722056802327}, {
       4698.694138347465, -3580.722056802327}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4135.403631372018, -3582.4770165926575`}, {
      4141.771855028642, -3582.4770165926575`}, {
      4141.771855028642, -3580.722056802327}, {
      4135.403631372018, -3580.722056802327}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4697.8166584523, -3581.1607967499094`}, \
{4698.694138347465, -3580.722056802327}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4697.8166584523, -3581.1607967499094`}, 0.877479895165238, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334923807, -3582.038276645075}, {
       4697.8166584523, -3582.038276645075}, {
       4697.8166584523, -3581.1607967499094`}, {
       4142.649334923807, -3581.1607967499094`}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334923807, -3582.038276645075}, 0.877479895165238, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4141.771855028642, -3582.4770165926575`}, \
{4142.649334923807, -3582.038276645075}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -3584.611259741039}, {
        113.30770658784944`, -3584.611259741039}, {
        113.30770658784944`, -3582.4770165926575`}, {
        100, -3582.4770165926575`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -3584.611259741039}, {
       853.5788923374777, -3584.611259741039}, {
       853.5788923374777, -3582.4770165926575`}, {
       604.1772733885804, -3582.4770165926575`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -3584.611259741039}, {
       1306.327311317362, -3584.611259741039}, {
       1306.327311317362, -3582.4770165926575`}, {
       1197.2683703802688`, -3582.4770165926575`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -3584.611259741039}, {
       1600.805103721155, -3584.611259741039}, {
       1600.805103721155, -3582.4770165926575`}, {
       1600.1736582524363`, -3582.4770165926575`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2067.0278655965553`, -3584.611259741039}, {
       2354.565493998216, -3584.611259741039}, {
       2354.565493998216, -3582.4770165926575`}, {
       2067.0278655965553`, -3582.4770165926575`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -3584.611259741039}, {
       3135.6722870386984`, -3584.611259741039}, {
       3135.6722870386984`, -3582.4770165926575`}, {
       3134.4891247673936`, -3582.4770165926575`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3401.8812595691634`, -3584.611259741039}, {
       3719.7338553089294`, -3584.611259741039}, {
       3719.7338553089294`, -3582.4770165926575`}, {
       3401.8812595691634`, -3582.4770165926575`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -3584.611259741039}, {
       4142.649334923807, -3584.611259741039}, {
       4142.649334923807, -3582.4770165926575`}, {
       4135.403631372018, -3582.4770165926575`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -3584.611259741039}, {
       4699.999999999999, -3584.611259741039}, {
       4699.999999999999, -3582.4770165926575`}, {
       4699.761259921655, -3582.4770165926575`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2570.6229887917716`, -3584.611259741039}, {
      2583.0983252321575`, -3584.611259741039}, {
      2583.0983252321575`, -3582.4770165926575`}, {
      2570.6229887917716`, -3582.4770165926575`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4698.694138347465, -3583.0105773797527`}, \
{4699.761259921655, -3582.4770165926575`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4698.694138347465, -3583.0105773797527`}, 1.0671215741906517`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.1654468063484`, -3584.0776989539436`}, {
       4698.694138347465, -3584.0776989539436`}, {
       4698.694138347465, -3583.0105773797527`}, {
       2584.1654468063484`, -3583.0105773797527`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.1654468063484`, -3584.0776989539436`}, 
       1.0671215741906517`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.0983252321575`, -3584.611259741039}, \
{2584.1654468063484`, -3584.0776989539436`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4119.929219298444}, {
        113.30770658784944`, -4119.929219298444}, {
        113.30770658784944`, -3584.6112597410383`}, {
        100, -3584.6112597410383`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -4119.929219298444}, {
       853.5788923374777, -4119.929219298444}, {
       853.5788923374777, -3584.6112597410383`}, {
       604.1772733885804, -3584.6112597410383`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -4119.929219298444}, {
       1306.327311317362, -4119.929219298444}, {
       1306.327311317362, -3584.6112597410383`}, {
       1197.2683703802688`, -3584.6112597410383`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4119.929219298444}, {
       1600.805103721155, -4119.929219298444}, {
       1600.805103721155, -3584.6112597410383`}, {
       1600.1736582524363`, -3584.6112597410383`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4119.929219298444}, {
       2584.1654468063484`, -4119.929219298444}, {
       2584.1654468063484`, -3584.6112597410383`}, {
       2570.6229887917716`, -3584.6112597410383`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.4891247673936`, -4119.929219298444}, {
       3135.6722870386984`, -4119.929219298444}, {
       3135.6722870386984`, -3584.6112597410383`}, {
       3134.4891247673936`, -3584.6112597410383`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3669.540239347866, -4119.929219298444}, {
       3719.7338553089294`, -4119.929219298444}, {
       3719.7338553089294`, -3584.6112597410383`}, {
       3669.540239347866, -3584.6112597410383`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4119.929219298444}, {
       4142.649334923807, -4119.929219298444}, {
       4142.649334923807, -3584.6112597410383`}, {
       4135.403631372018, -3584.6112597410383`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4119.929219298444}, {
       4699.999999999999, -4119.929219298444}, {
       4699.999999999999, -3584.6112597410383`}, {
       4699.761259921655, -3584.6112597410383`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2067.0278655965553`, -4119.929219298444}, {
      2354.565493998216, -4119.929219298444}, {
      2354.565493998216, -3584.6112597410383`}, {
      2067.0278655965553`, -3584.6112597410383`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3401.8812595691634`, -3718.4407496303897`}, \
{3669.540239347866, -3584.6112597410383`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3401.8812595691634`, -3718.4407496303897`}, 267.6589797787027, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.224473776919, -3986.0997294090926`}, {
       3401.8812595691634`, -3986.0997294090926`}, {
       3401.8812595691634`, -3718.4407496303897`}, {
       2622.224473776919, -3718.4407496303897`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.224473776919, -3986.0997294090926`}, 267.6589797787027, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2354.565493998216, -4119.929219298444}, \
{2622.224473776919, -3986.0997294090926`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4120.655441285451}, {
        112.94459559434564`, -4120.655441285451}, {
        112.94459559434564`, -4119.929219298444}, {
        100, -4119.929219298444}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -4120.655441285451}, {
       853.5788923374777, -4120.655441285451}, {
       853.5788923374777, -4119.929219298444}, {
       604.1772733885804, -4119.929219298444}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -4120.655441285451}, {
       1306.327311317362, -4120.655441285451}, {
       1306.327311317362, -4119.929219298444}, {
       1197.2683703802688`, -4119.929219298444}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4120.655441285451}, {
       1600.805103721155, -4120.655441285451}, {
       1600.805103721155, -4119.929219298444}, {
       1600.1736582524363`, -4119.929219298444}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2067.0278655965553`, -4120.655441285451}, {
       2622.224473776919, -4120.655441285451}, {
       2622.224473776919, -4119.929219298444}, {
       2067.0278655965553`, -4119.929219298444}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4120.655441285451}, {
       2584.1654468063484`, -4120.655441285451}, {
       2584.1654468063484`, -4119.929219298444}, {
       2570.6229887917716`, -4119.929219298444}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3669.540239347866, -4120.655441285451}, {
       3719.7338553089294`, -4120.655441285451}, {
       3719.7338553089294`, -4119.929219298444}, {
       3669.540239347866, -4119.929219298444}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4120.655441285451}, {
       4142.649334923807, -4120.655441285451}, {
       4142.649334923807, -4119.929219298444}, {
       4135.403631372018, -4119.929219298444}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4120.655441285451}, {
       4699.999999999999, -4120.655441285451}, {
       4699.999999999999, -4119.929219298444}, {
       4699.761259921655, -4119.929219298444}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3134.4891247673936`, -4120.655441285451}, {
      3135.6722870386984`, -4120.655441285451}, {
      3135.6722870386984`, -4119.929219298444}, {
      3134.4891247673936`, -4119.929219298444}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{112.94459559434564`, -4120.1107747951955`}, \
{113.30770658784944`, -4119.929219298444}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.30770658784944`, -4120.1107747951955`}, 
       0.36311099350379394`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.30770658784944`, -4120.4738857887}, {
       3134.12601377389, -4120.4738857887}, {
       3134.12601377389, -4120.1107747951955`}, {
       113.30770658784944`, -4120.1107747951955`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3134.12601377389, -4120.4738857887}, 0.36311099350379394`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3134.12601377389, -4120.655441285451}, \
{3134.4891247673936`, -4120.4738857887}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4338.590367775514}, {
        112.94459559434564`, -4338.590367775514}, {
        112.94459559434564`, -4120.655441285451}, {
        100, -4120.655441285451}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -4338.590367775514}, {
       1306.327311317362, -4338.590367775514}, {
       1306.327311317362, -4120.655441285451}, {
       1197.2683703802688`, -4120.655441285451}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4338.590367775514}, {
       1600.805103721155, -4338.590367775514}, {
       1600.805103721155, -4120.655441285451}, {
       1600.1736582524363`, -4120.655441285451}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2175.995328841587, -4338.590367775514}, {
       2622.224473776919, -4338.590367775514}, {
       2622.224473776919, -4120.655441285451}, {
       2175.995328841587, -4120.655441285451}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4338.590367775514}, {
       2584.1654468063484`, -4338.590367775514}, {
       2584.1654468063484`, -4120.655441285451}, {
       2570.6229887917716`, -4120.655441285451}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4338.590367775514}, {
       3135.6722870386984`, -4338.590367775514}, {
       3135.6722870386984`, -4120.655441285451}, {
       3134.12601377389, -4120.655441285451}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3669.540239347866, -4338.590367775514}, {
       3719.7338553089294`, -4338.590367775514}, {
       3719.7338553089294`, -4120.655441285451}, {
       3669.540239347866, -4120.655441285451}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4338.590367775514}, {
       4142.649334923807, -4338.590367775514}, {
       4142.649334923807, -4120.655441285451}, {
       4135.403631372018, -4120.655441285451}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4338.590367775514}, {
       4699.999999999999, -4338.590367775514}, {
       4699.999999999999, -4120.655441285451}, {
       4699.761259921655, -4120.655441285451}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -4338.590367775514}, {
      853.5788923374777, -4338.590367775514}, {
      853.5788923374777, -4120.655441285451}, {
      604.1772733885804, -4120.655441285451}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2067.0278655965553`, -4175.139172907967}, \
{2175.995328841587, -4120.655441285451}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2067.0278655965553`, -4175.139172907967}, 108.9674632450313, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{962.546355582509, -4284.106636152998}, {
       2067.0278655965553`, -4284.106636152998}, {
       2067.0278655965553`, -4175.139172907967}, {
       962.546355582509, -4175.139172907967}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{962.546355582509, -4284.106636152998}, 108.9674632450313, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{853.5788923374777, -4338.590367775514}, \
{962.546355582509, -4284.106636152998}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4348.521534084328}, {
        107.97901243993863`, -4348.521534084328}, {
        107.97901243993863`, -4338.590367775514}, {
        100, -4338.590367775514}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -4348.521534084328}, {
       962.546355582509, -4348.521534084328}, {
       962.546355582509, -4338.590367775514}, {
       604.1772733885804, -4338.590367775514}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1197.2683703802688`, -4348.521534084328}, {
       1306.327311317362, -4348.521534084328}, {
       1306.327311317362, -4338.590367775514}, {
       1197.2683703802688`, -4338.590367775514}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4348.521534084328}, {
       1600.805103721155, -4348.521534084328}, {
       1600.805103721155, -4338.590367775514}, {
       1600.1736582524363`, -4338.590367775514}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4348.521534084328}, {
       2584.1654468063484`, -4348.521534084328}, {
       2584.1654468063484`, -4338.590367775514}, {
       2570.6229887917716`, -4338.590367775514}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4348.521534084328}, {
       3135.6722870386984`, -4348.521534084328}, {
       3135.6722870386984`, -4338.590367775514}, {
       3134.12601377389, -4338.590367775514}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3669.540239347866, -4348.521534084328}, {
       3719.7338553089294`, -4348.521534084328}, {
       3719.7338553089294`, -4338.590367775514}, {
       3669.540239347866, -4338.590367775514}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4348.521534084328}, {
       4142.649334923807, -4348.521534084328}, {
       4142.649334923807, -4338.590367775514}, {
       4135.403631372018, -4338.590367775514}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4348.521534084328}, {
       4699.999999999999, -4348.521534084328}, {
       4699.999999999999, -4338.590367775514}, {
       4699.761259921655, -4338.590367775514}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2175.995328841587, -4348.521534084328}, {
      2622.2244737769192`, -4348.521534084328}, {
      2622.2244737769192`, -4338.590367775514}, {
      2175.995328841587, -4338.590367775514}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{107.97901243993863`, -4341.073159352717}, \
{112.94459559434564`, -4338.590367775514}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{112.94459559434564`, -4341.073159352717}, 4.96558315440701, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{112.94459559434564`, -4346.038742507124}, {
       2171.02974568718, -4346.038742507124}, {
       2171.02974568718, -4341.073159352717}, {
       112.94459559434564`, -4341.073159352717}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2171.02974568718, -4346.038742507124}, 4.96558315440701, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2171.02974568718, -4348.521534084328}, \
{2175.995328841587, -4346.038742507124}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4362.035639680649}, {
        101.2219596417781, -4362.035639680649}, {
        101.2219596417781, -4348.521534084328}, {
        100, -4348.521534084328}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{604.1772733885804, -4362.035639680649}, {
       962.546355582509, -4362.035639680649}, {
       962.546355582509, -4348.521534084328}, {
       604.1772733885804, -4348.521534084328}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4362.035639680649}, {
       1600.805103721155, -4362.035639680649}, {
       1600.805103721155, -4348.521534084328}, {
       1600.1736582524363`, -4348.521534084328}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.02974568718, -4362.035639680649}, {
       2622.2244737769192`, -4362.035639680649}, {
       2622.2244737769192`, -4348.521534084328}, {
       2171.02974568718, -4348.521534084328}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4362.035639680649}, {
       2584.1654468063484`, -4362.035639680649}, {
       2584.1654468063484`, -4348.521534084328}, {
       2570.6229887917716`, -4348.521534084328}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4362.035639680649}, {
       3135.6722870386984`, -4362.035639680649}, {
       3135.6722870386984`, -4348.521534084328}, {
       3134.12601377389, -4348.521534084328}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3669.540239347866, -4362.035639680649}, {
       3719.7338553089294`, -4362.035639680649}, {
       3719.7338553089294`, -4348.521534084328}, {
       3669.540239347866, -4348.521534084328}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4362.035639680649}, {
       4142.649334923807, -4362.035639680649}, {
       4142.649334923807, -4348.521534084328}, {
       4135.403631372018, -4348.521534084328}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4362.035639680649}, {
       4699.999999999999, -4362.035639680649}, {
       4699.999999999999, -4348.521534084328}, {
       4699.761259921655, -4348.521534084328}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1197.2683703802688`, -4362.035639680649}, {
      1306.3273113173623`, -4362.035639680649}, {
      1306.3273113173623`, -4348.521534084328}, {
      1197.2683703802688`, -4348.521534084328}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.2219596417781, -4351.900060483408}, \
{107.97901243993863`, -4348.521534084328}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{107.97901243993863`, -4351.900060483408}, 6.757052798160542, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{107.97901243993863`, -4358.657113281569}, {
       1190.5113175821084`, -4358.657113281569}, {
       1190.5113175821084`, -4351.900060483408}, {
       107.97901243993863`, -4351.900060483408}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1190.5113175821084`, -4358.657113281569}, 6.757052798160542, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1190.5113175821084`, -4362.035639680649}, \
{1197.2683703802688`, -4358.657113281569}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4366.210204253394}, {
        101.2219596417781, -4366.210204253394}, {
        101.2219596417781, -4362.035639680649}, {
        100, -4362.035639680649}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4366.210204253394}, {
       1306.3273113173623`, -4366.210204253394}, {
       1306.3273113173623`, -4362.035639680649}, {
       1190.5113175821084`, -4362.035639680649}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4366.210204253394}, {
       1600.805103721155, -4366.210204253394}, {
       1600.805103721155, -4362.035639680649}, {
       1600.1736582524363`, -4362.035639680649}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.02974568718, -4366.210204253394}, {
       2622.2244737769192`, -4366.210204253394}, {
       2622.2244737769192`, -4362.035639680649}, {
       2171.02974568718, -4362.035639680649}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4366.210204253394}, {
       2584.1654468063484`, -4366.210204253394}, {
       2584.1654468063484`, -4362.035639680649}, {
       2570.6229887917716`, -4362.035639680649}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4366.210204253394}, {
       3135.6722870386984`, -4366.210204253394}, {
       3135.6722870386984`, -4362.035639680649}, {
       3134.12601377389, -4362.035639680649}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4366.210204253394}, {
       3719.7338553089294`, -4366.210204253394}, {
       3719.7338553089294`, -4362.035639680649}, {
       3671.6275216342387`, -4362.035639680649}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4366.210204253394}, {
       4142.649334923807, -4366.210204253394}, {
       4142.649334923807, -4362.035639680649}, {
       4135.403631372018, -4362.035639680649}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4366.210204253394}, {
       4699.999999999999, -4366.210204253394}, {
       4699.999999999999, -4362.035639680649}, {
       4699.761259921655, -4362.035639680649}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -4366.210204253394}, {
      962.546355582509, -4366.210204253394}, {
      962.546355582509, -4362.035639680649}, {
      604.1772733885804, -4362.035639680649}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3669.540239347866, -4363.079280823836}, \
{3671.6275216342387`, -4362.035639680649}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3669.540239347866, -4363.079280823836}, 2.087282286372634, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{964.6336378688816, -4365.166563110208}, {
       3669.540239347866, -4365.166563110208}, {
       3669.540239347866, -4363.079280823836}, {
       964.6336378688816, -4363.079280823836}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{964.6336378688816, -4365.166563110208}, 2.087282286372634, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{962.546355582509, -4366.210204253394}, \
{964.6336378688816, -4365.166563110208}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4367.9494874052125`}, {
        100.35231806586914`, -4367.9494874052125`}, {
        100.35231806586914`, -4366.210204253394}, {
        100, -4366.210204253394}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4367.9494874052125`}, {
       1306.3273113173623`, -4367.9494874052125`}, {
       1306.3273113173623`, -4366.210204253394}, {
       1190.5113175821084`, -4366.210204253394}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4367.9494874052125`}, {
       1600.805103721155, -4367.9494874052125`}, {
       1600.805103721155, -4366.210204253394}, {
       1600.1736582524363`, -4366.210204253394}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.02974568718, -4367.9494874052125`}, {
       2622.2244737769192`, -4367.9494874052125`}, {
       2622.2244737769192`, -4366.210204253394}, {
       2171.02974568718, -4366.210204253394}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4367.9494874052125`}, {
       2584.1654468063484`, -4367.9494874052125`}, {
       2584.1654468063484`, -4366.210204253394}, {
       2570.6229887917716`, -4366.210204253394}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4367.9494874052125`}, {
       3135.6722870386984`, -4367.9494874052125`}, {
       3135.6722870386984`, -4366.210204253394}, {
       3134.12601377389, -4366.210204253394}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4367.9494874052125`}, {
       3719.7338553089294`, -4367.9494874052125`}, {
       3719.7338553089294`, -4366.210204253394}, {
       3671.6275216342387`, -4366.210204253394}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.403631372018, -4367.9494874052125`}, {
       4142.649334923807, -4367.9494874052125`}, {
       4142.649334923807, -4366.210204253394}, {
       4135.403631372018, -4366.210204253394}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4367.9494874052125`}, {
       4699.999999999999, -4367.9494874052125`}, {
       4699.999999999999, -4366.210204253394}, {
       4699.761259921655, -4366.210204253394}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{604.1772733885804, -4367.9494874052125`}, {
      964.6336378688816, -4367.9494874052125`}, {
      964.6336378688816, -4366.210204253394}, {
      604.1772733885804, -4366.210204253394}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.35231806586914`, -4366.645025041349}, \
{101.2219596417781, -4366.210204253394}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.2219596417781, -4366.645025041349}, 0.8696415759089495, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.2219596417781, -4367.514666617258}, {
       603.3076318126714, -4367.514666617258}, {
       603.3076318126714, -4366.645025041349}, {
       101.2219596417781, -4366.645025041349}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{603.3076318126714, -4367.514666617258}, 0.8696415759089495, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{603.3076318126714, -4367.9494874052125`}, \
{604.1772733885804, -4367.514666617258}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4379.068070868074}, {
        100.35231806586914`, -4379.068070868074}, {
        100.35231806586914`, -4367.9494874052125`}, {
        100, -4367.9494874052125`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4379.068070868074}, {
       964.6336378688816, -4379.068070868074}, {
       964.6336378688816, -4367.9494874052125`}, {
       603.3076318126714, -4367.9494874052125`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4379.068070868074}, {
       1300.7680195859314`, -4379.068070868074}, {
       1300.7680195859314`, -4367.9494874052125`}, {
       1190.5113175821084`, -4367.9494874052125`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4379.068070868074}, {
       1600.805103721155, -4379.068070868074}, {
       1600.805103721155, -4367.9494874052125`}, {
       1600.1736582524363`, -4367.9494874052125`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.02974568718, -4379.068070868074}, {
       2622.2244737769192`, -4379.068070868074}, {
       2622.2244737769192`, -4367.9494874052125`}, {
       2171.02974568718, -4367.9494874052125`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4379.068070868074}, {
       2584.1654468063484`, -4379.068070868074}, {
       2584.1654468063484`, -4367.9494874052125`}, {
       2570.6229887917716`, -4367.9494874052125`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4379.068070868074}, {
       3135.6722870386984`, -4379.068070868074}, {
       3135.6722870386984`, -4367.9494874052125`}, {
       3134.12601377389, -4367.9494874052125`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4379.068070868074}, {
       3719.7338553089294`, -4379.068070868074}, {
       3719.7338553089294`, -4367.9494874052125`}, {
       3671.6275216342387`, -4367.9494874052125`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.761259921655, -4379.068070868074}, {
       4699.999999999999, -4379.068070868074}, {
       4699.999999999999, -4367.9494874052125`}, {
       4699.761259921655, -4367.9494874052125`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4135.403631372018, -4379.068070868074}, {
      4142.649334923807, -4379.068070868074}, {
      4142.649334923807, -4367.9494874052125`}, {
      4135.403631372018, -4367.9494874052125`}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1300.7680195859314`, -4370.729133270927}, \
{1306.3273113173623`, -4367.9494874052125`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1306.3273113173623`, -4370.729133270927}, 5.5592917314307995`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1306.3273113173623`, -4376.288425002358}, {
       4129.844339640587, -4376.288425002358}, {
       4129.844339640587, -4370.729133270927}, {
       1306.3273113173623`, -4370.729133270927}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4129.844339640587, -4376.288425002358}, 5.5592917314307995`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4129.844339640587, -4379.068070868074}, \
{4135.403631372018, -4376.288425002358}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4379.478179524579}, {
        100.35231806586914`, -4379.478179524579}, {
        100.35231806586914`, -4379.068070868074}, {
        100, -4379.068070868074}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4379.478179524579}, {
       964.6336378688816, -4379.478179524579}, {
       964.6336378688816, -4379.068070868074}, {
       603.3076318126714, -4379.068070868074}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4379.478179524579}, {
       1300.7680195859314`, -4379.478179524579}, {
       1300.7680195859314`, -4379.068070868074}, {
       1190.5113175821084`, -4379.068070868074}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4379.478179524579}, {
       1600.805103721155, -4379.478179524579}, {
       1600.805103721155, -4379.068070868074}, {
       1600.1736582524363`, -4379.068070868074}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.02974568718, -4379.478179524579}, {
       2622.2244737769192`, -4379.478179524579}, {
       2622.2244737769192`, -4379.068070868074}, {
       2171.02974568718, -4379.068070868074}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4379.478179524579}, {
       2583.960392478096, -4379.478179524579}, {
       2583.960392478096, -4379.068070868074}, {
       2570.6229887917716`, -4379.068070868074}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4379.478179524579}, {
       3135.6722870386984`, -4379.478179524579}, {
       3135.6722870386984`, -4379.068070868074}, {
       3134.12601377389, -4379.068070868074}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4379.478179524579}, {
       3719.7338553089294`, -4379.478179524579}, {
       3719.7338553089294`, -4379.068070868074}, {
       3671.6275216342387`, -4379.068070868074}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4129.844339640587, -4379.478179524579}, {
       4142.649334923807, -4379.478179524579}, {
       4142.649334923807, -4379.068070868074}, {
       4129.844339640587, -4379.068070868074}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.761259921655, -4379.478179524579}, {
      4700., -4379.478179524579}, {4700., -4379.068070868074}, {
      4699.761259921655, -4379.068070868074}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.960392478096, -4379.1705980322}, \
{2584.1654468063484`, -4379.068070868074}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.1654468063484`, -4379.1705980322}, 0.2050543282524518, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.1654468063484`, -4379.3756523604525`}, {
       4699.556205593403, -4379.3756523604525`}, {
       4699.556205593403, -4379.1705980322}, {
       2584.1654468063484`, -4379.1705980322}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.556205593403, -4379.3756523604525`}, 0.2050543282524518, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.556205593403, -4379.478179524579}, \
{4699.761259921655, -4379.3756523604525`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4379.682074614695}, {
       964.6336378688816, -4379.682074614695}, {
       964.6336378688816, -4379.478179524579}, {
       603.3076318126714, -4379.478179524579}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4379.682074614695}, {
       1300.7680195859314`, -4379.682074614695}, {
       1300.7680195859314`, -4379.478179524579}, {
       1190.5113175821084`, -4379.478179524579}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4379.682074614695}, {
       1600.805103721155, -4379.682074614695}, {
       1600.805103721155, -4379.478179524579}, {
       1600.1736582524363`, -4379.478179524579}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.131693232238, -4379.682074614695}, {
       2622.2244737769192`, -4379.682074614695}, {
       2622.2244737769192`, -4379.478179524579}, {
       2171.131693232238, -4379.478179524579}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.6229887917716`, -4379.682074614695}, {
       2583.960392478096, -4379.682074614695}, {
       2583.960392478096, -4379.478179524579}, {
       2570.6229887917716`, -4379.478179524579}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4379.682074614695}, {
       3135.6722870386984`, -4379.682074614695}, {
       3135.6722870386984`, -4379.478179524579}, {
       3134.12601377389, -4379.478179524579}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4379.682074614695}, {
       3719.7338553089294`, -4379.682074614695}, {
       3719.7338553089294`, -4379.478179524579}, {
       3671.6275216342387`, -4379.478179524579}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4129.844339640587, -4379.682074614695}, {
       4142.649334923807, -4379.682074614695}, {
       4142.649334923807, -4379.478179524579}, {
       4129.844339640587, -4379.478179524579}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.556205593403, -4379.682074614695}, {
       4700., -4379.682074614695}, {4700., -4379.478179524579}, {
       4699.556205593403, -4379.478179524579}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -4379.682074614695}, {
       100.35231806586914`, -4379.682074614695}, {
       100.35231806586914`, -4379.478179524579}, {
       100, -4379.478179524579}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2171.02974568718, -4379.529153297108}, \
{2171.131693232238, -4379.478179524579}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2171.02974568718, -4379.529153297108}, 0.10194754505798609`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.45426561092712`, -4379.631100842166}, {
       2171.02974568718, -4379.631100842166}, {
       2171.02974568718, -4379.529153297108}, {
       100.45426561092712`, -4379.529153297108}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.45426561092712`, -4379.631100842166}, 0.10194754505798609`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.35231806586914`, -4379.682074614695}, \
{100.45426561092712`, -4379.631100842166}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4380.24493723815}, {
       964.6336378688816, -4380.24493723815}, {
       964.6336378688816, -4379.682074614695}, {
       603.3076318126714, -4379.682074614695}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4380.24493723815}, {
       1300.7680195859314`, -4380.24493723815}, {
       1300.7680195859314`, -4379.682074614695}, {
       1190.5113175821084`, -4379.682074614695}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4380.24493723815}, {
       1600.805103721155, -4380.24493723815}, {
       1600.805103721155, -4379.682074614695}, {
       1600.1736582524363`, -4379.682074614695}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2171.131693232238, -4380.24493723815}, {
       2622.2244737769192`, -4380.24493723815}, {
       2622.2244737769192`, -4379.682074614695}, {
       2171.131693232238, -4379.682074614695}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.904420103499, -4380.24493723815}, {
       2583.960392478096, -4380.24493723815}, {
       2583.960392478096, -4379.682074614695}, {
       2570.904420103499, -4379.682074614695}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4380.24493723815}, {
       3135.6722870386984`, -4380.24493723815}, {
       3135.6722870386984`, -4379.682074614695}, {
       3134.12601377389, -4379.682074614695}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4380.24493723815}, {
       3719.7338553089294`, -4380.24493723815}, {
       3719.7338553089294`, -4379.682074614695}, {
       3671.6275216342387`, -4379.682074614695}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4129.844339640587, -4380.24493723815}, {
       4142.649334923807, -4380.24493723815}, {
       4142.649334923807, -4379.682074614695}, {
       4129.844339640587, -4379.682074614695}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.556205593403, -4380.24493723815}, {
       4700., -4380.24493723815}, {4700., -4379.682074614695}, {
       4699.556205593403, -4379.682074614695}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -4380.24493723815}, {
       100.45426561092712`, -4380.24493723815}, {
       100.45426561092712`, -4379.682074614695}, {
       100, -4379.682074614695}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2570.6229887917716`, -4379.8227902705585`}, \
{2570.904420103499, -4379.682074614695}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2570.6229887917716`, -4379.8227902705585`}, 0.2814313117274052,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.73569692265454`, -4380.104221582286}, {
       2570.6229887917716`, -4380.104221582286}, {
       2570.6229887917716`, -4379.8227902705585`}, {
       100.73569692265454`, -4379.8227902705585`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.73569692265454`, -4380.104221582286}, 0.2814313117274052, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.45426561092712`, -4380.24493723815}, \
{100.73569692265454`, -4380.104221582286}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4380.988396121978}, {
        100.36396748074036`, -4380.988396121978}, {
        100.36396748074036`, -4380.24493723815}, {
        100, -4380.24493723815}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4380.988396121978}, {
       964.6336378688816, -4380.988396121978}, {
       964.6336378688816, -4380.24493723815}, {
       603.3076318126714, -4380.24493723815}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4380.988396121978}, {
       1300.7680195859314`, -4380.988396121978}, {
       1300.7680195859314`, -4380.24493723815}, {
       1190.5113175821084`, -4380.24493723815}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4380.988396121978}, {
       1600.805103721155, -4380.988396121978}, {
       1600.805103721155, -4380.24493723815}, {
       1600.1736582524363`, -4380.24493723815}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.904420103499, -4380.988396121978}, {
       2583.960392478096, -4380.988396121978}, {
       2583.960392478096, -4380.24493723815}, {
       2570.904420103499, -4380.24493723815}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4380.988396121978}, {
       3135.6722870386984`, -4380.988396121978}, {
       3135.6722870386984`, -4380.24493723815}, {
       3134.12601377389, -4380.24493723815}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4380.988396121978}, {
       3719.7338553089294`, -4380.988396121978}, {
       3719.7338553089294`, -4380.24493723815}, {
       3671.6275216342387`, -4380.24493723815}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4129.844339640587, -4380.988396121978}, {
       4142.649334923807, -4380.988396121978}, {
       4142.649334923807, -4380.24493723815}, {
       4129.844339640587, -4380.24493723815}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.556205593403, -4380.988396121978}, {
       4700., -4380.988396121978}, {4700., -4380.24493723815}, {
       4699.556205593403, -4380.24493723815}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2171.131693232238, -4380.988396121978}, {
      2622.224473776919, -4380.988396121978}, {
      2622.224473776919, -4380.24493723815}, {
      2171.131693232238, -4380.24493723815}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.36396748074036`, -4380.430801959107}, \
{100.73569692265454`, -4380.24493723815}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.73569692265454`, -4380.430801959107}, 0.3717294419141748, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.73569692265454`, -4380.802531401021}, {
       2170.7599637903236`, -4380.802531401021}, {
       2170.7599637903236`, -4380.430801959107}, {
       100.73569692265454`, -4380.430801959107}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2170.7599637903236`, -4380.802531401021}, 0.3717294419141748, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2170.7599637903236`, -4380.988396121978}, \
{2171.131693232238, -4380.802531401021}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4381.732361256002}, {
        100.36396748074036`, -4381.732361256002}, {
        100.36396748074036`, -4380.988396121978}, {
        100, -4380.988396121978}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4381.732361256002}, {
       964.6336378688816, -4381.732361256002}, {
       964.6336378688816, -4380.988396121978}, {
       603.3076318126714, -4380.988396121978}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4381.732361256002}, {
       1300.7680195859314`, -4381.732361256002}, {
       1300.7680195859314`, -4380.988396121978}, {
       1190.5113175821084`, -4380.988396121978}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4381.732361256002}, {
       1600.805103721155, -4381.732361256002}, {
       1600.805103721155, -4380.988396121978}, {
       1600.1736582524363`, -4380.988396121978}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4381.732361256002}, {
       2622.224473776919, -4381.732361256002}, {
       2622.224473776919, -4380.988396121978}, {
       2170.7599637903236`, -4380.988396121978}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4381.732361256002}, {
       3135.6722870386984`, -4381.732361256002}, {
       3135.6722870386984`, -4380.988396121978}, {
       3134.12601377389, -4380.988396121978}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4381.732361256002}, {
       3719.7338553089294`, -4381.732361256002}, {
       3719.7338553089294`, -4380.988396121978}, {
       3671.6275216342387`, -4380.988396121978}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4129.844339640587, -4381.732361256002}, {
       4142.649334923807, -4381.732361256002}, {
       4142.649334923807, -4380.988396121978}, {
       4129.844339640587, -4380.988396121978}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.928188160416, -4381.732361256002}, {
       4700., -4381.732361256002}, {4700., -4380.988396121978}, {
       4699.928188160416, -4380.988396121978}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2570.904420103499, -4381.732361256002}, {
      2583.960392478096, -4381.732361256002}, {
      2583.960392478096, -4380.988396121978}, {
      2570.904420103499, -4380.988396121978}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.556205593403, -4381.174387405484}, \
{4699.928188160416, -4380.988396121978}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.556205593403, -4381.174387405484}, 0.37198256701207194`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.3323750451077`, -4381.546369972496}, {
       4699.556205593403, -4381.546369972496}, {
       4699.556205593403, -4381.174387405484}, {
       2584.3323750451077`, -4381.174387405484}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.3323750451077`, -4381.546369972496}, 0.37198256701207194`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2583.960392478096, -4381.732361256002}, \
{2584.3323750451077`, -4381.546369972496}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4387.1714978393065`}, {
        100.36396748074036`, -4387.1714978393065`}, {
        100.36396748074036`, -4381.732361256002}, {
        100, -4381.732361256002}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4387.1714978393065`}, {
       1300.7680195859314`, -4387.1714978393065`}, {
       1300.7680195859314`, -4381.732361256002}, {
       1190.5113175821084`, -4381.732361256002}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4387.1714978393065`}, {
       1600.805103721155, -4387.1714978393065`}, {
       1600.805103721155, -4381.732361256002}, {
       1600.1736582524363`, -4381.732361256002}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4387.1714978393065`}, {
       2622.224473776919, -4387.1714978393065`}, {
       2622.224473776919, -4381.732361256002}, {
       2170.7599637903236`, -4381.732361256002}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2570.904420103499, -4387.1714978393065`}, {
       2584.3323750451077`, -4387.1714978393065`}, {
       2584.3323750451077`, -4381.732361256002}, {
       2570.904420103499, -4381.732361256002}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4387.1714978393065`}, {
       3135.6722870386984`, -4387.1714978393065`}, {
       3135.6722870386984`, -4381.732361256002}, {
       3134.12601377389, -4381.732361256002}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4387.1714978393065`}, {
       3719.7338553089294`, -4387.1714978393065`}, {
       3719.7338553089294`, -4381.732361256002}, {
       3671.6275216342387`, -4381.732361256002}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4387.1714978393065`}, {
       4142.649334923808, -4387.1714978393065`}, {
       4142.649334923808, -4381.732361256002}, {
       4132.56390793224, -4381.732361256002}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.928188160416, -4387.1714978393065`}, {
       4700., -4387.1714978393065`}, {4700., -4381.732361256002}, {
       4699.928188160416, -4381.732361256002}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -4387.1714978393065`}, {
      964.6336378688816, -4387.1714978393065`}, {
      964.6336378688816, -4381.732361256002}, {
      603.3076318126714, -4381.732361256002}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4129.844339640587, -4383.092145401828}, \
{4132.56390793224, -4381.732361256002}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4129.844339640587, -4383.092145401828}, 2.719568291652278, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{967.3532061605338, -4385.811713693481}, {
       4129.844339640587, -4385.811713693481}, {
       4129.844339640587, -4383.092145401828}, {
       967.3532061605338, -4383.092145401828}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{967.3532061605338, -4385.811713693481}, 2.719568291652278, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{964.6336378688816, -4387.1714978393065`}, \
{967.3532061605338, -4385.811713693481}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4398.518557977746}, {
        100.36396748074036`, -4398.518557977746}, {
        100.36396748074036`, -4387.1714978393065`}, {
        100, -4387.1714978393065`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4398.518557977746}, {
       961.6796760913137, -4398.518557977746}, {
       961.6796760913137, -4387.1714978393065`}, {
       603.3076318126714, -4387.1714978393065`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4398.518557977746}, {
       1300.7680195859314`, -4398.518557977746}, {
       1300.7680195859314`, -4387.1714978393065`}, {
       1190.5113175821084`, -4387.1714978393065`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4398.518557977746}, {
       1600.805103721155, -4398.518557977746}, {
       1600.805103721155, -4387.1714978393065`}, {
       1600.1736582524363`, -4387.1714978393065`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4398.518557977746}, {
       2622.224473776919, -4398.518557977746}, {
       2622.224473776919, -4387.1714978393065`}, {
       2170.7599637903236`, -4387.1714978393065`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4398.518557977746}, {
       3135.6722870386984`, -4398.518557977746}, {
       3135.6722870386984`, -4387.1714978393065`}, {
       3134.12601377389, -4387.1714978393065`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4398.518557977746}, {
       3719.7338553089294`, -4398.518557977746}, {
       3719.7338553089294`, -4387.1714978393065`}, {
       3671.6275216342387`, -4387.1714978393065`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4398.518557977746}, {
       4142.649334923808, -4398.518557977746}, {
       4142.649334923808, -4387.1714978393065`}, {
       4132.56390793224, -4387.1714978393065`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.928188160416, -4398.518557977746}, {
       4700., -4398.518557977746}, {4700., -4387.1714978393065`}, {
       4699.928188160416, -4387.1714978393065`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2570.904420103499, -4398.518557977746}, {
      2584.332375045108, -4398.518557977746}, {
      2584.332375045108, -4387.1714978393065`}, {
      2570.904420103499, -4387.1714978393065`}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{961.6796760913137, -4390.0082628739165`}, \
{967.3532061605338, -4387.1714978393065`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{967.3532061605338, -4390.0082628739165`}, 5.673530069220035, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{967.3532061605338, -4395.681792943136}, {
       2565.230890034279, -4395.681792943136}, {
       2565.230890034279, -4390.0082628739165`}, {
       967.3532061605338, -4390.0082628739165`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2565.230890034279, -4395.681792943136}, 5.673530069220035, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2565.230890034279, -4398.518557977746}, \
{2570.904420103499, -4395.681792943136}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4398.6298142034075`}, {
        100.30833936790961`, -4398.6298142034075`}, {
        100.30833936790961`, -4398.518557977746}, {
        100, -4398.518557977746}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4398.6298142034075`}, {
       961.6796760913137, -4398.6298142034075`}, {
       961.6796760913137, -4398.518557977746}, {
       603.3076318126714, -4398.518557977746}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4398.6298142034075`}, {
       1300.7680195859314`, -4398.6298142034075`}, {
       1300.7680195859314`, -4398.518557977746}, {
       1190.5113175821084`, -4398.518557977746}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4398.6298142034075`}, {
       1600.805103721155, -4398.6298142034075`}, {
       1600.805103721155, -4398.518557977746}, {
       1600.1736582524363`, -4398.518557977746}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4398.6298142034075`}, {
       2622.224473776919, -4398.6298142034075`}, {
       2622.224473776919, -4398.518557977746}, {
       2170.7599637903236`, -4398.518557977746}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4398.6298142034075`}, {
       2584.332375045108, -4398.6298142034075`}, {
       2584.332375045108, -4398.518557977746}, {
       2565.230890034279, -4398.518557977746}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4398.6298142034075`}, {
       3135.6722870386984`, -4398.6298142034075`}, {
       3135.6722870386984`, -4398.518557977746}, {
       3134.12601377389, -4398.518557977746}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4398.6298142034075`}, {
       3719.7338553089294`, -4398.6298142034075`}, {
       3719.7338553089294`, -4398.518557977746}, {
       3671.6275216342387`, -4398.518557977746}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4398.6298142034075`}, {
       4142.649334923808, -4398.6298142034075`}, {
       4142.649334923808, -4398.518557977746}, {
       4132.56390793224, -4398.518557977746}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.928188160416, -4398.6298142034075`}, {
      4700., -4398.6298142034075`}, {4700., -4398.518557977746}, {
      4699.928188160416, -4398.518557977746}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.30833936790961`, -4398.546372034161}, \
{100.36396748074036`, -4398.518557977746}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.36396748074036`, -4398.546372034161}, 
       0.055628112830751364`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.36396748074036`, -4398.602000146992}, {
       4699.872560047585, -4398.602000146992}, {
       4699.872560047585, -4398.546372034161}, {
       100.36396748074036`, -4398.546372034161}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.872560047585, -4398.602000146992}, 
       0.055628112830751364`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.872560047585, -4398.6298142034075`}, \
{4699.928188160416, -4398.602000146992}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4398.883444736673}, {
        100.30833936790961`, -4398.883444736673}, {
        100.30833936790961`, -4398.6298142034075`}, {
        100, -4398.6298142034075`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1190.5113175821084`, -4398.883444736673}, {
       1300.7680195859314`, -4398.883444736673}, {
       1300.7680195859314`, -4398.6298142034075`}, {
       1190.5113175821084`, -4398.6298142034075`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4398.883444736673}, {
       1600.805103721155, -4398.883444736673}, {
       1600.805103721155, -4398.6298142034075`}, {
       1600.1736582524363`, -4398.6298142034075`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4398.883444736673}, {
       2622.224473776919, -4398.883444736673}, {
       2622.224473776919, -4398.6298142034075`}, {
       2170.7599637903236`, -4398.6298142034075`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4398.883444736673}, {
       2584.332375045108, -4398.883444736673}, {
       2584.332375045108, -4398.6298142034075`}, {
       2565.230890034279, -4398.6298142034075`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4398.883444736673}, {
       3135.6722870386984`, -4398.883444736673}, {
       3135.6722870386984`, -4398.6298142034075`}, {
       3134.12601377389, -4398.6298142034075`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4398.883444736673}, {
       3719.7338553089294`, -4398.883444736673}, {
       3719.7338553089294`, -4398.6298142034075`}, {
       3671.6275216342387`, -4398.6298142034075`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4398.883444736673}, {
       4142.649334923808, -4398.883444736673}, {
       4142.649334923808, -4398.6298142034075`}, {
       4132.56390793224, -4398.6298142034075`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -4398.883444736673}, {
       4700., -4398.883444736673}, {4700., -4398.6298142034075`}, {
       4699.999375314217, -4398.6298142034075`}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -4398.883444736673}, {
      961.6796760913137, -4398.883444736673}, {
      961.6796760913137, -4398.6298142034075`}, {
      603.3076318126714, -4398.6298142034075`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.872560047585, -4398.693221836724}, \
{4699.999375314217, -4398.6298142034075`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.872560047585, -4398.693221836724}, 0.1268152666324005, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{961.8064913579461, -4398.820037103356}, {
       4699.872560047585, -4398.820037103356}, {
       4699.872560047585, -4398.693221836724}, {
       961.8064913579461, -4398.693221836724}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{961.8064913579461, -4398.820037103356}, 0.1268152666324005, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{961.6796760913137, -4398.883444736673}, \
{961.8064913579461, -4398.820037103356}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4457.768104920105}, {
        100.30833936790961`, -4457.768104920105}, {
        100.30833936790961`, -4398.883444736673}, {
        100, -4398.883444736673}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1219.9536476738244`, -4457.768104920105}, {
       1300.7680195859314`, -4457.768104920105}, {
       1300.7680195859314`, -4398.883444736673}, {
       1219.9536476738244`, -4398.883444736673}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4457.768104920105}, {
       1600.805103721155, -4457.768104920105}, {
       1600.805103721155, -4398.883444736673}, {
       1600.1736582524363`, -4398.883444736673}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4457.768104920105}, {
       2622.224473776919, -4457.768104920105}, {
       2622.224473776919, -4398.883444736673}, {
       2170.7599637903236`, -4398.883444736673}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4457.768104920105}, {
       2584.332375045108, -4457.768104920105}, {
       2584.332375045108, -4398.883444736673}, {
       2565.230890034279, -4398.883444736673}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4457.768104920105}, {
       3135.6722870386984`, -4457.768104920105}, {
       3135.6722870386984`, -4398.883444736673}, {
       3134.12601377389, -4398.883444736673}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4457.768104920105}, {
       3719.7338553089294`, -4457.768104920105}, {
       3719.7338553089294`, -4398.883444736673}, {
       3671.6275216342387`, -4398.883444736673}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4457.768104920105}, {
       4142.649334923808, -4457.768104920105}, {
       4142.649334923808, -4398.883444736673}, {
       4132.56390793224, -4398.883444736673}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -4457.768104920105}, {
       4700., -4457.768104920105}, {4700., -4398.883444736673}, {
       4699.999375314217, -4398.883444736673}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -4457.768104920105}, {
      961.8064913579461, -4457.768104920105}, {
      961.8064913579461, -4398.883444736673}, {
      603.3076318126714, -4398.883444736673}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1190.5113175821084`, -4413.604609782531}, \
{1219.9536476738244`, -4398.883444736673}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1190.5113175821084`, -4413.604609782531}, 29.442330091715974`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{991.248821449662, -4443.046939874247}, {
       1190.5113175821084`, -4443.046939874247}, {
       1190.5113175821084`, -4413.604609782531}, {
       991.248821449662, -4413.604609782531}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{991.248821449662, -4443.046939874247}, 29.442330091715974`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{961.8064913579461, -4457.768104920105}, \
{991.248821449662, -4443.046939874247}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4552.719410469784}, {
        100.30833936790961`, -4552.719410469784}, {
        100.30833936790961`, -4457.768104920105}, {
        100, -4457.768104920105}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -4552.719410469784}, {
       1300.7680195859314`, -4552.719410469784}, {
       1300.7680195859314`, -4457.768104920105}, {
       1267.429300448664, -4457.768104920105}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4552.719410469784}, {
       1600.805103721155, -4552.719410469784}, {
       1600.805103721155, -4457.768104920105}, {
       1600.1736582524363`, -4457.768104920105}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4552.719410469784}, {
       2622.224473776919, -4552.719410469784}, {
       2622.224473776919, -4457.768104920105}, {
       2170.7599637903236`, -4457.768104920105}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4552.719410469784}, {
       2584.332375045108, -4552.719410469784}, {
       2584.332375045108, -4457.768104920105}, {
       2565.230890034279, -4457.768104920105}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4552.719410469784}, {
       3135.6722870386984`, -4552.719410469784}, {
       3135.6722870386984`, -4457.768104920105}, {
       3134.12601377389, -4457.768104920105}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4552.719410469784}, {
       3719.7338553089294`, -4552.719410469784}, {
       3719.7338553089294`, -4457.768104920105}, {
       3671.6275216342387`, -4457.768104920105}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4132.56390793224, -4552.719410469784}, {
       4142.649334923808, -4552.719410469784}, {
       4142.649334923808, -4457.768104920105}, {
       4132.56390793224, -4457.768104920105}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -4552.719410469784}, {
       4700., -4552.719410469784}, {4700., -4457.768104920105}, {
       4699.999375314217, -4457.768104920105}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -4552.719410469784}, {
      991.248821449662, -4552.719410469784}, {
      991.248821449662, -4457.768104920105}, {
      603.3076318126714, -4457.768104920105}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1219.9536476738244`, -4481.505931307524}, \
{1267.429300448664, -4457.768104920105}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1219.9536476738244`, -4481.505931307524}, 47.47565277483966, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1038.7244742245018`, -4528.981584082364}, {
       1219.9536476738244`, -4528.981584082364}, {
       1219.9536476738244`, -4481.505931307524}, {
       1038.7244742245018`, -4481.505931307524}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1038.7244742245018`, -4528.981584082364}, 47.47565277483966, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{991.248821449662, -4552.719410469784}, \
{1038.7244742245018`, -4528.981584082364}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4569.096419273916}, {
        100.30833936790961`, -4569.096419273916}, {
        100.30833936790961`, -4552.719410469784}, {
        100, -4552.719410469784}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4569.096419273916}, {
       1038.7244742245018`, -4569.096419273916}, {
       1038.7244742245018`, -4552.719410469784}, {
       603.3076318126714, -4552.719410469784}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -4569.096419273916}, {
       1292.5795151838652`, -4569.096419273916}, {
       1292.5795151838652`, -4552.719410469784}, {
       1267.429300448664, -4552.719410469784}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4569.096419273916}, {
       1600.805103721155, -4569.096419273916}, {
       1600.805103721155, -4552.719410469784}, {
       1600.1736582524363`, -4552.719410469784}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4569.096419273916}, {
       2622.224473776919, -4569.096419273916}, {
       2622.224473776919, -4552.719410469784}, {
       2170.7599637903236`, -4552.719410469784}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4569.096419273916}, {
       2584.332375045108, -4569.096419273916}, {
       2584.332375045108, -4552.719410469784}, {
       2565.230890034279, -4552.719410469784}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3134.12601377389, -4569.096419273916}, {
       3135.6722870386984`, -4569.096419273916}, {
       3135.6722870386984`, -4552.719410469784}, {
       3134.12601377389, -4552.719410469784}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4569.096419273916}, {
       3719.7338553089294`, -4569.096419273916}, {
       3719.7338553089294`, -4552.719410469784}, {
       3671.6275216342387`, -4552.719410469784}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -4569.096419273916}, {
       4700., -4569.096419273916}, {4700., -4552.719410469784}, {
       4699.999375314217, -4552.719410469784}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4132.56390793224, -4569.096419273916}, {
      4142.649334923807, -4569.096419273916}, {
      4142.649334923807, -4552.719410469784}, {
      4132.56390793224, -4552.719410469784}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1292.5795151838652`, -4556.8136626708165`}, \
{1300.7680195859314`, -4552.719410469784}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1300.7680195859314`, -4556.8136626708165`}, 8.188504402066085, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1300.7680195859314`, -4565.002167072883}, {
       4124.375403530174, -4565.002167072883}, {
       4124.375403530174, -4556.8136626708165`}, {
       1300.7680195859314`, -4556.8136626708165`}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4124.375403530174, -4565.002167072883}, 8.188504402066085, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4124.375403530174, -4569.096419273916}, \
{4132.56390793224, -4565.002167072883}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -4569.746866940353}, {
        100.30833936790961`, -4569.746866940353}, {
        100.30833936790961`, -4569.096419273916}, {
        100, -4569.096419273916}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -4569.746866940353}, {
       1038.399250391283, -4569.746866940353}, {
       1038.399250391283, -4569.096419273916}, {
       603.3076318126714, -4569.096419273916}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -4569.746866940353}, {
       1292.5795151838652`, -4569.746866940353}, {
       1292.5795151838652`, -4569.096419273916}, {
       1267.429300448664, -4569.096419273916}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -4569.746866940353}, {
       1600.805103721155, -4569.746866940353}, {
       1600.805103721155, -4569.096419273916}, {
       1600.1736582524363`, -4569.096419273916}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2170.7599637903236`, -4569.746866940353}, {
       2622.224473776919, -4569.746866940353}, {
       2622.224473776919, -4569.096419273916}, {
       2170.7599637903236`, -4569.096419273916}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -4569.746866940353}, {
       2584.332375045108, -4569.746866940353}, {
       2584.332375045108, -4569.096419273916}, {
       2565.230890034279, -4569.096419273916}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -4569.746866940353}, {
       3719.7338553089294`, -4569.746866940353}, {
       3719.7338553089294`, -4569.096419273916}, {
       3671.6275216342387`, -4569.096419273916}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.375403530174, -4569.746866940353}, {
       4142.649334923807, -4569.746866940353}, {
       4142.649334923807, -4569.096419273916}, {
       4124.375403530174, -4569.096419273916}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -4569.746866940353}, {
       4700., -4569.746866940353}, {4700., -4569.096419273916}, {
       4699.999375314217, -4569.096419273916}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3134.12601377389, -4569.746866940353}, {
      3135.6722870386984`, -4569.746866940353}, {
      3135.6722870386984`, -4569.096419273916}, {
      3134.12601377389, -4569.096419273916}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1038.399250391283, -4569.259031190525}, \
{1038.7244742245018`, -4569.096419273916}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1038.7244742245018`, -4569.259031190525}, 0.32522383321873494`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1038.7244742245018`, -4569.584255023744}, {
       3133.800789940671, -4569.584255023744}, {
       3133.800789940671, -4569.259031190525}, {
       1038.7244742245018`, -4569.259031190525}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3133.800789940671, -4569.584255023744}, 0.32522383321873494`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3133.800789940671, -4569.746866940353}, \
{3134.12601377389, -4569.584255023744}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5325.183919393511}, {
        100.30833936790961`, -5325.183919393511}, {
        100.30833936790961`, -4569.746866940353}, {
        100, -4569.746866940353}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5325.183919393511}, {
       1292.5795151838652`, -5325.183919393511}, {
       1292.5795151838652`, -4569.746866940353}, {
       1267.429300448664, -4569.746866940353}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5325.183919393511}, {
       1600.805103721155, -5325.183919393511}, {
       1600.805103721155, -4569.746866940353}, {
       1600.1736582524363`, -4569.746866940353}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.4784900169025`, -5325.183919393511}, {
       2622.224473776919, -5325.183919393511}, {
       2622.224473776919, -4569.746866940353}, {
       2548.4784900169025`, -4569.746866940353}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5325.183919393511}, {
       2584.332375045108, -5325.183919393511}, {
       2584.332375045108, -4569.746866940353}, {
       2565.230890034279, -4569.746866940353}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.800789940671, -5325.183919393511}, {
       3135.6722870386984`, -5325.183919393511}, {
       3135.6722870386984`, -4569.746866940353}, {
       3133.800789940671, -4569.746866940353}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -5325.183919393511}, {
       3719.7338553089294`, -5325.183919393511}, {
       3719.7338553089294`, -4569.746866940353}, {
       3671.6275216342387`, -4569.746866940353}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.375403530174, -5325.183919393511}, {
       4142.649334923807, -5325.183919393511}, {
       4142.649334923807, -4569.746866940353}, {
       4124.375403530174, -4569.746866940353}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999375314217, -5325.183919393511}, {
       4700., -5325.183919393511}, {4700., -4569.746866940353}, {
       4699.999375314217, -4569.746866940353}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -5325.183919393511}, {
      1038.399250391283, -5325.183919393511}, {
      1038.399250391283, -4569.746866940353}, {
      603.3076318126714, -4569.746866940353}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2170.7599637903236`, -4758.606130053642}, \
{2548.4784900169025`, -4569.746866940353}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2170.7599637903236`, -4758.606130053642}, 377.71852622657906`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1416.117776617862, -5136.3246562802215`}, {
       2170.7599637903236`, -5136.3246562802215`}, {
       2170.7599637903236`, -4758.606130053642}, {
       1416.117776617862, -4758.606130053642}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1416.117776617862, -5136.3246562802215`}, 377.71852622657906`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1038.399250391283, -5325.183919393511}, \
{1416.117776617862, -5136.3246562802215`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5325.184274626205}, {
        100.30833936790961`, -5325.184274626205}, {
        100.30833936790961`, -5325.183919393511}, {
        100, -5325.183919393511}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5325.184274626205}, {
       1416.117776617862, -5325.184274626205}, {
       1416.117776617862, -5325.183919393511}, {
       603.3076318126714, -5325.183919393511}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5325.184274626205}, {
       1292.5795151838652`, -5325.184274626205}, {
       1292.5795151838652`, -5325.183919393511}, {
       1267.429300448664, -5325.183919393511}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5325.184274626205}, {
       1600.805103721155, -5325.184274626205}, {
       1600.805103721155, -5325.183919393511}, {
       1600.1736582524363`, -5325.183919393511}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.4784900169025`, -5325.184274626205}, {
       2622.224473776919, -5325.184274626205}, {
       2622.224473776919, -5325.183919393511}, {
       2548.4784900169025`, -5325.183919393511}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5325.184274626205}, {
       2584.332375045108, -5325.184274626205}, {
       2584.332375045108, -5325.183919393511}, {
       2565.230890034279, -5325.183919393511}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.800789940671, -5325.184274626205}, {
       3135.6721094223517`, -5325.184274626205}, {
       3135.6721094223517`, -5325.183919393511}, {
       3133.800789940671, -5325.183919393511}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -5325.184274626205}, {
       3719.7338553089294`, -5325.184274626205}, {
       3719.7338553089294`, -5325.183919393511}, {
       3671.6275216342387`, -5325.183919393511}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.375403530174, -5325.184274626205}, {
       4142.649334923807, -5325.184274626205}, {
       4142.649334923807, -5325.183919393511}, {
       4124.375403530174, -5325.183919393511}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999375314217, -5325.184274626205}, {
      4699.999999999999, -5325.184274626205}, {
      4699.999999999999, -5325.183919393511}, {
      4699.999375314217, -5325.183919393511}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3135.6721094223517`, -5325.184008201684}, \
{3135.6722870386984`, -5325.183919393511}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3135.6722870386984`, -5325.184008201684}, 
       0.00017761634681754583`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3135.6722870386984`, -5325.184185818031}, {
       4699.99919769787, -5325.184185818031}, {
       4699.99919769787, -5325.184008201684}, {
       3135.6722870386984`, -5325.184008201684}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99919769787, -5325.184185818031}, 
       0.00017761634681754583`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99919769787, -5325.184274626205}, \
{4699.999375314217, -5325.184185818031}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5325.184481867292}, {
        100.30833936790961`, -5325.184481867292}, {
        100.30833936790961`, -5325.184274626205}, {
        100, -5325.184274626205}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5325.184481867292}, {
       1416.117776617862, -5325.184481867292}, {
       1416.117776617862, -5325.184274626205}, {
       603.3076318126714, -5325.184274626205}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5325.184481867292}, {
       1292.5795151838652`, -5325.184481867292}, {
       1292.5795151838652`, -5325.184274626205}, {
       1267.429300448664, -5325.184274626205}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5325.184481867292}, {
       1600.805103721155, -5325.184481867292}, {
       1600.805103721155, -5325.184274626205}, {
       1600.1736582524363`, -5325.184274626205}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.4784900169025`, -5325.184481867292}, {
       2622.224473776919, -5325.184481867292}, {
       2622.224473776919, -5325.184274626205}, {
       2548.4784900169025`, -5325.184274626205}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5325.184481867292}, {
       2584.332375045108, -5325.184481867292}, {
       2584.332375045108, -5325.184274626205}, {
       2565.230890034279, -5325.184274626205}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -5325.184481867292}, {
       3719.7338553089294`, -5325.184481867292}, {
       3719.7338553089294`, -5325.184274626205}, {
       3671.6275216342387`, -5325.184274626205}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.375403530174, -5325.184481867292}, {
       4142.649334923807, -5325.184481867292}, {
       4142.649334923807, -5325.184274626205}, {
       4124.375403530174, -5325.184274626205}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5325.184481867292}, {
       4700., -5325.184481867292}, {4700., -5325.184274626205}, {
       4699.999301318414, -5325.184274626205}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3133.800789940671, -5325.184481867292}, {
      3135.6721094223517`, -5325.184481867292}, {
      3135.6721094223517`, -5325.184274626205}, {
      3133.800789940671, -5325.184274626205}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99919769787, -5325.184326436476}, \
{4699.999301318414, -5325.184274626205}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99919769787, -5325.184326436476}, 0.00010362054364845396`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3135.6722130428952`, -5325.18443005702}, {
       4699.99919769787, -5325.18443005702}, {
       4699.99919769787, -5325.184326436476}, {
       3135.6722130428952`, -5325.184326436476}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3135.6722130428952`, -5325.18443005702}, 
       0.00010362054364845396`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3135.6721094223517`, -5325.184481867292}, \
{3135.6722130428952`, -5325.18443005702}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5325.5882996683085`}, {
       1416.117776617862, -5325.5882996683085`}, {
       1416.117776617862, -5325.184481867292}, {
       603.3076318126714, -5325.184481867292}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5325.5882996683085`}, {
       1292.5795151838652`, -5325.5882996683085`}, {
       1292.5795151838652`, -5325.184481867292}, {
       1267.429300448664, -5325.184481867292}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5325.5882996683085`}, {
       1600.805103721155, -5325.5882996683085`}, {
       1600.805103721155, -5325.184481867292}, {
       1600.1736582524363`, -5325.184481867292}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5325.5882996683085`}, {
       2622.224473776919, -5325.5882996683085`}, {
       2622.224473776919, -5325.184481867292}, {
       2548.680398917411, -5325.184481867292}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5325.5882996683085`}, {
       2584.332375045108, -5325.5882996683085`}, {
       2584.332375045108, -5325.184481867292}, {
       2565.230890034279, -5325.184481867292}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.800789940671, -5325.5882996683085`}, {
       3135.6722130428952`, -5325.5882996683085`}, {
       3135.6722130428952`, -5325.184481867292}, {
       3133.800789940671, -5325.184481867292}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -5325.5882996683085`}, {
       3719.7338553089294`, -5325.5882996683085`}, {
       3719.7338553089294`, -5325.184481867292}, {
       3671.6275216342387`, -5325.184481867292}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.375403530174, -5325.5882996683085`}, {
       4142.649334923807, -5325.5882996683085`}, {
       4142.649334923807, -5325.184481867292}, {
       4124.375403530174, -5325.184481867292}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5325.5882996683085`}, {
       4700., -5325.5882996683085`}, {4700., -5325.184481867292}, {
       4699.999301318414, -5325.184481867292}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5325.5882996683085`}, {
       100.30833936790961`, -5325.5882996683085`}, {
       100.30833936790961`, -5325.184481867292}, {
       100, -5325.184481867292}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2548.4784900169025`, -5325.285436317546}, \
{2548.680398917411, -5325.184481867292}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2548.4784900169025`, -5325.285436317546}, 0.20190890050834348`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.51024826841795`, -5325.4873452180545`}, {
       2548.4784900169025`, -5325.4873452180545`}, {
       2548.4784900169025`, -5325.285436317546}, {
       100.51024826841795`, -5325.285436317546}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.51024826841795`, -5325.4873452180545`}, 
       0.20190890050834348`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.30833936790961`, -5325.5882996683085`}, \
{100.51024826841795`, -5325.4873452180545`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5326.584976822217}, {
        100.51024826841795`, -5326.584976822217}, {
        100.51024826841795`, -5325.5882996683085`}, {
        100, -5325.5882996683085`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5326.584976822217}, {
       1416.117776617862, -5326.584976822217}, {
       1416.117776617862, -5325.5882996683085`}, {
       603.3076318126714, -5325.5882996683085`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5326.584976822217}, {
       1292.5795151838652`, -5326.584976822217}, {
       1292.5795151838652`, -5325.5882996683085`}, {
       1267.429300448664, -5325.5882996683085`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5326.584976822217}, {
       2622.224473776919, -5326.584976822217}, {
       2622.224473776919, -5325.5882996683085`}, {
       2548.680398917411, -5325.5882996683085`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5326.584976822217}, {
       2584.332375045108, -5326.584976822217}, {
       2584.332375045108, -5325.5882996683085`}, {
       2565.230890034279, -5325.5882996683085`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.800789940671, -5326.584976822217}, {
       3135.6722130428952`, -5326.584976822217}, {
       3135.6722130428952`, -5325.5882996683085`}, {
       3133.800789940671, -5325.5882996683085`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3671.6275216342387`, -5326.584976822217}, {
       3719.7338553089294`, -5326.584976822217}, {
       3719.7338553089294`, -5325.5882996683085`}, {
       3671.6275216342387`, -5325.5882996683085`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5326.584976822217}, {
       4142.649334923807, -5326.584976822217}, {
       4142.649334923807, -5325.5882996683085`}, {
       4124.873742107127, -5325.5882996683085`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5326.584976822217}, {
       4700., -5326.584976822217}, {4700., -5325.5882996683085`}, {
       4699.999301318414, -5325.5882996683085`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1600.1736582524363`, -5326.584976822217}, {
      1600.805103721155, -5326.584976822217}, {
      1600.805103721155, -5325.5882996683085`}, {
      1600.1736582524363`, -5325.5882996683085`}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4124.375403530174, -5325.837468956785}, \
{4124.873742107127, -5325.5882996683085`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4124.375403530174, -5325.837468956785}, 0.49833857695415296`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.303442298109, -5326.33580753374}, {
       4124.375403530174, -5326.33580753374}, {
       4124.375403530174, -5325.837468956785}, {
       1601.303442298109, -5325.837468956785}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.303442298109, -5326.33580753374}, 0.49833857695415296`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.805103721155, -5326.584976822217}, \
{1601.303442298109, -5326.33580753374}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5343.552843031612}, {
        100.51024826841795`, -5343.552843031612}, {
        100.51024826841795`, -5326.584976822217}, {
        100, -5326.584976822217}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5343.552843031612}, {
       1416.117776617862, -5343.552843031612}, {
       1416.117776617862, -5326.584976822217}, {
       603.3076318126714, -5326.584976822217}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5343.552843031612}, {
       1284.095582079168, -5343.552843031612}, {
       1284.095582079168, -5326.584976822217}, {
       1267.429300448664, -5326.584976822217}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5343.552843031612}, {
       1601.303442298109, -5343.552843031612}, {
       1601.303442298109, -5326.584976822217}, {
       1600.1736582524363`, -5326.584976822217}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5343.552843031612}, {
       2622.224473776919, -5343.552843031612}, {
       2622.224473776919, -5326.584976822217}, {
       2548.680398917411, -5326.584976822217}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5343.552843031612}, {
       2584.332375045108, -5343.552843031612}, {
       2584.332375045108, -5326.584976822217}, {
       2565.230890034279, -5326.584976822217}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.800789940671, -5343.552843031612}, {
       3135.6722130428952`, -5343.552843031612}, {
       3135.6722130428952`, -5326.584976822217}, {
       3133.800789940671, -5326.584976822217}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5343.552843031612}, {
       4142.649334923807, -5343.552843031612}, {
       4142.649334923807, -5326.584976822217}, {
       4124.873742107127, -5326.584976822217}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5343.552843031612}, {
       4700., -5343.552843031612}, {4700., -5326.584976822217}, {
       4699.999301318414, -5326.584976822217}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3671.6275216342387`, -5343.552843031612}, {
      3719.733855308929, -5343.552843031612}, {
      3719.733855308929, -5326.584976822217}, {
      3671.6275216342387`, -5326.584976822217}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1284.095582079168, -5330.826943374565}, \
{1292.5795151838652`, -5326.584976822217}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1292.5795151838652`, -5330.826943374565}, 8.483933104697265, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1292.5795151838652`, -5339.310876479263}, {
       3663.1435885295414`, -5339.310876479263}, {
       3663.1435885295414`, -5330.826943374565}, {
       1292.5795151838652`, -5330.826943374565}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3663.1435885295414`, -5339.310876479263}, 8.483933104697265, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3663.1435885295414`, -5343.552843031612}, \
{3671.6275216342387`, -5339.310876479263}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5346.226653491324}, {
        100.51024826841795`, -5346.226653491324}, {
        100.51024826841795`, -5343.552843031612}, {
        100, -5343.552843031612}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5346.226653491324}, {
       1416.117776617862, -5346.226653491324}, {
       1416.117776617862, -5343.552843031612}, {
       603.3076318126714, -5343.552843031612}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5346.226653491324}, {
       1284.095582079168, -5346.226653491324}, {
       1284.095582079168, -5343.552843031612}, {
       1267.429300448664, -5343.552843031612}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5346.226653491324}, {
       1601.303442298109, -5346.226653491324}, {
       1601.303442298109, -5343.552843031612}, {
       1600.1736582524363`, -5343.552843031612}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5346.226653491324}, {
       2622.224473776919, -5346.226653491324}, {
       2622.224473776919, -5343.552843031612}, {
       2548.680398917411, -5343.552843031612}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5346.226653491324}, {
       2584.332375045108, -5346.226653491324}, {
       2584.332375045108, -5343.552843031612}, {
       2565.230890034279, -5343.552843031612}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3664.4804937593976`, -5346.226653491324}, {
       3719.7338553089294`, -5346.226653491324}, {
       3719.7338553089294`, -5343.552843031612}, {
       3664.4804937593976`, -5343.552843031612}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5346.226653491324}, {
       4142.649334923807, -5346.226653491324}, {
       4142.649334923807, -5343.552843031612}, {
       4124.873742107127, -5343.552843031612}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5346.226653491324}, {
       4700., -5346.226653491324}, {4700., -5343.552843031612}, {
       4699.999301318414, -5343.552843031612}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3133.800789940671, -5346.226653491324}, {
      3135.6722130428952`, -5346.226653491324}, {
      3135.6722130428952`, -5343.552843031612}, {
      3133.800789940671, -5343.552843031612}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3663.1435885295414`, -5344.22129564654}, \
{3664.4804937593976`, -5343.552843031612}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3663.1435885295414`, -5344.22129564654}, 1.3369052298561461`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3137.0091182727515`, -5345.558200876396}, {
       3663.1435885295414`, -5345.558200876396}, {
       3663.1435885295414`, -5344.22129564654}, {
       3137.0091182727515`, -5344.22129564654}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3137.0091182727515`, -5345.558200876396}, 1.3369052298561461`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3135.6722130428952`, -5346.226653491324}, \
{3137.0091182727515`, -5345.558200876396}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5348.128959383381}, {
        100.51024826841795`, -5348.128959383381}, {
        100.51024826841795`, -5346.226653491324}, {
        100, -5346.226653491324}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5348.128959383381}, {
       1416.117776617862, -5348.128959383381}, {
       1416.117776617862, -5346.226653491324}, {
       603.3076318126714, -5346.226653491324}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5348.128959383381}, {
       1284.095582079168, -5348.128959383381}, {
       1284.095582079168, -5346.226653491324}, {
       1267.429300448664, -5346.226653491324}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5348.128959383381}, {
       1601.303442298109, -5348.128959383381}, {
       1601.303442298109, -5346.226653491324}, {
       1600.1736582524363`, -5346.226653491324}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5348.128959383381}, {
       2621.2733208308905`, -5348.128959383381}, {
       2621.2733208308905`, -5346.226653491324}, {
       2548.680398917411, -5346.226653491324}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5348.128959383381}, {
       2584.332375045108, -5348.128959383381}, {
       2584.332375045108, -5346.226653491324}, {
       2565.230890034279, -5346.226653491324}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3664.4804937593976`, -5348.128959383381}, {
       3719.7338553089294`, -5348.128959383381}, {
       3719.7338553089294`, -5346.226653491324}, {
       3664.4804937593976`, -5346.226653491324}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5348.128959383381}, {
       4142.649334923807, -5348.128959383381}, {
       4142.649334923807, -5346.226653491324}, {
       4124.873742107127, -5346.226653491324}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5348.128959383381}, {
       4700., -5348.128959383381}, {4700., -5346.226653491324}, {
       4699.999301318414, -5346.226653491324}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3133.800789940671, -5348.128959383381}, {
      3137.0091182727515`, -5348.128959383381}, {
      3137.0091182727515`, -5346.226653491324}, {
      3133.800789940671, -5346.226653491324}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2621.2733208308905`, -5346.702229964339}, \
{2622.224473776919, -5346.226653491324}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.224473776919, -5346.702229964339}, 0.9511529460282229, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.224473776919, -5347.653382910366}, {
       3132.849636994643, -5347.653382910366}, {
       3132.849636994643, -5346.702229964339}, {
       2622.224473776919, -5346.702229964339}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3132.849636994643, -5347.653382910366}, 0.9511529460282229, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3132.849636994643, -5348.128959383381}, \
{3133.800789940671, -5347.653382910366}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5351.341025440281}, {
        100.51024826841795`, -5351.341025440281}, {
        100.51024826841795`, -5348.128959383381}, {
        100, -5348.128959383381}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5351.341025440281}, {
       1416.117776617862, -5351.341025440281}, {
       1416.117776617862, -5348.128959383381}, {
       603.3076318126714, -5348.128959383381}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5351.341025440281}, {
       1284.095582079168, -5351.341025440281}, {
       1284.095582079168, -5348.128959383381}, {
       1267.429300448664, -5348.128959383381}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5351.341025440281}, {
       1601.303442298109, -5351.341025440281}, {
       1601.303442298109, -5348.128959383381}, {
       1600.1736582524363`, -5348.128959383381}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5351.341025440281}, {
       2621.2733208308905`, -5351.341025440281}, {
       2621.2733208308905`, -5348.128959383381}, {
       2548.680398917411, -5348.128959383381}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.849636994643, -5351.341025440281}, {
       3137.0091182727515`, -5351.341025440281}, {
       3137.0091182727515`, -5348.128959383381}, {
       3132.849636994643, -5348.128959383381}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.0865267878476`, -5351.341025440281}, {
       3719.7338553089294`, -5351.341025440281}, {
       3719.7338553089294`, -5348.128959383381}, {
       3666.0865267878476`, -5348.128959383381}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5351.341025440281}, {
       4142.649334923807, -5351.341025440281}, {
       4142.649334923807, -5348.128959383381}, {
       4124.873742107127, -5348.128959383381}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5351.341025440281}, {
       4700., -5351.341025440281}, {4700., -5348.128959383381}, {
       4699.999301318414, -5348.128959383381}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2565.230890034279, -5351.341025440281}, {
      2584.332375045108, -5351.341025440281}, {
      2584.332375045108, -5348.128959383381}, {
      2565.230890034279, -5348.128959383381}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3664.4804937593976`, -5348.931975897606}, \
{3666.0865267878476`, -5348.128959383381}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3664.4804937593976`, -5348.931975897606}, 1.6060330284497653`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2585.938408073558, -5350.538008926056}, {
       3664.4804937593976`, -5350.538008926056}, {
       3664.4804937593976`, -5348.931975897606}, {
       2585.938408073558, -5348.931975897606}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2585.938408073558, -5350.538008926056}, 1.6060330284497653`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.332375045108, -5351.341025440281}, \
{2585.938408073558, -5350.538008926056}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5351.607012507885}, {
       1416.117776617862, -5351.607012507885}, {
       1416.117776617862, -5351.341025440281}, {
       603.3076318126714, -5351.341025440281}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5351.607012507885}, {
       1284.095582079168, -5351.607012507885}, {
       1284.095582079168, -5351.341025440281}, {
       1267.429300448664, -5351.341025440281}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5351.607012507885}, {
       1601.303442298109, -5351.607012507885}, {
       1601.303442298109, -5351.341025440281}, {
       1600.1736582524363`, -5351.341025440281}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5351.607012507885}, {
       2621.2733208308905`, -5351.607012507885}, {
       2621.2733208308905`, -5351.341025440281}, {
       2548.680398917411, -5351.341025440281}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5351.607012507885}, {
       2585.938408073558, -5351.607012507885}, {
       2585.938408073558, -5351.341025440281}, {
       2565.230890034279, -5351.341025440281}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5351.607012507885}, {
       3137.0091182727515`, -5351.607012507885}, {
       3137.0091182727515`, -5351.341025440281}, {
       3132.982630528445, -5351.341025440281}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.0865267878476`, -5351.607012507885}, {
       3719.7338553089294`, -5351.607012507885}, {
       3719.7338553089294`, -5351.341025440281}, {
       3666.0865267878476`, -5351.341025440281}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.873742107127, -5351.607012507885}, {
       4142.649334923807, -5351.607012507885}, {
       4142.649334923807, -5351.341025440281}, {
       4124.873742107127, -5351.341025440281}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5351.607012507885}, {
       4700., -5351.607012507885}, {4700., -5351.341025440281}, {
       4699.999301318414, -5351.341025440281}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5351.607012507885}, {
       100.51024826841795`, -5351.607012507885}, {
       100.51024826841795`, -5351.341025440281}, {
       100, -5351.341025440281}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3132.849636994643, -5351.4075222071815`}, \
{3132.982630528445, -5351.341025440281}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3132.849636994643, -5351.4075222071815`}, 0.13299353380203527`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.64324180221999`, -5351.540515740984}, {
       3132.849636994643, -5351.540515740984}, {
       3132.849636994643, -5351.4075222071815`}, {
       100.64324180221999`, -5351.4075222071815`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.64324180221999`, -5351.540515740984}, 0.13299353380203527`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.51024826841795`, -5351.607012507885}, \
{100.64324180221999`, -5351.540515740984}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5371.661917993304}, {
        100.64324180221999`, -5371.661917993304}, {
        100.64324180221999`, -5351.607012507885}, {
        100, -5351.607012507885}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5371.661917993304}, {
       1406.0903238751528`, -5371.661917993304}, {
       1406.0903238751528`, -5351.607012507885}, {
       603.3076318126714, -5351.607012507885}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5371.661917993304}, {
       1284.095582079168, -5371.661917993304}, {
       1284.095582079168, -5351.607012507885}, {
       1267.429300448664, -5351.607012507885}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5371.661917993304}, {
       1601.303442298109, -5371.661917993304}, {
       1601.303442298109, -5351.607012507885}, {
       1600.1736582524363`, -5351.607012507885}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5371.661917993304}, {
       2621.2733208308905`, -5371.661917993304}, {
       2621.2733208308905`, -5351.607012507885}, {
       2548.680398917411, -5351.607012507885}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5371.661917993304}, {
       2585.938408073558, -5371.661917993304}, {
       2585.938408073558, -5351.607012507885}, {
       2565.230890034279, -5351.607012507885}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5371.661917993304}, {
       3137.0091182727515`, -5371.661917993304}, {
       3137.0091182727515`, -5351.607012507885}, {
       3132.982630528445, -5351.607012507885}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.0865267878476`, -5371.661917993304}, {
       3719.7338553089294`, -5371.661917993304}, {
       3719.7338553089294`, -5351.607012507885}, {
       3666.0865267878476`, -5351.607012507885}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999301318414, -5371.661917993304}, {
       4700., -5371.661917993304}, {4700., -5351.607012507885}, {
       4699.999301318414, -5351.607012507885}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4124.873742107127, -5371.661917993304}, {
      4142.649334923807, -5371.661917993304}, {
      4142.649334923807, -5351.607012507885}, {
      4124.873742107127, -5351.607012507885}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1406.0903238751528`, -5356.62073887924}, \
{1416.117776617862, -5351.607012507885}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1416.117776617862, -5356.62073887924}, 10.027452742709347`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1416.117776617862, -5366.648191621949}, {
       4114.846289364418, -5366.648191621949}, {
       4114.846289364418, -5356.62073887924}, {
       1416.117776617862, -5356.62073887924}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4114.846289364418, -5366.648191621949}, 10.027452742709347`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4114.846289364418, -5371.661917993304}, \
{4124.873742107127, -5366.648191621949}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5371.663266516183}, {
        100.64324180221999`, -5371.663266516183}, {
        100.64324180221999`, -5371.661917993304}, {
        100, -5371.661917993304}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5371.663266516183}, {
       1406.0903238751528`, -5371.663266516183}, {
       1406.0903238751528`, -5371.661917993304}, {
       603.3076318126714, -5371.661917993304}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5371.663266516183}, {
       1601.303442298109, -5371.663266516183}, {
       1601.303442298109, -5371.661917993304}, {
       1600.1736582524363`, -5371.661917993304}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5371.663266516183}, {
       2621.2733208308905`, -5371.663266516183}, {
       2621.2733208308905`, -5371.661917993304}, {
       2548.680398917411, -5371.661917993304}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5371.663266516183}, {
       2585.938408073558, -5371.663266516183}, {
       2585.938408073558, -5371.661917993304}, {
       2565.230890034279, -5371.661917993304}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5371.663266516183}, {
       3137.0091182727515`, -5371.663266516183}, {
       3137.0091182727515`, -5371.661917993304}, {
       3132.982630528445, -5371.661917993304}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.0865267878476`, -5371.663266516183}, {
       3719.7338553089294`, -5371.663266516183}, {
       3719.7338553089294`, -5371.661917993304}, {
       3666.0865267878476`, -5371.661917993304}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.846289364418, -5371.663266516183}, {
       4142.649334923807, -5371.663266516183}, {
       4142.649334923807, -5371.661917993304}, {
       4114.846289364418, -5371.661917993304}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999755798535`, -5371.663266516183}, {
       4700., -5371.663266516183}, {4700., -5371.661917993304}, {
       4699.9999755798535`, -5371.661917993304}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1267.429300448664, -5371.663266516183}, {
      1284.095582079168, -5371.663266516183}, {
      1284.095582079168, -5371.661917993304}, {
      1267.429300448664, -5371.661917993304}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999301318414, -5371.662255124024}, \
{4699.9999755798535`, -5371.661917993304}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999301318414, -5371.662255124024}, 0.0006742614394101808, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1284.0962563406074`, -5371.662929385464}, {
       4699.999301318414, -5371.662929385464}, {
       4699.999301318414, -5371.662255124024}, {
       1284.0962563406074`, -5371.662255124024}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1284.0962563406074`, -5371.662929385464}, 
       0.0006742614394101808, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1284.095582079168, -5371.663266516183}, \
{1284.0962563406074`, -5371.662929385464}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5372.716595623297}, {
       1406.0903238751528`, -5372.716595623297}, {
       1406.0903238751528`, -5371.663266516183}, {
       603.3076318126714, -5371.663266516183}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5372.716595623297}, {
       1284.0962563406074`, -5372.716595623297}, {
       1284.0962563406074`, -5371.663266516183}, {
       1267.429300448664, -5371.663266516183}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5372.716595623297}, {
       1601.303442298109, -5372.716595623297}, {
       1601.303442298109, -5371.663266516183}, {
       1600.1736582524363`, -5371.663266516183}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5372.716595623297}, {
       2621.2733208308905`, -5372.716595623297}, {
       2621.2733208308905`, -5371.663266516183}, {
       2548.680398917411, -5371.663266516183}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5372.716595623297}, {
       2585.938408073558, -5372.716595623297}, {
       2585.938408073558, -5371.663266516183}, {
       2565.230890034279, -5371.663266516183}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5372.716595623297}, {
       3137.0091182727515`, -5372.716595623297}, {
       3137.0091182727515`, -5371.663266516183}, {
       3132.982630528445, -5371.663266516183}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5372.716595623297}, {
       3719.7338553089294`, -5372.716595623297}, {
       3719.7338553089294`, -5371.663266516183}, {
       3666.613191341404, -5371.663266516183}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.846289364418, -5372.716595623297}, {
       4142.649334923807, -5372.716595623297}, {
       4142.649334923807, -5371.663266516183}, {
       4114.846289364418, -5371.663266516183}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999755798535`, -5372.716595623297}, {
       4700., -5372.716595623297}, {4700., -5371.663266516183}, {
       4699.9999755798535`, -5371.663266516183}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5372.716595623297}, {
       100.64324180221999`, -5372.716595623297}, {
       100.64324180221999`, -5371.663266516183}, {
       100, -5371.663266516183}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3666.0865267878476`, -5371.926598792962}, \
{3666.613191341404, -5371.663266516183}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3666.0865267878476`, -5371.926598792962}, 0.5266645535565022, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.16990635577649`, -5372.453263346519}, {
       3666.0865267878476`, -5372.453263346519}, {
       3666.0865267878476`, -5371.926598792962}, {
       101.16990635577649`, -5371.926598792962}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.16990635577649`, -5372.453263346519}, 0.5266645535565022, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.64324180221999`, -5372.716595623297}, \
{101.16990635577649`, -5372.453263346519}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5372.716603168251}, {
        101.16990635577649`, -5372.716603168251}, {
        101.16990635577649`, -5372.716595623297}, {
        100, -5372.716595623297}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5372.716603168251}, {
       1406.0903238751528`, -5372.716603168251}, {
       1406.0903238751528`, -5372.716595623297}, {
       603.3076318126714, -5372.716595623297}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5372.716603168251}, {
       1284.0962563406074`, -5372.716603168251}, {
       1284.0962563406074`, -5372.716595623297}, {
       1267.429300448664, -5372.716595623297}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5372.716603168251}, {
       1601.303442298109, -5372.716603168251}, {
       1601.303442298109, -5372.716595623297}, {
       1600.1736582524363`, -5372.716595623297}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5372.716603168251}, {
       2621.2733208308905`, -5372.716603168251}, {
       2621.2733208308905`, -5372.716595623297}, {
       2548.680398917411, -5372.716595623297}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5372.716603168251}, {
       2585.938408073558, -5372.716603168251}, {
       2585.938408073558, -5372.716595623297}, {
       2565.230890034279, -5372.716595623297}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5372.716603168251}, {
       3137.0091145002743`, -5372.716603168251}, {
       3137.0091145002743`, -5372.716595623297}, {
       3132.982630528445, -5372.716595623297}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5372.716603168251}, {
       3719.7338553089294`, -5372.716603168251}, {
       3719.7338553089294`, -5372.716595623297}, {
       3666.613191341404, -5372.716595623297}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.846289364418, -5372.716603168251}, {
       4142.649334923807, -5372.716603168251}, {
       4142.649334923807, -5372.716595623297}, {
       4114.846289364418, -5372.716595623297}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.9999755798535`, -5372.716603168251}, {
      4700., -5372.716603168251}, {4700., -5372.716595623297}, {
      4699.9999755798535`, -5372.716595623297}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3137.0091145002743`, -5372.716597509535}, \
{3137.0091182727515`, -5372.716595623297}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3137.0091182727515`, -5372.716597509535}, 
       3.772477074687698*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3137.0091182727515`, -5372.716601282013}, {
       4699.999971807377, -5372.716601282013}, {
       4699.999971807377, -5372.716597509535}, {
       3137.0091182727515`, -5372.716597509535}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999971807377, -5372.716601282013}, 
       3.772477074687698*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999971807377, -5372.716603168251}, \
{4699.9999755798535`, -5372.716601282013}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5372.716633113178}, {
        101.16990635577649`, -5372.716633113178}, {
        101.16990635577649`, -5372.716603168251}, {
        100, -5372.716603168251}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5372.716633113178}, {
       1406.0903238751528`, -5372.716633113178}, {
       1406.0903238751528`, -5372.716603168251}, {
       603.3076318126714, -5372.716603168251}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5372.716633113178}, {
       1284.0962563406074`, -5372.716633113178}, {
       1284.0962563406074`, -5372.716603168251}, {
       1267.429300448664, -5372.716603168251}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1600.1736582524363`, -5372.716633113178}, {
       1601.303442298109, -5372.716633113178}, {
       1601.303442298109, -5372.716603168251}, {
       1600.1736582524363`, -5372.716603168251}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5372.716633113178}, {
       2621.2733208308905`, -5372.716633113178}, {
       2621.2733208308905`, -5372.716603168251}, {
       2548.680398917411, -5372.716603168251}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5372.716633113178}, {
       2585.9383931010943`, -5372.716633113178}, {
       2585.9383931010943`, -5372.716603168251}, {
       2565.230890034279, -5372.716603168251}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5372.716633113178}, {
       3137.0091145002743`, -5372.716633113178}, {
       3137.0091145002743`, -5372.716603168251}, {
       3132.982630528445, -5372.716603168251}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5372.716633113178}, {
       3719.7338553089294`, -5372.716633113178}, {
       3719.7338553089294`, -5372.716603168251}, {
       3666.613191341404, -5372.716603168251}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.846289364418, -5372.716633113178}, {
       4142.649334923807, -5372.716633113178}, {
       4142.649334923807, -5372.716603168251}, {
       4114.846289364418, -5372.716603168251}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999971807377, -5372.716633113178}, {
      4700., -5372.716633113178}, {4700., -5372.716603168251}, {
      4699.999971807377, -5372.716603168251}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2585.9383931010943`, -5372.716610654483}, \
{2585.938408073558, -5372.716603168251}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2585.938408073558, -5372.716610654483}, 
       0.000014972463651846681`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2585.938408073558, -5372.716625626947}, {
       4699.999956834913, -5372.716625626947}, {
       4699.999956834913, -5372.716610654483}, {
       2585.938408073558, -5372.716610654483}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999956834913, -5372.716625626947}, 
       0.000014972463651846681`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999956834913, -5372.716633113178}, \
{4699.999971807377, -5372.716625626947}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5374.934283688219}, {
        101.16990635577649`, -5374.934283688219}, {
        101.16990635577649`, -5372.716633113178}, {
        100, -5372.716633113178}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5374.934283688219}, {
       1284.0962563406074`, -5374.934283688219}, {
       1284.0962563406074`, -5372.716633113178}, {
       1267.429300448664, -5372.716633113178}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5374.934283688219}, {
       1601.303442298109, -5374.934283688219}, {
       1601.303442298109, -5372.716633113178}, {
       1601.2824835399565`, -5372.716633113178}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5374.934283688219}, {
       2621.2733208308905`, -5374.934283688219}, {
       2621.2733208308905`, -5372.716633113178}, {
       2548.680398917411, -5372.716633113178}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5374.934283688219}, {
       2585.9383931010943`, -5374.934283688219}, {
       2585.9383931010943`, -5372.716633113178}, {
       2565.230890034279, -5372.716633113178}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5374.934283688219}, {
       3137.0091145002743`, -5374.934283688219}, {
       3137.0091145002743`, -5372.716633113178}, {
       3132.982630528445, -5372.716633113178}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5374.934283688219}, {
       3719.7338553089294`, -5374.934283688219}, {
       3719.7338553089294`, -5372.716633113178}, {
       3666.613191341404, -5372.716633113178}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.846289364418, -5374.934283688219}, {
       4142.649334923807, -5374.934283688219}, {
       4142.649334923807, -5372.716633113178}, {
       4114.846289364418, -5372.716633113178}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999956834913, -5374.934283688219}, {
       4700., -5374.934283688219}, {4700., -5372.716633113178}, {
       4699.999956834913, -5372.716633113178}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -5374.934283688219}, {
      1406.0903238751528`, -5374.934283688219}, {
      1406.0903238751528`, -5372.716633113178}, {
      603.3076318126714, -5372.716633113178}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1600.1736582524363`, -5373.271045756938}, \
{1601.2824835399565`, -5372.716633113178}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1600.1736582524363`, -5373.271045756938}, 1.108825287520216, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1407.199149162673, -5374.379871044459}, {
       1600.1736582524363`, -5374.379871044459}, {
       1600.1736582524363`, -5373.271045756938}, {
       1407.199149162673, -5373.271045756938}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1407.199149162673, -5374.379871044459}, 1.108825287520216, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1406.0903238751528`, -5374.934283688219}, \
{1407.199149162673, -5374.379871044459}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5374.936582818687}, {
        101.16990635577649`, -5374.936582818687}, {
        101.16990635577649`, -5374.934283688219}, {
        100, -5374.934283688219}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5374.936582818687}, {
       1407.199149162673, -5374.936582818687}, {
       1407.199149162673, -5374.934283688219}, {
       603.3076318126714, -5374.934283688219}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5374.936582818687}, {
       1284.0962563406074`, -5374.936582818687}, {
       1284.0962563406074`, -5374.934283688219}, {
       1267.429300448664, -5374.934283688219}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5374.936582818687}, {
       1601.3022927328745`, -5374.936582818687}, {
       1601.3022927328745`, -5374.934283688219}, {
       1601.2824835399565`, -5374.934283688219}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5374.936582818687}, {
       2621.2733208308905`, -5374.936582818687}, {
       2621.2733208308905`, -5374.934283688219}, {
       2548.680398917411, -5374.934283688219}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5374.936582818687}, {
       2585.9383931010943`, -5374.936582818687}, {
       2585.9383931010943`, -5374.934283688219}, {
       2565.230890034279, -5374.934283688219}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5374.936582818687}, {
       3137.0091145002743`, -5374.936582818687}, {
       3137.0091145002743`, -5374.934283688219}, {
       3132.982630528445, -5374.934283688219}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5374.936582818687}, {
       3719.7338553089294`, -5374.936582818687}, {
       3719.7338553089294`, -5374.934283688219}, {
       3666.613191341404, -5374.934283688219}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999956834913, -5374.936582818687}, {
       4700., -5374.936582818687}, {4700., -5374.934283688219}, {
       4699.999956834913, -5374.934283688219}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4114.846289364418, -5374.936582818687}, {
      4142.649334923807, -5374.936582818687}, {
      4142.649334923807, -5374.934283688219}, {
      4114.846289364418, -5374.934283688219}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.3022927328745`, -5374.934858470836}, \
{1601.303442298109, -5374.934283688219}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.303442298109, -5374.934858470836}, 0.0011495652344672182`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.303442298109, -5374.93600803607}, {
       4114.845139799184, -5374.93600803607}, {
       4114.845139799184, -5374.934858470836}, {
       1601.303442298109, -5374.934858470836}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4114.845139799184, -5374.93600803607}, 
       0.0011495652344672182`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4114.845139799184, -5374.936582818687}, \
{4114.846289364418, -5374.93600803607}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5374.97316773813}, {
        101.16990635577649`, -5374.97316773813}, {
        101.16990635577649`, -5374.936582818687}, {
        100, -5374.936582818687}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5374.97316773813}, {
       1407.199149162673, -5374.97316773813}, {
       1407.199149162673, -5374.936582818687}, {
       603.3076318126714, -5374.936582818687}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5374.97316773813}, {
       1284.0962563406074`, -5374.97316773813}, {
       1284.0962563406074`, -5374.936582818687}, {
       1267.429300448664, -5374.936582818687}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5374.97316773813}, {
       1601.2840002731534`, -5374.97316773813}, {
       1601.2840002731534`, -5374.936582818687}, {
       1601.2824835399565`, -5374.936582818687}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5374.97316773813}, {
       2621.2733208308905`, -5374.97316773813}, {
       2621.2733208308905`, -5374.936582818687}, {
       2548.680398917411, -5374.936582818687}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5374.97316773813}, {
       2585.9383931010943`, -5374.97316773813}, {
       2585.9383931010943`, -5374.936582818687}, {
       2565.230890034279, -5374.936582818687}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5374.97316773813}, {
       3137.0091145002743`, -5374.97316773813}, {
       3137.0091145002743`, -5374.936582818687}, {
       3132.982630528445, -5374.936582818687}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5374.97316773813}, {
       3719.7338553089294`, -5374.97316773813}, {
       3719.7338553089294`, -5374.936582818687}, {
       3666.613191341404, -5374.936582818687}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999956834913, -5374.97316773813}, {
       4700., -5374.97316773813}, {4700., -5374.936582818687}, {
       4699.999956834913, -5374.936582818687}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4114.845139799184, -5374.97316773813}, {
      4142.649334923808, -5374.97316773813}, {
      4142.649334923808, -5374.936582818687}, {
      4114.845139799184, -5374.936582818687}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2840002731534`, -5374.945729048548}, \
{1601.3022927328745`, -5374.936582818687}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.3022927328745`, -5374.945729048548}, 
       0.018292459721285983`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.3022927328745`, -5374.964021508269}, {
       4114.826847339463, -5374.964021508269}, {
       4114.826847339463, -5374.945729048548}, {
       1601.3022927328745`, -5374.945729048548}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4114.826847339463, -5374.964021508269}, 
       0.018292459721285983`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4114.826847339463, -5374.97316773813}, \
{4114.845139799184, -5374.964021508269}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5374.973210334528}, {
        101.16990635577649`, -5374.973210334528}, {
        101.16990635577649`, -5374.97316773813}, {
        100, -5374.97316773813}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5374.973210334528}, {
       1407.199149162673, -5374.973210334528}, {
       1407.199149162673, -5374.97316773813}, {
       603.3076318126714, -5374.97316773813}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5374.973210334528}, {
       1284.0962563406074`, -5374.973210334528}, {
       1284.0962563406074`, -5374.97316773813}, {
       1267.429300448664, -5374.97316773813}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5374.973210334528}, {
       1601.2840002731534`, -5374.973210334528}, {
       1601.2840002731534`, -5374.97316773813}, {
       1601.2824835399565`, -5374.97316773813}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5374.973210334528}, {
       2621.2733208308905`, -5374.973210334528}, {
       2621.2733208308905`, -5374.97316773813}, {
       2548.680398917411, -5374.97316773813}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5374.973210334528}, {
       2585.9383931010943`, -5374.973210334528}, {
       2585.9383931010943`, -5374.97316773813}, {
       2565.230890034279, -5374.97316773813}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5374.973210334528}, {
       3137.0091145002743`, -5374.973210334528}, {
       3137.0091145002743`, -5374.97316773813}, {
       3132.982630528445, -5374.97316773813}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4114.826847339463, -5374.973210334528}, {
       4142.649334923808, -5374.973210334528}, {
       4142.649334923808, -5374.97316773813}, {
       4114.826847339463, -5374.97316773813}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999978133112, -5374.973210334528}, {
       4700., -5374.973210334528}, {4700., -5374.97316773813}, {
       4699.999978133112, -5374.97316773813}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3666.613191341404, -5374.973210334528}, {
      3719.7338553089294`, -5374.973210334528}, {
      3719.7338553089294`, -5374.97316773813}, {
      3666.613191341404, -5374.97316773813}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999956834913, -5374.973178387229}, \
{4699.999978133112, -5374.97316773813}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999956834913, -5374.973178387229}, 
       0.000021298198991872884`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3719.7338766071284`, -5374.973199685428}, {
       4699.999956834913, -5374.973199685428}, {
       4699.999956834913, -5374.973178387229}, {
       3719.7338766071284`, -5374.973178387229}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3719.7338766071284`, -5374.973199685428}, 
       0.000021298198991872884`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3719.7338553089294`, -5374.973210334528}, \
{3719.7338766071284`, -5374.973199685428}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5429.661676901514}, {
        101.16990635577649`, -5429.661676901514}, {
        101.16990635577649`, -5374.973210334528}, {
        100, -5374.973210334528}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5429.661676901514}, {
       1407.199149162673, -5429.661676901514}, {
       1407.199149162673, -5374.973210334528}, {
       603.3076318126714, -5374.973210334528}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5429.661676901514}, {
       1284.0962563406074`, -5429.661676901514}, {
       1284.0962563406074`, -5374.973210334528}, {
       1267.429300448664, -5374.973210334528}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5429.661676901514}, {
       1601.2840002731534`, -5429.661676901514}, {
       1601.2840002731534`, -5374.973210334528}, {
       1601.2824835399565`, -5374.973210334528}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5429.661676901514}, {
       2621.2733208308905`, -5429.661676901514}, {
       2621.2733208308905`, -5374.973210334528}, {
       2548.680398917411, -5374.973210334528}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2565.230890034279, -5429.661676901514}, {
       2585.9383931010943`, -5429.661676901514}, {
       2585.9383931010943`, -5374.973210334528}, {
       2565.230890034279, -5374.973210334528}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5429.661676901514}, {
       3137.0091145002743`, -5429.661676901514}, {
       3137.0091145002743`, -5374.973210334528}, {
       3132.982630528445, -5374.973210334528}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5429.661676901514}, {
       3692.3896433236355`, -5429.661676901514}, {
       3692.3896433236355`, -5374.973210334528}, {
       3666.613191341404, -5374.973210334528}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999978133112, -5429.661676901514}, {
       4700., -5429.661676901514}, {4700., -5374.973210334528}, {
       4699.999978133112, -5374.973210334528}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4114.826847339463, -5429.661676901514}, {
      4142.649334923808, -5429.661676901514}, {
      4142.649334923808, -5374.973210334528}, {
      4114.826847339463, -5374.973210334528}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3692.3896433236355`, -5388.645326976274}, \
{3719.7338766071284`, -5374.973210334528}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3719.7338766071284`, -5388.645326976274}, 27.34423328349288, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3719.7338766071284`, -5415.989560259767}, {
       4087.48261405597, -5415.989560259767}, {
       4087.48261405597, -5388.645326976274}, {
       3719.7338766071284`, -5388.645326976274}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4087.48261405597, -5415.989560259767}, 27.34423328349288, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4087.48261405597, -5429.661676901514}, \
{4114.826847339463, -5415.989560259767}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5446.81614312827}, {
        101.16990635577649`, -5446.81614312827}, {
        101.16990635577649`, -5429.661676901513}, {
        100, -5429.661676901513}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5446.81614312827}, {
       1407.199149162673, -5446.81614312827}, {
       1407.199149162673, -5429.661676901513}, {
       603.3076318126714, -5429.661676901513}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5446.81614312827}, {
       1275.5190232272291`, -5446.81614312827}, {
       1275.5190232272291`, -5429.661676901513}, {
       1267.429300448664, -5429.661676901513}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5446.81614312827}, {
       1601.2840002731534`, -5446.81614312827}, {
       1601.2840002731534`, -5429.661676901513}, {
       1601.2824835399565`, -5429.661676901513}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5446.81614312827}, {
       2621.2733208308905`, -5446.81614312827}, {
       2621.2733208308905`, -5429.661676901513}, {
       2548.680398917411, -5429.661676901513}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5446.81614312827}, {
       3137.0091145002743`, -5446.81614312827}, {
       3137.0091145002743`, -5429.661676901513}, {
       3132.982630528445, -5429.661676901513}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5446.81614312827}, {
       3692.3896433236355`, -5446.81614312827}, {
       3692.3896433236355`, -5429.661676901513}, {
       3666.613191341404, -5429.661676901513}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5446.81614312827}, {
       4142.649334923808, -5446.81614312827}, {
       4142.649334923808, -5429.661676901513}, {
       4087.48261405597, -5429.661676901513}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999978133112, -5446.81614312827}, {
       4700., -5446.81614312827}, {4700., -5429.661676901513}, {
       4699.999978133112, -5429.661676901513}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2565.2308900342796`, -5446.81614312827}, {
      2585.9383931010943`, -5446.81614312827}, {
      2585.9383931010943`, -5429.661676901513}, {
      2565.2308900342796`, -5429.661676901513}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1275.5190232272291`, -5433.950293458202}, \
{1284.0962563406074`, -5429.661676901513}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1284.0962563406074`, -5433.950293458202}, 8.57723311337827, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1284.0962563406074`, -5442.527526571581}, {
       2556.653656920901, -5442.527526571581}, {
       2556.653656920901, -5433.950293458202}, {
       1284.0962563406074`, -5433.950293458202}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2556.653656920901, -5442.527526571581}, 8.57723311337827, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2556.653656920901, -5446.81614312827}, \
{2565.2308900342796`, -5442.527526571581}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5486.995911731079}, {
        101.16990635577649`, -5486.995911731079}, {
        101.16990635577649`, -5446.81614312827}, {
        100, -5446.81614312827}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5486.995911731079}, {
       1387.1092648612685`, -5486.995911731079}, {
       1387.1092648612685`, -5446.81614312827}, {
       603.3076318126714, -5446.81614312827}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5486.995911731079}, {
       1275.5190232272291`, -5486.995911731079}, {
       1275.5190232272291`, -5446.81614312827}, {
       1267.429300448664, -5446.81614312827}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5486.995911731079}, {
       1601.2840002731534`, -5486.995911731079}, {
       1601.2840002731534`, -5446.81614312827}, {
       1601.2824835399565`, -5446.81614312827}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5486.995911731079}, {
       2621.2733208308905`, -5486.995911731079}, {
       2621.2733208308905`, -5446.81614312827}, {
       2548.680398917411, -5446.81614312827}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5486.995911731079}, {
       3137.0091145002743`, -5486.995911731079}, {
       3137.0091145002743`, -5446.81614312827}, {
       3132.982630528445, -5446.81614312827}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5486.995911731079}, {
       3692.3896433236355`, -5486.995911731079}, {
       3692.3896433236355`, -5446.81614312827}, {
       3666.613191341404, -5446.81614312827}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5486.995911731079}, {
       4142.649334923808, -5486.995911731079}, {
       4142.649334923808, -5446.81614312827}, {
       4087.48261405597, -5446.81614312827}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999978133112, -5486.995911731079}, {
       4700., -5486.995911731079}, {4700., -5446.81614312827}, {
       4699.999978133112, -5446.81614312827}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2556.653656920901, -5486.995911731079}, {
      2585.9383931010943`, -5486.995911731079}, {
      2585.9383931010943`, -5446.81614312827}, {
      2556.653656920901, -5446.81614312827}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1387.1092648612685`, -5456.8610852789725`}, \
{1407.199149162673, -5446.81614312827}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1407.199149162673, -5456.8610852789725`}, 20.089884301404588`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1407.199149162673, -5476.950969580377}, {
       2536.5637726194964`, -5476.950969580377}, {
       2536.5637726194964`, -5456.8610852789725`}, {
       1407.199149162673, -5456.8610852789725`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2536.5637726194964`, -5476.950969580377}, 
       20.089884301404588`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2536.5637726194964`, -5486.995911731079}, \
{2556.653656920901, -5476.950969580377}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5486.995924584996}, {
        101.16990635577649`, -5486.995924584996}, {
        101.16990635577649`, -5486.995911731079}, {
        100, -5486.995911731079}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5486.995924584996}, {
       1387.1092648612685`, -5486.995924584996}, {
       1387.1092648612685`, -5486.995911731079}, {
       603.3076318126714, -5486.995911731079}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5486.995924584996}, {
       1275.5190232272291`, -5486.995924584996}, {
       1275.5190232272291`, -5486.995911731079}, {
       1267.429300448664, -5486.995911731079}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5486.995924584996}, {
       1601.2840002731534`, -5486.995924584996}, {
       1601.2840002731534`, -5486.995911731079}, {
       1601.2824835399565`, -5486.995911731079}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5486.995924584996}, {
       2621.2733144039325`, -5486.995924584996}, {
       2621.2733144039325`, -5486.995911731079}, {
       2548.680398917411, -5486.995911731079}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2536.5637726194964`, -5486.995924584996}, {
       2585.9383931010943`, -5486.995924584996}, {
       2585.9383931010943`, -5486.995911731079}, {
       2536.5637726194964`, -5486.995911731079}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5486.995924584996}, {
       3137.0091145002743`, -5486.995924584996}, {
       3137.0091145002743`, -5486.995911731079}, {
       3132.982630528445, -5486.995911731079}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5486.995924584996}, {
       3692.3896433236355`, -5486.995924584996}, {
       3692.3896433236355`, -5486.995911731079}, {
       3666.613191341404, -5486.995911731079}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5486.995924584996}, {4142.649334923808, 
       -5486.995924584996}, {4142.649334923808, -5486.995911731079}, {
       4087.48261405597, -5486.995911731079}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999978133112, -5486.995924584996}, {
      4700., -5486.995924584996}, {4700., -5486.995911731079}, {
      4699.999978133112, -5486.995911731079}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2621.2733144039325`, -5486.9959149445585`}, \
{2621.2733208308905`, -5486.995911731079}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2621.2733208308905`, -5486.9959149445585`}, 
       6.426958263660614*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2621.2733208308905`, -5486.9959213715165`}, {
       4699.999971706154, -5486.9959213715165`}, {
       4699.999971706154, -5486.9959149445585`}, {
       2621.2733208308905`, -5486.9959149445585`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999971706154, -5486.9959213715165`}, 
       6.426958263660614*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999971706154, -5486.995924584996}, \
{4699.999978133112, -5486.9959213715165`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5486.995954284856}, {
        101.16990635577649`, -5486.995954284856}, {
        101.16990635577649`, -5486.995924584996}, {
        100, -5486.995924584996}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5486.995954284856}, {
       1387.1092648612685`, -5486.995954284856}, {
       1387.1092648612685`, -5486.995924584996}, {
       603.3076318126714, -5486.995924584996}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5486.995954284856}, {
       1275.5190232272291`, -5486.995954284856}, {
       1275.5190232272291`, -5486.995924584996}, {
       1267.429300448664, -5486.995924584996}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5486.995954284856}, {
       1601.2840002731534`, -5486.995954284856}, {
       1601.2840002731534`, -5486.995924584996}, {
       1601.2824835399565`, -5486.995924584996}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5486.995954284856}, {
       2621.2733144039325`, -5486.995954284856}, {
       2621.2733144039325`, -5486.995924584996}, {
       2548.680398917411, -5486.995924584996}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5486.995954284856}, {
       3137.0091145002743`, -5486.995954284856}, {
       3137.0091145002743`, -5486.995924584996}, {
       3132.982630528445, -5486.995924584996}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5486.995954284856}, {
       3692.3896433236355`, -5486.995954284856}, {
       3692.3896433236355`, -5486.995924584996}, {
       3666.613191341404, -5486.995924584996}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5486.995954284856}, {
       4142.649334923808, -5486.995954284856}, {
       4142.649334923808, -5486.995924584996}, {
       4087.48261405597, -5486.995924584996}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5486.995954284856}, {
       4700., -5486.995954284856}, {4700., -5486.995924584996}, {
       4699.999986556084, -5486.995924584996}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2536.5637726194964`, -5486.995954284856}, {
      2585.9383931010943`, -5486.995954284856}, {
      2585.9383931010943`, -5486.995924584996}, {
      2536.5637726194964`, -5486.995924584996}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999971706154, -5486.995932009961}, \
{4699.999986556084, -5486.995924584996}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999971706154, -5486.995932009961}, 
       0.000014849930458371216`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2585.9384079510246`, -5486.995946859891}, {
       4699.999971706154, -5486.995946859891}, {
       4699.999971706154, -5486.995932009961}, {
       2585.9384079510246`, -5486.995932009961}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2585.9384079510246`, -5486.995946859891}, 
       0.000014849930458371216`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2585.9383931010943`, -5486.995954284856}, \
{2585.9384079510246`, -5486.995946859891}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5502.388362746558}, {
        101.16990635577649`, -5502.388362746558}, {
        101.16990635577649`, -5486.995954284856}, {
        100, -5486.995954284856}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5502.388362746558}, {
       1379.413060630417, -5502.388362746558}, {
       1379.413060630417, -5486.995954284856}, {
       603.3076318126714, -5486.995954284856}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5502.388362746558}, {
       1275.5190232272291`, -5502.388362746558}, {
       1275.5190232272291`, -5486.995954284856}, {
       1267.429300448664, -5486.995954284856}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5502.388362746558}, {
       1601.2840002731534`, -5502.388362746558}, {
       1601.2840002731534`, -5486.995954284856}, {
       1601.2824835399565`, -5486.995954284856}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5502.388362746558}, {
       2621.2733144039325`, -5502.388362746558}, {
       2621.2733144039325`, -5486.995954284856}, {
       2548.680398917411, -5486.995954284856}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5502.388362746558}, {
       3137.0091145002743`, -5502.388362746558}, {
       3137.0091145002743`, -5486.995954284856}, {
       3132.982630528445, -5486.995954284856}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5502.388362746558}, {
       3692.3896433236355`, -5502.388362746558}, {
       3692.3896433236355`, -5486.995954284856}, {
       3666.613191341404, -5486.995954284856}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5502.388362746558}, {
       4142.649334923808, -5502.388362746558}, {
       4142.649334923808, -5486.995954284856}, {
       4087.48261405597, -5486.995954284856}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5502.388362746558}, {
       4700., -5502.388362746558}, {4700., -5486.995954284856}, {
       4699.999986556084, -5486.995954284856}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2536.5637726194964`, -5502.388362746558}, {
      2585.938407951025, -5502.388362746558}, {
      2585.938407951025, -5486.995954284856}, {
      2536.5637726194964`, -5486.995954284856}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1379.413060630417, -5490.844056400281}, \
{1387.1092648612685`, -5486.995954284856}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1387.1092648612685`, -5490.844056400281}, 7.696204230851201, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1387.1092648612685`, -5498.540260631133}, {
       2528.8675683886454`, -5498.540260631133}, {
       2528.8675683886454`, -5490.844056400281}, {
       1387.1092648612685`, -5490.844056400281}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2528.8675683886454`, -5498.540260631133}, 7.696204230851201, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2528.8675683886454`, -5502.388362746558}, \
{2536.5637726194964`, -5498.540260631133}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5615.644552536014}, {
        101.16990635577649`, -5615.644552536014}, {
        101.16990635577649`, -5502.388362746558}, {
        100, -5502.388362746558}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5615.644552536014}, {
       1275.5190232272291`, -5615.644552536014}, {
       1275.5190232272291`, -5502.388362746558}, {
       1267.429300448664, -5502.388362746558}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5615.644552536014}, {
       1601.2840002731534`, -5615.644552536014}, {
       1601.2840002731534`, -5502.388362746558}, {
       1601.2824835399565`, -5502.388362746558}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5615.644552536014}, {
       2621.2733144039325`, -5615.644552536014}, {
       2621.2733144039325`, -5502.388362746558}, {
       2548.680398917411, -5502.388362746558}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2585.4956632833732`, -5615.644552536014}, {
       2585.938407951025, -5615.644552536014}, {
       2585.938407951025, -5502.388362746558}, {
       2585.4956632833732`, -5502.388362746558}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5615.644552536014}, {
       3137.0091145002743`, -5615.644552536014}, {
       3137.0091145002743`, -5502.388362746558}, {
       3132.982630528445, -5502.388362746558}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5615.644552536014}, {
       3692.3896433236355`, -5615.644552536014}, {
       3692.3896433236355`, -5502.388362746558}, {
       3666.613191341404, -5502.388362746558}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.48261405597, -5615.644552536014}, {
       4142.649334923808, -5615.644552536014}, {
       4142.649334923808, -5502.388362746558}, {
       4087.48261405597, -5502.388362746558}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5615.644552536014}, {
       4700., -5615.644552536014}, {4700., -5502.388362746558}, {
       4699.999986556084, -5502.388362746558}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -5615.644552536014}, {
      1379.413060630417, -5615.644552536014}, {
      1379.413060630417, -5502.388362746558}, {
      603.3076318126714, -5502.388362746558}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2528.8675683886454`, -5530.702410193922}, \
{2585.4956632833732`, -5502.388362746558}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2528.8675683886454`, -5530.702410193922}, 56.62809489472786, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1436.0411555251449`, -5587.33050508865}, {
       2528.8675683886454`, -5587.33050508865}, {
       2528.8675683886454`, -5530.702410193922}, {
       1436.0411555251449`, -5530.702410193922}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1436.0411555251449`, -5587.33050508865}, 56.62809489472786, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1379.413060630417, -5615.644552536014}, \
{1436.0411555251449`, -5587.33050508865}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5615.780771950596}, {
        101.16990635577649`, -5615.780771950596}, {
        101.16990635577649`, -5615.644552536014}, {
        100, -5615.644552536014}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5615.780771950596}, {
       1436.0411555251449`, -5615.780771950596}, {
       1436.0411555251449`, -5615.644552536014}, {
       603.3076318126714, -5615.644552536014}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5615.780771950596}, {
       1275.5190232272291`, -5615.780771950596}, {
       1275.5190232272291`, -5615.644552536014}, {
       1267.429300448664, -5615.644552536014}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5615.780771950596}, {
       1601.2840002731534`, -5615.780771950596}, {
       1601.2840002731534`, -5615.644552536014}, {
       1601.2824835399565`, -5615.644552536014}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5615.780771950596}, {
       2621.2733144039325`, -5615.780771950596}, {
       2621.2733144039325`, -5615.644552536014}, {
       2548.680398917411, -5615.644552536014}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5615.780771950596}, {
       3137.0091145002743`, -5615.780771950596}, {
       3137.0091145002743`, -5615.644552536014}, {
       3132.982630528445, -5615.644552536014}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.613191341404, -5615.780771950596}, {
       3692.3896433236355`, -5615.780771950596}, {
       3692.3896433236355`, -5615.644552536014}, {
       3666.613191341404, -5615.644552536014}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5615.780771950596}, {
       4142.649334923808, -5615.780771950596}, {
       4142.649334923808, -5615.644552536014}, {
       4087.550723763261, -5615.644552536014}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5615.780771950596}, {
       4700., -5615.780771950596}, {4700., -5615.644552536014}, {
       4699.999986556084, -5615.644552536014}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2585.4956632833732`, -5615.780771950596}, {
      2585.938407951025, -5615.780771950596}, {
      2585.938407951025, -5615.644552536014}, {
      2585.4956632833732`, -5615.644552536014}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4087.48261405597, -5615.678607389659}, \
{4087.550723763261, -5615.644552536014}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4087.48261405597, -5615.678607389659}, 0.06810970729117427, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2586.006517658316, -5615.74671709695}, {
       4087.48261405597, -5615.74671709695}, {
       4087.48261405597, -5615.678607389659}, {
       2586.006517658316, -5615.678607389659}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2586.006517658316, -5615.74671709695}, 0.06810970729117427, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2585.938407951025, -5615.780771950596}, \
{2586.006517658316, -5615.74671709695}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5615.780930264495}, {
        101.16990635577649`, -5615.780930264495}, {
        101.16990635577649`, -5615.780771950596}, {
        100, -5615.780771950596}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5615.780930264495}, {
       1436.0411555251449`, -5615.780930264495}, {
       1436.0411555251449`, -5615.780771950596}, {
       603.3076318126714, -5615.780771950596}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5615.780930264495}, {
       1275.5190232272291`, -5615.780930264495}, {
       1275.5190232272291`, -5615.780771950596}, {
       1267.429300448664, -5615.780771950596}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5615.780930264495}, {
       2621.2733144039325`, -5615.780930264495}, {
       2621.2733144039325`, -5615.780771950596}, {
       2548.680398917411, -5615.780771950596}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2585.4956632833732`, -5615.780930264495}, {
       2586.006517658316, -5615.780930264495}, {
       2586.006517658316, -5615.780771950596}, {
       2585.4956632833732`, -5615.780771950596}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.982630528445, -5615.780930264495}, {
       3137.0091145002743`, -5615.780930264495}, {
       3137.0091145002743`, -5615.780771950596}, {
       3132.982630528445, -5615.780771950596}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5615.780930264495}, {
       3692.389643323636, -5615.780930264495}, {
       3692.389643323636, -5615.780771950596}, {
       3666.6132704983534`, -5615.780771950596}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5615.780930264495}, {
       4142.649334923808, -5615.780930264495}, {
       4142.649334923808, -5615.780771950596}, {
       4087.550723763261, -5615.780771950596}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5615.780930264495}, {
       4700., -5615.780930264495}, {4700., -5615.780771950596}, {
       4699.999986556084, -5615.780771950596}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2824835399565`, -5615.780930264495}, {
      1601.2840002731534`, -5615.780930264495}, {
      1601.2840002731534`, -5615.780771950596}, {
      1601.2824835399565`, -5615.780771950596}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3666.613191341404, -5615.780811529071}, \
{3666.6132704983534`, -5615.780771950596}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3666.613191341404, -5615.780811529071}, 0.00007915694895182916,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 6.283185307179586}
        ]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2840794301023`, -5615.78089068602}, {
       3666.613191341404, -5615.78089068602}, {
       3666.613191341404, -5615.780811529071}, {
       1601.2840794301023`, -5615.780811529071}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2840794301023`, -5615.78089068602}, 
       0.00007915694895182916, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2840002731534`, -5615.780930264495}, \
{1601.2840794301023`, -5615.78089068602}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5616.275137397131}, {
        100.92280278945823`, -5616.275137397131}, {
        100.92280278945823`, -5615.780930264495}, {
        100, -5615.780930264495}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5616.275137397131}, {
       1436.0411555251449`, -5616.275137397131}, {
       1436.0411555251449`, -5615.780930264495}, {
       603.3076318126714, -5615.780930264495}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.429300448664, -5616.275137397131}, {
       1275.5190232272291`, -5616.275137397131}, {
       1275.5190232272291`, -5615.780930264495}, {
       1267.429300448664, -5615.780930264495}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5616.275137397131}, {
       1601.2840794301023`, -5616.275137397131}, {
       1601.2840794301023`, -5615.780930264495}, {
       1601.2824835399565`, -5615.780930264495}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5616.275137397131}, {
       2621.2733144039325`, -5616.275137397131}, {
       2621.2733144039325`, -5615.780930264495}, {
       2548.680398917411, -5615.780930264495}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2585.4956632833732`, -5616.275137397131}, {
       2586.006517658316, -5616.275137397131}, {
       2586.006517658316, -5615.780930264495}, {
       2585.4956632833732`, -5615.780930264495}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5616.275137397131}, {
       3692.389643323636, -5616.275137397131}, {
       3692.389643323636, -5615.780930264495}, {
       3666.6132704983534`, -5615.780930264495}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5616.275137397131}, {
       4142.649334923808, -5616.275137397131}, {
       4142.649334923808, -5615.780930264495}, {
       4087.550723763261, -5615.780930264495}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5616.275137397131}, {
       4700., -5616.275137397131}, {4700., -5615.780930264495}, {
       4699.999986556084, -5615.780930264495}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3132.982630528445, -5616.275137397131}, {
      3137.0091145002743`, -5616.275137397131}, {
      3137.0091145002743`, -5615.780930264495}, {
      3132.982630528445, -5615.780930264495}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.92280278945823`, -5615.904482047654}, \
{101.16990635577649`, -5615.780930264495}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.16990635577649`, -5615.904482047654}, 0.24710356631825525`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.16990635577649`, -5616.151585613972}, {
       3132.7355269621266`, -5616.151585613972}, {
       3132.7355269621266`, -5615.904482047654}, {
       101.16990635577649`, -5615.904482047654}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3132.7355269621266`, -5616.151585613972}, 
       0.24710356631825525`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3132.7355269621266`, -5616.275137397131}, \
{3132.982630528445, -5616.151585613972}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5616.665345683194}, {
       1436.0411555251449`, -5616.665345683194}, {
       1436.0411555251449`, -5616.275137397131}, {
       603.3076318126714, -5616.275137397131}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.6244045916953`, -5616.665345683194}, {
       1275.5190232272291`, -5616.665345683194}, {
       1275.5190232272291`, -5616.275137397131}, {
       1267.6244045916953`, -5616.275137397131}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5616.665345683194}, {
       1601.2840794301023`, -5616.665345683194}, {
       1601.2840794301023`, -5616.275137397131}, {
       1601.2824835399565`, -5616.275137397131}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5616.665345683194}, {
       2621.2733144039325`, -5616.665345683194}, {
       2621.2733144039325`, -5616.275137397131}, {
       2548.680398917411, -5616.275137397131}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2585.4956632833732`, -5616.665345683194}, {
       2586.006517658316, -5616.665345683194}, {
       2586.006517658316, -5616.275137397131}, {
       2585.4956632833732`, -5616.275137397131}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5616.665345683194}, {
       3137.0091145002743`, -5616.665345683194}, {
       3137.0091145002743`, -5616.275137397131}, {
       3132.7355269621266`, -5616.275137397131}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5616.665345683194}, {
       3692.389643323636, -5616.665345683194}, {
       3692.389643323636, -5616.275137397131}, {
       3666.6132704983534`, -5616.275137397131}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5616.665345683194}, {
       4142.649334923808, -5616.665345683194}, {
       4142.649334923808, -5616.275137397131}, {
       4087.550723763261, -5616.275137397131}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5616.665345683194}, {
       4700., -5616.665345683194}, {4700., -5616.275137397131}, {
       4699.999986556084, -5616.275137397131}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5616.665345683194}, {
       100.92280278945823`, -5616.665345683194}, {
       100.92280278945823`, -5616.275137397131}, {
       100, -5616.275137397131}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1267.429300448664, -5616.372689468647}, \
{1267.6244045916953`, -5616.275137397131}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1267.429300448664, -5616.372689468647}, 0.19510414303134405`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.11790693248957`, -5616.567793611678}, {
       1267.429300448664, -5616.567793611678}, {
       1267.429300448664, -5616.372689468647}, {
       101.11790693248957`, -5616.372689468647}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.11790693248957`, -5616.567793611678}, 0.19510414303134405`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.92280278945823`, -5616.665345683194}, \
{101.11790693248957`, -5616.567793611678}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5617.480742762167}, {
        101.11790693248957`, -5617.480742762167}, {
        101.11790693248957`, -5616.665345683194}, {
        100, -5616.665345683194}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5617.480742762167}, {
       1436.0411555251449`, -5617.480742762167}, {
       1436.0411555251449`, -5616.665345683194}, {
       603.3076318126714, -5616.665345683194}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1267.6244045916953`, -5617.480742762167}, {
       1275.5190232272291`, -5617.480742762167}, {
       1275.5190232272291`, -5616.665345683194}, {
       1267.6244045916953`, -5616.665345683194}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5617.480742762167}, {
       1601.2840794301023`, -5617.480742762167}, {
       1601.2840794301023`, -5616.665345683194}, {
       1601.2824835399565`, -5616.665345683194}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5617.480742762167}, {
       2620.8656158644458`, -5617.480742762167}, {
       2620.8656158644458`, -5616.665345683194}, {
       2548.680398917411, -5616.665345683194}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5617.480742762167}, {
       3137.0091145002743`, -5617.480742762167}, {
       3137.0091145002743`, -5616.665345683194}, {
       3132.7355269621266`, -5616.665345683194}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5617.480742762167}, {
       3692.389643323636, -5617.480742762167}, {
       3692.389643323636, -5616.665345683194}, {
       3666.6132704983534`, -5616.665345683194}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5617.480742762167}, {
       4142.649334923808, -5617.480742762167}, {
       4142.649334923808, -5616.665345683194}, {
       4087.550723763261, -5616.665345683194}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5617.480742762167}, {
       4700., -5617.480742762167}, {4700., -5616.665345683194}, {
       4699.999986556084, -5616.665345683194}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2585.4956632833732`, -5617.480742762167}, {
      2586.006517658316, -5617.480742762167}, {
      2586.006517658316, -5616.665345683194}, {
      2585.4956632833732`, -5616.665345683194}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2620.8656158644458`, -5616.8691949529375`}, \
{2621.2733144039325`, -5616.665345683194}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2621.2733144039325`, -5616.8691949529375`}, 
       0.40769853948676016`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2621.2733144039325`, -5617.276893492424}, {
       2585.0879647438865`, -5617.276893492424}, {
       2585.0879647438865`, -5616.8691949529375`}, {
       2621.2733144039325`, -5616.8691949529375`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2585.0879647438865`, -5617.276893492424}, 
       0.40769853948676016`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2585.0879647438865`, -5617.480742762167}, \
{2585.4956632833732`, -5617.276893492424}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5626.992115416659}, {
        101.11790693248957`, -5626.992115416659}, {
        101.11790693248957`, -5617.480742762167}, {
        100, -5617.480742762167}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5626.992115416659}, {
       1275.5190232272291`, -5626.992115416659}, {
       1275.5190232272291`, -5617.480742762167}, {
       1272.380090918941, -5617.480742762167}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5626.992115416659}, {
       1601.2840794301023`, -5626.992115416659}, {
       1601.2840794301023`, -5617.480742762167}, {
       1601.2824835399565`, -5617.480742762167}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5626.992115416659}, {
       2620.8656158644458`, -5626.992115416659}, {
       2620.8656158644458`, -5617.480742762167}, {
       2548.680398917411, -5617.480742762167}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2585.0879647438865`, -5626.992115416659}, {
       2586.006517658316, -5626.992115416659}, {
       2586.006517658316, -5617.480742762167}, {
       2585.0879647438865`, -5617.480742762167}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5626.992115416659}, {
       3137.0091145002743`, -5626.992115416659}, {
       3137.0091145002743`, -5617.480742762167}, {
       3132.7355269621266`, -5617.480742762167}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5626.992115416659}, {
       3692.389643323636, -5626.992115416659}, {
       3692.389643323636, -5617.480742762167}, {
       3666.6132704983534`, -5617.480742762167}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5626.992115416659}, {
       4142.649334923808, -5626.992115416659}, {
       4142.649334923808, -5617.480742762167}, {
       4087.550723763261, -5617.480742762167}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5626.992115416659}, {
       4700., -5626.992115416659}, {4700., -5617.480742762167}, {
       4699.999986556084, -5617.480742762167}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{603.3076318126714, -5626.992115416659}, {
      1436.0411555251449`, -5626.992115416659}, {
      1436.0411555251449`, -5617.480742762167}, {
      603.3076318126714, -5617.480742762167}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1267.6244045916953`, -5619.85858592579}, \
{1272.380090918941, -5617.480742762167}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1267.6244045916953`, -5619.85858592579}, 4.755686327245622, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1440.7968418523906`, -5624.614272253036}, {
       1267.6244045916953`, -5624.614272253036}, {
       1267.6244045916953`, -5619.85858592579}, {
       1440.7968418523906`, -5619.85858592579}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1440.7968418523906`, -5624.614272253036}, 4.755686327245622, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1436.0411555251449`, -5626.992115416659}, \
{1440.7968418523906`, -5624.614272253036}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5627.205857069239}, {
        101.11790693248957`, -5627.205857069239}, {
        101.11790693248957`, -5626.992115416659}, {
        100, -5626.992115416659}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.3076318126714, -5627.205857069239}, {
       1440.7968418523906`, -5627.205857069239}, {
       1440.7968418523906`, -5626.992115416659}, {
       603.3076318126714, -5626.992115416659}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5627.205857069239}, {
       1275.4121524009392`, -5627.205857069239}, {
       1275.4121524009392`, -5626.992115416659}, {
       1272.380090918941, -5626.992115416659}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5627.205857069239}, {
       1601.2840794301023`, -5627.205857069239}, {
       1601.2840794301023`, -5626.992115416659}, {
       1601.2824835399565`, -5626.992115416659}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5627.205857069239}, {
       2620.8656158644458`, -5627.205857069239}, {
       2620.8656158644458`, -5626.992115416659}, {
       2548.680398917411, -5626.992115416659}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5627.205857069239}, {
       3137.0091145002743`, -5627.205857069239}, {
       3137.0091145002743`, -5626.992115416659}, {
       3132.7355269621266`, -5626.992115416659}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5627.205857069239}, {
       3692.389643323636, -5627.205857069239}, {
       3692.389643323636, -5626.992115416659}, {
       3666.6132704983534`, -5626.992115416659}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5627.205857069239}, {
       4142.649334923808, -5627.205857069239}, {
       4142.649334923808, -5626.992115416659}, {
       4087.550723763261, -5626.992115416659}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5627.205857069239}, {
       4700., -5627.205857069239}, {4700., -5626.992115416659}, {
       4699.999986556084, -5626.992115416659}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2585.0879647438865`, -5627.205857069239}, {
      2586.006517658316, -5627.205857069239}, {
      2586.006517658316, -5626.992115416659}, {
      2585.0879647438865`, -5626.992115416659}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1275.4121524009392`, -5627.045550829804}, \
{1275.5190232272291`, -5626.992115416659}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1275.5190232272291`, -5627.045550829804}, 0.10687082628996947`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1275.5190232272291`, -5627.152421656094}, {
       2584.9810939175964`, -5627.152421656094}, {
       2584.9810939175964`, -5627.045550829804}, {
       1275.5190232272291`, -5627.045550829804}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.9810939175964`, -5627.152421656094}, 
       0.10687082628996947`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.9810939175964`, -5627.205857069239}, \
{2585.0879647438865`, -5627.152421656094}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5628.500618235775}, {
       1440.7968418523906`, -5628.500618235775}, {
       1440.7968418523906`, -5627.205857069239}, {
       603.9550123959395, -5627.205857069239}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5628.500618235775}, {
       1275.4121524009392`, -5628.500618235775}, {
       1275.4121524009392`, -5627.205857069239}, {
       1272.380090918941, -5627.205857069239}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5628.500618235775}, {
       1601.2840794301023`, -5628.500618235775}, {
       1601.2840794301023`, -5627.205857069239}, {
       1601.2824835399565`, -5627.205857069239}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5628.500618235775}, {
       2620.8656158644458`, -5628.500618235775}, {
       2620.8656158644458`, -5627.205857069239}, {
       2548.680398917411, -5627.205857069239}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5628.500618235775}, {
       2586.006517658316, -5628.500618235775}, {
       2586.006517658316, -5627.205857069239}, {
       2584.9810939175964`, -5627.205857069239}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5628.500618235775}, {
       3137.0091145002743`, -5628.500618235775}, {
       3137.0091145002743`, -5627.205857069239}, {
       3132.7355269621266`, -5627.205857069239}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3666.6132704983534`, -5628.500618235775}, {
       3692.389643323636, -5628.500618235775}, {
       3692.389643323636, -5627.205857069239}, {
       3666.6132704983534`, -5627.205857069239}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5628.500618235775}, {
       4142.649334923808, -5628.500618235775}, {
       4142.649334923808, -5627.205857069239}, {
       4087.550723763261, -5627.205857069239}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5628.500618235775}, {
       4700., -5628.500618235775}, {4700., -5627.205857069239}, {
       4699.999986556084, -5627.205857069239}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5628.500618235775}, {
       101.11790693248957`, -5628.500618235775}, {
       101.11790693248957`, -5627.205857069239}, {
       100, -5627.205857069239}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{603.3076318126714, -5627.529547360872}, \
{603.9550123959395, -5627.205857069239}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{603.3076318126714, -5627.529547360872}, 0.6473805832681394, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.76528751575772`, -5628.1769279441405`}, {
       603.3076318126714, -5628.1769279441405`}, {
       603.3076318126714, -5627.529547360872}, {
       101.76528751575772`, -5627.529547360872}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.76528751575772`, -5628.1769279441405`}, 0.6473805832681394,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.11790693248957`, -5628.500618235775}, \
{101.76528751575772`, -5628.1769279441405`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5667.362402037116}, {
        101.76528751575772`, -5667.362402037116}, {
        101.76528751575772`, -5628.500618235775}, {
        100, -5628.500618235775}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5667.362402037116}, {
       1421.3659499517198`, -5667.362402037116}, {
       1421.3659499517198`, -5628.500618235775}, {
       603.9550123959395, -5628.500618235775}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5667.362402037116}, {
       1275.4121524009392`, -5667.362402037116}, {
       1275.4121524009392`, -5628.500618235775}, {
       1272.380090918941, -5628.500618235775}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5667.362402037116}, {
       1601.2840794301023`, -5667.362402037116}, {
       1601.2840794301023`, -5628.500618235775}, {
       1601.2824835399565`, -5628.500618235775}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5667.362402037116}, {
       2620.8656158644458`, -5667.362402037116}, {
       2620.8656158644458`, -5628.500618235775}, {
       2548.680398917411, -5628.500618235775}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5667.362402037116}, {
       2586.006517658316, -5667.362402037116}, {
       2586.006517658316, -5628.500618235775}, {
       2584.9810939175964`, -5628.500618235775}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5667.362402037116}, {
       3137.0091145002743`, -5667.362402037116}, {
       3137.0091145002743`, -5628.500618235775}, {
       3132.7355269621266`, -5628.500618235775}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5667.362402037116}, {
       4142.649334923808, -5667.362402037116}, {
       4142.649334923808, -5628.500618235775}, {
       4087.550723763261, -5628.500618235775}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999986556084, -5667.362402037116}, {
       4700., -5667.362402037116}, {4700., -5628.500618235775}, {
       4699.999986556084, -5628.500618235775}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3666.6132704983534`, -5667.362402037116}, {
      3692.389643323636, -5667.362402037116}, {
      3692.389643323636, -5628.500618235775}, {
      3666.6132704983534`, -5628.500618235775}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1421.3659499517198`, -5638.21606418611}, \
{1440.7968418523906`, -5628.500618235775}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1440.7968418523906`, -5638.21606418611}, 19.43089190067085, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1440.7968418523906`, -5657.646956086781}, {
       3647.1823785976826`, -5657.646956086781}, {
       3647.1823785976826`, -5638.21606418611}, {
       1440.7968418523906`, -5638.21606418611}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3647.1823785976826`, -5657.646956086781}, 19.43089190067085, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3647.1823785976826`, -5667.362402037116}, \
{3666.6132704983534`, -5657.646956086781}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5667.362428452113}, {
        101.76528751575772`, -5667.362428452113}, {
        101.76528751575772`, -5667.362402037116}, {
        100, -5667.362402037116}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5667.362428452113}, {
       1421.3659499517198`, -5667.362428452113}, {
       1421.3659499517198`, -5667.362402037116}, {
       603.9550123959395, -5667.362402037116}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5667.362428452113}, {
       1275.4121524009392`, -5667.362428452113}, {
       1275.4121524009392`, -5667.362402037116}, {
       1272.380090918941, -5667.362402037116}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5667.362428452113}, {
       2620.8656158644458`, -5667.362428452113}, {
       2620.8656158644458`, -5667.362402037116}, {
       2548.680398917411, -5667.362402037116}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5667.362428452113}, {
       2586.006517658316, -5667.362428452113}, {
       2586.006517658316, -5667.362402037116}, {
       2584.9810939175964`, -5667.362402037116}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3132.7355269621266`, -5667.362428452113}, {
       3137.0091145002743`, -5667.362428452113}, {
       3137.0091145002743`, -5667.362402037116}, {
       3132.7355269621266`, -5667.362402037116}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5667.362428452113}, {
       3692.389643323636, -5667.362428452113}, {
       3692.389643323636, -5667.362402037116}, {
       3647.1823785976826`, -5667.362402037116}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5667.362428452113}, {
       4142.649334923808, -5667.362428452113}, {
       4142.649334923808, -5667.362402037116}, {
       4087.550723763261, -5667.362402037116}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999763582, -5667.362428452113}, {
       4700., -5667.362428452113}, {4700., -5667.362402037116}, {
       4699.999999763582, -5667.362402037116}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2824835399565`, -5667.362428452113}, {
      1601.2840794301023`, -5667.362428452113}, {
      1601.2840794301023`, -5667.362402037116}, {
      1601.2824835399565`, -5667.362402037116}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999986556084, -5667.362408640865}, \
{4699.999999763582, -5667.362402037116}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999986556084, -5667.362408640865}, 0.00001320749852101066,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.284092637601, -5667.362421848364}, {
       4699.999986556084, -5667.362421848364}, {
       4699.999986556084, -5667.362408640865}, {
       1601.284092637601, -5667.362408640865}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.284092637601, -5667.362421848364}, 0.00001320749852101066,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2840794301023`, -5667.362428452113}, \
{1601.284092637601, -5667.362421848364}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5668.297394305097}, {
       1421.3659499517198`, -5668.297394305097}, {
       1421.3659499517198`, -5667.362428452113}, {
       603.9550123959395, -5667.362428452113}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5668.297394305097}, {
       1275.4121524009392`, -5668.297394305097}, {
       1275.4121524009392`, -5667.362428452113}, {
       1272.380090918941, -5667.362428452113}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5668.297394305097}, {
       1601.284092637601, -5668.297394305097}, {
       1601.284092637601, -5667.362428452113}, {
       1601.2824835399565`, -5667.362428452113}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5668.297394305097}, {
       2620.8656158644458`, -5668.297394305097}, {
       2620.8656158644458`, -5667.362428452113}, {
       2548.680398917411, -5667.362428452113}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5668.297394305097}, {
       2586.006517658316, -5668.297394305097}, {
       2586.006517658316, -5667.362428452113}, {
       2584.9810939175964`, -5667.362428452113}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5668.297394305097}, {
       3137.009114500274, -5668.297394305097}, {
       3137.009114500274, -5667.362428452113}, {
       3133.203009888619, -5667.362428452113}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5668.297394305097}, {
       3692.389643323636, -5668.297394305097}, {
       3692.389643323636, -5667.362428452113}, {
       3647.1823785976826`, -5667.362428452113}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5668.297394305097}, {
       4142.649334923808, -5668.297394305097}, {
       4142.649334923808, -5667.362428452113}, {
       4087.550723763261, -5667.362428452113}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999763582, -5668.297394305097}, {
       4700., -5668.297394305097}, {4700., -5667.362428452113}, {
       4699.999999763582, -5667.362428452113}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5668.297394305097}, {
       101.76528751575772`, -5668.297394305097}, {
       101.76528751575772`, -5667.362428452113}, {
       100, -5667.362428452113}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3132.7355269621266`, -5667.596169915359}, \
{3133.203009888619, -5667.362428452113}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3132.7355269621266`, -5667.596169915359}, 0.46748292649238365`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{102.2327704422501, -5668.063652841851}, {
       3132.7355269621266`, -5668.063652841851}, {
       3132.7355269621266`, -5667.596169915359}, {
       102.2327704422501, -5667.596169915359}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{102.2327704422501, -5668.063652841851}, 0.46748292649238365`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.76528751575772`, -5668.297394305097}, \
{102.2327704422501, -5668.063652841851}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5668.297394548584}, {
        102.2327704422501, -5668.297394548584}, {
        102.2327704422501, -5668.297394305097}, {
        100, -5668.297394305097}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5668.297394548584}, {
       1421.3659499517198`, -5668.297394548584}, {
       1421.3659499517198`, -5668.297394305097}, {
       603.9550123959395, -5668.297394305097}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5668.297394548584}, {
       1275.4121524009392`, -5668.297394548584}, {
       1275.4121524009392`, -5668.297394305097}, {
       1272.380090918941, -5668.297394305097}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5668.297394548584}, {
       1601.284092637601, -5668.297394548584}, {
       1601.284092637601, -5668.297394305097}, {
       1601.2824835399565`, -5668.297394305097}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5668.297394548584}, {
       2620.865615742702, -5668.297394548584}, {
       2620.865615742702, -5668.297394305097}, {
       2548.680398917411, -5668.297394305097}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5668.297394548584}, {
       2586.006517658316, -5668.297394548584}, {
       2586.006517658316, -5668.297394305097}, {
       2584.9810939175964`, -5668.297394305097}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5668.297394548584}, {
       3137.009114500274, -5668.297394548584}, {
       3137.009114500274, -5668.297394305097}, {
       3133.203009888619, -5668.297394305097}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5668.297394548584}, {
       3692.389643323636, -5668.297394548584}, {
       3692.389643323636, -5668.297394305097}, {
       3647.1823785976826`, -5668.297394305097}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5668.297394548584}, {
       4142.649334923808, -5668.297394548584}, {
       4142.649334923808, -5668.297394305097}, {
       4087.550723763261, -5668.297394305097}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999763582, -5668.297394548584}, {
      4700., -5668.297394548584}, {4700., -5668.297394305097}, {
      4699.999999763582, -5668.297394305097}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2620.865615742702, -5668.297394365969}, \
{2620.8656158644458`, -5668.297394305097}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2620.8656158644458`, -5668.297394365969}, 
       1.2174335945844333`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2620.8656158644458`, -5668.297394487712}, {
       4699.999999641839, -5668.297394487712}, {
       4699.999999641839, -5668.297394365969}, {
       2620.8656158644458`, -5668.297394365969}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999641839, -5668.297394487712}, 
       1.2174335945844333`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999641839, -5668.297394548584}, \
{4699.999999763582, -5668.297394487712}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5668.297395151507}, {
        102.2327704422501, -5668.297395151507}, {
        102.2327704422501, -5668.297394548584}, {
        100, -5668.297394548584}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5668.297395151507}, {
       1421.3659499517198`, -5668.297395151507}, {
       1421.3659499517198`, -5668.297394548584}, {
       603.9550123959395, -5668.297394548584}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5668.297395151507}, {
       1275.4121524009392`, -5668.297395151507}, {
       1275.4121524009392`, -5668.297394548584}, {
       1272.380090918941, -5668.297394548584}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5668.297395151507}, {
       1601.284092637601, -5668.297395151507}, {
       1601.284092637601, -5668.297394548584}, {
       1601.2824835399565`, -5668.297394548584}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.680398917411, -5668.297395151507}, {
       2620.865615742702, -5668.297395151507}, {
       2620.865615742702, -5668.297394548584}, {
       2548.680398917411, -5668.297394548584}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5668.297395151507}, {
       2586.006517658316, -5668.297395151507}, {
       2586.006517658316, -5668.297394548584}, {
       2584.9810939175964`, -5668.297394548584}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5668.297395151507}, {
       3137.009114500274, -5668.297395151507}, {
       3137.009114500274, -5668.297394548584}, {
       3133.203009888619, -5668.297394548584}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5668.297395151507}, {
       4142.649334923808, -5668.297395151507}, {
       4142.649334923808, -5668.297394548584}, {
       4087.550723763261, -5668.297394548584}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5668.297395151507}, {
       4700., -5668.297395151507}, {4700., -5668.297394548584}, {
       4699.999999943301, -5668.297394548584}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3647.1823785976826`, -5668.297395151507}, {
      3692.389643323636, -5668.297395151507}, {
      3692.389643323636, -5668.297394548584}, {
      3647.1823785976826`, -5668.297394548584}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999641839, -5668.297394699314}, \
{4699.999999943301, -5668.297394548584}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999641839, -5668.297394699314}, 3.014616911186681*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3692.3896436250975`, -5668.297395000776}, {
       4699.999999641839, -5668.297395000776}, {
       4699.999999641839, -5668.297394699314}, {
       3692.3896436250975`, -5668.297394699314}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3692.3896436250975`, -5668.297395000776}, 
       3.014616911186681*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3692.389643323636, -5668.297395151507}, \
{3692.3896436250975`, -5668.297395000776}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5668.2990880129055`}, {
        102.2327704422501, -5668.2990880129055`}, {
        102.2327704422501, -5668.297395151507}, {
        100, -5668.297395151507}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5668.2990880129055`}, {
       1421.3659499517198`, -5668.2990880129055`}, {
       1421.3659499517198`, -5668.297395151507}, {
       603.9550123959395, -5668.297395151507}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5668.2990880129055`}, {
       1275.4121524009392`, -5668.2990880129055`}, {
       1275.4121524009392`, -5668.297395151507}, {
       1272.380090918941, -5668.297395151507}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5668.2990880129055`}, {
       1601.2832462069016`, -5668.2990880129055`}, {
       1601.2832462069016`, -5668.297395151507}, {
       1601.2824835399565`, -5668.297395151507}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9810939175964`, -5668.2990880129055`}, {
       2586.006517658316, -5668.2990880129055`}, {
       2586.006517658316, -5668.297395151507}, {
       2584.9810939175964`, -5668.297395151507}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5668.2990880129055`}, {
       3137.009114500274, -5668.2990880129055`}, {
       3137.009114500274, -5668.297395151507}, {
       3133.203009888619, -5668.297395151507}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5668.2990880129055`}, {
       3692.3896436250975`, -5668.2990880129055`}, {
       3692.3896436250975`, -5668.297395151507}, {
       3647.1823785976826`, -5668.297395151507}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5668.2990880129055`}, {
       4142.649334923808, -5668.2990880129055`}, {
       4142.649334923808, -5668.297395151507}, {
       4087.550723763261, -5668.297395151507}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5668.2990880129055`}, {
       4700., -5668.2990880129055`}, {4700., -5668.297395151507}, {
       4699.999999943301, -5668.297395151507}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2548.680398917411, -5668.2990880129055`}, {
      2620.865615742702, -5668.2990880129055`}, {
      2620.865615742702, -5668.297395151507}, {
      2548.680398917411, -5668.297395151507}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2832462069016`, -5668.2978183668565`}, \
{1601.284092637601, -5668.297395151507}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.284092637601, -5668.2978183668565`}, 
       0.0008464306993350066, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.284092637601, -5668.298664797556}, {
       2548.6795524867116`, -5668.298664797556}, {
       2548.6795524867116`, -5668.2978183668565`}, {
       1601.284092637601, -5668.2978183668565`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2548.6795524867116`, -5668.298664797556}, 
       0.0008464306993350066, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2548.6795524867116`, -5668.2990880129055`}, \
{2548.680398917411, -5668.298664797556}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5668.300032980349}, {
        102.2327704422501, -5668.300032980349}, {
        102.2327704422501, -5668.2990880129055`}, {
        100, -5668.2990880129055`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5668.300032980349}, {
       1421.3659499517198`, -5668.300032980349}, {
       1421.3659499517198`, -5668.2990880129055`}, {
       603.9550123959395, -5668.2990880129055`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5668.300032980349}, {
       1275.4121524009392`, -5668.300032980349}, {
       1275.4121524009392`, -5668.2990880129055`}, {
       1272.380090918941, -5668.2990880129055`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5668.300032980349}, {
       1601.2827737231798`, -5668.300032980349}, {
       1601.2827737231798`, -5668.2990880129055`}, {
       1601.2824835399565`, -5668.2990880129055`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.6795524867116`, -5668.300032980349}, {
       2620.865615742702, -5668.300032980349}, {
       2620.865615742702, -5668.2990880129055`}, {
       2548.6795524867116`, -5668.2990880129055`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5668.300032980349}, {
       3137.009114500274, -5668.300032980349}, {
       3137.009114500274, -5668.2990880129055`}, {
       3133.203009888619, -5668.2990880129055`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5668.300032980349}, {
       3692.3896436250975`, -5668.300032980349}, {
       3692.3896436250975`, -5668.2990880129055`}, {
       3647.1823785976826`, -5668.2990880129055`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4087.550723763261, -5668.300032980349}, {
       4142.649334923808, -5668.300032980349}, {
       4142.649334923808, -5668.2990880129055`}, {
       4087.550723763261, -5668.2990880129055`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5668.300032980349}, {
       4700., -5668.300032980349}, {4700., -5668.2990880129055`}, {
       4699.999999943301, -5668.2990880129055`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.9810939175964`, -5668.300032980349}, {
      2586.006517658316, -5668.300032980349}, {
      2586.006517658316, -5668.2990880129055`}, {
      2584.9810939175964`, -5668.2990880129055`}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2827737231798`, -5668.299324254766}, \
{1601.2832462069016`, -5668.2990880129055`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2832462069016`, -5668.299324254766}, 
       0.00047248372176057047`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2832462069016`, -5668.299796738488}, {
       2584.9806214338746`, -5668.299796738488}, {
       2584.9806214338746`, -5668.299324254766}, {
       1601.2832462069016`, -5668.299324254766}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.9806214338746`, -5668.299796738488}, 
       0.00047248372176057047`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.9806214338746`, -5668.300032980349}, \
{2584.9810939175964`, -5668.299796738488}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5729.364803050445}, {
        102.2327704422501, -5729.364803050445}, {
        102.2327704422501, -5668.300032980349}, {
        100, -5668.300032980349}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5729.364803050445}, {
       1390.833564916672, -5729.364803050445}, {
       1390.833564916672, -5668.300032980349}, {
       603.9550123959395, -5668.300032980349}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5729.364803050445}, {
       1275.4121524009392`, -5729.364803050445}, {
       1275.4121524009392`, -5668.300032980349}, {
       1272.380090918941, -5668.300032980349}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5729.364803050445}, {
       1601.2827737231798`, -5729.364803050445}, {
       1601.2827737231798`, -5668.300032980349}, {
       1601.2824835399565`, -5668.300032980349}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.6795524867116`, -5729.364803050445}, {
       2620.865615742702, -5729.364803050445}, {
       2620.865615742702, -5668.300032980349}, {
       2548.6795524867116`, -5668.300032980349}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5729.364803050445}, {
       2586.006517658316, -5729.364803050445}, {
       2586.006517658316, -5668.300032980349}, {
       2584.9806214338746`, -5668.300032980349}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5729.364803050445}, {
       3137.009114500274, -5729.364803050445}, {
       3137.009114500274, -5668.300032980349}, {
       3133.203009888619, -5668.300032980349}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5729.364803050445}, {
       3692.3896436250975`, -5729.364803050445}, {
       3692.3896436250975`, -5668.300032980349}, {
       3647.1823785976826`, -5668.300032980349}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5729.364803050445}, {
       4700., -5729.364803050445}, {4700., -5668.300032980349}, {
       4699.999999943301, -5668.300032980349}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4087.550723763261, -5729.364803050445}, {
      4142.649334923808, -5729.364803050445}, {
      4142.649334923808, -5668.300032980349}, {
      4087.550723763261, -5668.300032980349}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1390.833564916672, -5683.566225497872}, \
{1421.3659499517198`, -5668.300032980349}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1421.3659499517198`, -5683.566225497872}, 30.53238503504783, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1421.3659499517198`, -5714.09861053292}, {
       4057.018338728213, -5714.09861053292}, {
       4057.018338728213, -5683.566225497872}, {
       1421.3659499517198`, -5683.566225497872}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4057.018338728213, -5714.09861053292}, 30.53238503504783, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4057.018338728213, -5729.364803050445}, \
{4087.550723763261, -5714.09861053292}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5732.646571967372}, {
       1390.833564916672, -5732.646571967372}, {
       1390.833564916672, -5729.364803050445}, {
       603.9550123959395, -5729.364803050445}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1272.380090918941, -5732.646571967372}, {
       1275.4121524009392`, -5732.646571967372}, {
       1275.4121524009392`, -5729.364803050445}, {
       1272.380090918941, -5729.364803050445}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5732.646571967372}, {
       1601.2827737231798`, -5732.646571967372}, {
       1601.2827737231798`, -5729.364803050445}, {
       1601.2824835399565`, -5729.364803050445}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.6795524867116`, -5732.646571967372}, {
       2620.865615742702, -5732.646571967372}, {
       2620.865615742702, -5729.364803050445}, {
       2548.6795524867116`, -5729.364803050445}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5732.646571967372}, {
       2586.006517658316, -5732.646571967372}, {
       2586.006517658316, -5729.364803050445}, {
       2584.9806214338746`, -5729.364803050445}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5732.646571967372}, {
       3137.009114500274, -5732.646571967372}, {
       3137.009114500274, -5729.364803050445}, {
       3133.203009888619, -5729.364803050445}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5732.646571967372}, {
       3692.3896436250975`, -5732.646571967372}, {
       3692.3896436250975`, -5729.364803050445}, {
       3647.1823785976826`, -5729.364803050445}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4058.659223186677, -5732.646571967372}, {
       4142.649334923807, -5732.646571967372}, {
       4142.649334923807, -5729.364803050445}, {
       4058.659223186677, -5729.364803050445}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5732.646571967372}, {
       4700., -5732.646571967372}, {4700., -5729.364803050445}, {
       4699.999999943301, -5729.364803050445}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5732.646571967372}, {
       102.2327704422501, -5732.646571967372}, {
       102.2327704422501, -5729.364803050445}, {
       100, -5729.364803050445}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4057.018338728213, -5730.185245279677}, \
{4058.659223186677, -5729.364803050445}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4057.018338728213, -5730.185245279677}, 1.6408844584639986`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{103.8736549007141, -5731.8261297381405`}, {
       4057.018338728213, -5731.8261297381405`}, {
       4057.018338728213, -5730.185245279677}, {
       103.8736549007141, -5730.185245279677}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{103.8736549007141, -5731.8261297381405`}, 1.6408844584639986`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{102.2327704422501, -5732.646571967372}, \
{103.8736549007141, -5731.8261297381405`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5734.653381360796}, {
        102.87025020400247`, -5734.653381360796}, {
        102.87025020400247`, -5732.646571967372}, {
        100, -5732.646571967372}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5734.653381360796}, {
       1390.833564916672, -5734.653381360796}, {
       1390.833564916672, -5732.646571967372}, {
       603.9550123959395, -5732.646571967372}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5734.653381360796}, {
       1601.2827737231798`, -5734.653381360796}, {
       1601.2827737231798`, -5732.646571967372}, {
       1601.2824835399565`, -5732.646571967372}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.6795524867116`, -5734.653381360796}, {
       2620.865615742702, -5734.653381360796}, {
       2620.865615742702, -5732.646571967372}, {
       2548.6795524867116`, -5732.646571967372}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5734.653381360796}, {
       2586.006517658316, -5734.653381360796}, {
       2586.006517658316, -5732.646571967372}, {
       2584.9806214338746`, -5732.646571967372}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5734.653381360796}, {
       3137.009114500274, -5734.653381360796}, {
       3137.009114500274, -5732.646571967372}, {
       3133.203009888619, -5732.646571967372}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5734.653381360796}, {
       3692.3896436250975`, -5734.653381360796}, {
       3692.3896436250975`, -5732.646571967372}, {
       3647.1823785976826`, -5732.646571967372}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4058.659223186677, -5734.653381360796}, {
       4142.649334923807, -5734.653381360796}, {
       4142.649334923807, -5732.646571967372}, {
       4058.659223186677, -5732.646571967372}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5734.653381360796}, {
       4700., -5734.653381360796}, {4700., -5732.646571967372}, {
       4699.999999943301, -5732.646571967372}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1272.380090918941, -5734.653381360796}, {
      1275.4121524009392`, -5734.653381360796}, {
      1275.4121524009392`, -5732.646571967372}, {
      1272.380090918941, -5732.646571967372}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{102.87025020400247`, -5733.1482743157285`}, \
{103.8736549007141, -5732.646571967372}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{103.8736549007141, -5733.1482743157285`}, 1.0034046967116295`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{103.8736549007141, -5734.15167901244}, {
       1271.3766862222294`, -5734.15167901244}, {
       1271.3766862222294`, -5733.1482743157285`}, {
       103.8736549007141, -5733.1482743157285`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1271.3766862222294`, -5734.15167901244}, 1.0034046967116295`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1271.3766862222294`, -5734.653381360796}, \
{1272.380090918941, -5734.15167901244}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5744.906366601479}, {
        102.87025020400247`, -5744.906366601479}, {
        102.87025020400247`, -5734.653381360796}, {
        100, -5734.653381360796}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5744.906366601479}, {
       1390.833564916672, -5744.906366601479}, {
       1390.833564916672, -5734.653381360796}, {
       603.9550123959395, -5734.653381360796}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1271.3766862222294`, -5744.906366601479}, {
       1275.4121524009392`, -5744.906366601479}, {
       1275.4121524009392`, -5734.653381360796}, {
       1271.3766862222294`, -5734.653381360796}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5744.906366601479}, {
       1601.2827737231798`, -5744.906366601479}, {
       1601.2827737231798`, -5734.653381360796}, {
       1601.2824835399565`, -5734.653381360796}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2548.6795524867116`, -5744.906366601479}, {
       2620.865615742702, -5744.906366601479}, {
       2620.865615742702, -5734.653381360796}, {
       2548.6795524867116`, -5734.653381360796}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5744.906366601479}, {
       2586.006517658316, -5744.906366601479}, {
       2586.006517658316, -5734.653381360796}, {
       2584.9806214338746`, -5734.653381360796}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5744.906366601479}, {
       3137.009114500274, -5744.906366601479}, {
       3137.009114500274, -5734.653381360796}, {
       3133.203009888619, -5734.653381360796}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5744.906366601479}, {
       4142.649334923807, -5744.906366601479}, {
       4142.649334923807, -5734.653381360796}, {
       4063.7857158070187`, -5734.653381360796}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5744.906366601479}, {
       4700., -5744.906366601479}, {4700., -5734.653381360796}, {
       4699.999999943301, -5734.653381360796}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3647.1823785976826`, -5744.906366601479}, {
      3692.3896436250975`, -5744.906366601479}, {
      3692.3896436250975`, -5734.653381360796}, {
      3647.1823785976826`, -5734.653381360796}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4058.659223186677, -5737.216627670966}, \
{4063.7857158070187`, -5734.653381360796}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4058.659223186677, -5737.216627670966}, 5.126492620341828, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3697.5161362454396`, -5742.343120291308}, {
       4058.659223186677, -5742.343120291308}, {
       4058.659223186677, -5737.216627670966}, {
       3697.5161362454396`, -5737.216627670966}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3697.5161362454396`, -5742.343120291308}, 5.126492620341828, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3692.3896436250975`, -5744.906366601479}, \
{3697.5161362454396`, -5742.343120291308}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5880.080046342244}, {
        102.87025020400247`, -5880.080046342244}, {
        102.87025020400247`, -5744.906366601479}, {
        100, -5744.906366601479}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5880.080046342244}, {
       1323.2467250462896`, -5880.080046342244}, {
       1323.2467250462896`, -5744.906366601479}, {
       603.9550123959395, -5744.906366601479}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1271.3766862222294`, -5880.080046342244}, {
       1275.4121524009392`, -5880.080046342244}, {
       1275.4121524009392`, -5744.906366601479}, {
       1271.3766862222294`, -5744.906366601479}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2824835399565`, -5880.080046342244}, {
       1601.2827737231798`, -5880.080046342244}, {
       1601.2827737231798`, -5744.906366601479}, {
       1601.2824835399565`, -5744.906366601479}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5880.080046342244}, {
       2586.006517658316, -5880.080046342244}, {
       2586.006517658316, -5744.906366601479}, {
       2584.9806214338746`, -5744.906366601479}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5880.080046342244}, {
       3137.009114500274, -5880.080046342244}, {
       3137.009114500274, -5744.906366601479}, {
       3133.203009888619, -5744.906366601479}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5880.080046342244}, {
       3697.5161362454396`, -5880.080046342244}, {
       3697.5161362454396`, -5744.906366601479}, {
       3647.1823785976826`, -5744.906366601479}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5880.080046342244}, {
       4142.649334923807, -5880.080046342244}, {
       4142.649334923807, -5744.906366601479}, {
       4063.7857158070187`, -5744.906366601479}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5880.080046342244}, {
       4700., -5880.080046342244}, {4700., -5744.906366601479}, {
       4699.999999943301, -5744.906366601479}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2548.6795524867116`, -5880.080046342244}, {
      2620.865615742702, -5880.080046342244}, {
      2620.865615742702, -5744.906366601479}, {
      2548.6795524867116`, -5744.906366601479}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1323.2467250462896`, -5778.69978653667}, \
{1390.833564916672, -5744.906366601479}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1390.833564916672, -5778.69978653667}, 67.58683987038236, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1390.833564916672, -5846.286626407053}, {
       2481.092712616329, -5846.286626407053}, {
       2481.092712616329, -5778.69978653667}, {
       1390.833564916672, -5778.69978653667}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2481.092712616329, -5846.286626407053}, 67.58683987038236, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2481.092712616329, -5880.080046342244}, \
{2548.6795524867116`, -5846.286626407053}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5880.080577317733}, {
        102.87025020400247`, -5880.080577317733}, {
        102.87025020400247`, -5880.080046342244}, {
        100, -5880.080046342244}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5880.080577317733}, {
       1323.2467250462896`, -5880.080577317733}, {
       1323.2467250462896`, -5880.080046342244}, {
       603.9550123959395, -5880.080046342244}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1271.3766862222294`, -5880.080577317733}, {
       1275.4118869131946`, -5880.080577317733}, {
       1275.4118869131946`, -5880.080046342244}, {
       1271.3766862222294`, -5880.080046342244}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5880.080577317733}, {
       2620.865615742702, -5880.080577317733}, {
       2620.865615742702, -5880.080046342244}, {
       2481.092712616329, -5880.080046342244}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5880.080577317733}, {
       2586.006517658316, -5880.080577317733}, {
       2586.006517658316, -5880.080046342244}, {
       2584.9806214338746`, -5880.080046342244}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5880.080577317733}, {
       3137.009114500274, -5880.080577317733}, {
       3137.009114500274, -5880.080046342244}, {
       3133.203009888619, -5880.080046342244}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5880.080577317733}, {
       3697.5161362454396`, -5880.080577317733}, {
       3697.5161362454396`, -5880.080046342244}, {
       3647.1823785976826`, -5880.080046342244}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5880.080577317733}, {
       4142.649334923807, -5880.080577317733}, {
       4142.649334923807, -5880.080046342244}, {
       4063.7857158070187`, -5880.080046342244}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5880.080577317733}, {
       4700., -5880.080577317733}, {4700., -5880.080046342244}, {
       4699.999999943301, -5880.080046342244}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2824835399565`, -5880.080577317733}, {
      1601.2827737231796`, -5880.080577317733}, {
      1601.2827737231796`, -5880.080046342244}, {
      1601.2824835399565`, -5880.080046342244}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1275.4118869131946`, -5880.080179086116}, \
{1275.4121524009392`, -5880.080046342244}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1275.4121524009392`, -5880.080179086116}, 
       0.0002654877446125586, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1275.4121524009392`, -5880.08044457386}, {
       1601.2822180522119`, -5880.08044457386}, {
       1601.2822180522119`, -5880.080179086116}, {
       1275.4121524009392`, -5880.080179086116}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2822180522119`, -5880.08044457386}, 
       0.0002654877446125586, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2822180522119`, -5880.080577317733}, \
{1601.2824835399565`, -5880.08044457386}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5883.203529191345}, {
        102.87025020400247`, -5883.203529191345}, {
        102.87025020400247`, -5880.080577317733}, {
        100, -5880.080577317733}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5883.203529191345}, {
       1321.6852491094833`, -5883.203529191345}, {
       1321.6852491094833`, -5880.080577317733}, {
       603.9550123959395, -5880.080577317733}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2822180522119`, -5883.203529191345}, {
       1601.2827737231796`, -5883.203529191345}, {
       1601.2827737231796`, -5880.080577317733}, {
       1601.2822180522119`, -5880.080577317733}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5883.203529191345}, {
       2620.865615742702, -5883.203529191345}, {
       2620.865615742702, -5880.080577317733}, {
       2481.092712616329, -5880.080577317733}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.9806214338746`, -5883.203529191345}, {
       2586.006517658316, -5883.203529191345}, {
       2586.006517658316, -5880.080577317733}, {
       2584.9806214338746`, -5880.080577317733}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5883.203529191345}, {
       3137.009114500274, -5883.203529191345}, {
       3137.009114500274, -5880.080577317733}, {
       3133.203009888619, -5880.080577317733}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5883.203529191345}, {
       3697.5161362454396`, -5883.203529191345}, {
       3697.5161362454396`, -5880.080577317733}, {
       3647.1823785976826`, -5880.080577317733}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5883.203529191345}, {
       4142.649334923807, -5883.203529191345}, {
       4142.649334923807, -5880.080577317733}, {
       4063.7857158070187`, -5880.080577317733}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5883.203529191345}, {
       4700., -5883.203529191345}, {4700., -5880.080577317733}, {
       4699.999999943301, -5880.080577317733}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1271.3766862222294`, -5883.203529191345}, {
      1275.4118869131946`, -5883.203529191345}, {
      1275.4118869131946`, -5880.080577317733}, {
      1271.3766862222294`, -5880.080577317733}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1321.6852491094833`, -5880.861315286136}, \
{1323.2467250462896`, -5880.080577317733}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1323.2467250462896`, -5880.861315286136}, 1.5614759368063051`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1323.2467250462896`, -5882.422791222943}, {
       1269.815210285423, -5882.422791222943}, {
       1269.815210285423, -5880.861315286136}, {
       1323.2467250462896`, -5880.861315286136}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1269.815210285423, -5882.422791222943}, 1.5614759368063051`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1269.815210285423, -5883.203529191345}, \
{1271.3766862222294`, -5882.422791222943}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5883.204493090336}, {
        102.87025020400247`, -5883.204493090336}, {
        102.87025020400247`, -5883.203529191345}, {
        100, -5883.203529191345}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5883.204493090336}, {
       1321.6852491094833`, -5883.204493090336}, {
       1321.6852491094833`, -5883.203529191345}, {
       603.9550123959395, -5883.203529191345}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5883.204493090336}, {
       1275.4118869131946`, -5883.204493090336}, {
       1275.4118869131946`, -5883.203529191345}, {
       1269.815210285423, -5883.203529191345}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5883.204493090336}, {
       2620.865615742702, -5883.204493090336}, {
       2620.865615742702, -5883.203529191345}, {
       2481.092712616329, -5883.203529191345}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5883.204493090336}, {
       2586.006517658316, -5883.204493090336}, {
       2586.006517658316, -5883.203529191345}, {
       2584.98110338337, -5883.203529191345}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3133.203009888619, -5883.204493090336}, {
       3137.009114500274, -5883.204493090336}, {
       3137.009114500274, -5883.203529191345}, {
       3133.203009888619, -5883.203529191345}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5883.204493090336}, {
       3697.5161362454396`, -5883.204493090336}, {
       3697.5161362454396`, -5883.203529191345}, {
       3647.1823785976826`, -5883.203529191345}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5883.204493090336}, {
       4142.649334923807, -5883.204493090336}, {
       4142.649334923807, -5883.203529191345}, {
       4063.7857158070187`, -5883.203529191345}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5883.204493090336}, {
       4700., -5883.204493090336}, {4700., -5883.203529191345}, {
       4699.999999943301, -5883.203529191345}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2822180522119`, -5883.204493090336}, {
      1601.2827737231796`, -5883.204493090336}, {
      1601.2827737231796`, -5883.203529191345}, {
      1601.2822180522119`, -5883.203529191345}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.9806214338746`, -5883.203770166093}, \
{2584.98110338337, -5883.203529191345}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.9806214338746`, -5883.203770166093}, 0.000481949495190304,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2832556726748`, -5883.204252115588}, {
       2584.9806214338746`, -5883.204252115588}, {
       2584.9806214338746`, -5883.203770166093}, {
       1601.2832556726748`, -5883.203770166093}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2832556726748`, -5883.204252115588}, 0.000481949495190304,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2827737231796`, -5883.204493090336}, \
{1601.2832556726748`, -5883.204252115588}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5886.7985943027825`}, {
        102.87025020400247`, -5886.7985943027825`}, {
        102.87025020400247`, -5883.204493090336}, {
        100, -5883.204493090336}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5886.7985943027825`}, {
       1321.6852491094833`, -5886.7985943027825`}, {
       1321.6852491094833`, -5883.204493090336}, {
       603.9550123959395, -5883.204493090336}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5886.7985943027825`}, {
       1275.4118869131946`, -5886.7985943027825`}, {
       1275.4118869131946`, -5883.204493090336}, {
       1269.815210285423, -5883.204493090336}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2822180522119`, -5886.7985943027825`}, {
       1601.2832556726748`, -5886.7985943027825`}, {
       1601.2832556726748`, -5883.204493090336}, {
       1601.2822180522119`, -5883.204493090336}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5886.7985943027825`}, {
       2586.006517658316, -5886.7985943027825`}, {
       2586.006517658316, -5883.204493090336}, {
       2584.98110338337, -5883.204493090336}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5886.7985943027825`}, {
       3137.0091145002743`, -5886.7985943027825`}, {
       3137.0091145002743`, -5883.204493090336}, {
       3135.0000604948423`, -5883.204493090336}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5886.7985943027825`}, {
       3697.5161362454396`, -5886.7985943027825`}, {
       3697.5161362454396`, -5883.204493090336}, {
       3647.1823785976826`, -5883.204493090336}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5886.7985943027825`}, {
       4142.649334923807, -5886.7985943027825`}, {
       4142.649334923807, -5883.204493090336}, {
       4063.7857158070187`, -5883.204493090336}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999943301, -5886.7985943027825`}, {
       4700., -5886.7985943027825`}, {4700., -5883.204493090336}, {
       4699.999999943301, -5883.204493090336}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2481.092712616329, -5886.7985943027825`}, {
      2620.865615742702, -5886.7985943027825`}, {
      2620.865615742702, -5883.204493090336}, {
      2481.092712616329, -5883.204493090336}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3133.203009888619, -5884.103018393448}, \
{3135.0000604948423`, -5883.204493090336}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3133.203009888619, -5884.103018393448}, 1.7970506062231912`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.6626663489255`, -5885.900068999671}, {
       3133.203009888619, -5885.900068999671}, {
       3133.203009888619, -5884.103018393448}, {
       2622.6626663489255`, -5884.103018393448}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.6626663489255`, -5885.900068999671}, 1.7970506062231912`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2620.865615742702, -5886.7985943027825`}, \
{2622.6626663489255`, -5885.900068999671}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5886.798594332155}, {
        102.87025020400247`, -5886.798594332155}, {
        102.87025020400247`, -5886.7985943027825`}, {
        100, -5886.7985943027825`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5886.798594332155}, {
       1321.6852491094833`, -5886.798594332155}, {
       1321.6852491094833`, -5886.7985943027825`}, {
       603.9550123959395, -5886.7985943027825`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5886.798594332155}, {
       1275.4118869131946`, -5886.798594332155}, {
       1275.4118869131946`, -5886.7985943027825`}, {
       1269.815210285423, -5886.7985943027825`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2822180522119`, -5886.798594332155}, {
       1601.2832556726748`, -5886.798594332155}, {
       1601.2832556726748`, -5886.7985943027825`}, {
       1601.2822180522119`, -5886.7985943027825`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5886.798594332155}, {
       2622.6626663489255`, -5886.798594332155}, {
       2622.6626663489255`, -5886.7985943027825`}, {
       2481.092712616329, -5886.7985943027825`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5886.798594332155}, {
       2586.006517658316, -5886.798594332155}, {
       2586.006517658316, -5886.7985943027825`}, {
       2584.98110338337, -5886.7985943027825`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5886.798594332155}, {
       3137.0091144855883`, -5886.798594332155}, {
       3137.0091144855883`, -5886.7985943027825`}, {
       3135.0000604948423`, -5886.7985943027825`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3647.1823785976826`, -5886.798594332155}, {
       3697.5161362454396`, -5886.798594332155}, {
       3697.5161362454396`, -5886.7985943027825`}, {
       3647.1823785976826`, -5886.7985943027825`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5886.798594332155}, {
       4142.649334923807, -5886.798594332155}, {
       4142.649334923807, -5886.7985943027825`}, {
       4063.7857158070187`, -5886.7985943027825`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999943301, -5886.798594332155}, {
      4700.000000000001, -5886.798594332155}, {
      4700.000000000001, -5886.7985943027825`}, {
      4699.999999943301, -5886.7985943027825`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3137.0091144855883`, -5886.798594310126}, \
{3137.0091145002743`, -5886.7985943027825`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3137.0091145002743`, -5886.798594310126}, 
       1.4685928276180076`*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3137.0091145002743`, -5886.798594324811}, {
       4699.999999928616, -5886.798594324811}, {
       4699.999999928616, -5886.798594310126}, {
       3137.0091145002743`, -5886.798594310126}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999928616, -5886.798594324811}, 
       1.4685928276180076`*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999928616, -5886.798594332155}, \
{4699.999999943301, -5886.798594324811}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5888.476049401214}, {
        102.87025020400247`, -5888.476049401214}, {
        102.87025020400247`, -5886.798594332155}, {
        100, -5886.798594332155}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5888.476049401214}, {
       1321.6852491094833`, -5888.476049401214}, {
       1321.6852491094833`, -5886.798594332155}, {
       603.9550123959395, -5886.798594332155}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5888.476049401214}, {
       1275.4118869131946`, -5888.476049401214}, {
       1275.4118869131946`, -5886.798594332155}, {
       1269.815210285423, -5886.798594332155}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2822180522119`, -5888.476049401214}, {
       1601.2832556726748`, -5888.476049401214}, {
       1601.2832556726748`, -5886.798594332155}, {
       1601.2822180522119`, -5886.798594332155}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5888.476049401214}, {
       2622.6626663489255`, -5888.476049401214}, {
       2622.6626663489255`, -5886.798594332155}, {
       2481.092712616329, -5886.798594332155}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5888.476049401214}, {
       2585.167790123786, -5888.476049401214}, {
       2585.167790123786, -5886.798594332155}, {
       2584.98110338337, -5886.798594332155}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5888.476049401214}, {
       3137.0091144855883`, -5888.476049401214}, {
       3137.0091144855883`, -5886.798594332155}, {
       3135.0000604948423`, -5886.798594332155}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5888.476049401214}, {
       4142.649334923807, -5888.476049401214}, {
       4142.649334923807, -5886.798594332155}, {
       4063.7857158070187`, -5886.798594332155}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5888.476049401214}, {
       4700.000000000001, -5888.476049401214}, {
       4700.000000000001, -5886.798594332155}, {
       4699.999999928616, -5886.798594332155}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3647.1823785976826`, -5888.476049401214}, {
      3697.5161362454396`, -5888.476049401214}, {
      3697.5161362454396`, -5886.798594332155}, {
      3647.1823785976826`, -5886.798594332155}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2585.167790123786, -5887.21795809942}, \
{2586.006517658316, -5886.798594332155}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2586.006517658316, -5887.21795809942}, 0.8387275345299967, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2586.006517658316, -5888.056685633949}, {
       3646.3436510631527`, -5888.056685633949}, {
       3646.3436510631527`, -5887.21795809942}, {
       2586.006517658316, -5887.21795809942}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3646.3436510631527`, -5888.056685633949}, 0.8387275345299967, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3646.3436510631527`, -5888.476049401214}, \
{3647.1823785976826`, -5888.056685633949}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5913.439981282659}, {
        102.87025020400247`, -5913.439981282659}, {
        102.87025020400247`, -5888.476049401214}, {
        100, -5888.476049401214}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5913.439981282659}, {
       1309.2032831687611`, -5913.439981282659}, {
       1309.2032831687611`, -5888.476049401214}, {
       603.9550123959395, -5888.476049401214}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5913.439981282659}, {
       1275.4118869131946`, -5913.439981282659}, {
       1275.4118869131946`, -5888.476049401214}, {
       1269.815210285423, -5888.476049401214}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2822180522119`, -5913.439981282659}, {
       1601.2832556726748`, -5913.439981282659}, {
       1601.2832556726748`, -5888.476049401214}, {
       1601.2822180522119`, -5888.476049401214}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5913.439981282659}, {
       2622.6626663489255`, -5913.439981282659}, {
       2622.6626663489255`, -5888.476049401214}, {
       2481.092712616329, -5888.476049401214}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5913.439981282659}, {
       2585.167790123786, -5913.439981282659}, {
       2585.167790123786, -5888.476049401214}, {
       2584.98110338337, -5888.476049401214}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5913.439981282659}, {
       3137.0091144855883`, -5913.439981282659}, {
       3137.0091144855883`, -5888.476049401214}, {
       3135.0000604948423`, -5888.476049401214}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5913.439981282659}, {
       4142.649334923807, -5913.439981282659}, {
       4142.649334923807, -5888.476049401214}, {
       4063.7857158070187`, -5888.476049401214}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5913.439981282659}, {
       4700.000000000001, -5913.439981282659}, {
       4700.000000000001, -5888.476049401214}, {
       4699.999999928616, -5888.476049401214}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3646.3436510631527`, -5913.439981282659}, {
      3697.5161362454396`, -5913.439981282659}, {
      3697.5161362454396`, -5888.476049401214}, {
      3646.3436510631527`, -5888.476049401214}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1309.2032831687611`, -5894.717032371575}, \
{1321.6852491094833`, -5888.476049401214}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1321.6852491094833`, -5894.717032371575}, 12.481965940722027`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1321.6852491094833`, -5907.198998312298}, {
       3633.8616851224306`, -5907.198998312298}, {
       3633.8616851224306`, -5894.717032371575}, {
       1321.6852491094833`, -5894.717032371575}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3633.8616851224306`, -5907.198998312298}, 
       12.481965940722027`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3633.8616851224306`, -5913.439981282659}, \
{3646.3436510631527`, -5907.198998312298}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5913.441076713121}, {
        102.86970248877097`, -5913.441076713121}, {
        102.86970248877097`, -5913.439981282659}, {
        100, -5913.439981282659}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{603.9550123959395, -5913.441076713121}, {
       1309.2032831687611`, -5913.441076713121}, {
       1309.2032831687611`, -5913.439981282659}, {
       603.9550123959395, -5913.439981282659}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5913.441076713121}, {
       1275.4118869131946`, -5913.441076713121}, {
       1275.4118869131946`, -5913.439981282659}, {
       1269.815210285423, -5913.439981282659}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5913.441076713121}, {
       2622.6626663489255`, -5913.441076713121}, {
       2622.6626663489255`, -5913.439981282659}, {
       2481.092712616329, -5913.439981282659}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5913.441076713121}, {
       2585.167790123786, -5913.441076713121}, {
       2585.167790123786, -5913.439981282659}, {
       2584.98110338337, -5913.439981282659}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5913.441076713121}, {
       3137.0091144855883`, -5913.441076713121}, {
       3137.0091144855883`, -5913.439981282659}, {
       3135.0000604948423`, -5913.439981282659}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3633.8616851224306`, -5913.441076713121}, {
       3697.5161362454396`, -5913.441076713121}, {
       3697.5161362454396`, -5913.439981282659}, {
       3633.8616851224306`, -5913.439981282659}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5913.441076713121}, {
       4142.649334923807, -5913.441076713121}, {
       4142.649334923807, -5913.439981282659}, {
       4063.7857158070187`, -5913.439981282659}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5913.441076713121}, {
       4700.000000000001, -5913.441076713121}, {
       4700.000000000001, -5913.439981282659}, {
       4699.999999928616, -5913.439981282659}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2822180522119`, -5913.441076713121}, {
      1601.2832556726748`, -5913.441076713121}, {
      1601.2832556726748`, -5913.439981282659}, {
      1601.2822180522119`, -5913.439981282659}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{102.86970248877097`, -5913.440255140274}, \
{102.87025020400247`, -5913.439981282659}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{102.87025020400247`, -5913.440255140274}, 
       0.0005477152315009972, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{102.87025020400247`, -5913.440802855505}, {
       1601.2816703369804`, -5913.440802855505}, {
       1601.2816703369804`, -5913.440255140274}, {
       102.87025020400247`, -5913.440255140274}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816703369804`, -5913.440802855505}, 
       0.0005477152315009972, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816703369804`, -5913.441076713121}, \
{1601.2822180522119`, -5913.440802855505}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5916.010603513699}, {
       1309.2032831687611`, -5916.010603513699}, {
       1309.2032831687611`, -5913.441076713121}, {
       605.2397757962283, -5913.441076713121}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5916.010603513699}, {
       1275.4118869131946`, -5916.010603513699}, {
       1275.4118869131946`, -5913.441076713121}, {
       1269.815210285423, -5913.441076713121}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5916.010603513699}, {
       1601.2832556726748`, -5916.010603513699}, {
       1601.2832556726748`, -5913.441076713121}, {
       1601.2816703369804`, -5913.441076713121}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5916.010603513699}, {
       2622.6626663489255`, -5916.010603513699}, {
       2622.6626663489255`, -5913.441076713121}, {
       2481.092712616329, -5913.441076713121}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5916.010603513699}, {
       2585.167790123786, -5916.010603513699}, {
       2585.167790123786, -5913.441076713121}, {
       2584.98110338337, -5913.441076713121}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5916.010603513699}, {
       3137.0091144855883`, -5916.010603513699}, {
       3137.0091144855883`, -5913.441076713121}, {
       3135.0000604948423`, -5913.441076713121}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3633.8616851224306`, -5916.010603513699}, {
       3697.5161362454396`, -5916.010603513699}, {
       3697.5161362454396`, -5913.441076713121}, {
       3633.8616851224306`, -5913.441076713121}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5916.010603513699}, {
       4142.649334923807, -5916.010603513699}, {
       4142.649334923807, -5913.441076713121}, {
       4063.7857158070187`, -5913.441076713121}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5916.010603513699}, {
       4700.000000000001, -5916.010603513699}, {
       4700.000000000001, -5913.441076713121}, {
       4699.999999928616, -5913.441076713121}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5916.010603513699}, {
       102.86970248877097`, -5916.010603513699}, {
       102.86970248877097`, -5913.441076713121}, {
       100, -5913.441076713121}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{603.9550123959395, -5914.083458413265}, \
{605.2397757962283, -5913.441076713121}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{603.9550123959395, -5914.083458413265}, 1.2847634002887696`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{104.15446588905974`, -5915.368221813555}, {
       603.9550123959395, -5915.368221813555}, {
       603.9550123959395, -5914.083458413265}, {
       104.15446588905974`, -5914.083458413265}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{104.15446588905974`, -5915.368221813555}, 1.2847634002887696`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{102.86970248877097`, -5916.010603513699}, \
{104.15446588905974`, -5915.368221813555}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5917.117046957224}, {
        103.60124416729712`, -5917.117046957224}, {
        103.60124416729712`, -5916.010603513699}, {
        100, -5916.010603513699}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5917.117046957224}, {
       1309.2032831687611`, -5917.117046957224}, {
       1309.2032831687611`, -5916.010603513699}, {
       605.2397757962283, -5916.010603513699}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5917.117046957224}, {
       1275.4118869131946`, -5917.117046957224}, {
       1275.4118869131946`, -5916.010603513699}, {
       1269.815210285423, -5916.010603513699}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5917.117046957224}, {
       1601.2832556726748`, -5917.117046957224}, {
       1601.2832556726748`, -5916.010603513699}, {
       1601.2816703369804`, -5916.010603513699}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5917.117046957224}, {
       2622.6626663489255`, -5917.117046957224}, {
       2622.6626663489255`, -5916.010603513699}, {
       2481.092712616329, -5916.010603513699}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5917.117046957224}, {
       2585.167790123786, -5917.117046957224}, {
       2585.167790123786, -5916.010603513699}, {
       2584.98110338337, -5916.010603513699}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5917.117046957224}, {
       3137.0091144855883`, -5917.117046957224}, {
       3137.0091144855883`, -5916.010603513699}, {
       3135.0000604948423`, -5916.010603513699}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4063.7857158070187`, -5917.117046957224}, {
       4142.649334923807, -5917.117046957224}, {
       4142.649334923807, -5916.010603513699}, {
       4063.7857158070187`, -5916.010603513699}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5917.117046957224}, {
       4700.000000000001, -5917.117046957224}, {
       4700.000000000001, -5916.010603513699}, {
       4699.999999928616, -5916.010603513699}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3633.8616851224306`, -5917.117046957224}, {
      3697.516136245439, -5917.117046957224}, {
      3697.516136245439, -5916.010603513699}, {
      3633.8616851224306`, -5916.010603513699}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{103.60124416729712`, -5916.287214374581}, \
{104.15446588905974`, -5916.010603513699}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{104.15446588905974`, -5916.287214374581}, 0.5532217217626165, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{104.15446588905974`, -5916.840436096343}, {
       3633.3084634006677`, -5916.840436096343}, {
       3633.3084634006677`, -5916.287214374581}, {
       104.15446588905974`, -5916.287214374581}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3633.3084634006677`, -5916.840436096343}, 0.5532217217626165, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3633.3084634006677`, -5917.117046957224}, \
{3633.8616851224306`, -5916.840436096343}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5923.896388271202}, {
       1309.2032831687611`, -5923.896388271202}, {
       1309.2032831687611`, -5917.117046957224}, {
       605.2397757962283, -5917.117046957224}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5923.896388271202}, {
       1275.4118869131946`, -5923.896388271202}, {
       1275.4118869131946`, -5917.117046957224}, {
       1269.815210285423, -5917.117046957224}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5923.896388271202}, {
       1601.2832556726748`, -5923.896388271202}, {
       1601.2832556726748`, -5917.117046957224}, {
       1601.2816703369804`, -5917.117046957224}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5923.896388271202}, {
       2622.6626663489255`, -5923.896388271202}, {
       2622.6626663489255`, -5917.117046957224}, {
       2481.092712616329, -5917.117046957224}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5923.896388271202}, {
       2585.167790123786, -5923.896388271202}, {
       2585.167790123786, -5917.117046957224}, {
       2584.98110338337, -5917.117046957224}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5923.896388271202}, {
       3137.0091144855883`, -5923.896388271202}, {
       3137.0091144855883`, -5917.117046957224}, {
       3135.0000604948423`, -5917.117046957224}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3633.3084634006677`, -5923.896388271202}, {
       3697.516136245439, -5923.896388271202}, {
       3697.516136245439, -5917.117046957224}, {
       3633.3084634006677`, -5917.117046957224}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4067.1753864640077`, -5923.896388271202}, {
       4142.649334923807, -5923.896388271202}, {
       4142.649334923807, -5917.117046957224}, {
       4067.1753864640077`, -5917.117046957224}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928616, -5923.896388271202}, {
       4700.000000000001, -5923.896388271202}, {
       4700.000000000001, -5917.117046957224}, {
       4699.999999928616, -5917.117046957224}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5923.896388271202}, {
       103.60124416729712`, -5923.896388271202}, {
       103.60124416729712`, -5917.117046957224}, {
       100, -5917.117046957224}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4063.7857158070187`, -5918.811882285719}, \
{4067.1753864640077`, -5917.117046957224}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4063.7857158070187`, -5918.811882285719}, 3.389670656988833, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{106.99091482428595`, -5922.201552942708}, {
       4063.7857158070187`, -5922.201552942708}, {
       4063.7857158070187`, -5918.811882285719}, {
       106.99091482428595`, -5918.811882285719}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{106.99091482428595`, -5922.201552942708}, 3.389670656988833, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{103.60124416729712`, -5923.896388271202}, \
{106.99091482428595`, -5922.201552942708}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5923.896388271807}, {
        106.99091482428595`, -5923.896388271807}, {
        106.99091482428595`, -5923.896388271202}, {
        100, -5923.896388271202}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5923.896388271807}, {
       1309.2032831687611`, -5923.896388271807}, {
       1309.2032831687611`, -5923.896388271202}, {
       605.2397757962283, -5923.896388271202}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1269.815210285423, -5923.896388271807}, {
       1275.4118869131946`, -5923.896388271807}, {
       1275.4118869131946`, -5923.896388271202}, {
       1269.815210285423, -5923.896388271202}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5923.896388271807}, {
       1601.2832556726748`, -5923.896388271807}, {
       1601.2832556726748`, -5923.896388271202}, {
       1601.2816703369804`, -5923.896388271202}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5923.896388271807}, {
       2622.6626663489255`, -5923.896388271807}, {
       2622.6626663489255`, -5923.896388271202}, {
       2481.092712616329, -5923.896388271202}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5923.896388271807}, {
       2585.167790123786, -5923.896388271807}, {
       2585.167790123786, -5923.896388271202}, {
       2584.98110338337, -5923.896388271202}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5923.896388271807}, {
       3137.0091144855883`, -5923.896388271807}, {
       3137.0091144855883`, -5923.896388271202}, {
       3135.0000604948423`, -5923.896388271202}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3633.3084634006677`, -5923.896388271807}, {
       3697.516136245439, -5923.896388271807}, {
       3697.516136245439, -5923.896388271202}, {
       3633.3084634006677`, -5923.896388271202}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4067.1753864640077`, -5923.896388271807}, {
       4142.649334923505, -5923.896388271807}, {
       4142.649334923505, -5923.896388271202}, {
       4067.1753864640077`, -5923.896388271202}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999928616, -5923.896388271807}, {
      4700., -5923.896388271807}, {4700., -5923.896388271202}, {
      4699.999999928616, -5923.896388271202}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334923505, -5923.896388271353}, \
{4142.649334923807, -5923.896388271202}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334923807, -5923.896388271353}, 
       3.0241361782069754`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334923807, -5923.896388271656}, {
       4699.999999928313, -5923.896388271656}, {
       4699.999999928313, -5923.896388271353}, {
       4142.649334923807, -5923.896388271353}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999928313, -5923.896388271656}, 
       3.0241361782069754`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999928313, -5923.896388271807}, \
{4699.999999928616, -5923.896388271656}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5933.121106173687}, {
        106.99091482428595`, -5933.121106173687}, {
        106.99091482428595`, -5923.896388271807}, {
        100, -5923.896388271807}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5933.121106173687}, {
       1304.5909242178213`, -5933.121106173687}, {
       1304.5909242178213`, -5923.896388271807}, {
       605.2397757962283, -5923.896388271807}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5933.121106173687}, {
       1601.2832556726748`, -5933.121106173687}, {
       1601.2832556726748`, -5923.896388271807}, {
       1601.2816703369804`, -5923.896388271807}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5933.121106173687}, {
       2622.6626663489255`, -5933.121106173687}, {
       2622.6626663489255`, -5923.896388271807}, {
       2481.092712616329, -5923.896388271807}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5933.121106173687}, {
       2585.167790123786, -5933.121106173687}, {
       2585.167790123786, -5923.896388271807}, {
       2584.98110338337, -5923.896388271807}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5933.121106173687}, {
       3137.0091144855883`, -5933.121106173687}, {
       3137.0091144855883`, -5923.896388271807}, {
       3135.0000604948423`, -5923.896388271807}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3633.3084634006677`, -5933.121106173687}, {
       3697.516136245439, -5933.121106173687}, {
       3697.516136245439, -5923.896388271807}, {
       3633.3084634006677`, -5923.896388271807}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4067.1753864640077`, -5933.121106173687}, {
       4142.649334923505, -5933.121106173687}, {
       4142.649334923505, -5923.896388271807}, {
       4067.1753864640077`, -5923.896388271807}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5933.121106173687}, {
       4700., -5933.121106173687}, {4700., -5923.896388271807}, {
       4699.999999928313, -5923.896388271807}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1269.815210285423, -5933.121106173687}, {
      1275.4118869131946`, -5933.121106173687}, {
      1275.4118869131946`, -5923.896388271807}, {
      1269.815210285423, -5923.896388271807}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1304.5909242178213`, -5926.2025677472775`}, \
{1309.2032831687611`, -5923.896388271807}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1309.2032831687611`, -5926.2025677472775`}, 4.612358950939737, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1309.2032831687611`, -5930.814926698217}, {
       1265.2028513344833`, -5930.814926698217}, {
       1265.2028513344833`, -5926.2025677472775`}, {
       1309.2032831687611`, -5926.2025677472775`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1265.2028513344833`, -5930.814926698217}, 4.612358950939737, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1265.2028513344833`, -5933.121106173687}, \
{1269.815210285423, -5930.814926698217}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5942.021128195251}, {
        106.99091482428595`, -5942.021128195251}, {
        106.99091482428595`, -5933.121106173687}, {
        100, -5933.121106173687}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5942.021128195251}, {
       1275.4118869131946`, -5942.021128195251}, {
       1275.4118869131946`, -5933.121106173687}, {
       1265.2028513344833`, -5933.121106173687}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5942.021128195251}, {
       1601.2832556726748`, -5942.021128195251}, {
       1601.2832556726748`, -5933.121106173687}, {
       1601.2816703369804`, -5933.121106173687}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5942.021128195251}, {
       2622.6626663489255`, -5942.021128195251}, {
       2622.6626663489255`, -5933.121106173687}, {
       2481.092712616329, -5933.121106173687}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5942.021128195251}, {
       2585.167790123786, -5942.021128195251}, {
       2585.167790123786, -5933.121106173687}, {
       2584.98110338337, -5933.121106173687}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5942.021128195251}, {
       3137.0091144855883`, -5942.021128195251}, {
       3137.0091144855883`, -5933.121106173687}, {
       3135.0000604948423`, -5933.121106173687}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7584744114497`, -5942.021128195251}, {
       3697.516136245439, -5942.021128195251}, {
       3697.516136245439, -5933.121106173687}, {
       3637.7584744114497`, -5933.121106173687}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4067.1753864640077`, -5942.021128195251}, {
       4142.649334923505, -5942.021128195251}, {
       4142.649334923505, -5933.121106173687}, {
       4067.1753864640077`, -5933.121106173687}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5942.021128195251}, {
       4700., -5942.021128195251}, {4700., -5933.121106173687}, {
       4699.999999928313, -5933.121106173687}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{605.2397757962283, -5942.021128195251}, {
      1304.5909242178213`, -5942.021128195251}, {
      1304.5909242178213`, -5933.121106173687}, {
      605.2397757962283, -5933.121106173687}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3633.3084634006677`, -5935.346111679078}, \
{3637.7584744114497`, -5933.121106173687}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3633.3084634006677`, -5935.346111679078}, 4.450011010781878, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1309.0409352286033`, -5939.79612268986}, {
       3633.3084634006677`, -5939.79612268986}, {
       3633.3084634006677`, -5935.346111679078}, {
       1309.0409352286033`, -5935.346111679078}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1309.0409352286033`, -5939.79612268986}, 4.450011010781878, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1304.5909242178213`, -5942.021128195251}, \
{1309.0409352286033`, -5939.79612268986}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5956.579505655283}, {
        106.99091482428595`, -5956.579505655283}, {
        106.99091482428595`, -5942.021128195251}, {
        100, -5942.021128195251}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5956.579505655283}, {
       1309.0409352286033`, -5956.579505655283}, {
       1309.0409352286033`, -5942.021128195251}, {
       605.2397757962283, -5942.021128195251}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5956.579505655283}, {
       1601.2832556726748`, -5956.579505655283}, {
       1601.2832556726748`, -5942.021128195251}, {
       1601.2816703369804`, -5942.021128195251}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5956.579505655283}, {
       2622.6626663489255`, -5956.579505655283}, {
       2622.6626663489255`, -5942.021128195251}, {
       2481.092712616329, -5942.021128195251}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.98110338337, -5956.579505655283}, {
       2585.167790123786, -5956.579505655283}, {
       2585.167790123786, -5942.021128195251}, {
       2584.98110338337, -5942.021128195251}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5956.579505655283}, {
       3137.0091144855883`, -5956.579505655283}, {
       3137.0091144855883`, -5942.021128195251}, {
       3135.0000604948423`, -5942.021128195251}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7584744114497`, -5956.579505655283}, {
       3697.516136245439, -5956.579505655283}, {
       3697.516136245439, -5942.021128195251}, {
       3637.7584744114497`, -5942.021128195251}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.454575194024, -5956.579505655283}, {
       4142.649334923505, -5956.579505655283}, {
       4142.649334923505, -5942.021128195251}, {
       4074.454575194024, -5942.021128195251}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5956.579505655283}, {
       4700., -5956.579505655283}, {4700., -5942.021128195251}, {
       4699.999999928313, -5942.021128195251}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1265.2028513344833`, -5956.579505655283}, {
      1275.4118869131946`, -5956.579505655283}, {
      1275.4118869131946`, -5942.021128195251}, {
      1265.2028513344833`, -5942.021128195251}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4067.1753864640077`, -5945.660722560258}, \
{4074.454575194024, -5942.021128195251}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4067.1753864640077`, -5945.660722560258}, 7.279188730016584, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1282.6910756432112`, -5952.939911290275}, {
       4067.1753864640077`, -5952.939911290275}, {
       4067.1753864640077`, -5945.660722560258}, {
       1282.6910756432112`, -5945.660722560258}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1282.6910756432112`, -5952.939911290275}, 7.279188730016584, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1275.4118869131946`, -5956.579505655283}, \
{1282.6910756432112`, -5952.939911290275}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5956.816909816759}, {
        106.99091482428595`, -5956.816909816759}, {
        106.99091482428595`, -5956.579505655283}, {
        100, -5956.579505655283}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5956.816909816759}, {
       1309.0409352286033`, -5956.816909816759}, {
       1309.0409352286033`, -5956.579505655283}, {
       605.2397757962283, -5956.579505655283}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5956.816909816759}, {
       1282.6910756432112`, -5956.816909816759}, {
       1282.6910756432112`, -5956.579505655283}, {
       1265.2028513344833`, -5956.579505655283}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5956.816909816759}, {
       1601.2832556726748`, -5956.816909816759}, {
       1601.2832556726748`, -5956.579505655283}, {
       1601.2816703369804`, -5956.579505655283}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5956.816909816759}, {
       2622.5439642681877`, -5956.816909816759}, {
       2622.5439642681877`, -5956.579505655283}, {
       2481.092712616329, -5956.579505655283}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5956.816909816759}, {
       3137.0091144855883`, -5956.816909816759}, {
       3137.0091144855883`, -5956.579505655283}, {
       3135.0000604948423`, -5956.579505655283}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7584744114497`, -5956.816909816759}, {
       3697.516136245439, -5956.816909816759}, {
       3697.516136245439, -5956.579505655283}, {
       3637.7584744114497`, -5956.579505655283}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.454575194024, -5956.816909816759}, {
       4142.649334923505, -5956.816909816759}, {
       4142.649334923505, -5956.579505655283}, {
       4074.454575194024, -5956.579505655283}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5956.816909816759}, {
       4700., -5956.816909816759}, {4700., -5956.579505655283}, {
       4699.999999928313, -5956.579505655283}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.98110338337, -5956.816909816759}, {
      2585.167790123786, -5956.816909816759}, {
      2585.167790123786, -5956.579505655283}, {
      2584.98110338337, -5956.579505655283}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.5439642681877`, -5956.638856695653}, \
{2622.6626663489255`, -5956.579505655283}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.6626663489255`, -5956.638856695653}, 0.11870208073771205`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.6626663489255`, -5956.75755877639}, {
       2584.862401302632, -5956.75755877639}, {
       2584.862401302632, -5956.638856695653}, {
       2622.6626663489255`, -5956.638856695653}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.862401302632, -5956.75755877639}, 0.11870208073771205`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.862401302632, -5956.816909816759}, \
{2584.98110338337, -5956.75755877639}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5957.3831158408475`}, {
        106.99091482428595`, -5957.3831158408475`}, {
        106.99091482428595`, -5956.816909816759}, {
        100, -5956.816909816759}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5957.3831158408475`}, {
       1309.0409352286033`, -5957.3831158408475`}, {
       1309.0409352286033`, -5956.816909816759}, {
       605.2397757962283, -5956.816909816759}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5957.3831158408475`}, {
       1282.6910756432112`, -5957.3831158408475`}, {
       1282.6910756432112`, -5956.816909816759}, {
       1265.2028513344833`, -5956.816909816759}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5957.3831158408475`}, {
       1601.2832556726748`, -5957.3831158408475`}, {
       1601.2832556726748`, -5956.816909816759}, {
       1601.2816703369804`, -5956.816909816759}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5957.3831158408475`}, {
       2622.5439642681877`, -5957.3831158408475`}, {
       2622.5439642681877`, -5956.816909816759}, {
       2481.092712616329, -5956.816909816759}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.862401302632, -5957.3831158408475`}, {
       2584.8846871117416`, -5957.3831158408475`}, {
       2584.8846871117416`, -5956.816909816759}, {
       2584.862401302632, -5956.816909816759}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5957.3831158408475`}, {
       3137.0091144855883`, -5957.3831158408475`}, {
       3137.0091144855883`, -5956.816909816759}, {
       3135.0000604948423`, -5956.816909816759}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7584744114497`, -5957.3831158408475`}, {
       3697.516136245439, -5957.3831158408475`}, {
       3697.516136245439, -5956.816909816759}, {
       3637.7584744114497`, -5956.816909816759}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5957.3831158408475`}, {
       4700., -5957.3831158408475`}, {4700., -5956.816909816759}, {
       4699.999999928313, -5956.816909816759}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4074.454575194024, -5957.3831158408475`}, {
      4142.649334923505, -5957.3831158408475`}, {
      4142.649334923505, -5956.816909816759}, {
      4074.454575194024, -5956.816909816759}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8846871117416`, -5956.958461322782}, \
{2585.167790123786, -5956.816909816759}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2585.167790123786, -5956.958461322782}, 0.28310301204413113`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2585.167790123786, -5957.241564334826}, {
       4074.17147218198, -5957.241564334826}, {
       4074.17147218198, -5956.958461322782}, {
       2585.167790123786, -5956.958461322782}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4074.17147218198, -5957.241564334826}, 0.28310301204413113`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4074.17147218198, -5957.3831158408475`}, \
{4074.454575194024, -5957.241564334826}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5957.38474010563}, {
        106.99091482428595`, -5957.38474010563}, {
        106.99091482428595`, -5957.3831158408475`}, {
        100, -5957.3831158408475`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5957.38474010563}, {
       1309.0409352286033`, -5957.38474010563}, {
       1309.0409352286033`, -5957.3831158408475`}, {
       605.2397757962283, -5957.3831158408475`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5957.38474010563}, {
       1282.6910756432112`, -5957.38474010563}, {
       1282.6910756432112`, -5957.3831158408475`}, {
       1265.2028513344833`, -5957.3831158408475`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5957.38474010563}, {
       1601.2824435402838`, -5957.38474010563}, {
       1601.2824435402838`, -5957.3831158408475`}, {
       1601.2816703369804`, -5957.3831158408475`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5957.38474010563}, {
       2622.5439642681877`, -5957.38474010563}, {
       2622.5439642681877`, -5957.3831158408475`}, {
       2481.092712616329, -5957.3831158408475`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.862401302632, -5957.38474010563}, {
       2584.8846871117416`, -5957.38474010563}, {
       2584.8846871117416`, -5957.3831158408475`}, {
       2584.862401302632, -5957.3831158408475`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5957.38474010563}, {
       3137.0091144855883`, -5957.38474010563}, {
       3137.0091144855883`, -5957.3831158408475`}, {
       3135.0000604948423`, -5957.3831158408475`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7584744114497`, -5957.38474010563}, {
       3697.516136245439, -5957.38474010563}, {
       3697.516136245439, -5957.3831158408475`}, {
       3637.7584744114497`, -5957.3831158408475`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5957.38474010563}, {
       4700., -5957.38474010563}, {4700., -5957.3831158408475`}, {
       4699.999999928313, -5957.3831158408475`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4074.17147218198, -5957.38474010563}, {
      4142.649334923504, -5957.38474010563}, {
      4142.649334923504, -5957.3831158408475`}, {
      4074.17147218198, -5957.3831158408475`}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2824435402838`, -5957.383521907043}, \
{1601.2832556726748`, -5957.3831158408475`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2832556726748`, -5957.383521907043}, 
       0.0008121323911313904, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2832556726748`, -5957.384334039434}, {
       4074.1706600495886`, -5957.384334039434}, {
       4074.1706600495886`, -5957.383521907043}, {
       1601.2832556726748`, -5957.383521907043}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4074.1706600495886`, -5957.384334039434}, 
       0.0008121323911313904, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4074.1706600495886`, -5957.38474010563}, \
{4074.17147218198, -5957.384334039434}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5957.385933626414}, {
        106.99091482428595`, -5957.385933626414}, {
        106.99091482428595`, -5957.38474010563}, {
        100, -5957.38474010563}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5957.385933626414}, {
       1309.0409352286033`, -5957.385933626414}, {
       1309.0409352286033`, -5957.38474010563}, {
       605.2397757962283, -5957.38474010563}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5957.385933626414}, {
       1282.6910756432112`, -5957.385933626414}, {
       1282.6910756432112`, -5957.38474010563}, {
       1265.2028513344833`, -5957.38474010563}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5957.385933626414}, {
       1601.281846779892, -5957.385933626414}, {
       1601.281846779892, -5957.38474010563}, {
       1601.2816703369804`, -5957.38474010563}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5957.385933626414}, {
       2622.5439642681877`, -5957.385933626414}, {
       2622.5439642681877`, -5957.38474010563}, {
       2481.092712616329, -5957.38474010563}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.862401302632, -5957.385933626414}, {
       2584.8846871117416`, -5957.385933626414}, {
       2584.8846871117416`, -5957.38474010563}, {
       2584.862401302632, -5957.38474010563}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5957.385933626414}, {
       3137.0091144855883`, -5957.385933626414}, {
       3137.0091144855883`, -5957.38474010563}, {
       3135.0000604948423`, -5957.38474010563}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -5957.385933626414}, {
       4142.649334923504, -5957.385933626414}, {
       4142.649334923504, -5957.38474010563}, {
       4074.1706600495886`, -5957.38474010563}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5957.385933626414}, {
       4700., -5957.385933626414}, {4700., -5957.38474010563}, {
       4699.999999928313, -5957.38474010563}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3637.7584744114497`, -5957.385933626414}, {
      3697.516136245439, -5957.385933626414}, {
      3697.516136245439, -5957.38474010563}, {
      3637.7584744114497`, -5957.38474010563}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281846779892, -5957.385038485826}, \
{1601.2824435402838`, -5957.38474010563}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2824435402838`, -5957.385038485826}, 
       0.0005967603918038062, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2824435402838`, -5957.385635246218}, {
       3637.7578776510577`, -5957.385635246218}, {
       3637.7578776510577`, -5957.385038485826}, {
       1601.2824435402838`, -5957.385038485826}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3637.7578776510577`, -5957.385635246218}, 
       0.0005967603918038062, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3637.7578776510577`, -5957.385933626414}, \
{3637.7584744114497`, -5957.385635246218}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5957.390466743209}, {
        106.98864826588859`, -5957.390466743209}, {
        106.98864826588859`, -5957.385933626414}, {
        100, -5957.385933626414}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5957.390466743209}, {
       1309.0409352286033`, -5957.390466743209}, {
       1309.0409352286033`, -5957.385933626414}, {
       605.2397757962283, -5957.385933626414}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5957.390466743209}, {
       1282.6910756432112`, -5957.390466743209}, {
       1282.6910756432112`, -5957.385933626414}, {
       1265.2028513344833`, -5957.385933626414}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5957.390466743209}, {
       1601.281846779892, -5957.390466743209}, {
       1601.281846779892, -5957.385933626414}, {
       1601.2816703369804`, -5957.385933626414}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5957.390466743209}, {
       2622.5439642681877`, -5957.390466743209}, {
       2622.5439642681877`, -5957.385933626414}, {
       2481.092712616329, -5957.385933626414}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.0000604948423`, -5957.390466743209}, {
       3137.0091144855883`, -5957.390466743209}, {
       3137.0091144855883`, -5957.385933626414}, {
       3135.0000604948423`, -5957.385933626414}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7578776510577`, -5957.390466743209}, {
       3697.516136245439, -5957.390466743209}, {
       3697.516136245439, -5957.385933626414}, {
       3637.7578776510577`, -5957.385933626414}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -5957.390466743209}, {
       4142.649334923504, -5957.390466743209}, {
       4142.649334923504, -5957.385933626414}, {
       4074.1706600495886`, -5957.385933626414}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5957.390466743209}, {
       4700., -5957.390466743209}, {4700., -5957.385933626414}, {
       4699.999999928313, -5957.385933626414}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.862401302632, -5957.390466743209}, {
      2584.8846871117416`, -5957.390466743209}, {
      2584.8846871117416`, -5957.385933626414}, {
      2584.862401302632, -5957.385933626414}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{106.98864826588859`, -5957.387066905613}, \
{106.99091482428595`, -5957.385933626414}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{106.99091482428595`, -5957.387066905613}, 0.002266558397364754,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{106.99091482428595`, -5957.389333464011}, {
       2584.8601347442345`, -5957.389333464011}, {
       2584.8601347442345`, -5957.387066905613}, {
       106.99091482428595`, -5957.387066905613}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8601347442345`, -5957.389333464011}, 
       0.002266558397364754, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8601347442345`, -5957.390466743209}, \
{2584.862401302632, -5957.389333464011}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5959.282052886246}, {
       1309.0409352286033`, -5959.282052886246}, {
       1309.0409352286033`, -5957.390466743209}, {
       605.2397757962283, -5957.390466743209}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5959.282052886246}, {
       1282.6910756432112`, -5959.282052886246}, {
       1282.6910756432112`, -5957.390466743209}, {
       1265.2028513344833`, -5957.390466743209}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5959.282052886246}, {
       1601.281846779892, -5959.282052886246}, {
       1601.281846779892, -5957.390466743209}, {
       1601.2816703369804`, -5957.390466743209}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2481.092712616329, -5959.282052886246}, {
       2622.5439642681877`, -5959.282052886246}, {
       2622.5439642681877`, -5957.390466743209}, {
       2481.092712616329, -5957.390466743209}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8601347442345`, -5959.282052886246}, {
       2584.8846871117416`, -5959.282052886246}, {
       2584.8846871117416`, -5957.390466743209}, {
       2584.8601347442345`, -5957.390466743209}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -5959.282052886246}, {
       3137.0091144855883`, -5959.282052886246}, {
       3137.0091144855883`, -5957.390466743209}, {
       3135.9458535663607`, -5957.390466743209}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7578776510577`, -5959.282052886246}, {
       3697.516136245439, -5959.282052886246}, {
       3697.516136245439, -5957.390466743209}, {
       3637.7578776510577`, -5957.390466743209}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -5959.282052886246}, {
       4142.649334923504, -5959.282052886246}, {
       4142.649334923504, -5957.390466743209}, {
       4074.1706600495886`, -5957.390466743209}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5959.282052886246}, {
       4700., -5959.282052886246}, {4700., -5957.390466743209}, {
       4699.999999928313, -5957.390466743209}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5959.282052886246}, {
       106.98864826588859`, -5959.282052886246}, {
       106.98864826588859`, -5957.390466743209}, {
       100, -5957.390466743209}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3135.0000604948423`, -5957.863363278968}, \
{3135.9458535663607`, -5957.390466743209}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3135.0000604948423`, -5957.863363278968}, 0.94579307151864, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{107.93444133740724`, -5958.809156350487}, {
       3135.0000604948423`, -5958.809156350487}, {
       3135.0000604948423`, -5957.863363278968}, {
       107.93444133740724`, -5957.863363278968}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{107.93444133740724`, -5958.809156350487}, 0.94579307151864, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{106.98864826588859`, -5959.282052886246}, \
{107.93444133740724`, -5958.809156350487}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5969.748332671046}, {
       1309.0409352286033`, -5969.748332671046}, {
       1309.0409352286033`, -5959.282052886246}, {
       605.2397757962283, -5959.282052886246}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5969.748332671046}, {
       1282.6910756432112`, -5969.748332671046}, {
       1282.6910756432112`, -5959.282052886246}, {
       1265.2028513344833`, -5959.282052886246}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5969.748332671046}, {
       1601.281846779892, -5969.748332671046}, {
       1601.281846779892, -5959.282052886246}, {
       1601.2816703369804`, -5959.282052886246}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -5969.748332671046}, {
       2622.5439642681877`, -5969.748332671046}, {
       2622.5439642681877`, -5959.282052886246}, {
       2486.3258525087294`, -5959.282052886246}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8601347442345`, -5969.748332671046}, {
       2584.8846871117416`, -5969.748332671046}, {
       2584.8846871117416`, -5959.282052886246}, {
       2584.8601347442345`, -5959.282052886246}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -5969.748332671046}, {
       3137.0091144855883`, -5969.748332671046}, {
       3137.0091144855883`, -5959.282052886246}, {
       3135.9458535663607`, -5959.282052886246}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3637.7578776510577`, -5969.748332671046}, {
       3697.516136245439, -5969.748332671046}, {
       3697.516136245439, -5959.282052886246}, {
       3637.7578776510577`, -5959.282052886246}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -5969.748332671046}, {
       4142.649334923504, -5969.748332671046}, {
       4142.649334923504, -5959.282052886246}, {
       4074.1706600495886`, -5959.282052886246}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5969.748332671046}, {
       4700., -5969.748332671046}, {4700., -5959.282052886246}, {
       4699.999999928313, -5959.282052886246}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -5969.748332671046}, {
       107.93444133740724`, -5969.748332671046}, {
       107.93444133740724`, -5959.282052886246}, {
       100, -5959.282052886246}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2481.092712616329, -5961.898622832446}, \
{2486.3258525087294`, -5959.282052886246}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2481.092712616329, -5961.898622832446}, 5.233139892400215, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.16758122980744`, -5967.131762724846}, {
       2481.092712616329, -5967.131762724846}, {
       2481.092712616329, -5961.898622832446}, {
       113.16758122980744`, -5961.898622832446}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.16758122980744`, -5967.131762724846}, 5.233139892400215, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{107.93444133740724`, -5969.748332671046}, \
{113.16758122980744`, -5967.131762724846}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -5994.815186761327}, {
        113.16758122980744`, -5994.815186761327}, {
        113.16758122980744`, -5969.748332671046}, {
        100, -5969.748332671046}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -5994.815186761327}, {
       1296.507508183463, -5994.815186761327}, {
       1296.507508183463, -5969.748332671046}, {
       605.2397757962283, -5969.748332671046}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1265.2028513344833`, -5994.815186761327}, {
       1282.6910756432112`, -5994.815186761327}, {
       1282.6910756432112`, -5969.748332671046}, {
       1265.2028513344833`, -5969.748332671046}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -5994.815186761327}, {
       1601.281846779892, -5994.815186761327}, {
       1601.281846779892, -5969.748332671046}, {
       1601.2816703369804`, -5969.748332671046}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -5994.815186761327}, {
       2622.5439642681877`, -5994.815186761327}, {
       2622.5439642681877`, -5969.748332671046}, {
       2486.3258525087294`, -5969.748332671046}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8601347442345`, -5994.815186761327}, {
       2584.8846871117416`, -5994.815186761327}, {
       2584.8846871117416`, -5969.748332671046}, {
       2584.8601347442345`, -5969.748332671046}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -5994.815186761327}, {
       3137.0091144855883`, -5994.815186761327}, {
       3137.0091144855883`, -5969.748332671046}, {
       3135.9458535663607`, -5969.748332671046}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -5994.815186761327}, {
       4142.649334923504, -5994.815186761327}, {
       4142.649334923504, -5969.748332671046}, {
       4074.1706600495886`, -5969.748332671046}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -5994.815186761327}, {
       4700., -5994.815186761327}, {4700., -5969.748332671046}, {
       4699.999999928313, -5969.748332671046}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3637.7578776510577`, -5994.815186761327}, {
      3697.5161362454387`, -5994.815186761327}, {
      3697.5161362454387`, -5969.748332671046}, {
      3637.7578776510577`, -5969.748332671046}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1296.507508183463, -5976.015046193616}, \
{1309.0409352286033`, -5969.748332671046}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1309.0409352286033`, -5976.015046193616}, 12.533427045140158`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1309.0409352286033`, -5988.548473238757}, {
       3625.2244506059174`, -5988.548473238757}, {
       3625.2244506059174`, -5976.015046193616}, {
       1309.0409352286033`, -5976.015046193616}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3625.2244506059174`, -5988.548473238757}, 
       12.533427045140158`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3625.2244506059174`, -5994.815186761327}, \
{3637.7578776510577`, -5988.548473238757}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.790339528176}, {
        113.16758122980744`, -6018.790339528176}, {
        113.16758122980744`, -5994.815186761327}, {
        100, -5994.815186761327}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.790339528176}, {
       1282.691075643211, -6018.790339528176}, {
       1282.691075643211, -5994.815186761327}, {
       1277.1904277179078`, -5994.815186761327}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -6018.790339528176}, {
       1601.281846779892, -6018.790339528176}, {
       1601.281846779892, -5994.815186761327}, {
       1601.2816703369804`, -5994.815186761327}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -6018.790339528176}, {
       2622.5439642681877`, -6018.790339528176}, {
       2622.5439642681877`, -5994.815186761327}, {
       2486.3258525087294`, -5994.815186761327}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8601347442345`, -6018.790339528176}, {
       2584.8846871117416`, -6018.790339528176}, {
       2584.8846871117416`, -5994.815186761327}, {
       2584.8601347442345`, -5994.815186761327}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -6018.790339528176}, {
       3137.0091144855883`, -6018.790339528176}, {
       3137.0091144855883`, -5994.815186761327}, {
       3135.9458535663607`, -5994.815186761327}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.790339528176}, {
       3697.5161362454387`, -6018.790339528176}, {
       3697.5161362454387`, -5994.815186761327}, {
       3625.2244506059174`, -5994.815186761327}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.790339528176}, {
       4142.649334923504, -6018.790339528176}, {
       4142.649334923504, -5994.815186761327}, {
       4074.1706600495886`, -5994.815186761327}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -6018.790339528176}, {
       4700., -6018.790339528176}, {4700., -5994.815186761327}, {
       4699.999999928313, -5994.815186761327}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{605.2397757962283, -6018.790339528176}, {
      1296.507508183463, -6018.790339528176}, {
      1296.507508183463, -5994.815186761327}, {
      605.2397757962283, -5994.815186761327}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1265.2028513344833`, -6000.808974953039}, \
{1277.1904277179078`, -5994.815186761327}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1265.2028513344833`, -6000.808974953039}, 11.98757638342465, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1308.4950845668877`, -6012.796551336464}, {
       1265.2028513344833`, -6012.796551336464}, {
       1265.2028513344833`, -6000.808974953039}, {
       1308.4950845668877`, -6000.808974953039}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1308.4950845668877`, -6012.796551336464}, 11.98757638342465, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1296.507508183463, -6018.790339528176}, \
{1308.4950845668877`, -6012.796551336464}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.830321117493}, {
       1308.4950845668877`, -6018.830321117493}, {
       1308.4950845668877`, -6018.790339528176}, {
       605.2397757962283, -6018.790339528176}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.830321117493}, {
       1282.691075643211, -6018.830321117493}, {
       1282.691075643211, -6018.790339528176}, {
       1277.1904277179078`, -6018.790339528176}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -6018.830321117493}, {
       1601.281846779892, -6018.830321117493}, {
       1601.281846779892, -6018.790339528176}, {
       1601.2816703369804`, -6018.790339528176}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -6018.830321117493}, {
       2622.5439642681877`, -6018.830321117493}, {
       2622.5439642681877`, -6018.790339528176}, {
       2486.3258525087294`, -6018.790339528176}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.830321117493}, {
       2584.8846871117416`, -6018.830321117493}, {
       2584.8846871117416`, -6018.790339528176}, {
       2584.880125538893, -6018.790339528176}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -6018.830321117493}, {
       3137.0091144855883`, -6018.830321117493}, {
       3137.0091144855883`, -6018.790339528176}, {
       3135.9458535663607`, -6018.790339528176}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.830321117493}, {
       3697.5161362454387`, -6018.830321117493}, {
       3697.5161362454387`, -6018.790339528176}, {
       3625.2244506059174`, -6018.790339528176}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.830321117493}, {
       4142.649334923504, -6018.830321117493}, {
       4142.649334923504, -6018.790339528176}, {
       4074.1706600495886`, -6018.790339528176}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999928313, -6018.830321117493}, {
       4700., -6018.830321117493}, {4700., -6018.790339528176}, {
       4699.999999928313, -6018.790339528176}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -6018.830321117493}, {
       113.16758122980744`, -6018.830321117493}, {
       113.16758122980744`, -6018.790339528176}, {
       100, -6018.790339528176}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8601347442345`, -6018.800334925506}, \
{2584.880125538893, -6018.790339528176}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8601347442345`, -6018.800334925506}, 0.01999079465863996, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.18757202446608`, -6018.820325720164}, {
       2584.8601347442345`, -6018.820325720164}, {
       2584.8601347442345`, -6018.800334925506}, {
       113.18757202446608`, -6018.800334925506}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.18757202446608`, -6018.820325720164}, 0.01999079465863996, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{113.16758122980744`, -6018.830321117493}, \
{113.18757202446608`, -6018.820325720164}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.830321140534}, {
        113.18757202446608`, -6018.830321140534}, {
        113.18757202446608`, -6018.830321117493}, {
        100, -6018.830321117493}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.830321140534}, {
       1308.4950845668877`, -6018.830321140534}, {
       1308.4950845668877`, -6018.830321117493}, {
       605.2397757962283, -6018.830321117493}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.830321140534}, {
       1282.691075643211, -6018.830321140534}, {
       1282.691075643211, -6018.830321117493}, {
       1277.1904277179078`, -6018.830321117493}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -6018.830321140534}, {
       1601.281846779892, -6018.830321140534}, {
       1601.281846779892, -6018.830321117493}, {
       1601.2816703369804`, -6018.830321117493}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.830321140534}, {
       2584.8846871117416`, -6018.830321140534}, {
       2584.8846871117416`, -6018.830321117493}, {
       2584.880125538893, -6018.830321117493}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3135.9458535663607`, -6018.830321140534}, {
       3137.0091144855883`, -6018.830321140534}, {
       3137.0091144855883`, -6018.830321117493}, {
       3135.9458535663607`, -6018.830321117493}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.830321140534}, {
       3697.5161362454387`, -6018.830321140534}, {
       3697.5161362454387`, -6018.830321117493}, {
       3625.2244506059174`, -6018.830321117493}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.830321140534}, {
       4142.649334923504, -6018.830321140534}, {
       4142.649334923504, -6018.830321117493}, {
       4074.1706600495886`, -6018.830321117493}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.830321140534}, {
       4700., -6018.830321140534}, {4700., -6018.830321117493}, {
       4699.999999939832, -6018.830321117493}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2486.3258525087294`, -6018.830321140534}, {
      2622.5439642681877`, -6018.830321140534}, {
      2622.5439642681877`, -6018.830321117493}, {
      2486.3258525087294`, -6018.830321117493}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999928313, -6018.830321123253}, \
{4699.999999939832, -6018.830321117493}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999928313, -6018.830321123253}, 
       1.1520078387925306`*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.543964279708, -6018.830321134774}, {
       4699.999999928313, -6018.830321134774}, {
       4699.999999928313, -6018.830321123253}, {
       2622.543964279708, -6018.830321123253}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.543964279708, -6018.830321134774}, 
       1.1520078387925306`*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.5439642681877`, -6018.830321140534}, \
{2622.543964279708, -6018.830321134774}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.986165571914}, {
       1308.4950845668877`, -6018.986165571914}, {
       1308.4950845668877`, -6018.830321140534}, {
       605.2397757962283, -6018.830321140534}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.986165571914}, {
       1282.691075643211, -6018.986165571914}, {
       1282.691075643211, -6018.830321140534}, {
       1277.1904277179078`, -6018.830321140534}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816703369804`, -6018.986165571914}, {
       1601.281846779892, -6018.986165571914}, {
       1601.281846779892, -6018.830321140534}, {
       1601.2816703369804`, -6018.830321140534}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -6018.986165571914}, {
       2622.543964279708, -6018.986165571914}, {
       2622.543964279708, -6018.830321140534}, {
       2486.3258525087294`, -6018.830321140534}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.986165571914}, {
       2584.8846871117416`, -6018.986165571914}, {
       2584.8846871117416`, -6018.830321140534}, {
       2584.880125538893, -6018.830321140534}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6018.986165571914}, {
       3137.0091144855883`, -6018.986165571914}, {
       3137.0091144855883`, -6018.830321140534}, {
       3136.023775782051, -6018.830321140534}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.986165571914}, {
       3697.5161362454387`, -6018.986165571914}, {
       3697.5161362454387`, -6018.830321140534}, {
       3625.2244506059174`, -6018.830321140534}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.986165571914}, {
       4142.649334923504, -6018.986165571914}, {
       4142.649334923504, -6018.830321140534}, {
       4074.1706600495886`, -6018.830321140534}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.986165571914}, {
       4700., -6018.986165571914}, {4700., -6018.830321140534}, {
       4699.999999939832, -6018.830321140534}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -6018.986165571914}, {
       113.18757202446608`, -6018.986165571914}, {
       113.18757202446608`, -6018.830321140534}, {
       100, -6018.830321140534}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3135.9458535663607`, -6018.869282248379}, \
{3136.023775782051, -6018.830321140534}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3135.9458535663607`, -6018.869282248379}, 0.07792221569006741, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.26549424015616`, -6018.947204464069}, {
       3135.9458535663607`, -6018.947204464069}, {
       3135.9458535663607`, -6018.869282248379}, {
       113.26549424015616`, -6018.869282248379}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.26549424015616`, -6018.947204464069}, 0.07792221569006741, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{113.18757202446608`, -6018.986165571914}, \
{113.26549424015616`, -6018.947204464069}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.986311298898}, {
        113.26549424015616`, -6018.986311298898}, {
        113.26549424015616`, -6018.986165571914}, {
        100, -6018.986165571914}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.986311298898}, {
       1308.4950845668877`, -6018.986311298898}, {
       1308.4950845668877`, -6018.986165571914}, {
       605.2397757962283, -6018.986165571914}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.986311298898}, {
       1282.6910027797194`, -6018.986311298898}, {
       1282.6910027797194`, -6018.986165571914}, {
       1277.1904277179078`, -6018.986165571914}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3258525087294`, -6018.986311298898}, {
       2622.543964279708, -6018.986311298898}, {
       2622.543964279708, -6018.986165571914}, {
       2486.3258525087294`, -6018.986165571914}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.986311298898}, {
       2584.8846871117416`, -6018.986311298898}, {
       2584.8846871117416`, -6018.986165571914}, {
       2584.880125538893, -6018.986165571914}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6018.986311298898}, {
       3137.0091144855883`, -6018.986311298898}, {
       3137.0091144855883`, -6018.986165571914}, {
       3136.023775782051, -6018.986165571914}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.986311298898}, {
       3697.5161362454387`, -6018.986311298898}, {
       3697.5161362454387`, -6018.986165571914}, {
       3625.2244506059174`, -6018.986165571914}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.986311298898}, {
       4142.649334923504, -6018.986311298898}, {
       4142.649334923504, -6018.986165571914}, {
       4074.1706600495886`, -6018.986165571914}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.986311298898}, {
       4700., -6018.986311298898}, {4700., -6018.986165571914}, {
       4699.999999939832, -6018.986165571914}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816703369804`, -6018.986311298898}, {
      1601.281846779892, -6018.986311298898}, {
      1601.281846779892, -6018.986165571914}, {
      1601.2816703369804`, -6018.986165571914}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1282.6910027797194`, -6018.98620200366}, \
{1282.691075643211, -6018.986165571914}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1282.691075643211, -6018.98620200366}, 0.00007286349169653597, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1282.691075643211, -6018.986274867152}, {
       1601.2815974734888`, -6018.986274867152}, {
       1601.2815974734888`, -6018.98620200366}, {
       1282.691075643211, -6018.98620200366}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2815974734888`, -6018.986274867152}, 
       0.00007286349169653597, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2815974734888`, -6018.986311298898}, \
{1601.2816703369804`, -6018.986274867152}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.986518363441}, {
        113.26549424015616`, -6018.986518363441}, {
        113.26549424015616`, -6018.986311298898}, {
        100, -6018.986311298898}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.986518363441}, {
       1308.4950845668877`, -6018.986518363441}, {
       1308.4950845668877`, -6018.986311298898}, {
       605.2397757962283, -6018.986311298898}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.986518363441}, {
       1282.6910027797194`, -6018.986518363441}, {
       1282.6910027797194`, -6018.986311298898}, {
       1277.1904277179078`, -6018.986311298898}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.325956041001, -6018.986518363441}, {
       2622.543964279708, -6018.986518363441}, {
       2622.543964279708, -6018.986311298898}, {
       2486.325956041001, -6018.986311298898}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.986518363441}, {
       2584.8846871117416`, -6018.986518363441}, {
       2584.8846871117416`, -6018.986311298898}, {
       2584.880125538893, -6018.986311298898}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6018.986518363441}, {
       3137.0091144855883`, -6018.986518363441}, {
       3137.0091144855883`, -6018.986311298898}, {
       3136.023775782051, -6018.986311298898}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.986518363441}, {
       3697.5161362454387`, -6018.986518363441}, {
       3697.5161362454387`, -6018.986311298898}, {
       3625.2244506059174`, -6018.986311298898}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.986518363441}, {
       4142.649334923504, -6018.986518363441}, {
       4142.649334923504, -6018.986311298898}, {
       4074.1706600495886`, -6018.986311298898}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.986518363441}, {
       4700., -6018.986518363441}, {4700., -6018.986311298898}, {
       4699.999999939832, -6018.986311298898}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2815974734888`, -6018.986518363441}, {
      1601.281846779892, -6018.986518363441}, {
      1601.281846779892, -6018.986311298898}, {
      1601.2815974734888`, -6018.986311298898}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2486.3258525087294`, -6018.986363065033}, \
{2486.325956041001, -6018.986311298898}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2486.3258525087294`, -6018.986363065033}, 
       0.00010353227158193954`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2819503121636`, -6018.9864665973055`}, {
       2486.3258525087294`, -6018.9864665973055`}, {
       2486.3258525087294`, -6018.986363065033}, {
       1601.2819503121636`, -6018.986363065033}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2819503121636`, -6018.9864665973055`}, 
       0.00010353227158193954`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281846779892, -6018.986518363441}, \
{1601.2819503121636`, -6018.9864665973055`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.987091323528}, {
        113.26549424015616`, -6018.987091323528}, {
        113.26549424015616`, -6018.986518363441}, {
        100, -6018.986518363441}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.987091323528}, {
       1308.4950845668877`, -6018.987091323528}, {
       1308.4950845668877`, -6018.986518363441}, {
       605.2397757962283, -6018.986518363441}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.987091323528}, {
       1282.6910027797194`, -6018.987091323528}, {
       1282.6910027797194`, -6018.986518363441}, {
       1277.1904277179078`, -6018.986518363441}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6018.987091323528}, {
       2622.543964279708, -6018.987091323528}, {
       2622.543964279708, -6018.986518363441}, {
       2486.3262425210446`, -6018.986518363441}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.987091323528}, {
       2584.8846871117416`, -6018.987091323528}, {
       2584.8846871117416`, -6018.986518363441}, {
       2584.880125538893, -6018.986518363441}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6018.987091323528}, {
       3137.0091144855883`, -6018.987091323528}, {
       3137.0091144855883`, -6018.986518363441}, {
       3136.023775782051, -6018.986518363441}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3625.2244506059174`, -6018.987091323528}, {
       3697.5161362454387`, -6018.987091323528}, {
       3697.5161362454387`, -6018.986518363441}, {
       3625.2244506059174`, -6018.986518363441}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.987091323528}, {
       4142.649334923504, -6018.987091323528}, {
       4142.649334923504, -6018.986518363441}, {
       4074.1706600495886`, -6018.986518363441}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.987091323528}, {
       4700., -6018.987091323528}, {4700., -6018.986518363441}, {
       4699.999999939832, -6018.986518363441}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2815974734888`, -6018.987091323528}, {
      1601.2819503121636`, -6018.987091323528}, {
      1601.2819503121636`, -6018.986518363441}, {
      1601.2815974734888`, -6018.986518363441}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2486.325956041001, -6018.986661603462}, \
{2486.3262425210446`, -6018.986518363441}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2486.325956041001, -6018.986661603462}, 0.0002864800436945282, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2822367922074`, -6018.986948083506}, {
       2486.325956041001, -6018.986948083506}, {
       2486.325956041001, -6018.986661603462}, {
       1601.2822367922074`, -6018.986661603462}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2822367922074`, -6018.986948083506}, 
       0.0002864800436945282, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2819503121636`, -6018.987091323528}, \
{1601.2822367922074`, -6018.986948083506}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6018.988068008518}, {
        113.26549424015616`, -6018.988068008518}, {
        113.26549424015616`, -6018.987091323528}, {
        100, -6018.987091323528}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6018.988068008518}, {
       1308.4950845668877`, -6018.988068008518}, {
       1308.4950845668877`, -6018.987091323528}, {
       605.2397757962283, -6018.987091323528}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6018.988068008518}, {
       1282.6910027797194`, -6018.988068008518}, {
       1282.6910027797194`, -6018.987091323528}, {
       1277.1904277179078`, -6018.987091323528}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6018.988068008518}, {
       1601.2817484497123`, -6018.988068008518}, {
       1601.2817484497123`, -6018.987091323528}, {
       1601.2815974734888`, -6018.987091323528}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6018.988068008518}, {
       2622.543964279708, -6018.988068008518}, {
       2622.543964279708, -6018.987091323528}, {
       2486.3262425210446`, -6018.987091323528}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6018.988068008518}, {
       2584.8846871117416`, -6018.988068008518}, {
       2584.8846871117416`, -6018.987091323528}, {
       2584.880125538893, -6018.987091323528}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6018.988068008518}, {
       3137.0091144855883`, -6018.988068008518}, {
       3137.0091144855883`, -6018.987091323528}, {
       3136.023775782051, -6018.987091323528}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6018.988068008518}, {
       4142.649334923504, -6018.988068008518}, {
       4142.649334923504, -6018.987091323528}, {
       4074.1706600495886`, -6018.987091323528}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6018.988068008518}, {
       4700., -6018.988068008518}, {4700., -6018.987091323528}, {
       4699.999999939832, -6018.987091323528}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3625.2244506059174`, -6018.988068008518}, {
      3697.516136245439, -6018.988068008518}, {
      3697.516136245439, -6018.987091323528}, {
      3625.2244506059174`, -6018.987091323528}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2817484497123`, -6018.987335494776}, \
{1601.2822367922074`, -6018.987091323528}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2822367922074`, -6018.987335494776}, 
       0.0004883424950343549, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2822367922074`, -6018.98782383727}, {
       3625.2239622634224`, -6018.98782383727}, {
       3625.2239622634224`, -6018.987335494776}, {
       1601.2822367922074`, -6018.987335494776}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3625.2239622634224`, -6018.98782383727}, 
       0.0004883424950343549, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3625.2239622634224`, -6018.988068008518}, \
{3625.2244506059174`, -6018.98782383727}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6028.905853940218}, {
        113.26549424015616`, -6028.905853940218}, {
        113.26549424015616`, -6018.988068008518}, {
        100, -6018.988068008518}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6028.905853940218}, {
       1308.4950845668877`, -6028.905853940218}, {
       1308.4950845668877`, -6018.988068008518}, {
       605.2397757962283, -6018.988068008518}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6028.905853940218}, {
       1601.2817484497123`, -6028.905853940218}, {
       1601.2817484497123`, -6018.988068008518}, {
       1601.2815974734888`, -6018.988068008518}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6028.905853940218}, {
       2622.543964279708, -6028.905853940218}, {
       2622.543964279708, -6018.988068008518}, {
       2486.3262425210446`, -6018.988068008518}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6028.905853940218}, {
       2584.8846871117416`, -6028.905853940218}, {
       2584.8846871117416`, -6018.988068008518}, {
       2584.880125538893, -6018.988068008518}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6028.905853940218}, {
       3137.0091144855883`, -6028.905853940218}, {
       3137.0091144855883`, -6018.988068008518}, {
       3136.023775782051, -6018.988068008518}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3630.1828552292723`, -6028.905853940218}, {
       3697.516136245439, -6028.905853940218}, {
       3697.516136245439, -6018.988068008518}, {
       3630.1828552292723`, -6018.988068008518}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.1706600495886`, -6028.905853940218}, {
       4142.649334923504, -6028.905853940218}, {
       4142.649334923504, -6018.988068008518}, {
       4074.1706600495886`, -6018.988068008518}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6028.905853940218}, {
       4700., -6028.905853940218}, {4700., -6018.988068008518}, {
       4699.999999939832, -6018.988068008518}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1277.1904277179078`, -6028.905853940218}, {
      1282.6910027797194`, -6028.905853940218}, {
      1282.6910027797194`, -6018.988068008518}, {
      1277.1904277179078`, -6018.988068008518}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3625.2239622634224`, -6021.467514491443}, \
{3630.1828552292723`, -6018.988068008518}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3625.2239622634224`, -6021.467514491443}, 4.9588929658497, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1287.649895745569, -6026.426407457293}, {
       3625.2239622634224`, -6026.426407457293}, {
       3625.2239622634224`, -6021.467514491443}, {
       1287.649895745569, -6021.467514491443}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1287.649895745569, -6026.426407457293}, 4.9588929658497, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1282.6910027797194`, -6028.905853940218}, \
{1287.649895745569, -6026.426407457293}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6037.417335320819}, {
        109.00975354985533`, -6037.417335320819}, {
        109.00975354985533`, -6028.905853940218}, {
        100, -6028.905853940218}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6037.417335320819}, {
       1308.4950845668877`, -6037.417335320819}, {
       1308.4950845668877`, -6028.905853940218}, {
       605.2397757962283, -6028.905853940218}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6037.417335320819}, {
       1287.649895745569, -6037.417335320819}, {
       1287.649895745569, -6028.905853940218}, {
       1277.1904277179078`, -6028.905853940218}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6037.417335320819}, {
       1601.2817484497123`, -6037.417335320819}, {
       1601.2817484497123`, -6028.905853940218}, {
       1601.2815974734888`, -6028.905853940218}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6037.417335320819}, {
       2622.543964279708, -6037.417335320819}, {
       2622.543964279708, -6028.905853940218}, {
       2486.3262425210446`, -6028.905853940218}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6037.417335320819}, {
       2584.8846871117416`, -6037.417335320819}, {
       2584.8846871117416`, -6028.905853940218}, {
       2584.880125538893, -6028.905853940218}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6037.417335320819}, {
       3137.0091144855883`, -6037.417335320819}, {
       3137.0091144855883`, -6028.905853940218}, {
       3136.023775782051, -6028.905853940218}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3630.1828552292723`, -6037.417335320819}, {
       3697.516136245439, -6037.417335320819}, {
       3697.516136245439, -6028.905853940218}, {
       3630.1828552292723`, -6028.905853940218}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6037.417335320819}, {
       4700., -6037.417335320819}, {4700., -6028.905853940218}, {
       4699.999999939832, -6028.905853940218}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4074.1706600495886`, -6037.417335320819}, {
      4142.649334923505, -6037.417335320819}, {
      4142.649334923505, -6028.905853940218}, {
      4074.1706600495886`, -6028.905853940218}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{109.00975354985533`, -6031.0337242853675`}, \
{113.26549424015616`, -6028.905853940218}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{113.26549424015616`, -6031.0337242853675`}, 
       4.2557406903008275`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{113.26549424015616`, -6035.289464975668}, {
       4069.914919359288, -6035.289464975668}, {
       4069.914919359288, -6031.0337242853675`}, {
       113.26549424015616`, -6031.0337242853675`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4069.914919359288, -6035.289464975668}, 4.2557406903008275`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4069.914919359288, -6037.417335320819}, \
{4074.1706600495886`, -6035.289464975668}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6041.314963767468}, {
        107.06093932653069`, -6041.314963767468}, {
        107.06093932653069`, -6037.417335320819}, {
        100, -6037.417335320819}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6041.314963767468}, {
       1308.4950845668877`, -6041.314963767468}, {
       1308.4950845668877`, -6037.417335320819}, {
       605.2397757962283, -6037.417335320819}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6041.314963767468}, {
       1287.649895745569, -6041.314963767468}, {
       1287.649895745569, -6037.417335320819}, {
       1277.1904277179078`, -6037.417335320819}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6041.314963767468}, {
       1601.2817484497123`, -6041.314963767468}, {
       1601.2817484497123`, -6037.417335320819}, {
       1601.2815974734888`, -6037.417335320819}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6041.314963767468}, {
       2622.543964279708, -6041.314963767468}, {
       2622.543964279708, -6037.417335320819}, {
       2486.3262425210446`, -6037.417335320819}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6041.314963767468}, {
       2584.8846871117416`, -6041.314963767468}, {
       2584.8846871117416`, -6037.417335320819}, {
       2584.880125538893, -6037.417335320819}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6041.314963767468}, {
       3137.0091144855883`, -6041.314963767468}, {
       3137.0091144855883`, -6037.417335320819}, {
       3136.023775782051, -6037.417335320819}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4069.914919359288, -6041.314963767468}, {
       4142.649334923505, -6041.314963767468}, {
       4142.649334923505, -6037.417335320819}, {
       4069.914919359288, -6037.417335320819}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999939832, -6041.314963767468}, {
       4700., -6041.314963767468}, {4700., -6037.417335320819}, {
       4699.999999939832, -6037.417335320819}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3630.1828552292723`, -6041.314963767468}, {
      3697.516136245439, -6041.314963767468}, {
      3697.516136245439, -6037.417335320819}, {
      3630.1828552292723`, -6037.417335320819}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{107.06093932653069`, -6038.391742432481}, \
{109.00975354985533`, -6037.417335320819}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{109.00975354985533`, -6038.391742432481}, 1.9488142233246393`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{109.00975354985533`, -6040.340556655806}, {
       3628.234041005948, -6040.340556655806}, {
       3628.234041005948, -6038.391742432481}, {
       109.00975354985533`, -6038.391742432481}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3628.234041005948, -6040.340556655806}, 1.9488142233246393`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3628.234041005948, -6041.314963767468}, \
{3630.1828552292723`, -6040.340556655806}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6041.314963771337}, {
        107.06093932653069`, -6041.314963771337}, {
        107.06093932653069`, -6041.314963767468}, {
        100, -6041.314963767468}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6041.314963771337}, {
       1308.4950845668877`, -6041.314963771337}, {
       1308.4950845668877`, -6041.314963767468}, {
       605.2397757962283, -6041.314963767468}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6041.314963771337}, {
       1287.649895745569, -6041.314963771337}, {
       1287.649895745569, -6041.314963767468}, {
       1277.1904277179078`, -6041.314963767468}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6041.314963771337}, {
       1601.2817484497123`, -6041.314963771337}, {
       1601.2817484497123`, -6041.314963767468}, {
       1601.2815974734888`, -6041.314963767468}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2486.3262425210446`, -6041.314963771337}, {
       2622.543964279708, -6041.314963771337}, {
       2622.543964279708, -6041.314963767468}, {
       2486.3262425210446`, -6041.314963767468}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6041.314963771337}, {
       2584.8846871117416`, -6041.314963771337}, {
       2584.8846871117416`, -6041.314963767468}, {
       2584.880125538893, -6041.314963767468}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3628.234041005948, -6041.314963771337}, {
       3697.516136245439, -6041.314963771337}, {
       3697.516136245439, -6041.314963767468}, {
       3628.234041005948, -6041.314963767468}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4069.914919359288, -6041.314963771337}, {
       4142.649334923505, -6041.314963771337}, {
       4142.649334923505, -6041.314963767468}, {
       4069.914919359288, -6041.314963767468}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6041.314963771337}, {
       4700., -6041.314963771337}, {4700., -6041.314963767468}, {
       4699.999999941767, -6041.314963767468}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.023775782051, -6041.314963771337}, {
      3137.0091144855883`, -6041.314963771337}, {
      3137.0091144855883`, -6041.314963767468}, {
      3136.023775782051, -6041.314963767468}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999939832, -6041.3149637684355`}, \
{4699.999999941767, -6041.314963767468}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999939832, -6041.3149637684355`}, 
       1.9344712853711147`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3137.0091144875228`, -6041.31496377037}, {
       4699.999999939832, -6041.31496377037}, {
       4699.999999939832, -6041.3149637684355`}, {
       3137.0091144875228`, -6041.3149637684355`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3137.0091144875228`, -6041.31496377037}, 
       1.9344712853711147`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3137.0091144855883`, -6041.314963771337}, \
{3137.0091144875228`, -6041.31496377037}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6059.176935948307}, {
        107.06093932653069`, -6059.176935948307}, {
        107.06093932653069`, -6041.314963771337}, {
        100, -6041.314963771337}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6059.176935948307}, {
       1308.4950845668877`, -6059.176935948307}, {
       1308.4950845668877`, -6041.314963771337}, {
       605.2397757962283, -6041.314963771337}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6059.176935948307}, {
       1601.2817484497123`, -6059.176935948307}, {
       1601.2817484497123`, -6041.314963771337}, {
       1601.2815974734888`, -6041.314963771337}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6059.176935948307}, {
       2622.543964279708, -6059.176935948307}, {
       2622.543964279708, -6041.314963771337}, {
       2495.2572286095296`, -6041.314963771337}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6059.176935948307}, {
       2584.8846871117416`, -6059.176935948307}, {
       2584.8846871117416`, -6041.314963771337}, {
       2584.880125538893, -6041.314963771337}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6059.176935948307}, {
       3137.0091144875228`, -6059.176935948307}, {
       3137.0091144875228`, -6041.314963771337}, {
       3136.023775782051, -6041.314963771337}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3628.234041005948, -6059.176935948307}, {
       3697.516136245439, -6059.176935948307}, {
       3697.516136245439, -6041.314963771337}, {
       3628.234041005948, -6041.314963771337}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4069.914919359288, -6059.176935948307}, {
       4142.649334923505, -6059.176935948307}, {
       4142.649334923505, -6041.314963771337}, {
       4069.914919359288, -6041.314963771337}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6059.176935948307}, {
       4700., -6059.176935948307}, {4700., -6041.314963771337}, {
       4699.999999941767, -6041.314963771337}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1277.1904277179078`, -6059.176935948307}, {
      1287.649895745569, -6059.176935948307}, {
      1287.649895745569, -6041.314963771337}, {
      1277.1904277179078`, -6041.314963771337}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2486.3262425210446`, -6045.780456815579}, \
{2495.2572286095296`, -6041.314963771337}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2486.3262425210446`, -6045.780456815579}, 8.930986088485074, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1296.580881834054, -6054.711442904064}, {
       2486.3262425210446`, -6054.711442904064}, {
       2486.3262425210446`, -6045.780456815579}, {
       1296.580881834054, -6045.780456815579}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1296.580881834054, -6054.711442904064}, 8.930986088485074, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1287.649895745569, -6059.176935948307}, \
{1296.580881834054, -6054.711442904064}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6068.990209541051}, {
        107.06093932653069`, -6068.990209541051}, {
        107.06093932653069`, -6059.176935948307}, {
        100, -6059.176935948307}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6068.990209541051}, {
       1308.4950845668877`, -6068.990209541051}, {
       1308.4950845668877`, -6059.176935948307}, {
       605.2397757962283, -6059.176935948307}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6068.990209541051}, {
       1601.2817484497123`, -6068.990209541051}, {
       1601.2817484497123`, -6059.176935948307}, {
       1601.2815974734888`, -6059.176935948307}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6068.990209541051}, {
       2622.543964279708, -6068.990209541051}, {
       2622.543964279708, -6059.176935948307}, {
       2495.2572286095296`, -6059.176935948307}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6068.990209541051}, {
       2584.8846871117416`, -6068.990209541051}, {
       2584.8846871117416`, -6059.176935948307}, {
       2584.880125538893, -6059.176935948307}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6068.990209541051}, {
       3137.0091144875228`, -6068.990209541051}, {
       3137.0091144875228`, -6059.176935948307}, {
       3136.023775782051, -6059.176935948307}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3628.234041005948, -6068.990209541051}, {
       3697.516136245439, -6068.990209541051}, {
       3697.516136245439, -6059.176935948307}, {
       3628.234041005948, -6059.176935948307}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4074.82155615566, -6068.990209541051}, {
       4142.649334923505, -6068.990209541051}, {
       4142.649334923505, -6059.176935948307}, {
       4074.82155615566, -6059.176935948307}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6068.990209541051}, {
       4700., -6068.990209541051}, {4700., -6059.176935948307}, {
       4699.999999941767, -6059.176935948307}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1277.1904277179078`, -6068.990209541051}, {
      1296.580881834054, -6068.990209541051}, {
      1296.580881834054, -6059.176935948307}, {
      1277.1904277179078`, -6059.176935948307}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4069.914919359288, -6061.630254346493}, \
{4074.82155615566, -6059.176935948307}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4069.914919359288, -6061.630254346493}, 4.90663679637186, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1301.487518630426, -6066.536891142865}, {
       4069.914919359288, -6066.536891142865}, {
       4069.914919359288, -6061.630254346493}, {
       1301.487518630426, -6061.630254346493}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1301.487518630426, -6066.536891142865}, 4.90663679637186, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1296.580881834054, -6068.990209541051}, \
{1301.487518630426, -6066.536891142865}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6073.81464532294}, {
        107.06093932653069`, -6073.81464532294}, {
        107.06093932653069`, -6068.990209541051}, {
        100, -6068.990209541051}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6073.81464532294}, {
       1308.4950845668877`, -6073.81464532294}, {
       1308.4950845668877`, -6068.990209541051}, {
       605.2397757962283, -6068.990209541051}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6073.81464532294}, {
       1301.487518630426, -6073.81464532294}, {
       1301.487518630426, -6068.990209541051}, {
       1277.1904277179078`, -6068.990209541051}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6073.81464532294}, {
       1601.2817484497123`, -6073.81464532294}, {
       1601.2817484497123`, -6068.990209541051}, {
       1601.2815974734888`, -6068.990209541051}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6073.81464532294}, {
       2622.543964279708, -6073.81464532294}, {
       2622.543964279708, -6068.990209541051}, {
       2495.2572286095296`, -6068.990209541051}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6073.81464532294}, {
       2584.8846871117416`, -6073.81464532294}, {
       2584.8846871117416`, -6068.990209541051}, {
       2584.880125538893, -6068.990209541051}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6073.81464532294}, {
       3137.0091144875228`, -6073.81464532294}, {
       3137.0091144875228`, -6068.990209541051}, {
       3136.023775782051, -6068.990209541051}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3628.234041005948, -6073.81464532294}, {
       3695.103918354495, -6073.81464532294}, {
       3695.103918354495, -6068.990209541051}, {
       3628.234041005948, -6068.990209541051}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6073.81464532294}, {
       4700., -6073.81464532294}, {4700., -6068.990209541051}, {
       4699.999999941767, -6068.990209541051}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4074.82155615566, -6073.81464532294}, {
      4142.649334923505, -6073.81464532294}, {
      4142.649334923505, -6068.990209541051}, {
      4074.82155615566, -6068.990209541051}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.103918354495, -6070.1963184865235`}, \
{3697.516136245439, -6068.990209541051}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3697.516136245439, -6070.1963184865235`}, 2.412217890944632, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3697.516136245439, -6072.608536377468}, {
       4072.409338264715, -6072.608536377468}, {
       4072.409338264715, -6070.1963184865235`}, {
       3697.516136245439, -6070.1963184865235`}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4072.409338264715, -6072.608536377468}, 2.412217890944632, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4072.409338264715, -6073.81464532294}, \
{4074.82155615566, -6072.608536377468}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6074.2179998753445`}, {
        107.06093932653069`, -6074.2179998753445`}, {
        107.06093932653069`, -6073.81464532294}, {
        100, -6073.81464532294}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6074.2179998753445`}, {
       1308.4950845668877`, -6074.2179998753445`}, {
       1308.4950845668877`, -6073.81464532294}, {
       605.2397757962283, -6073.81464532294}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6074.2179998753445`}, {
       1301.487518630426, -6074.2179998753445`}, {
       1301.487518630426, -6073.81464532294}, {
       1277.1904277179078`, -6073.81464532294}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6074.2179998753445`}, {
       1601.2817484497123`, -6074.2179998753445`}, {
       1601.2817484497123`, -6073.81464532294}, {
       1601.2815974734888`, -6073.81464532294}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6074.2179998753445`}, {
       2622.3422870035056`, -6074.2179998753445`}, {
       2622.3422870035056`, -6073.81464532294}, {
       2495.2572286095296`, -6073.81464532294}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6074.2179998753445`}, {
       2584.8846871117416`, -6074.2179998753445`}, {
       2584.8846871117416`, -6073.81464532294}, {
       2584.880125538893, -6073.81464532294}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6074.2179998753445`}, {
       3137.0091144875228`, -6074.2179998753445`}, {
       3137.0091144875228`, -6073.81464532294}, {
       3136.023775782051, -6073.81464532294}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.409338264715, -6074.2179998753445`}, {
       4142.649334923505, -6074.2179998753445`}, {
       4142.649334923505, -6073.81464532294}, {
       4072.409338264715, -6073.81464532294}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6074.2179998753445`}, {
       4700., -6074.2179998753445`}, {4700., -6073.81464532294}, {
       4699.999999941767, -6073.81464532294}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3628.234041005948, -6074.2179998753445`}, {
      3695.103918354495, -6074.2179998753445`}, {
      3695.103918354495, -6073.81464532294}, {
      3628.234041005948, -6073.81464532294}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.3422870035056`, -6073.915483961041}, \
{2622.543964279708, -6073.81464532294}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.543964279708, -6073.915483961041}, 0.20167727620224696`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.543964279708, -6074.117161237244}, {
       3628.0323637297456`, -6074.117161237244}, {
       3628.0323637297456`, -6073.915483961041}, {
       2622.543964279708, -6073.915483961041}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3628.0323637297456`, -6074.117161237244}, 
       0.20167727620224696`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3628.0323637297456`, -6074.2179998753445`}, \
{3628.234041005948, -6074.117161237244}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6074.959349984889}, {
        107.06093932653069`, -6074.959349984889}, {
        107.06093932653069`, -6074.2179998753445`}, {
        100, -6074.2179998753445`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6074.959349984889}, {
       1308.4950845668877`, -6074.959349984889}, {
       1308.4950845668877`, -6074.2179998753445`}, {
       605.2397757962283, -6074.2179998753445`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6074.959349984889}, {
       1301.487518630426, -6074.959349984889}, {
       1301.487518630426, -6074.2179998753445`}, {
       1277.1904277179078`, -6074.2179998753445`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6074.959349984889}, {
       1601.2817484497123`, -6074.959349984889}, {
       1601.2817484497123`, -6074.2179998753445`}, {
       1601.2815974734888`, -6074.2179998753445`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6074.959349984889}, {
       2622.3422870035056`, -6074.959349984889}, {
       2622.3422870035056`, -6074.2179998753445`}, {
       2495.2572286095296`, -6074.2179998753445`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6074.959349984889}, {
       2584.8846871117416`, -6074.959349984889}, {
       2584.8846871117416`, -6074.2179998753445`}, {
       2584.880125538893, -6074.2179998753445`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6074.959349984889}, {
       3136.6384394327506`, -6074.959349984889}, {
       3136.6384394327506`, -6074.2179998753445`}, {
       3136.023775782051, -6074.2179998753445`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3628.0323637297456`, -6074.959349984889}, {
       3695.103918354495, -6074.959349984889}, {
       3695.103918354495, -6074.2179998753445`}, {
       3628.0323637297456`, -6074.2179998753445`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6074.959349984889}, {
       4700., -6074.959349984889}, {4700., -6074.2179998753445`}, {
       4699.999999941767, -6074.2179998753445`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4072.409338264715, -6074.959349984889}, {
      4142.649334923505, -6074.959349984889}, {
      4142.649334923505, -6074.2179998753445`}, {
      4072.409338264715, -6074.2179998753445`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.6384394327506`, -6074.40333740273}, 
       {3137.0091144875228`, -6074.2179998753445`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3137.0091144875228`, -6074.40333740273}, 0.37067505477231144`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3137.0091144875228`, -6074.774012457503}, {
       4072.038663209943, -6074.774012457503}, {
       4072.038663209943, -6074.40333740273}, {
       3137.0091144875228`, -6074.40333740273}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4072.038663209943, -6074.774012457503}, 0.37067505477231144`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4072.038663209943, -6074.959349984889}, \
{4072.409338264715, -6074.774012457503}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6076.113301182221}, {
        107.06093932653069`, -6076.113301182221}, {
        107.06093932653069`, -6074.959349984889}, {
        100, -6074.959349984889}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6076.113301182221}, {
       1308.4950845668877`, -6076.113301182221}, {
       1308.4950845668877`, -6074.959349984889}, {
       605.2397757962283, -6074.959349984889}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6076.113301182221}, {
       1301.487518630426, -6076.113301182221}, {
       1301.487518630426, -6074.959349984889}, {
       1277.1904277179078`, -6074.959349984889}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6076.113301182221}, {
       1601.2817484497123`, -6076.113301182221}, {
       1601.2817484497123`, -6074.959349984889}, {
       1601.2815974734888`, -6074.959349984889}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6076.113301182221}, {
       2622.3422870035056`, -6076.113301182221}, {
       2622.3422870035056`, -6074.959349984889}, {
       2495.2572286095296`, -6074.959349984889}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6076.113301182221}, {
       2584.8846871117416`, -6076.113301182221}, {
       2584.8846871117416`, -6074.959349984889}, {
       2584.880125538893, -6074.959349984889}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6076.113301182221}, {
       3136.061463834084, -6076.113301182221}, {
       3136.061463834084, -6074.959349984889}, {
       3136.023775782051, -6074.959349984889}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6076.113301182221}, {
       4142.649334923505, -6076.113301182221}, {
       4142.649334923505, -6074.959349984889}, {
       4072.038663209943, -6074.959349984889}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941767, -6076.113301182221}, {
       4700., -6076.113301182221}, {4700., -6074.959349984889}, {
       4699.999999941767, -6074.959349984889}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3628.0323637297456`, -6076.113301182221}, {
      3695.103918354495, -6076.113301182221}, {
      3695.103918354495, -6074.959349984889}, {
      3628.0323637297456`, -6074.959349984889}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.061463834084, -6075.247837784222}, \
{3136.6384394327506`, -6074.959349984889}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.6384394327506`, -6075.247837784222}, 0.5769755986663476, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.6384394327506`, -6075.824813382888}, {
       3627.4553881310794`, -6075.824813382888}, {
       3627.4553881310794`, -6075.247837784222}, {
       3136.6384394327506`, -6075.247837784222}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3627.4553881310794`, -6075.824813382888}, 0.5769755986663476, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3627.4553881310794`, -6076.113301182221}, \
{3628.0323637297456`, -6075.824813382888}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6076.113301240145}, {
        107.06093932653069`, -6076.113301240145}, {
        107.06093932653069`, -6076.113301182221}, {
        100, -6076.113301182221}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1277.1904277179078`, -6076.113301240145}, {
       1301.487518630426, -6076.113301240145}, {
       1301.487518630426, -6076.113301182221}, {
       1277.1904277179078`, -6076.113301182221}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6076.113301240145}, {
       1601.2817484497123`, -6076.113301240145}, {
       1601.2817484497123`, -6076.113301182221}, {
       1601.2815974734888`, -6076.113301182221}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2495.2572286095296`, -6076.113301240145}, {
       2622.3422870035056`, -6076.113301240145}, {
       2622.3422870035056`, -6076.113301182221}, {
       2495.2572286095296`, -6076.113301182221}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6076.113301240145}, {
       2584.8846871117416`, -6076.113301240145}, {
       2584.8846871117416`, -6076.113301182221}, {
       2584.880125538893, -6076.113301182221}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6076.113301240145}, {
       3136.061463834084, -6076.113301240145}, {
       3136.061463834084, -6076.113301182221}, {
       3136.023775782051, -6076.113301182221}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6076.113301240145}, {
       3695.103918354495, -6076.113301240145}, {
       3695.103918354495, -6076.113301182221}, {
       3627.4553881310794`, -6076.113301182221}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6076.113301240145}, {
       4142.649334923505, -6076.113301240145}, {
       4142.649334923505, -6076.113301182221}, {
       4072.038663209943, -6076.113301182221}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999970729, -6076.113301240145}, {
       4700., -6076.113301240145}, {4700., -6076.113301182221}, {
       4699.999999970729, -6076.113301182221}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{605.2397757962283, -6076.113301240145}, {
      1308.4950845668877`, -6076.113301240145}, {
      1308.4950845668877`, -6076.113301182221}, {
      605.2397757962283, -6076.113301182221}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999941767, -6076.113301196702}, \
{4699.999999970729, -6076.113301182221}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999941767, -6076.113301196702}, 
       2.8962124608210662`*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1308.49508459585, -6076.113301225664}, {
       4699.999999941767, -6076.113301225664}, {
       4699.999999941767, -6076.113301196702}, {
       1308.49508459585, -6076.113301196702}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1308.49508459585, -6076.113301225664}, 2.8962124608210662`*^-8,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1308.4950845668877`, -6076.113301240145}, \
{1308.49508459585, -6076.113301225664}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6115.171579211972}, {
        107.06093932653069`, -6115.171579211972}, {
        107.06093932653069`, -6076.113301240145}, {
        100, -6076.113301240145}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6115.171579211972}, {
       1308.49508459585, -6115.171579211972}, {
       1308.49508459585, -6076.113301240145}, {
       605.2397757962283, -6076.113301240145}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6115.171579211972}, {
       1601.2817484497123`, -6115.171579211972}, {
       1601.2817484497123`, -6076.113301240145}, {
       1601.2815974734888`, -6076.113301240145}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6115.171579211972}, {
       2622.3422870035056`, -6115.171579211972}, {
       2622.3422870035056`, -6076.113301240145}, {
       2514.786367595443, -6076.113301240145}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6115.171579211972}, {
       2584.8846871117416`, -6115.171579211972}, {
       2584.8846871117416`, -6076.113301240145}, {
       2584.880125538893, -6076.113301240145}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6115.171579211972}, {
       3136.061463834084, -6115.171579211972}, {
       3136.061463834084, -6076.113301240145}, {
       3136.023775782051, -6076.113301240145}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6115.171579211972}, {
       3695.103918354495, -6115.171579211972}, {
       3695.103918354495, -6076.113301240145}, {
       3627.4553881310794`, -6076.113301240145}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6115.171579211972}, {
       4142.649334923505, -6115.171579211972}, {
       4142.649334923505, -6076.113301240145}, {
       4072.038663209943, -6076.113301240145}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999970729, -6115.171579211972}, {
       4700., -6115.171579211972}, {4700., -6076.113301240145}, {
       4699.999999970729, -6076.113301240145}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1277.1904277179078`, -6115.171579211972}, {
      1301.487518630426, -6115.171579211972}, {
      1301.487518630426, -6076.113301240145}, {
      1277.1904277179078`, -6076.113301240145}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2495.2572286095296`, -6085.877870733102}, \
{2514.786367595443, -6076.113301240145}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2495.2572286095296`, -6085.877870733102}, 19.52913898591351, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1321.0166576163394`, -6105.407009719015}, {
       2495.2572286095296`, -6105.407009719015}, {
       2495.2572286095296`, -6085.877870733102}, {
       1321.0166576163394`, -6085.877870733102}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1321.0166576163394`, -6105.407009719015}, 19.52913898591351, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1301.487518630426, -6115.171579211972}, \
{1321.0166576163394`, -6105.407009719015}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6170.734678544485}, {
        107.06093932653069`, -6170.734678544485}, {
        107.06093932653069`, -6115.171579211972}, {
        100, -6115.171579211972}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6170.734678544485}, {
       1280.7135349295934`, -6170.734678544485}, {
       1280.7135349295934`, -6115.171579211972}, {
       605.2397757962283, -6115.171579211972}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6170.734678544485}, {
       1601.2817484497123`, -6170.734678544485}, {
       1601.2817484497123`, -6115.171579211972}, {
       1601.2815974734888`, -6115.171579211972}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6170.734678544485}, {
       2622.3422870035056`, -6170.734678544485}, {
       2622.3422870035056`, -6115.171579211972}, {
       2514.786367595443, -6115.171579211972}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6170.734678544485}, {
       2584.8846871117416`, -6170.734678544485}, {
       2584.8846871117416`, -6115.171579211972}, {
       2584.880125538893, -6115.171579211972}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6170.734678544485}, {
       3136.061463834084, -6170.734678544485}, {
       3136.061463834084, -6115.171579211972}, {
       3136.023775782051, -6115.171579211972}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6170.734678544485}, {
       3695.103918354495, -6170.734678544485}, {
       3695.103918354495, -6115.171579211972}, {
       3627.4553881310794`, -6115.171579211972}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6170.734678544485}, {
       4142.649334923505, -6170.734678544485}, {
       4142.649334923505, -6115.171579211972}, {
       4072.038663209943, -6115.171579211972}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999970729, -6170.734678544485}, {
       4700., -6170.734678544485}, {4700., -6115.171579211972}, {
       4699.999999970729, -6115.171579211972}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1277.1904277179078`, -6170.734678544485}, {
      1321.0166576163394`, -6170.734678544485}, {
      1321.0166576163394`, -6115.171579211972}, {
      1277.1904277179078`, -6115.171579211972}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1280.7135349295934`, -6129.062354045101}, \
{1308.49508459585, -6115.171579211972}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1308.49508459585, -6129.062354045101}, 27.78154966625653, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1308.49508459585, -6156.843903711357}, {
       1249.4088780516513`, -6156.843903711357}, {
       1249.4088780516513`, -6129.062354045101}, {
       1308.49508459585, -6129.062354045101}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1249.4088780516513`, -6156.843903711357}, 27.78154966625653, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1249.4088780516513`, -6170.734678544485}, \
{1277.1904277179078`, -6156.843903711357}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6170.734678558127}, {
        107.06093932653069`, -6170.734678558127}, {
        107.06093932653069`, -6170.734678544485}, {
        100, -6170.734678544485}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{605.2397757962283, -6170.734678558127}, {
       1280.7135349295934`, -6170.734678558127}, {
       1280.7135349295934`, -6170.734678544485}, {
       605.2397757962283, -6170.734678544485}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6170.734678558127}, {
       1321.0166576163394`, -6170.734678558127}, {
       1321.0166576163394`, -6170.734678544485}, {
       1249.4088780516513`, -6170.734678544485}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6170.734678558127}, {
       1601.2817484497123`, -6170.734678558127}, {
       1601.2817484497123`, -6170.734678544485}, {
       1601.2815974734888`, -6170.734678544485}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6170.734678558127}, {
       2622.3422870035056`, -6170.734678558127}, {
       2622.3422870035056`, -6170.734678544485}, {
       2514.786367595443, -6170.734678544485}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6170.734678558127}, {
       2584.8846871117416`, -6170.734678558127}, {
       2584.8846871117416`, -6170.734678544485}, {
       2584.880125538893, -6170.734678544485}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6170.734678558127}, {
       3136.061463827263, -6170.734678558127}, {
       3136.061463827263, -6170.734678544485}, {
       3136.023775782051, -6170.734678544485}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6170.734678558127}, {
       3695.103918354495, -6170.734678558127}, {
       3695.103918354495, -6170.734678544485}, {
       3627.4553881310794`, -6170.734678544485}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6170.734678558127}, {
       4142.649334923505, -6170.734678558127}, {
       4142.649334923505, -6170.734678544485}, {
       4072.038663209943, -6170.734678544485}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999970729, -6170.734678558127}, {
      4700., -6170.734678558127}, {4700., -6170.734678544485}, {
      4699.999999970729, -6170.734678544485}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.061463827263, -6170.734678547896}, \
{3136.061463834084, -6170.734678544485}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.061463834084, -6170.734678547896}, 6.820712076476017*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.061463834084, -6170.734678554716}, {
       4699.9999999639085`, -6170.734678554716}, {
       4699.9999999639085`, -6170.734678547896}, {
       3136.061463834084, -6170.734678547896}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999639085`, -6170.734678554716}, 
       6.820712076476017*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999639085`, -6170.734678558127}, \
{4699.999999970729, -6170.734678554716}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6178.728399653807}, {
        103.06407877869054`, -6178.728399653807}, {
        103.06407877869054`, -6170.734678558127}, {
        100, -6170.734678558127}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6178.728399653807}, {
       1321.0166576163394`, -6178.728399653807}, {
       1321.0166576163394`, -6170.734678558127}, {
       1249.4088780516513`, -6170.734678558127}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6178.728399653807}, {
       1601.2817484497123`, -6178.728399653807}, {
       1601.2817484497123`, -6170.734678558127}, {
       1601.2815974734888`, -6170.734678558127}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6178.728399653807}, {
       2622.3422870035056`, -6178.728399653807}, {
       2622.3422870035056`, -6170.734678558127}, {
       2514.786367595443, -6170.734678558127}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6178.728399653807}, {
       2584.8846871117416`, -6178.728399653807}, {
       2584.8846871117416`, -6170.734678558127}, {
       2584.880125538893, -6170.734678558127}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6178.728399653807}, {
       3136.061463827263, -6178.728399653807}, {
       3136.061463827263, -6170.734678558127}, {
       3136.023775782051, -6170.734678558127}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6178.728399653807}, {
       3695.103918354495, -6178.728399653807}, {
       3695.103918354495, -6170.734678558127}, {
       3627.4553881310794`, -6170.734678558127}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6178.728399653807}, {
       4142.649334923505, -6178.728399653807}, {
       4142.649334923505, -6170.734678558127}, {
       4072.038663209943, -6170.734678558127}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999639085`, -6178.728399653807}, {
       4700., -6178.728399653807}, {4700., -6170.734678558127}, {
       4699.9999999639085`, -6170.734678558127}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{605.2397757962283, -6178.728399653807}, {
      1280.7135349295934`, -6178.728399653807}, {
      1280.7135349295934`, -6170.734678558127}, {
      605.2397757962283, -6170.734678558127}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{103.06407877869054`, -6172.733108832047}, \
{107.06093932653069`, -6170.734678558127}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{107.06093932653069`, -6172.733108832047}, 3.99686054784015, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{107.06093932653069`, -6176.729969379887}, {
       601.2429152483882, -6176.729969379887}, {
       601.2429152483882, -6172.733108832047}, {
       107.06093932653069`, -6172.733108832047}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.2429152483882, -6176.729969379887}, 3.99686054784015, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.2429152483882, -6178.728399653807}, \
{605.2397757962283, -6176.729969379887}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6180.861496607239}, {
        101.99753030197449`, -6180.861496607239}, {
        101.99753030197449`, -6178.728399653807}, {
        100, -6178.728399653807}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6180.861496607239}, {
       1321.0166576163394`, -6180.861496607239}, {
       1321.0166576163394`, -6178.728399653807}, {
       1249.4088780516513`, -6178.728399653807}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6180.861496607239}, {
       1601.2817484497123`, -6180.861496607239}, {
       1601.2817484497123`, -6178.728399653807}, {
       1601.2815974734888`, -6178.728399653807}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6180.861496607239}, {
       2622.3422870035056`, -6180.861496607239}, {
       2622.3422870035056`, -6178.728399653807}, {
       2514.786367595443, -6178.728399653807}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6180.861496607239}, {
       2584.8846871117416`, -6180.861496607239}, {
       2584.8846871117416`, -6178.728399653807}, {
       2584.880125538893, -6178.728399653807}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6180.861496607239}, {
       3136.061463827263, -6180.861496607239}, {
       3136.061463827263, -6178.728399653807}, {
       3136.023775782051, -6178.728399653807}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6180.861496607239}, {
       3695.103918354495, -6180.861496607239}, {
       3695.103918354495, -6178.728399653807}, {
       3627.4553881310794`, -6178.728399653807}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6180.861496607239}, {
       4142.649334923505, -6180.861496607239}, {
       4142.649334923505, -6178.728399653807}, {
       4072.038663209943, -6178.728399653807}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999639085`, -6180.861496607239}, {
       4700., -6180.861496607239}, {4700., -6178.728399653807}, {
       4699.9999999639085`, -6178.728399653807}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{601.2429152483882, -6180.861496607239}, {
      1280.7135349295934`, -6180.861496607239}, {
      1280.7135349295934`, -6178.728399653807}, {
      601.2429152483882, -6178.728399653807}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.99753030197449`, -6179.261673892165}, \
{103.06407877869054`, -6178.728399653807}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{103.06407877869054`, -6179.261673892165}, 1.0665484767160374`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{103.06407877869054`, -6180.328222368881}, {
       600.1763667716721, -6180.328222368881}, {
       600.1763667716721, -6179.261673892165}, {
       103.06407877869054`, -6179.261673892165}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.1763667716721, -6180.328222368881}, 1.0665484767160374`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.1763667716721, -6180.861496607239}, \
{601.2429152483882, -6180.328222368881}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6180.86149665283}, {
        101.99753030197449`, -6180.86149665283}, {
        101.99753030197449`, -6180.861496607239}, {
        100, -6180.861496607239}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6180.86149665283}, {
       1280.7135349295934`, -6180.86149665283}, {
       1280.7135349295934`, -6180.861496607239}, {
       600.1763667716721, -6180.861496607239}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6180.86149665283}, {
       1321.0166576163394`, -6180.86149665283}, {
       1321.0166576163394`, -6180.861496607239}, {
       1249.4088780516513`, -6180.861496607239}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6180.86149665283}, {
       1601.2817484269165`, -6180.86149665283}, {
       1601.2817484269165`, -6180.861496607239}, {
       1601.2815974734888`, -6180.861496607239}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6180.86149665283}, {
       2622.3422870035056`, -6180.86149665283}, {
       2622.3422870035056`, -6180.861496607239}, {
       2514.786367595443, -6180.861496607239}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880125538893, -6180.86149665283}, {
       2584.8846871117416`, -6180.86149665283}, {
       2584.8846871117416`, -6180.861496607239}, {
       2584.880125538893, -6180.861496607239}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6180.86149665283}, {
       3136.061463827263, -6180.86149665283}, {
       3136.061463827263, -6180.861496607239}, {
       3136.023775782051, -6180.861496607239}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6180.86149665283}, {
       3695.103918354495, -6180.86149665283}, {
       3695.103918354495, -6180.861496607239}, {
       3627.4553881310794`, -6180.861496607239}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6180.86149665283}, {
       4142.649334923505, -6180.86149665283}, {
       4142.649334923505, -6180.861496607239}, {
       4072.038663209943, -6180.861496607239}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.9999999639085`, -6180.86149665283}, {
      4700., -6180.86149665283}, {4700., -6180.861496607239}, {
      4699.9999999639085`, -6180.861496607239}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2817484269165`, -6180.861496618637}, \
{1601.2817484497123`, -6180.861496607239}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2817484497123`, -6180.861496618637}, 
       2.2795747985428413`*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2817484497123`, -6180.8614966414325`}, {
       4699.999999941113, -6180.8614966414325`}, {
       4699.999999941113, -6180.861496618637}, {
       1601.2817484497123`, -6180.861496618637}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999941113, -6180.8614966414325`}, 
       2.2795747985428413`*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999941113, -6180.86149665283}, \
{4699.9999999639085`, -6180.8614966414325`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6180.864951803614}, {
        101.99753030197449`, -6180.864951803614}, {
        101.99753030197449`, -6180.86149665283}, {
        100, -6180.86149665283}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6180.864951803614}, {
       1280.7135349295934`, -6180.864951803614}, {
       1280.7135349295934`, -6180.86149665283}, {
       600.1763667716721, -6180.86149665283}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6180.864951803614}, {
       1321.0166576163394`, -6180.864951803614}, {
       1321.0166576163394`, -6180.86149665283}, {
       1249.4088780516513`, -6180.86149665283}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6180.864951803614}, {
       1601.2817484269165`, -6180.864951803614}, {
       1601.2817484269165`, -6180.86149665283}, {
       1601.2815974734888`, -6180.86149665283}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6180.864951803614}, {
       2584.8846871117416`, -6180.864951803614}, {
       2584.8846871117416`, -6180.86149665283}, {
       2584.8818531142847`, -6180.86149665283}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6180.864951803614}, {
       3136.061463827263, -6180.864951803614}, {
       3136.061463827263, -6180.86149665283}, {
       3136.023775782051, -6180.86149665283}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6180.864951803614}, {
       3695.103918354495, -6180.864951803614}, {
       3695.103918354495, -6180.86149665283}, {
       3627.4553881310794`, -6180.86149665283}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038663209943, -6180.864951803614}, {
       4142.649334923505, -6180.864951803614}, {
       4142.649334923505, -6180.86149665283}, {
       4072.038663209943, -6180.86149665283}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6180.864951803614}, {
       4700., -6180.864951803614}, {4700., -6180.86149665283}, {
       4699.999999941113, -6180.86149665283}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2514.786367595443, -6180.864951803614}, {
      2622.3422870035056`, -6180.864951803614}, {
      2622.3422870035056`, -6180.86149665283}, {
      2514.786367595443, -6180.86149665283}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.880125538893, -6180.862360440527}, \
{2584.8818531142847`, -6180.86149665283}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.880125538893, -6180.862360440527}, 0.0017275753915309043`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.344014578897, -6180.864088015918}, {
       2584.880125538893, -6180.864088015918}, {
       2584.880125538893, -6180.862360440527}, {
       2622.344014578897, -6180.862360440527}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.344014578897, -6180.864088015918}, 0.0017275753915309043`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.3422870035056`, -6180.864951803614}, \
{2622.344014578897, -6180.864088015918}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6180.865799640358}, {
        101.99753030197449`, -6180.865799640358}, {
        101.99753030197449`, -6180.864951803614}, {
        100, -6180.864951803614}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6180.865799640358}, {
       1280.7135349295934`, -6180.865799640358}, {
       1280.7135349295934`, -6180.864951803614}, {
       600.1763667716721, -6180.864951803614}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6180.865799640358}, {
       1321.0166576163394`, -6180.865799640358}, {
       1321.0166576163394`, -6180.864951803614}, {
       1249.4088780516513`, -6180.864951803614}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6180.865799640358}, {
       1601.2817484269165`, -6180.865799640358}, {
       1601.2817484269165`, -6180.864951803614}, {
       1601.2815974734888`, -6180.864951803614}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6180.865799640358}, {
       2622.344014578897, -6180.865799640358}, {
       2622.344014578897, -6180.864951803614}, {
       2514.786367595443, -6180.864951803614}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6180.865799640358}, {
       3136.061463827263, -6180.865799640358}, {
       3136.061463827263, -6180.864951803614}, {
       3136.023775782051, -6180.864951803614}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.4553881310794`, -6180.865799640358}, {
       3695.103918354495, -6180.865799640358}, {
       3695.103918354495, -6180.864951803614}, {
       3627.4553881310794`, -6180.864951803614}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.0390871283153`, -6180.865799640358}, {
       4142.649334923505, -6180.865799640358}, {
       4142.649334923505, -6180.864951803614}, {
       4072.0390871283153`, -6180.864951803614}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6180.865799640358}, {
       4700., -6180.865799640358}, {4700., -6180.864951803614}, {
       4699.999999941113, -6180.864951803614}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8818531142847`, -6180.865799640358}, {
      2584.8846871117416`, -6180.865799640358}, {
      2584.8846871117416`, -6180.864951803614}, {
      2584.8818531142847`, -6180.864951803614}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4072.038663209943, -6180.8651637628}, \
{4072.0390871283153`, -6180.864951803614}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4072.038663209943, -6180.8651637628}, 0.0004239183723100449, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.885111030114, -6180.865587681172}, {
       4072.038663209943, -6180.865587681172}, {
       4072.038663209943, -6180.8651637628}, {
       2584.885111030114, -6180.8651637628}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.885111030114, -6180.865587681172}, 0.0004239183723100449, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8846871117416`, -6180.865799640358}, \
{2584.885111030114, -6180.865587681172}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6184.67312273511}, {
       1280.7135349295934`, -6184.67312273511}, {
       1280.7135349295934`, -6180.865799640358}, {
       600.1763667716721, -6180.865799640358}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6184.67312273511}, {
       1321.0166576163394`, -6184.67312273511}, {
       1321.0166576163394`, -6180.865799640358}, {
       1249.4088780516513`, -6180.865799640358}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6184.67312273511}, {
       1601.2817484269165`, -6184.67312273511}, {
       1601.2817484269165`, -6180.865799640358}, {
       1601.2815974734888`, -6180.865799640358}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2514.786367595443, -6184.67312273511}, {
       2622.344014578897, -6184.67312273511}, {
       2622.344014578897, -6180.865799640358}, {
       2514.786367595443, -6180.865799640358}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6184.67312273511}, {
       2584.885111030114, -6184.67312273511}, {
       2584.885111030114, -6180.865799640358}, {
       2584.8818531142847`, -6180.865799640358}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6184.67312273511}, {
       3136.061463827263, -6184.67312273511}, {
       3136.061463827263, -6180.865799640358}, {
       3136.023775782051, -6180.865799640358}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6184.67312273511}, {
       3695.103918354495, -6184.67312273511}, {
       3695.103918354495, -6180.865799640358}, {
       3629.3590496784554`, -6180.865799640358}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.0390871283153`, -6184.67312273511}, {
       4142.649334923505, -6184.67312273511}, {
       4142.649334923505, -6180.865799640358}, {
       4072.0390871283153`, -6180.865799640358}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6184.67312273511}, {
       4700., -6184.67312273511}, {4700., -6180.865799640358}, {
       4699.999999941113, -6180.865799640358}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -6184.67312273511}, {
       101.99753030197449`, -6184.67312273511}, {
       101.99753030197449`, -6180.865799640358}, {
       100, -6180.865799640358}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3627.4553881310794`, -6181.817630414046}, \
{3629.3590496784554`, -6180.865799640358}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3627.4553881310794`, -6181.817630414046}, 1.9036615473759122`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{103.90119184935041`, -6183.721291961422}, {
       3627.4553881310794`, -6183.721291961422}, {
       3627.4553881310794`, -6181.817630414046}, {
       103.90119184935041`, -6181.817630414046}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{103.90119184935041`, -6183.721291961422}, 1.9036615473759122`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.99753030197449`, -6184.67312273511}, \
{103.90119184935041`, -6183.721291961422}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6189.008731668977}, {
        101.73338738241691`, -6189.008731668977}, {
        101.73338738241691`, -6184.67312273511}, {
        100, -6184.67312273511}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6189.008731668977}, {
       1280.7135349295934`, -6189.008731668977}, {
       1280.7135349295934`, -6184.67312273511}, {
       600.1763667716721, -6184.67312273511}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6189.008731668977}, {
       1321.0166576163394`, -6189.008731668977}, {
       1321.0166576163394`, -6184.67312273511}, {
       1249.4088780516513`, -6184.67312273511}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6189.008731668977}, {
       1601.2817484269165`, -6189.008731668977}, {
       1601.2817484269165`, -6184.67312273511}, {
       1601.2815974734888`, -6184.67312273511}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6189.008731668977}, {
       2584.885111030114, -6189.008731668977}, {
       2584.885111030114, -6184.67312273511}, {
       2584.8818531142847`, -6184.67312273511}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6189.008731668977}, {
       3136.061463827263, -6189.008731668977}, {
       3136.061463827263, -6184.67312273511}, {
       3136.023775782051, -6184.67312273511}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6189.008731668977}, {
       3695.103918354495, -6189.008731668977}, {
       3695.103918354495, -6184.67312273511}, {
       3629.3590496784554`, -6184.67312273511}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.0390871283153`, -6189.008731668977}, {
       4142.649334923505, -6189.008731668977}, {
       4142.649334923505, -6184.67312273511}, {
       4072.0390871283153`, -6184.67312273511}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6189.008731668977}, {
       4700., -6189.008731668977}, {4700., -6184.67312273511}, {
       4699.999999941113, -6184.67312273511}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2514.786367595443, -6189.008731668977}, {
      2622.3440145788973`, -6189.008731668977}, {
      2622.3440145788973`, -6184.67312273511}, {
      2514.786367595443, -6184.67312273511}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{101.73338738241691`, -6185.757024968577}, \
{103.90119184935041`, -6184.67312273511}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{103.90119184935041`, -6185.757024968577}, 2.1678044669334993`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{103.90119184935041`, -6187.92482943551}, {
       2512.61856312851, -6187.92482943551}, {
       2512.61856312851, -6185.757024968577}, {
       103.90119184935041`, -6185.757024968577}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2512.61856312851, -6187.92482943551}, 2.1678044669334993`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2512.61856312851, -6189.008731668977}, \
{2514.786367595443, -6187.92482943551}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6189.010868808104}, {
        101.73338738241691`, -6189.010868808104}, {
        101.73338738241691`, -6189.008731668977}, {
        100, -6189.008731668977}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6189.010868808104}, {
       1280.7135349295934`, -6189.010868808104}, {
       1280.7135349295934`, -6189.008731668977}, {
       600.1763667716721, -6189.008731668977}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6189.010868808104}, {
       1321.0166576163394`, -6189.010868808104}, {
       1321.0166576163394`, -6189.008731668977}, {
       1249.4088780516513`, -6189.008731668977}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6189.010868808104}, {
       1601.2817484269165`, -6189.010868808104}, {
       1601.2817484269165`, -6189.008731668977}, {
       1601.2815974734888`, -6189.008731668977}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2512.61856312851, -6189.010868808104}, {
       2622.3440145788973`, -6189.010868808104}, {
       2622.3440145788973`, -6189.008731668977}, {
       2512.61856312851, -6189.008731668977}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6189.010868808104}, {
       2584.8840424605505`, -6189.010868808104}, {
       2584.8840424605505`, -6189.008731668977}, {
       2584.8818531142847`, -6189.008731668977}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.023775782051, -6189.010868808104}, {
       3136.061463827263, -6189.010868808104}, {
       3136.061463827263, -6189.008731668977}, {
       3136.023775782051, -6189.008731668977}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6189.010868808104}, {
       3695.103918354495, -6189.010868808104}, {
       3695.103918354495, -6189.008731668977}, {
       3629.3590496784554`, -6189.008731668977}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6189.010868808104}, {
       4700., -6189.010868808104}, {4700., -6189.008731668977}, {
       4699.999999941113, -6189.008731668977}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4072.0390871283153`, -6189.010868808104}, {
      4142.649334923505, -6189.010868808104}, {
      4142.649334923505, -6189.008731668977}, {
      4072.0390871283153`, -6189.008731668977}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8840424605505`, -6189.009265953759}, \
{2584.885111030114, -6189.008731668977}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.885111030114, -6189.009265953759}, 0.0010685695634664893`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.885111030114, -6189.010334523322}, {
       4072.038018558752, -6189.010334523322}, {
       4072.038018558752, -6189.009265953759}, {
       2584.885111030114, -6189.009265953759}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4072.038018558752, -6189.010334523322}, 
       0.0010685695634664893`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4072.038018558752, -6189.010868808104}, \
{4072.0390871283153`, -6189.010334523322}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6189.069805876886}, {
        101.73338738241691`, -6189.069805876886}, {
        101.73338738241691`, -6189.010868808104}, {
        100, -6189.010868808104}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6189.069805876886}, {
       1280.7135349295934`, -6189.069805876886}, {
       1280.7135349295934`, -6189.010868808104}, {
       600.1763667716721, -6189.010868808104}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6189.069805876886}, {
       1321.0166576163394`, -6189.069805876886}, {
       1321.0166576163394`, -6189.010868808104}, {
       1249.4088780516513`, -6189.010868808104}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6189.069805876886}, {
       1601.2817484269165`, -6189.069805876886}, {
       1601.2817484269165`, -6189.010868808104}, {
       1601.2815974734888`, -6189.010868808104}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6189.069805876886}, {
       2584.8840424605505`, -6189.069805876886}, {
       2584.8840424605505`, -6189.010868808104}, {
       2584.8818531142847`, -6189.010868808104}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.053244316442, -6189.069805876886}, {
       3136.0614638272637`, -6189.069805876886}, {
       3136.0614638272637`, -6189.010868808104}, {
       3136.053244316442, -6189.010868808104}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6189.069805876886}, {
       3695.103918354495, -6189.069805876886}, {
       3695.103918354495, -6189.010868808104}, {
       3629.3590496784554`, -6189.010868808104}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038018558752, -6189.069805876886}, {
       4142.649334923505, -6189.069805876886}, {
       4142.649334923505, -6189.010868808104}, {
       4072.038018558752, -6189.010868808104}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6189.069805876886}, {
       4700., -6189.069805876886}, {4700., -6189.010868808104}, {
       4699.999999941113, -6189.010868808104}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2512.61856312851, -6189.069805876886}, {
      2622.3440145788973`, -6189.069805876886}, {
      2622.3440145788973`, -6189.010868808104}, {
      2512.61856312851, -6189.010868808104}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.023775782051, -6189.025603075299}, \
{3136.053244316442, -6189.010868808104}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.023775782051, -6189.025603075299}, 0.029468534390981085`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2622.373483113288, -6189.0550716096905`}, {
       3136.023775782051, -6189.0550716096905`}, {
       3136.023775782051, -6189.025603075299}, {
       2622.373483113288, -6189.025603075299}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2622.373483113288, -6189.0550716096905`}, 
       0.029468534390981085`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.3440145788973`, -6189.069805876886}, \
{2622.373483113288, -6189.0550716096905`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6191.674840796807}, {
        100.43086992245617`, -6191.674840796807}, {
        100.43086992245617`, -6189.069805876886}, {
        100, -6189.069805876886}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6191.674840796807}, {
       1280.7135349295934`, -6191.674840796807}, {
       1280.7135349295934`, -6189.069805876886}, {
       600.1763667716721, -6189.069805876886}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6191.674840796807}, {
       1321.0166576163394`, -6191.674840796807}, {
       1321.0166576163394`, -6189.069805876886}, {
       1249.4088780516513`, -6189.069805876886}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6191.674840796807}, {
       1601.2817484269165`, -6191.674840796807}, {
       1601.2817484269165`, -6189.069805876886}, {
       1601.2815974734888`, -6189.069805876886}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6191.674840796807}, {
       2584.8840424605505`, -6191.674840796807}, {
       2584.8840424605505`, -6189.069805876886}, {
       2584.8818531142847`, -6189.069805876886}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.053244316442, -6191.674840796807}, {
       3136.0614638272637`, -6191.674840796807}, {
       3136.0614638272637`, -6189.069805876886}, {
       3136.053244316442, -6189.069805876886}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6191.674840796807}, {
       3695.103918354495, -6191.674840796807}, {
       3695.103918354495, -6189.069805876886}, {
       3629.3590496784554`, -6189.069805876886}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4072.038018558752, -6191.674840796807}, {
       4142.649334923505, -6191.674840796807}, {
       4142.649334923505, -6189.069805876886}, {
       4072.038018558752, -6189.069805876886}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6191.674840796807}, {
       4700., -6191.674840796807}, {4700., -6189.069805876886}, {
       4699.999999941113, -6189.069805876886}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2512.61856312851, -6191.674840796807}, {
      2622.3734831132883`, -6191.674840796807}, {
      2622.3734831132883`, -6189.069805876886}, {
      2512.61856312851, -6189.069805876886}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.43086992245617`, -6189.721064606866}, \
{101.73338738241691`, -6189.069805876886}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{101.73338738241691`, -6189.721064606866}, 1.3025174599607472`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{101.73338738241691`, -6191.023582066827}, {
       2511.316045668549, -6191.023582066827}, {
       2511.316045668549, -6189.721064606866}, {
       101.73338738241691`, -6189.721064606866}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2511.316045668549, -6191.023582066827}, 1.3025174599607472`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2511.316045668549, -6191.674840796807}, \
{2512.61856312851, -6191.023582066827}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6264.0888033496385`}, {
        100.43086992245617`, -6264.0888033496385`}, {
        100.43086992245617`, -6191.674840796807}, {
        100, -6191.674840796807}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6264.0888033496385`}, {
       1280.7135349295934`, -6264.0888033496385`}, {
       1280.7135349295934`, -6191.674840796807}, {
       600.1763667716721, -6191.674840796807}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6264.0888033496385`}, {
       1321.0166576163394`, -6264.0888033496385`}, {
       1321.0166576163394`, -6191.674840796807}, {
       1249.4088780516513`, -6191.674840796807}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6264.0888033496385`}, {
       1601.2817484269165`, -6264.0888033496385`}, {
       1601.2817484269165`, -6191.674840796807}, {
       1601.2815974734888`, -6191.674840796807}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6264.0888033496385`}, {
       2584.8840424605505`, -6264.0888033496385`}, {
       2584.8840424605505`, -6191.674840796807}, {
       2584.8818531142847`, -6191.674840796807}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.053244316442, -6264.0888033496385`}, {
       3136.0614638272637`, -6264.0888033496385`}, {
       3136.0614638272637`, -6191.674840796807}, {
       3136.053244316442, -6191.674840796807}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6264.0888033496385`}, {
       3695.103918354495, -6264.0888033496385`}, {
       3695.103918354495, -6191.674840796807}, {
       3629.3590496784554`, -6191.674840796807}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4108.244999835168, -6264.0888033496385`}, {
       4142.649334923505, -6264.0888033496385`}, {
       4142.649334923505, -6191.674840796807}, {
       4108.244999835168, -6191.674840796807}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999941113, -6264.0888033496385`}, {
       4700., -6264.0888033496385`}, {4700., -6191.674840796807}, {
       4699.999999941113, -6191.674840796807}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2511.316045668549, -6264.0888033496385`}, {
      2622.3734831132883`, -6264.0888033496385`}, {
      2622.3734831132883`, -6191.674840796807}, {
      2511.316045668549, -6191.674840796807}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4072.038018558752, -6209.778331435015}, \
{4108.244999835168, -6191.674840796807}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4072.038018558752, -6209.778331435015}, 36.20698127641563, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2658.5804643897036`, -6245.985312711431}, {
       4072.038018558752, -6245.985312711431}, {
       4072.038018558752, -6209.778331435015}, {
       2658.5804643897036`, -6209.778331435015}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2658.5804643897036`, -6245.985312711431}, 36.20698127641563, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2622.3734831132883`, -6264.0888033496385`}, \
{2658.5804643897036`, -6245.985312711431}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6264.0888033577685`}, {
        100.43086992245617`, -6264.0888033577685`}, {
        100.43086992245617`, -6264.0888033496385`}, {
        100, -6264.0888033496385`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6264.0888033577685`}, {
       1280.7135349295934`, -6264.0888033577685`}, {
       1280.7135349295934`, -6264.0888033496385`}, {
       600.1763667716721, -6264.0888033496385`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6264.0888033577685`}, {
       1321.0166576163394`, -6264.0888033577685`}, {
       1321.0166576163394`, -6264.0888033496385`}, {
       1249.4088780516513`, -6264.0888033496385`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6264.0888033577685`}, {
       1601.2817484269165`, -6264.0888033577685`}, {
       1601.2817484269165`, -6264.0888033496385`}, {
       1601.2815974734888`, -6264.0888033496385`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6264.0888033577685`}, {
       2658.5804643897036`, -6264.0888033577685`}, {
       2658.5804643897036`, -6264.0888033496385`}, {
       2511.316045668549, -6264.0888033496385`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6264.0888033577685`}, {
       2584.8840424605505`, -6264.0888033577685`}, {
       2584.8840424605505`, -6264.0888033496385`}, {
       2584.8818531142847`, -6264.0888033496385`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6264.0888033577685`}, {
       3695.103918354495, -6264.0888033577685`}, {
       3695.103918354495, -6264.0888033496385`}, {
       3629.3590496784554`, -6264.0888033496385`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4108.244999835168, -6264.0888033577685`}, {
       4142.649334923505, -6264.0888033577685`}, {
       4142.649334923505, -6264.0888033496385`}, {
       4108.244999835168, -6264.0888033496385`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6264.0888033577685`}, {
       4700., -6264.0888033577685`}, {4700., -6264.0888033496385`}, {
       4699.9999999451775`, -6264.0888033496385`}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.053244316442, -6264.0888033577685`}, {
      3136.0614638272637`, -6264.0888033577685`}, {
      3136.0614638272637`, -6264.0888033496385`}, {
      3136.053244316442, -6264.0888033496385`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999941113, -6264.088803351671}, \
{4699.9999999451775`, -6264.0888033496385`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999941113, -6264.088803351671}, 4.064768842019673*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.061463831328, -6264.088803355736}, {
       4699.999999941113, -6264.088803355736}, {
       4699.999999941113, -6264.088803351671}, {
       3136.061463831328, -6264.088803351671}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.061463831328, -6264.088803355736}, 4.064768842019673*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0614638272637`, -6264.0888033577685`}, \
{3136.061463831328, -6264.088803355736}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6264.088974854352}, {
        100.43086992245617`, -6264.088974854352}, {
        100.43086992245617`, -6264.0888033577685`}, {
        100, -6264.0888033577685`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6264.088974854352}, {
       1280.7135349295934`, -6264.088974854352}, {
       1280.7135349295934`, -6264.0888033577685`}, {
       600.1763667716721, -6264.0888033577685`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6264.088974854352}, {
       1321.0166576163394`, -6264.088974854352}, {
       1321.0166576163394`, -6264.0888033577685`}, {
       1249.4088780516513`, -6264.0888033577685`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6264.088974854352}, {
       1601.2816626786248`, -6264.088974854352}, {
       1601.2816626786248`, -6264.0888033577685`}, {
       1601.2815974734888`, -6264.0888033577685`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6264.088974854352}, {
       2658.5804643897036`, -6264.088974854352}, {
       2658.5804643897036`, -6264.0888033577685`}, {
       2511.316045668549, -6264.0888033577685`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6264.088974854352}, {
       2584.8840424605505`, -6264.088974854352}, {
       2584.8840424605505`, -6264.0888033577685`}, {
       2584.8818531142847`, -6264.0888033577685`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6264.088974854352}, {
       3695.103918354495, -6264.088974854352}, {
       3695.103918354495, -6264.0888033577685`}, {
       3629.3590496784554`, -6264.0888033577685`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4108.244999835168, -6264.088974854352}, {
       4142.649334923505, -6264.088974854352}, {
       4142.649334923505, -6264.0888033577685`}, {
       4108.244999835168, -6264.0888033577685`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6264.088974854352}, {
       4700., -6264.088974854352}, {4700., -6264.0888033577685`}, {
       4699.9999999451775`, -6264.0888033577685`}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.053244316442, -6264.088974854352}, {
      3136.061463831328, -6264.088974854352}, {
      3136.061463831328, -6264.0888033577685`}, {
      3136.053244316442, -6264.0888033577685`}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816626786248`, -6264.088846231914}, \
{1601.2817484269165`, -6264.0888033577685`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2817484269165`, -6264.088846231914}, 
       0.00008574829184255475, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2817484269165`, -6264.088931980206}, {
       3136.05315856815, -6264.088931980206}, {
       3136.05315856815, -6264.088846231914}, {
       1601.2817484269165`, -6264.088846231914}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05315856815, -6264.088931980206}, 
       0.00008574829184255475, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05315856815, -6264.088974854352}, \
{3136.053244316442, -6264.088931980206}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6264.094728885521}, {
        100.43086992245617`, -6264.094728885521}, {
        100.43086992245617`, -6264.088974854352}, {
        100, -6264.088974854352}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6264.094728885521}, {
       1280.7135349295934`, -6264.094728885521}, {
       1280.7135349295934`, -6264.088974854352}, {
       600.1763667716721, -6264.088974854352}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6264.094728885521}, {
       1321.0166576163394`, -6264.094728885521}, {
       1321.0166576163394`, -6264.088974854352}, {
       1249.4088780516513`, -6264.088974854352}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6264.094728885521}, {
       1601.2816626786248`, -6264.094728885521}, {
       1601.2816626786248`, -6264.088974854352}, {
       1601.2815974734888`, -6264.088974854352}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6264.094728885521}, {
       2584.8840424605505`, -6264.094728885521}, {
       2584.8840424605505`, -6264.088974854352}, {
       2584.8818531142847`, -6264.088974854352}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6264.094728885521}, {
       3136.061463831328, -6264.094728885521}, {
       3136.061463831328, -6264.088974854352}, {
       3136.0560355837347`, -6264.088974854352}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3629.3590496784554`, -6264.094728885521}, {
       3695.103918354495, -6264.094728885521}, {
       3695.103918354495, -6264.088974854352}, {
       3629.3590496784554`, -6264.088974854352}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4108.244999835168, -6264.094728885521}, {
       4142.649334923505, -6264.094728885521}, {
       4142.649334923505, -6264.088974854352}, {
       4108.244999835168, -6264.088974854352}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6264.094728885521}, {
       4700., -6264.094728885521}, {4700., -6264.088974854352}, {
       4699.9999999451775`, -6264.088974854352}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2511.316045668549, -6264.094728885521}, {
      2658.5804643897036`, -6264.094728885521}, {
      2658.5804643897036`, -6264.088974854352}, {
      2511.316045668549, -6264.088974854352}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05315856815, -6264.090413362144}, \
{3136.0560355837347`, -6264.088974854352}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05315856815, -6264.090413362144}, 0.002877015584587618, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2658.5833414052886`, -6264.093290377729}, {
       3136.05315856815, -6264.093290377729}, {
       3136.05315856815, -6264.090413362144}, {
       2658.5833414052886`, -6264.090413362144}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2658.5833414052886`, -6264.093290377729}, 0.002877015584587618,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2658.5804643897036`, -6264.094728885521}, \
{2658.5833414052886`, -6264.093290377729}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6276.263353375019}, {
        100.43086992245617`, -6276.263353375019}, {
        100.43086992245617`, -6264.094728885521}, {
        100, -6264.094728885521}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6276.263353375019}, {
       1280.7135349295934`, -6276.263353375019}, {
       1280.7135349295934`, -6264.094728885521}, {
       600.1763667716721, -6264.094728885521}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6276.263353375019}, {
       1321.0166576163394`, -6276.263353375019}, {
       1321.0166576163394`, -6264.094728885521}, {
       1249.4088780516513`, -6264.094728885521}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6276.263353375019}, {
       1601.2816626786248`, -6276.263353375019}, {
       1601.2816626786248`, -6264.094728885521}, {
       1601.2815974734888`, -6264.094728885521}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6276.263353375019}, {
       2652.4990291605395`, -6276.263353375019}, {
       2652.4990291605395`, -6264.094728885521}, {
       2511.316045668549, -6264.094728885521}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6276.263353375019}, {
       2584.8840424605505`, -6276.263353375019}, {
       2584.8840424605505`, -6264.094728885521}, {
       2584.8818531142847`, -6264.094728885521}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6276.263353375019}, {
       3136.061463831328, -6276.263353375019}, {
       3136.061463831328, -6264.094728885521}, {
       3136.0560355837347`, -6264.094728885521}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4108.244999835168, -6276.263353375019}, {
       4142.649334923505, -6276.263353375019}, {
       4142.649334923505, -6264.094728885521}, {
       4108.244999835168, -6264.094728885521}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6276.263353375019}, {
       4700., -6276.263353375019}, {4700., -6264.094728885521}, {
       4699.9999999451775`, -6264.094728885521}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3629.3590496784554`, -6276.263353375019}, {
      3695.1039183544954`, -6276.263353375019}, {
      3695.1039183544954`, -6264.094728885521}, {
      3629.3590496784554`, -6264.094728885521}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.4990291605395`, -6267.136885007895}, \
{2658.5833414052886`, -6264.094728885521}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2658.5833414052886`, -6267.136885007895}, 6.084312244748816, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2658.5833414052886`, -6273.221197252644}, {
       3623.274737433707, -6273.221197252644}, {
       3623.274737433707, -6267.136885007895}, {
       2658.5833414052886`, -6267.136885007895}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3623.274737433707, -6273.221197252644}, 6.084312244748816, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3623.274737433707, -6276.263353375019}, \
{3629.3590496784554`, -6273.221197252644}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6336.661787699577}, {
        100.43086992245617`, -6336.661787699577}, {
        100.43086992245617`, -6276.263353375019}, {
        100, -6276.263353375019}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6336.661787699577}, {
       1280.7135349295934`, -6336.661787699577}, {
       1280.7135349295934`, -6276.263353375019}, {
       600.1763667716721, -6276.263353375019}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6336.661787699577}, {
       1290.8174404540605`, -6336.661787699577}, {
       1290.8174404540605`, -6276.263353375019}, {
       1249.4088780516513`, -6276.263353375019}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6336.661787699577}, {
       1601.2816626786248`, -6336.661787699577}, {
       1601.2816626786248`, -6276.263353375019}, {
       1601.2815974734888`, -6276.263353375019}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6336.661787699577}, {
       2652.4990291605395`, -6336.661787699577}, {
       2652.4990291605395`, -6276.263353375019}, {
       2511.316045668549, -6276.263353375019}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6336.661787699577}, {
       2584.8840424605505`, -6336.661787699577}, {
       2584.8840424605505`, -6276.263353375019}, {
       2584.8818531142847`, -6276.263353375019}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6336.661787699577}, {
       3136.061463831328, -6336.661787699577}, {
       3136.061463831328, -6276.263353375019}, {
       3136.0560355837347`, -6276.263353375019}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274737433707, -6336.661787699577}, {
       3695.1039183544954`, -6336.661787699577}, {
       3695.1039183544954`, -6276.263353375019}, {
       3623.274737433707, -6276.263353375019}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6336.661787699577}, {
       4700., -6336.661787699577}, {4700., -6276.263353375019}, {
       4699.9999999451775`, -6276.263353375019}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4108.244999835168, -6336.661787699577}, {
      4142.649334923505, -6336.661787699577}, {
      4142.649334923505, -6276.263353375019}, {
      4108.244999835168, -6276.263353375019}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1290.8174404540605`, -6291.362961956158}, \
{1321.0166576163394`, -6276.263353375019}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1321.0166576163394`, -6291.362961956158}, 30.199217162279083`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1321.0166576163394`, -6321.562179118438}, {
       4078.0457826728884`, -6321.562179118438}, {
       4078.0457826728884`, -6291.362961956158}, {
       1321.0166576163394`, -6291.362961956158}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4078.0457826728884`, -6321.562179118438}, 
       30.199217162279083`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4078.0457826728884`, -6336.661787699577}, \
{4108.244999835168, -6321.562179118438}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6336.690136682964}, {
        100.43086992245617`, -6336.690136682964}, {
        100.43086992245617`, -6336.661787699577}, {
        100, -6336.661787699577}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6336.690136682964}, {
       1280.7135349295934`, -6336.690136682964}, {
       1280.7135349295934`, -6336.661787699577}, {
       600.1763667716721, -6336.661787699577}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6336.690136682964}, {
       1290.8174404540605`, -6336.690136682964}, {
       1290.8174404540605`, -6336.661787699577}, {
       1249.4088780516513`, -6336.661787699577}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6336.690136682964}, {
       1601.2816626786248`, -6336.690136682964}, {
       1601.2816626786248`, -6336.661787699577}, {
       1601.2815974734888`, -6336.661787699577}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6336.690136682964}, {
       2584.8840424605505`, -6336.690136682964}, {
       2584.8840424605505`, -6336.661787699577}, {
       2584.8818531142847`, -6336.661787699577}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6336.690136682964}, {
       3136.061463831328, -6336.690136682964}, {
       3136.061463831328, -6336.661787699577}, {
       3136.0560355837347`, -6336.661787699577}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274737433707, -6336.690136682964}, {
       3695.1039183544954`, -6336.690136682964}, {
       3695.1039183544954`, -6336.661787699577}, {
       3623.274737433707, -6336.661787699577}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4078.059957164582, -6336.690136682964}, {
       4142.649334923505, -6336.690136682964}, {
       4142.649334923505, -6336.661787699577}, {
       4078.059957164582, -6336.661787699577}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999451775`, -6336.690136682964}, {
       4700., -6336.690136682964}, {4700., -6336.661787699577}, {
       4699.9999999451775`, -6336.661787699577}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2511.316045668549, -6336.690136682964}, {
      2652.4990291605395`, -6336.690136682964}, {
      2652.4990291605395`, -6336.661787699577}, {
      2511.316045668549, -6336.661787699577}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4078.0457826728884`, -6336.668874945423}, \
{4078.059957164582, -6336.661787699577}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4078.0457826728884`, -6336.668874945423}, 
       0.014174491693736968`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.513203652233, -6336.683049437117}, {
       4078.0457826728884`, -6336.683049437117}, {
       4078.0457826728884`, -6336.668874945423}, {
       2652.513203652233, -6336.668874945423}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.513203652233, -6336.683049437117}, 0.014174491693736968`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.4990291605395`, -6336.690136682964}, \
{2652.513203652233, -6336.683049437117}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6336.69013677137}, {
        100.43086992245617`, -6336.69013677137}, {
        100.43086992245617`, -6336.690136682964}, {
        100, -6336.690136682964}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6336.69013677137}, {
       1280.7135349295934`, -6336.69013677137}, {
       1280.7135349295934`, -6336.690136682964}, {
       600.1763667716721, -6336.690136682964}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6336.69013677137}, {
       1290.8174404540605`, -6336.69013677137}, {
       1290.8174404540605`, -6336.690136682964}, {
       1249.4088780516513`, -6336.690136682964}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6336.69013677137}, {
       1601.2816626786248`, -6336.69013677137}, {
       1601.2816626786248`, -6336.690136682964}, {
       1601.2815974734888`, -6336.690136682964}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6336.69013677137}, {
       2652.513203652233, -6336.69013677137}, {
       2652.513203652233, -6336.690136682964}, {
       2511.316045668549, -6336.690136682964}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6336.69013677137}, {
       2584.8840424605505`, -6336.69013677137}, {
       2584.8840424605505`, -6336.690136682964}, {
       2584.8818531142847`, -6336.690136682964}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6336.69013677137}, {
       3136.061463831328, -6336.69013677137}, {
       3136.061463831328, -6336.690136682964}, {
       3136.0560355837347`, -6336.690136682964}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274737433707, -6336.69013677137}, {
       3695.1039183544954`, -6336.69013677137}, {
       3695.1039183544954`, -6336.690136682964}, {
       3623.274737433707, -6336.690136682964}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4078.059957164582, -6336.69013677137}, {
       4142.649334879302, -6336.69013677137}, {
       4142.649334879302, -6336.690136682964}, {
       4078.059957164582, -6336.690136682964}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.9999999451775`, -6336.69013677137}, {
      4700., -6336.69013677137}, {4700., -6336.690136682964}, {
      4699.9999999451775`, -6336.690136682964}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334879302, -6336.690136705065}, \
{4142.649334923505, -6336.690136682964}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334923505, -6336.690136705065}, 4.420302062806214*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334923505, -6336.690136749268}, {
       4699.999999900974, -6336.690136749268}, {
       4699.999999900974, -6336.690136705065}, {
       4142.649334923505, -6336.690136705065}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999900974, -6336.690136749268}, 
       4.420302062806214*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999900974, -6336.69013677137}, \
{4699.9999999451775`, -6336.690136749268}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6337.222304706349}, {
       1280.7135349295934`, -6337.222304706349}, {
       1280.7135349295934`, -6336.69013677137}, {
       600.1763667716721, -6336.69013677137}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6337.222304706349}, {
       1290.8174404540605`, -6337.222304706349}, {
       1290.8174404540605`, -6336.69013677137}, {
       1249.4088780516513`, -6336.69013677137}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2815974734888`, -6337.222304706349}, {
       1601.2816626786248`, -6337.222304706349}, {
       1601.2816626786248`, -6336.69013677137}, {
       1601.2815974734888`, -6336.69013677137}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6337.222304706349}, {
       2652.513203652233, -6337.222304706349}, {
       2652.513203652233, -6336.69013677137}, {
       2511.316045668549, -6336.69013677137}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6337.222304706349}, {
       2584.8840424605505`, -6337.222304706349}, {
       2584.8840424605505`, -6336.69013677137}, {
       2584.8818531142847`, -6336.69013677137}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6337.222304706349}, {
       3136.061463831328, -6337.222304706349}, {
       3136.061463831328, -6336.69013677137}, {
       3136.0560355837347`, -6336.69013677137}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274737433707, -6337.222304706349}, {
       3695.1039183544954`, -6337.222304706349}, {
       3695.1039183544954`, -6336.69013677137}, {
       3623.274737433707, -6336.69013677137}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4078.3260411320716`, -6337.222304706349}, {
       4142.649334879302, -6337.222304706349}, {
       4142.649334879302, -6336.69013677137}, {
       4078.3260411320716`, -6336.69013677137}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6337.222304706349}, {
       4700., -6337.222304706349}, {4700., -6336.69013677137}, {
       4699.999999900974, -6336.69013677137}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -6337.222304706349}, {
       100.43086992245617`, -6337.222304706349}, {
       100.43086992245617`, -6336.69013677137}, {
       100, -6336.69013677137}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4078.059957164582, -6336.823178755115}, \
{4078.3260411320716`, -6336.69013677137}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4078.059957164582, -6336.823178755115}, 0.2660839674894758, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.69695388994565`, -6337.089262722604}, {
       4078.059957164582, -6337.089262722604}, {
       4078.059957164582, -6336.823178755115}, {
       100.69695388994565`, -6336.823178755115}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.69695388994565`, -6337.089262722604}, 0.2660839674894758, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.43086992245617`, -6337.222304706349}, \
{100.69695388994565`, -6337.089262722604}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6337.2223131708}, {
        100.69695388994565`, -6337.2223131708}, {
        100.69695388994565`, -6337.222304706349}, {
        100, -6337.222304706349}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6337.2223131708}, {
       1280.7135349295934`, -6337.2223131708}, {
       1280.7135349295934`, -6337.222304706349}, {
       600.1763667716721, -6337.222304706349}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6337.2223131708}, {
       1290.8174404540605`, -6337.2223131708}, {
       1290.8174404540605`, -6337.222304706349}, {
       1249.4088780516513`, -6337.222304706349}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6337.2223131708}, {
       2652.513203652233, -6337.2223131708}, {
       2652.513203652233, -6337.222304706349}, {
       2511.316045668549, -6337.222304706349}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6337.2223131708}, {
       2584.8840424605505`, -6337.2223131708}, {
       2584.8840424605505`, -6337.222304706349}, {
       2584.8818531142847`, -6337.222304706349}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6337.2223131708}, {
       3136.061463831328, -6337.2223131708}, {
       3136.061463831328, -6337.222304706349}, {
       3136.0560355837347`, -6337.222304706349}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6337.2223131708}, {
       3695.1039183544954`, -6337.2223131708}, {
       3695.1039183544954`, -6337.222304706349}, {
       3623.274741665932, -6337.222304706349}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4078.3260411320716`, -6337.2223131708}, {
       4142.649334879302, -6337.2223131708}, {
       4142.649334879302, -6337.222304706349}, {
       4078.3260411320716`, -6337.222304706349}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6337.2223131708}, {
       4700., -6337.2223131708}, {4700., -6337.222304706349}, {
       4699.999999900974, -6337.222304706349}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2815974734888`, -6337.2223131708}, {
      1601.2816626786248`, -6337.2223131708}, {
      1601.2816626786248`, -6337.222304706349}, {
      1601.2815974734888`, -6337.222304706349}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3623.274737433707, -6337.222306822461}, \
{3623.274741665932, -6337.222304706349}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3623.274737433707, -6337.222306822461}, 4.232225377355555*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816669108502`, -6337.2223110546865`}, {
       3623.274737433707, -6337.2223110546865`}, {
       3623.274737433707, -6337.222306822461}, {
       1601.2816669108502`, -6337.222306822461}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816669108502`, -6337.2223110546865`}, 
       4.232225377355555*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816626786248`, -6337.2223131708}, \
{1601.2816669108502`, -6337.2223110546865`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6337.222385224527}, {
        100.69695388994565`, -6337.222385224527}, {
        100.69695388994565`, -6337.2223131708}, {100, -6337.2223131708}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6337.222385224527}, {
       1290.8174404540605`, -6337.222385224527}, {
       1290.8174404540605`, -6337.2223131708}, {
       1249.4088780516513`, -6337.2223131708}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816335003527`, -6337.222385224527}, {
       1601.2816669108502`, -6337.222385224527}, {
       1601.2816669108502`, -6337.2223131708}, {
       1601.2816335003527`, -6337.2223131708}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6337.222385224527}, {
       2652.513203652233, -6337.222385224527}, {
       2652.513203652233, -6337.2223131708}, {
       2511.316045668549, -6337.2223131708}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6337.222385224527}, {
       2584.8840424605505`, -6337.222385224527}, {
       2584.8840424605505`, -6337.2223131708}, {
       2584.8818531142847`, -6337.2223131708}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6337.222385224527}, {
       3136.061463831328, -6337.222385224527}, {
       3136.061463831328, -6337.2223131708}, {
       3136.0560355837347`, -6337.2223131708}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6337.222385224527}, {
       3695.1039183544954`, -6337.222385224527}, {
       3695.1039183544954`, -6337.2223131708}, {
       3623.274741665932, -6337.2223131708}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4078.3260411320716`, -6337.222385224527}, {
       4142.649334879302, -6337.222385224527}, {
       4142.649334879302, -6337.2223131708}, {
       4078.3260411320716`, -6337.2223131708}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6337.222385224527}, {
       4700., -6337.222385224527}, {4700., -6337.2223131708}, {
       4699.999999900974, -6337.2223131708}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1763667716721, -6337.222385224527}, {
      1280.7135349295934`, -6337.222385224527}, {
      1280.7135349295934`, -6337.2223131708}, {
      600.1763667716721, -6337.2223131708}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2815974734888`, -6337.222331184232}, \
{1601.2816335003527`, -6337.2223131708}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2815974734888`, -6337.222331184232}, 
       0.000036026863784679916`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1280.7135709564573`, -6337.222367211095}, {
       1601.2815974734888`, -6337.222367211095}, {
       1601.2815974734888`, -6337.222331184232}, {
       1280.7135709564573`, -6337.222331184232}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1280.7135709564573`, -6337.222367211095}, 
       0.000036026863784679916`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1280.7135349295934`, -6337.222385224527}, \
{1280.7135709564573`, -6337.222367211095}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6413.824185608801}, {
        100.69695388994565`, -6413.824185608801}, {
        100.69695388994565`, -6337.222385224527}, {
        100, -6337.222385224527}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6413.824185608801}, {
       1280.7135709564573`, -6413.824185608801}, {
       1280.7135709564573`, -6337.222385224527}, {
       600.1763667716721, -6337.222385224527}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816335003527`, -6413.824185608801}, {
       1601.2816669108502`, -6413.824185608801}, {
       1601.2816669108502`, -6337.222385224527}, {
       1601.2816335003527`, -6337.222385224527}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6413.824185608801}, {
       2652.513203652233, -6413.824185608801}, {
       2652.513203652233, -6337.222385224527}, {
       2511.316045668549, -6337.222385224527}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6413.824185608801}, {
       2584.8840424605505`, -6413.824185608801}, {
       2584.8840424605505`, -6337.222385224527}, {
       2584.8818531142847`, -6337.222385224527}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6413.824185608801}, {
       3136.061463831328, -6413.824185608801}, {
       3136.061463831328, -6337.222385224527}, {
       3136.0560355837347`, -6337.222385224527}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6413.824185608801}, {
       3695.1039183544954`, -6413.824185608801}, {
       3695.1039183544954`, -6337.222385224527}, {
       3623.274741665932, -6337.222385224527}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6413.824185608801}, {
       4142.649334879302, -6413.824185608801}, {
       4142.649334879302, -6337.222385224527}, {
       4116.626941324208, -6337.222385224527}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6413.824185608801}, {
       4700., -6413.824185608801}, {4700., -6337.222385224527}, {
       4699.999999900974, -6337.222385224527}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1249.4088780516513`, -6413.824185608801}, {
      1290.8174404540605`, -6413.824185608801}, {
      1290.8174404540605`, -6337.222385224527}, {
      1249.4088780516513`, -6337.222385224527}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4078.326041132071, -6356.372835320596}, \
{4116.626941324208, -6337.222385224527}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4078.326041132071, -6356.372835320596}, 38.30090019213668, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1329.118340646197, -6394.6737355127325`}, {
       4078.326041132071, -6394.6737355127325`}, {
       4078.326041132071, -6356.372835320596}, {
       1329.118340646197, -6356.372835320596}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1329.118340646197, -6394.6737355127325`}, 38.30090019213668, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1290.8174404540605`, -6413.824185608801}, \
{1329.118340646197, -6394.6737355127325`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6413.824187313573}, {
        100.69695388994565`, -6413.824187313573}, {
        100.69695388994565`, -6413.824185608801}, {
        100, -6413.824185608801}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6413.824187313573}, {
       1329.118340646197, -6413.824187313573}, {
       1329.118340646197, -6413.824185608801}, {
       1249.4088780516513`, -6413.824185608801}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816343527388`, -6413.824187313573}, {
       1601.2816669108504`, -6413.824187313573}, {
       1601.2816669108504`, -6413.824185608801}, {
       1601.2816343527388`, -6413.824185608801}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6413.824187313573}, {
       2652.513203652233, -6413.824187313573}, {
       2652.513203652233, -6413.824185608801}, {
       2511.316045668549, -6413.824185608801}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8818531142847`, -6413.824187313573}, {
       2584.8840424605505`, -6413.824187313573}, {
       2584.8840424605505`, -6413.824185608801}, {
       2584.8818531142847`, -6413.824185608801}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6413.824187313573}, {
       3136.061463831328, -6413.824187313573}, {
       3136.061463831328, -6413.824185608801}, {
       3136.0560355837347`, -6413.824185608801}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6413.824187313573}, {
       3695.1039183544954`, -6413.824187313573}, {
       3695.1039183544954`, -6413.824185608801}, {
       3623.274741665932, -6413.824185608801}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6413.824187313573}, {
       4142.649334879302, -6413.824187313573}, {
       4142.649334879302, -6413.824185608801}, {
       4116.626941324208, -6413.824185608801}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6413.824187313573}, {
       4700., -6413.824187313573}, {4700., -6413.824185608801}, {
       4699.999999900974, -6413.824185608801}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1763667716721, -6413.824187313573}, {
      1280.7135709564573`, -6413.824187313573}, {
      1280.7135709564573`, -6413.824185608801}, {
      600.1763667716721, -6413.824185608801}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816335003527`, -6413.8241860349935`}, \
{1601.2816343527388`, -6413.824185608801}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816335003527`, -6413.8241860349935`}, 
       8.523860671599216*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1280.7135718088432`, -6413.82418688738}, {
       1601.2816335003527`, -6413.82418688738}, {
       1601.2816335003527`, -6413.8241860349935`}, {
       1280.7135718088432`, -6413.8241860349935`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1280.7135718088432`, -6413.82418688738}, 8.523860671599216*^-7,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1280.7135709564573`, -6413.824187313573}, \
{1280.7135718088432`, -6413.82418688738}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6413.824222358159}, {
        100.69695388994565`, -6413.824222358159}, {
        100.69695388994565`, -6413.824187313573}, {
        100, -6413.824187313573}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6413.824222358159}, {
       1280.7135718088432`, -6413.824222358159}, {
       1280.7135718088432`, -6413.824187313573}, {
       600.1763667716721, -6413.824187313573}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1249.4088780516513`, -6413.824222358159}, {
       1329.118340646197, -6413.824222358159}, {
       1329.118340646197, -6413.824187313573}, {
       1249.4088780516513`, -6413.824187313573}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6413.824222358159}, {
       2652.513203652233, -6413.824222358159}, {
       2652.513203652233, -6413.824187313573}, {
       2511.316045668549, -6413.824187313573}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6413.824222358159}, {
       2584.8840424605505`, -6413.824222358159}, {
       2584.8840424605505`, -6413.824187313573}, {
       2584.881870636578, -6413.824187313573}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6413.824222358159}, {
       3136.061463831328, -6413.824222358159}, {
       3136.061463831328, -6413.824187313573}, {
       3136.0560355837347`, -6413.824187313573}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6413.824222358159}, {
       3695.1039183544954`, -6413.824222358159}, {
       3695.1039183544954`, -6413.824187313573}, {
       3623.274741665932, -6413.824187313573}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6413.824222358159}, {
       4142.649334879302, -6413.824222358159}, {
       4142.649334879302, -6413.824187313573}, {
       4116.626941324208, -6413.824187313573}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6413.824222358159}, {
       4700., -6413.824222358159}, {4700., -6413.824187313573}, {
       4699.999999900974, -6413.824187313573}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816343527388`, -6413.824222358159}, {
      1601.2816669108504`, -6413.824222358159}, {
      1601.2816669108504`, -6413.824187313573}, {
      1601.2816343527388`, -6413.824187313573}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8818531142847`, -6413.824196074719}, \
{2584.881870636578, -6413.824187313573}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8818531142847`, -6413.824196074719}, 
       0.000017522293317925747`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816844331437`, -6413.824213597012}, {
       2584.8818531142847`, -6413.824213597012}, {
       2584.8818531142847`, -6413.824196074719}, {
       1601.2816844331437`, -6413.824196074719}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816844331437`, -6413.824213597012}, 
       0.000017522293317925747`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816669108504`, -6413.824222358159}, \
{1601.2816844331437`, -6413.824213597012}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.096187138528}, {
        100.69695388994565`, -6418.096187138528}, {
        100.69695388994565`, -6413.824222358159}, {
        100, -6413.824222358159}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.096187138528}, {
       1278.5775894186588`, -6418.096187138528}, {
       1278.5775894186588`, -6413.824222358159}, {
       600.1763667716721, -6413.824222358159}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816343527388`, -6418.096187138528}, {
       1601.2816844331437`, -6418.096187138528}, {
       1601.2816844331437`, -6413.824222358159}, {
       1601.2816343527388`, -6413.824222358159}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.096187138528}, {
       2652.513203652233, -6418.096187138528}, {
       2652.513203652233, -6413.824222358159}, {
       2511.316045668549, -6413.824222358159}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.096187138528}, {
       2584.8840424605505`, -6418.096187138528}, {
       2584.8840424605505`, -6413.824222358159}, {
       2584.881870636578, -6413.824222358159}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0560355837347`, -6418.096187138528}, {
       3136.061463831328, -6418.096187138528}, {
       3136.061463831328, -6413.824222358159}, {
       3136.0560355837347`, -6413.824222358159}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6418.096187138528}, {
       3695.1039183544954`, -6418.096187138528}, {
       3695.1039183544954`, -6413.824222358159}, {
       3623.274741665932, -6413.824222358159}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.096187138528}, {
       4142.649334879302, -6418.096187138528}, {
       4142.649334879302, -6413.824222358159}, {
       4116.626941324208, -6413.824222358159}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.096187138528}, {
       4700., -6418.096187138528}, {4700., -6413.824222358159}, {
       4699.999999900974, -6413.824222358159}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1249.4088780516513`, -6418.096187138528}, {
      1329.118340646197, -6418.096187138528}, {
      1329.118340646197, -6413.824222358159}, {
      1249.4088780516513`, -6413.824222358159}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1278.5775894186588`, -6414.892213553251}, \
{1280.7135718088432`, -6413.824222358159}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1280.7135718088432`, -6414.892213553251}, 2.135982390184367, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1280.7135718088432`, -6417.028195943436}, {
       1247.272895661467, -6417.028195943436}, {
       1247.272895661467, -6414.892213553251}, {
       1280.7135718088432`, -6414.892213553251}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1247.272895661467, -6417.028195943436}, 2.135982390184367, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1247.272895661467, -6418.096187138528}, \
{1249.4088780516513`, -6417.028195943436}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.09756202023}, {
        100.69695388994565`, -6418.09756202023}, {
        100.69695388994565`, -6418.096187138528}, {
        100, -6418.096187138528}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.09756202023}, {
       1278.5769019778077`, -6418.09756202023}, {
       1278.5769019778077`, -6418.096187138528}, {
       600.1763667716721, -6418.096187138528}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.272895661467, -6418.09756202023}, {
       1329.118340646197, -6418.09756202023}, {
       1329.118340646197, -6418.096187138528}, {
       1247.272895661467, -6418.096187138528}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816343527388`, -6418.09756202023}, {
       1601.2816844331437`, -6418.09756202023}, {
       1601.2816844331437`, -6418.096187138528}, {
       1601.2816343527388`, -6418.096187138528}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.09756202023}, {
       2652.513203652233, -6418.09756202023}, {
       2652.513203652233, -6418.096187138528}, {
       2511.316045668549, -6418.096187138528}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.09756202023}, {
       2584.8840424605505`, -6418.09756202023}, {
       2584.8840424605505`, -6418.096187138528}, {
       2584.881870636578, -6418.096187138528}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6418.09756202023}, {
       3695.1039183544954`, -6418.09756202023}, {
       3695.1039183544954`, -6418.096187138528}, {
       3623.274741665932, -6418.096187138528}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.09756202023}, {
       4142.649334879302, -6418.09756202023}, {
       4142.649334879302, -6418.096187138528}, {
       4116.626941324208, -6418.096187138528}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.09756202023}, {
       4700., -6418.09756202023}, {4700., -6418.096187138528}, {
       4699.999999900974, -6418.096187138528}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0560355837347`, -6418.09756202023}, {
      3136.061463831328, -6418.09756202023}, {
      3136.061463831328, -6418.096187138528}, {
      3136.0560355837347`, -6418.096187138528}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1278.5769019778077`, -6418.096530858953}, \
{1278.5775894186588`, -6418.096187138528}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1278.5775894186588`, -6418.096530858953}, 
       0.0006874408511438092, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1278.5775894186588`, -6418.097218299804}, {
       3136.0553481428838`, -6418.097218299804}, {
       3136.0553481428838`, -6418.096530858953}, {
       1278.5775894186588`, -6418.096530858953}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0553481428838`, -6418.097218299804}, 
       0.0006874408511438092, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0553481428838`, -6418.09756202023}, \
{3136.0560355837347`, -6418.097218299804}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.097617107514}, {
        100.69695388994565`, -6418.097617107514}, {
        100.69695388994565`, -6418.09756202023}, {
        100, -6418.09756202023}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.097617107514}, {
       1278.5769019778077`, -6418.097617107514}, {
       1278.5769019778077`, -6418.09756202023}, {
       600.1763667716721, -6418.09756202023}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6418.097617107514}, {
       1601.2816844331437`, -6418.097617107514}, {
       1601.2816844331437`, -6418.09756202023}, {
       1601.2816618963811`, -6418.09756202023}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.097617107514}, {
       2652.513203652233, -6418.097617107514}, {
       2652.513203652233, -6418.09756202023}, {
       2511.316045668549, -6418.09756202023}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.097617107514}, {
       2584.8840424605505`, -6418.097617107514}, {
       2584.8840424605505`, -6418.09756202023}, {
       2584.881870636578, -6418.09756202023}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0553481428838`, -6418.097617107514}, {
       3136.061463831328, -6418.097617107514}, {
       3136.061463831328, -6418.09756202023}, {
       3136.0553481428838`, -6418.09756202023}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3623.274741665932, -6418.097617107514}, {
       3695.1039183544954`, -6418.097617107514}, {
       3695.1039183544954`, -6418.09756202023}, {
       3623.274741665932, -6418.09756202023}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.097617107514}, {
       4142.649334879302, -6418.097617107514}, {
       4142.649334879302, -6418.09756202023}, {
       4116.626941324208, -6418.09756202023}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.097617107514}, {
       4700., -6418.097617107514}, {4700., -6418.09756202023}, {
       4699.999999900974, -6418.09756202023}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1247.272895661467, -6418.097617107514}, {
      1329.118340646197, -6418.097617107514}, {
      1329.118340646197, -6418.09756202023}, {
      1247.272895661467, -6418.09756202023}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816343527388`, -6418.097575792051}, \
{1601.2816618963811`, -6418.09756202023}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816343527388`, -6418.097575792051}, 
       0.00002754364228607491, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1329.1183681898394`, -6418.097603335694}, {
       1601.2816343527388`, -6418.097603335694}, {
       1601.2816343527388`, -6418.097575792051}, {
       1329.1183681898394`, -6418.097575792051}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1329.1183681898394`, -6418.097603335694}, 
       0.00002754364228607491, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.118340646197, -6418.097617107514}, \
{1329.1183681898394`, -6418.097603335694}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.9336118692}, {
        100.2789565091028, -6418.9336118692}, {
        100.2789565091028, -6418.097617107514}, {
        100, -6418.097617107514}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.9336118692}, {
       1278.5769019778077`, -6418.9336118692}, {
       1278.5769019778077`, -6418.097617107514}, {
       600.1763667716721, -6418.097617107514}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.272895661467, -6418.9336118692}, {
       1329.1183681898394`, -6418.9336118692}, {
       1329.1183681898394`, -6418.097617107514}, {
       1247.272895661467, -6418.097617107514}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6418.9336118692}, {
       1601.2816844331437`, -6418.9336118692}, {
       1601.2816844331437`, -6418.097617107514}, {
       1601.2816618963811`, -6418.097617107514}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.9336118692}, {
       2652.513203652233, -6418.9336118692}, {
       2652.513203652233, -6418.097617107514}, {
       2511.316045668549, -6418.097617107514}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.9336118692}, {
       2584.8840424605505`, -6418.9336118692}, {
       2584.8840424605505`, -6418.097617107514}, {
       2584.881870636578, -6418.097617107514}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0553481428838`, -6418.9336118692}, {
       3136.061463831328, -6418.9336118692}, {
       3136.061463831328, -6418.097617107514}, {
       3136.0553481428838`, -6418.097617107514}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.9336118692}, {
       4142.649334879302, -6418.9336118692}, {
       4142.649334879302, -6418.097617107514}, {
       4116.626941324208, -6418.097617107514}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.9336118692}, {
       4700., -6418.9336118692}, {4700., -6418.097617107514}, {
       4699.999999900974, -6418.097617107514}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3623.274741665932, -6418.9336118692}, {
      3695.1039183544954`, -6418.9336118692}, {
      3695.1039183544954`, -6418.097617107514}, {
      3623.274741665932, -6418.097617107514}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.2789565091028, -6418.306615797936}, \
{100.69695388994565`, -6418.097617107514}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.69695388994565`, -6418.306615797936}, 0.41799738084284777`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.69695388994565`, -6418.724613178779}, {
       3622.8567442850895`, -6418.724613178779}, {
       3622.8567442850895`, -6418.306615797936}, {
       100.69695388994565`, -6418.306615797936}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3622.8567442850895`, -6418.724613178779}, 
       0.41799738084284777`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3622.8567442850895`, -6418.9336118692}, \
{3623.274741665932, -6418.724613178779}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.934670366529}, {
        100.2789565091028, -6418.934670366529}, {
        100.2789565091028, -6418.9336118692}, {100, -6418.9336118692}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.934670366529}, {
       1278.5769019778077`, -6418.934670366529}, {
       1278.5769019778077`, -6418.9336118692}, {
       600.1763667716721, -6418.9336118692}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.272895661467, -6418.934670366529}, {
       1329.1183681898394`, -6418.934670366529}, {
       1329.1183681898394`, -6418.9336118692}, {
       1247.272895661467, -6418.9336118692}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6418.934670366529}, {
       1601.2816844331437`, -6418.934670366529}, {
       1601.2816844331437`, -6418.9336118692}, {
       1601.2816618963811`, -6418.9336118692}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.934670366529}, {
       2652.513203652233, -6418.934670366529}, {
       2652.513203652233, -6418.9336118692}, {
       2511.316045668549, -6418.9336118692}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.934670366529}, {
       2584.883513211886, -6418.934670366529}, {
       2584.883513211886, -6418.9336118692}, {
       2584.881870636578, -6418.9336118692}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567442850895`, -6418.934670366529}, {
       3695.1039183544954`, -6418.934670366529}, {
       3695.1039183544954`, -6418.9336118692}, {
       3622.8567442850895`, -6418.9336118692}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.934670366529}, {
       4142.649334879302, -6418.934670366529}, {
       4142.649334879302, -6418.9336118692}, {
       4116.626941324208, -6418.9336118692}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.934670366529}, {
       4700., -6418.934670366529}, {4700., -6418.9336118692}, {
       4699.999999900974, -6418.9336118692}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0553481428838`, -6418.934670366529}, {
      3136.061463831328, -6418.934670366529}, {
      3136.061463831328, -6418.9336118692}, {
      3136.0553481428838`, -6418.9336118692}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883513211886, -6418.933876493532}, \
{2584.8840424605505`, -6418.9336118692}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8840424605505`, -6418.933876493532}, 
       0.0005292486644283335, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8840424605505`, -6418.934405742197}, {
       3136.0548188942194`, -6418.934405742197}, {
       3136.0548188942194`, -6418.933876493532}, {
       2584.8840424605505`, -6418.933876493532}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548188942194`, -6418.934405742197}, 
       0.0005292486644283335, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548188942194`, -6418.934670366529}, \
{3136.0553481428838`, -6418.934405742197}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6418.934702217863}, {
        100.2789565091028, -6418.934702217863}, {
        100.2789565091028, -6418.934670366529}, {
        100, -6418.934670366529}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6418.934702217863}, {
       1278.5769019778077`, -6418.934702217863}, {
       1278.5769019778077`, -6418.934670366529}, {
       600.1763667716721, -6418.934670366529}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.272895661467, -6418.934702217863}, {
       1329.1183681898394`, -6418.934702217863}, {
       1329.1183681898394`, -6418.934670366529}, {
       1247.272895661467, -6418.934670366529}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6418.934702217863}, {
       1601.2816685074768`, -6418.934702217863}, {
       1601.2816685074768`, -6418.934670366529}, {
       1601.2816618963811`, -6418.934670366529}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6418.934702217863}, {
       2652.513203652233, -6418.934702217863}, {
       2652.513203652233, -6418.934670366529}, {
       2511.316045668549, -6418.934670366529}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6418.934702217863}, {
       2584.883513211886, -6418.934702217863}, {
       2584.883513211886, -6418.934670366529}, {
       2584.881870636578, -6418.934670366529}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -6418.934702217863}, {
       3136.061463831328, -6418.934702217863}, {
       3136.061463831328, -6418.934670366529}, {
       3136.0548188942194`, -6418.934670366529}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6418.934702217863}, {
       4142.649334879302, -6418.934702217863}, {
       4142.649334879302, -6418.934670366529}, {
       4116.626941324208, -6418.934670366529}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6418.934702217863}, {
       4700., -6418.934702217863}, {4700., -6418.934670366529}, {
       4699.999999900974, -6418.934670366529}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3622.8567442850895`, -6418.934702217863}, {
      3695.1039183544954`, -6418.934702217863}, {
      3695.1039183544954`, -6418.934670366529}, {
      3622.8567442850895`, -6418.934670366529}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816685074768`, -6418.934678329362}, \
{1601.2816844331437`, -6418.934670366529}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816844331437`, -6418.934678329362}, 
       0.000015925666904481428`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816844331437`, -6418.934694255029}, {
       3622.8567283594225`, -6418.934694255029}, {
       3622.8567283594225`, -6418.934678329362}, {
       1601.2816844331437`, -6418.934678329362}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3622.8567283594225`, -6418.934694255029}, 
       0.000015925666904481428`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3622.8567283594225`, -6418.934702217863}, \
{3622.8567442850895`, -6418.934694255029}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6419.36132745712}, {
        100.06564388947439`, -6419.36132745712}, {
        100.06564388947439`, -6418.934702217863}, {
        100, -6418.934702217863}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6419.36132745712}, {
       1278.5769019778077`, -6419.36132745712}, {
       1278.5769019778077`, -6418.934702217863}, {
       600.1763667716721, -6418.934702217863}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6419.36132745712}, {
       1601.2816685074768`, -6419.36132745712}, {
       1601.2816685074768`, -6418.934702217863}, {
       1601.2816618963811`, -6418.934702217863}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2511.316045668549, -6419.36132745712}, {
       2652.513203652233, -6419.36132745712}, {
       2652.513203652233, -6418.934702217863}, {
       2511.316045668549, -6418.934702217863}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6419.36132745712}, {
       2584.883513211886, -6419.36132745712}, {
       2584.883513211886, -6418.934702217863}, {
       2584.881870636578, -6418.934702217863}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -6419.36132745712}, {
       3136.061463831328, -6419.36132745712}, {
       3136.061463831328, -6418.934702217863}, {
       3136.0548188942194`, -6418.934702217863}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -6419.36132745712}, {
       3695.1039183544954`, -6419.36132745712}, {
       3695.1039183544954`, -6418.934702217863}, {
       3622.8567283594225`, -6418.934702217863}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6419.36132745712}, {
       4142.649334879302, -6419.36132745712}, {
       4142.649334879302, -6418.934702217863}, {
       4116.626941324208, -6418.934702217863}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6419.36132745712}, {
       4700., -6419.36132745712}, {4700., -6418.934702217863}, {
       4699.999999900974, -6418.934702217863}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1247.272895661467, -6419.36132745712}, {
      1329.1183681898394`, -6419.36132745712}, {
      1329.1183681898394`, -6418.934702217863}, {
      1247.272895661467, -6418.934702217863}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06564388947439`, -6419.041358527677}, \
{100.2789565091028, -6418.934702217863}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.2789565091028, -6419.041358527677}, 0.21331261962840997`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.2789565091028, -6419.254671147306}, {
       1247.0595830418386`, -6419.254671147306}, {
       1247.0595830418386`, -6419.041358527677}, {
       100.2789565091028, -6419.041358527677}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1247.0595830418386`, -6419.254671147306}, 
       0.21331261962840997`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1247.0595830418386`, -6419.36132745712}, \
{1247.272895661467, -6419.254671147306}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -6628.5355758282485`}, {
        100.06564388947439`, -6628.5355758282485`}, {
        100.06564388947439`, -6419.36132745712}, {
        100, -6419.36132745712}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -6628.5355758282485`}, {
       1173.9897777922433`, -6628.5355758282485`}, {
       1173.9897777922433`, -6419.36132745712}, {
       600.1763667716721, -6419.36132745712}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.0595830418386`, -6628.5355758282485`}, {
       1329.1183681898394`, -6628.5355758282485`}, {
       1329.1183681898394`, -6419.36132745712}, {
       1247.0595830418386`, -6419.36132745712}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -6628.5355758282485`}, {
       1601.2816685074768`, -6628.5355758282485`}, {
       1601.2816685074768`, -6419.36132745712}, {
       1601.2816618963811`, -6419.36132745712}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -6628.5355758282485`}, {
       2584.883513211886, -6628.5355758282485`}, {
       2584.883513211886, -6419.36132745712}, {
       2584.881870636578, -6419.36132745712}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -6628.5355758282485`}, {
       3136.061463831328, -6628.5355758282485`}, {
       3136.061463831328, -6419.36132745712}, {
       3136.0548188942194`, -6419.36132745712}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -6628.5355758282485`}, {
       3695.1039183544954`, -6628.5355758282485`}, {
       3695.1039183544954`, -6419.36132745712}, {
       3622.8567283594225`, -6419.36132745712}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -6628.5355758282485`}, {
       4142.649334879302, -6628.5355758282485`}, {
       4142.649334879302, -6419.36132745712}, {
       4116.626941324208, -6419.36132745712}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -6628.5355758282485`}, {
       4700., -6628.5355758282485`}, {4700., -6419.36132745712}, {
       4699.999999900974, -6419.36132745712}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2511.316045668549, -6628.5355758282485`}, {
      2652.513203652233, -6628.5355758282485`}, {
      2652.513203652233, -6419.36132745712}, {
      2511.316045668549, -6419.36132745712}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1173.9897777922433`, -6471.654889549902}, \
{1278.5769019778077`, -6419.36132745712}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1278.5769019778077`, -6471.654889549902}, 104.58712418556422`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1278.5769019778077`, -6576.242013735467}, {
       2406.728921482985, -6576.242013735467}, {
       2406.728921482985, -6471.654889549902}, {
       1278.5769019778077`, -6471.654889549902}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2406.728921482985, -6576.242013735467}, 104.58712418556422`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2406.728921482985, -6628.5355758282485`}, 
       {2511.316045668549, -6576.242013735467}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7018.651659036652}, {
        100.06564388947439`, -7018.651659036652}, {
        100.06564388947439`, -6628.5355758282485`}, {
        100, -6628.5355758282485`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.0595830418386`, -7018.651659036652}, {
       1329.1183681898394`, -7018.651659036652}, {
       1329.1183681898394`, -6628.5355758282485`}, {
       1247.0595830418386`, -6628.5355758282485`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.651659036652}, {
       1601.2816685074768`, -7018.651659036652}, {
       1601.2816685074768`, -6628.5355758282485`}, {
       1601.2816618963811`, -6628.5355758282485`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7018.651659036652}, {
       2652.513203652233, -7018.651659036652}, {
       2652.513203652233, -6628.5355758282485`}, {
       2601.7869630871865`, -6628.5355758282485`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.651659036652}, {
       2584.883513211886, -7018.651659036652}, {
       2584.883513211886, -6628.5355758282485`}, {
       2584.881870636578, -6628.5355758282485`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -7018.651659036652}, {
       3136.061463831328, -7018.651659036652}, {
       3136.061463831328, -6628.5355758282485`}, {
       3136.0548188942194`, -6628.5355758282485`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.651659036652}, {
       3695.1039183544954`, -7018.651659036652}, {
       3695.1039183544954`, -6628.5355758282485`}, {
       3622.8567283594225`, -6628.5355758282485`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -7018.651659036652}, {
       4142.649334879302, -7018.651659036652}, {
       4142.649334879302, -6628.5355758282485`}, {
       4116.626941324208, -6628.5355758282485`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -7018.651659036652}, {
       4700., -7018.651659036652}, {4700., -6628.5355758282485`}, {
       4699.999999900974, -6628.5355758282485`}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1763667716721, -7018.651659036652}, {
      1173.9897777922433`, -7018.651659036652}, {
      1173.9897777922433`, -6628.5355758282485`}, {
      600.1763667716721, -6628.5355758282485`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2406.728921482985, -6726.064596630349}, \
{2601.7869630871865`, -6628.5355758282485`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2406.728921482985, -6726.064596630349}, 195.05804160420183`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1369.0478193964452`, -6921.122638234551}, {
       2406.728921482985, -6921.122638234551}, {
       2406.728921482985, -6726.064596630349}, {
       1369.0478193964452`, -6726.064596630349}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1369.0478193964452`, -6921.122638234551}, 195.05804160420183`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1173.9897777922433`, -7018.651659036652}, \
{1369.0478193964452`, -6921.122638234551}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1763667716721, -7018.771276706964}, {
       1369.0478193964452`, -7018.771276706964}, {
       1369.0478193964452`, -7018.651659036652}, {
       600.1763667716721, -7018.651659036652}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.1193918769948`, -7018.771276706964}, {
       1329.1183681898394`, -7018.771276706964}, {
       1329.1183681898394`, -7018.651659036652}, {
       1247.1193918769948`, -7018.651659036652}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.771276706964}, {
       1601.2816685074768`, -7018.771276706964}, {
       1601.2816685074768`, -7018.651659036652}, {
       1601.2816618963811`, -7018.651659036652}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7018.771276706964}, {
       2652.513203652233, -7018.771276706964}, {
       2652.513203652233, -7018.651659036652}, {
       2601.7869630871865`, -7018.651659036652}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.771276706964}, {
       2584.883513211886, -7018.771276706964}, {
       2584.883513211886, -7018.651659036652}, {
       2584.881870636578, -7018.651659036652}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -7018.771276706964}, {
       3136.061463831328, -7018.771276706964}, {
       3136.061463831328, -7018.651659036652}, {
       3136.0548188942194`, -7018.651659036652}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.771276706964}, {
       3695.1039183544954`, -7018.771276706964}, {
       3695.1039183544954`, -7018.651659036652}, {
       3622.8567283594225`, -7018.651659036652}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -7018.771276706964}, {
       4142.649334879302, -7018.771276706964}, {
       4142.649334879302, -7018.651659036652}, {
       4116.626941324208, -7018.651659036652}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -7018.771276706964}, {
       4700., -7018.771276706964}, {4700., -7018.651659036652}, {
       4699.999999900974, -7018.651659036652}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7018.771276706964}, {
       100.06564388947439`, -7018.771276706964}, {
       100.06564388947439`, -7018.651659036652}, {
       100, -7018.651659036652}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1247.0595830418386`, -7018.68156345423}, \
{1247.1193918769948`, -7018.651659036652}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1247.0595830418386`, -7018.68156345423}, 0.059808835156164614`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.12545272463055`, -7018.741372289386}, {
       1247.0595830418386`, -7018.741372289386}, {
       1247.0595830418386`, -7018.68156345423}, {
       100.12545272463055`, -7018.68156345423}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.12545272463055`, -7018.741372289386}, 
       0.059808835156164614`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06564388947439`, -7018.771276706964}, \
{100.12545272463055`, -7018.741372289386}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7018.840540875457}, {
        100.09082064038434`, -7018.840540875457}, {
        100.09082064038434`, -7018.771276706964}, {
        100, -7018.771276706964}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.1193918769948`, -7018.840540875457}, {
       1329.1183681898394`, -7018.840540875457}, {
       1329.1183681898394`, -7018.771276706964}, {
       1247.1193918769948`, -7018.771276706964}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.840540875457}, {
       1601.2816685074768`, -7018.840540875457}, {
       1601.2816685074768`, -7018.771276706964}, {
       1601.2816618963811`, -7018.771276706964}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7018.840540875457}, {
       2652.513203652233, -7018.840540875457}, {
       2652.513203652233, -7018.771276706964}, {
       2601.7869630871865`, -7018.771276706964}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.840540875457}, {
       2584.883513211886, -7018.840540875457}, {
       2584.883513211886, -7018.771276706964}, {
       2584.881870636578, -7018.771276706964}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548188942194`, -7018.840540875457}, {
       3136.061463831328, -7018.840540875457}, {
       3136.061463831328, -7018.771276706964}, {
       3136.0548188942194`, -7018.771276706964}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.840540875457}, {
       3695.1039183544954`, -7018.840540875457}, {
       3695.1039183544954`, -7018.771276706964}, {
       3622.8567283594225`, -7018.771276706964}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -7018.840540875457}, {
       4142.649334879302, -7018.840540875457}, {
       4142.649334879302, -7018.771276706964}, {
       4116.626941324208, -7018.771276706964}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -7018.840540875457}, {
       4700., -7018.840540875457}, {4700., -7018.771276706964}, {
       4699.999999900974, -7018.771276706964}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1763667716721, -7018.840540875457}, {
      1369.0478193964452`, -7018.840540875457}, {
      1369.0478193964452`, -7018.771276706964}, {
      600.1763667716721, -7018.771276706964}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.09082064038434`, -7018.788592749088}, \
{100.12545272463055`, -7018.771276706964}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.12545272463055`, -7018.788592749088}, 0.03463208424621639, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.12545272463055`, -7018.823224833334}, {
       600.1417346874258, -7018.823224833334}, {
       600.1417346874258, -7018.788592749088}, {
       100.12545272463055`, -7018.788592749088}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.1417346874258, -7018.823224833334}, 0.03463208424621639, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.1417346874258, -7018.840540875457}, \
{600.1763667716721, -7018.823224833334}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7018.845200877474}, {
        100.09082064038434`, -7018.845200877474}, {
        100.09082064038434`, -7018.840540875457}, {
        100, -7018.840540875457}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7018.845200877474}, {
       1369.0478193964452`, -7018.845200877474}, {
       1369.0478193964452`, -7018.840540875457}, {
       600.1417346874258, -7018.840540875457}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.1193918769948`, -7018.845200877474}, {
       1329.1183681898394`, -7018.845200877474}, {
       1329.1183681898394`, -7018.840540875457}, {
       1247.1193918769948`, -7018.840540875457}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.845200877474}, {
       1601.2816685074768`, -7018.845200877474}, {
       1601.2816685074768`, -7018.840540875457}, {
       1601.2816618963811`, -7018.840540875457}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.845200877474}, {
       2584.883513211886, -7018.845200877474}, {
       2584.883513211886, -7018.840540875457}, {
       2584.881870636578, -7018.840540875457}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.057148895228, -7018.845200877474}, {
       3136.0614638313286`, -7018.845200877474}, {
       3136.0614638313286`, -7018.840540875457}, {
       3136.057148895228, -7018.840540875457}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.845200877474}, {
       3695.1039183544954`, -7018.845200877474}, {
       3695.1039183544954`, -7018.840540875457}, {
       3622.8567283594225`, -7018.840540875457}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -7018.845200877474}, {
       4142.649334879302, -7018.845200877474}, {
       4142.649334879302, -7018.840540875457}, {
       4116.626941324208, -7018.840540875457}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999900974, -7018.845200877474}, {
       4700., -7018.845200877474}, {4700., -7018.840540875457}, {
       4699.999999900974, -7018.840540875457}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.7869630871865`, -7018.845200877474}, {
      2652.513203652233, -7018.845200877474}, {
      2652.513203652233, -7018.840540875457}, {
      2601.7869630871865`, -7018.840540875457}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548188942194`, -7018.841705875961}, \
{3136.057148895228, -7018.840540875457}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548188942194`, -7018.841705875961}, 0.002330001008355292,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.515533653241, -7018.844035876969}, {
       3136.0548188942194`, -7018.844035876969}, {
       3136.0548188942194`, -7018.841705875961}, {
       2652.515533653241, -7018.841705875961}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.515533653241, -7018.844035876969}, 0.002330001008355292, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.513203652233, -7018.845200877474}, \
{2652.515533653241, -7018.844035876969}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7018.845200903151}, {
        100.09082064038434`, -7018.845200903151}, {
        100.09082064038434`, -7018.845200877474}, {
        100, -7018.845200877474}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.1193918769948`, -7018.845200903151}, {
       1329.1183681898394`, -7018.845200903151}, {
       1329.1183681898394`, -7018.845200877474}, {
       1247.1193918769948`, -7018.845200877474}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.845200903151}, {
       1601.2816685074768`, -7018.845200903151}, {
       1601.2816685074768`, -7018.845200877474}, {
       1601.2816618963811`, -7018.845200877474}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7018.845200903151}, {
       2652.515533653241, -7018.845200903151}, {
       2652.515533653241, -7018.845200877474}, {
       2601.7869630871865`, -7018.845200877474}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.845200903151}, {
       2584.883513211886, -7018.845200903151}, {
       2584.883513211886, -7018.845200877474}, {
       2584.881870636578, -7018.845200877474}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.057148895228, -7018.845200903151}, {
       3136.0614638313286`, -7018.845200903151}, {
       3136.0614638313286`, -7018.845200877474}, {
       3136.057148895228, -7018.845200877474}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.845200903151}, {
       3695.1039183544954`, -7018.845200903151}, {
       3695.1039183544954`, -7018.845200877474}, {
       3622.8567283594225`, -7018.845200877474}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.626941324208, -7018.845200903151}, {
       4142.649334879302, -7018.845200903151}, {
       4142.649334879302, -7018.845200877474}, {
       4116.626941324208, -7018.845200877474}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999913813, -7018.845200903151}, {
       4700., -7018.845200903151}, {4700., -7018.845200877474}, {
       4699.999999913813, -7018.845200877474}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1417346874258, -7018.845200903151}, {
      1369.0478193964452`, -7018.845200903151}, {
      1369.0478193964452`, -7018.845200877474}, {
      600.1417346874258, -7018.845200877474}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999900974, -7018.845200883893}, \
{4699.999999913813, -7018.845200877474}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999900974, -7018.845200883893}, 
       1.2838476959422909`*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1369.0478194092836`, -7018.8452008967315`}, {
       4699.999999900974, -7018.8452008967315`}, {
       4699.999999900974, -7018.845200883893}, {
       1369.0478194092836`, -7018.845200883893}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1369.0478194092836`, -7018.8452008967315`}, 
       1.2838476959422909`*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1369.0478193964452`, -7018.845200903151}, \
{1369.0478194092836`, -7018.8452008967315`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7018.867587073336}, {
       1369.0478194092836`, -7018.867587073336}, {
       1369.0478194092836`, -7018.845200903151}, {
       600.1417346874258, -7018.845200903151}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1247.1193918769948`, -7018.867587073336}, {
       1329.1183681898394`, -7018.867587073336}, {
       1329.1183681898394`, -7018.845200903151}, {
       1247.1193918769948`, -7018.845200903151}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7018.867587073336}, {
       1601.2816685074768`, -7018.867587073336}, {
       1601.2816685074768`, -7018.845200903151}, {
       1601.2816618963811`, -7018.845200903151}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7018.867587073336}, {
       2652.515533653241, -7018.867587073336}, {
       2652.515533653241, -7018.845200903151}, {
       2601.7869630871865`, -7018.845200903151}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7018.867587073336}, {
       2584.883513211886, -7018.867587073336}, {
       2584.883513211886, -7018.845200903151}, {
       2584.881870636578, -7018.845200903151}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.057148895228, -7018.867587073336}, {
       3136.0614638313286`, -7018.867587073336}, {
       3136.0614638313286`, -7018.845200903151}, {
       3136.057148895228, -7018.845200903151}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7018.867587073336}, {
       3695.1039183544954`, -7018.867587073336}, {
       3695.1039183544954`, -7018.845200903151}, {
       3622.8567283594225`, -7018.845200903151}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7018.867587073336}, {
       4142.649334879302, -7018.867587073336}, {
       4142.649334879302, -7018.845200903151}, {
       4116.638134409301, -7018.845200903151}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999913813, -7018.867587073336}, {
       4700., -7018.867587073336}, {4700., -7018.845200903151}, {
       4699.999999913813, -7018.845200903151}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7018.867587073336}, {
       100.09082064038434`, -7018.867587073336}, {
       100.09082064038434`, -7018.845200903151}, {
       100, -7018.845200903151}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4116.626941324208, -7018.850797445697}, \
{4116.638134409301, -7018.845200903151}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4116.626941324208, -7018.850797445697}, 0.01119308509247055, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.1020137254768, -7018.86199053079}, {
       4116.626941324208, -7018.86199053079}, {
       4116.626941324208, -7018.850797445697}, {
       100.1020137254768, -7018.850797445697}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.1020137254768, -7018.86199053079}, 0.01119308509247055, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.09082064038434`, -7018.867587073336}, \
{100.1020137254768, -7018.86199053079}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7126.603868107383}, {
        100.1020137254768, -7126.603868107383}, {
        100.1020137254768, -7018.867587073336}, {
        100, -7018.867587073336}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7126.603868107383}, {
       1329.1183681898397`, -7126.603868107383}, {
       1329.1183681898397`, -7018.867587073336}, {
       1300.9875323940187`, -7018.867587073336}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816618963811`, -7126.603868107383}, {
       1601.2816685074768`, -7126.603868107383}, {
       1601.2816685074768`, -7018.867587073336}, {
       1601.2816618963811`, -7018.867587073336}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7126.603868107383}, {
       2652.515533653241, -7126.603868107383}, {
       2652.515533653241, -7018.867587073336}, {
       2601.7869630871865`, -7018.867587073336}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7126.603868107383}, {
       2584.883513211886, -7126.603868107383}, {
       2584.883513211886, -7018.867587073336}, {
       2584.881870636578, -7018.867587073336}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.057148895228, -7126.603868107383}, {
       3136.0614638313286`, -7126.603868107383}, {
       3136.0614638313286`, -7018.867587073336}, {
       3136.057148895228, -7018.867587073336}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7126.603868107383}, {
       3695.1039183544954`, -7126.603868107383}, {
       3695.1039183544954`, -7018.867587073336}, {
       3622.8567283594225`, -7018.867587073336}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7126.603868107383}, {
       4142.649334879302, -7126.603868107383}, {
       4142.649334879302, -7018.867587073336}, {
       4116.638134409301, -7018.867587073336}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999913813, -7126.603868107383}, {
       4700., -7126.603868107383}, {4700., -7018.867587073336}, {
       4699.999999913813, -7018.867587073336}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1417346874258, -7126.603868107383}, {
      1369.0478194092836`, -7126.603868107383}, {
      1369.0478194092836`, -7018.867587073336}, {
      600.1417346874258, -7018.867587073336}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1247.119391876995, -7045.801657331847}, \
{1300.9875323940187`, -7018.867587073336}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1247.119391876995, -7045.801657331847}, 53.86814051702379, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1422.9159599263076`, -7099.669797848871}, {
       1247.119391876995, -7099.669797848871}, {
       1247.119391876995, -7045.801657331847}, {
       1422.9159599263076`, -7045.801657331847}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1422.9159599263076`, -7099.669797848871}, 53.86814051702379, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1369.0478194092836`, -7126.603868107383}, \
{1422.9159599263076`, -7099.669797848871}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7126.603879192574}, {
       1422.9159599263076`, -7126.603879192574}, {
       1422.9159599263076`, -7126.603868107383}, {
       600.1417346874258, -7126.603868107383}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7126.603879192574}, {
       1329.1183681898397`, -7126.603879192574}, {
       1329.1183681898397`, -7126.603868107383}, {
       1300.9875323940187`, -7126.603868107383}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816674389767`, -7126.603879192574}, {
       1601.2816685074768`, -7126.603879192574}, {
       1601.2816685074768`, -7126.603868107383}, {
       1601.2816674389767`, -7126.603868107383}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7126.603879192574}, {
       2652.515533653241, -7126.603879192574}, {
       2652.515533653241, -7126.603868107383}, {
       2601.7869630871865`, -7126.603868107383}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7126.603879192574}, {
       2584.883513211886, -7126.603879192574}, {
       2584.883513211886, -7126.603868107383}, {
       2584.881870636578, -7126.603868107383}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.057148895228, -7126.603879192574}, {
       3136.0614638313286`, -7126.603879192574}, {
       3136.0614638313286`, -7126.603868107383}, {
       3136.057148895228, -7126.603868107383}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7126.603879192574}, {
       3695.1039183544954`, -7126.603879192574}, {
       3695.1039183544954`, -7126.603868107383}, {
       3622.8567283594225`, -7126.603868107383}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7126.603879192574}, {
       4142.649334879302, -7126.603879192574}, {
       4142.649334879302, -7126.603868107383}, {
       4116.638134409301, -7126.603868107383}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999913813, -7126.603879192574}, {
       4700., -7126.603879192574}, {4700., -7126.603868107383}, {
       4699.999999913813, -7126.603868107383}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7126.603879192574}, {
       100.1020137254768, -7126.603879192574}, {
       100.1020137254768, -7126.603868107383}, {
       100, -7126.603868107383}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816618963811`, -7126.603870878681}, \
{1601.2816674389767`, -7126.603868107383}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816618963811`, -7126.603870878681}, 
       5.542595457519525*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.10201926807225`, -7126.603876421276}, {
       1601.2816618963811`, -7126.603876421276}, {
       1601.2816618963811`, -7126.603870878681}, {
       100.10201926807225`, -7126.603870878681}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.10201926807225`, -7126.603876421276}, 
       5.542595457519525*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.1020137254768, -7126.603879192574}, \
{100.10201926807225`, -7126.603876421276}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7126.604962314674}, {
        100.10201926807225`, -7126.604962314674}, {
        100.10201926807225`, -7126.603879192574}, {
        100, -7126.603879192574}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7126.604962314674}, {
       1422.9159599263076`, -7126.604962314674}, {
       1422.9159599263076`, -7126.603879192574}, {
       600.1417346874258, -7126.603879192574}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816674389767`, -7126.604962314674}, {
       1601.2816685074768`, -7126.604962314674}, {
       1601.2816685074768`, -7126.603879192574}, {
       1601.2816674389767`, -7126.603879192574}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7126.604962314674}, {
       2652.515533653241, -7126.604962314674}, {
       2652.515533653241, -7126.603879192574}, {
       2601.7869630871865`, -7126.603879192574}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7126.604962314674}, {
       2584.883513211886, -7126.604962314674}, {
       2584.883513211886, -7126.603879192574}, {
       2584.881870636578, -7126.603879192574}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0576904562777`, -7126.604962314674}, {
       3136.0614638313286`, -7126.604962314674}, {
       3136.0614638313286`, -7126.603879192574}, {
       3136.0576904562777`, -7126.603879192574}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7126.604962314674}, {
       3695.1039183544954`, -7126.604962314674}, {
       3695.1039183544954`, -7126.603879192574}, {
       3622.8567283594225`, -7126.603879192574}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7126.604962314674}, {
       4142.649334879302, -7126.604962314674}, {
       4142.649334879302, -7126.603879192574}, {
       4116.638134409301, -7126.603879192574}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999913813, -7126.604962314674}, {
       4700., -7126.604962314674}, {4700., -7126.603879192574}, {
       4699.999999913813, -7126.603879192574}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1300.9875323940187`, -7126.604962314674}, {
      1329.1183681898397`, -7126.604962314674}, {
      1329.1183681898397`, -7126.603879192574}, {
      1300.9875323940187`, -7126.603879192574}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.057148895228, -7126.604149973099}, \
{3136.0576904562777`, -7126.603879192574}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.057148895228, -7126.604149973099}, 0.0005415610496728417, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1329.1189097508893`, -7126.6046915341485`}, {
       3136.057148895228, -7126.6046915341485`}, {
       3136.057148895228, -7126.604149973099}, {
       1329.1189097508893`, -7126.604149973099}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1329.1189097508893`, -7126.6046915341485`}, 
       0.0005415610496728417, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.1183681898397`, -7126.604962314674}, \
{1329.1189097508893`, -7126.6046915341485`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7126.604962344}, {
        100.10201925340914`, -7126.604962344}, {
        100.10201925340914`, -7126.604962314674}, {
        100, -7126.604962314674}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7126.604962344}, {
       1422.9159599263076`, -7126.604962344}, {
       1422.9159599263076`, -7126.604962314674}, {
       600.1417346874258, -7126.604962314674}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7126.604962344}, {
       1329.1189097508893`, -7126.604962344}, {
       1329.1189097508893`, -7126.604962314674}, {
       1300.9875323940187`, -7126.604962314674}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816674389767`, -7126.604962344}, {
       1601.2816685074768`, -7126.604962344}, {
       1601.2816685074768`, -7126.604962314674}, {
       1601.2816674389767`, -7126.604962314674}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7126.604962344}, {
       2652.515533653241, -7126.604962344}, {
       2652.515533653241, -7126.604962314674}, {
       2601.7869630871865`, -7126.604962314674}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7126.604962344}, {
       2584.883513211886, -7126.604962344}, {
       2584.883513211886, -7126.604962314674}, {
       2584.881870636578, -7126.604962314674}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0576904562777`, -7126.604962344}, {
       3136.0614638313286`, -7126.604962344}, {
       3136.0614638313286`, -7126.604962314674}, {
       3136.0576904562777`, -7126.604962314674}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7126.604962344}, {
       3695.1039183544954`, -7126.604962344}, {
       3695.1039183544954`, -7126.604962314674}, {
       3622.8567283594225`, -7126.604962314674}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7126.604962344}, {
       4142.649334879302, -7126.604962344}, {
       4142.649334879302, -7126.604962314674}, {
       4116.638134409301, -7126.604962314674}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999913813, -7126.604962344}, {
      4700., -7126.604962344}, {4700., -7126.604962314674}, {
      4699.999999913813, -7126.604962314674}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.10201925340914`, -7126.604962322006}, \
{100.10201926807225`, -7126.604962314674}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.10201926807225`, -7126.604962322006}, 
       1.4663115291005882`*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.10201926807225`, -7126.604962336669}, {
       4699.99999989915, -7126.604962336669}, {
       4699.99999989915, -7126.604962322006}, {
       100.10201926807225`, -7126.604962322006}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99999989915, -7126.604962336669}, 
       1.4663115291005882`*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99999989915, -7126.604962344}, \
{4699.999999913813, -7126.604962336669}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7126.604963780311}, {
        100.10201925340914`, -7126.604963780311}, {
        100.10201925340914`, -7126.604962344}, {100, -7126.604962344}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7126.604963780311}, {
       1422.9159599263076`, -7126.604963780311}, {
       1422.9159599263076`, -7126.604962344}, {
       600.1417346874258, -7126.604962344}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7126.604963780311}, {
       1601.2816685074768`, -7126.604963780311}, {
       1601.2816685074768`, -7126.604962344}, {
       1601.2816681571321`, -7126.604962344}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7126.604963780311}, {
       2652.515533653241, -7126.604963780311}, {
       2652.515533653241, -7126.604962344}, {
       2601.7869630871865`, -7126.604962344}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7126.604963780311}, {
       2584.883513211886, -7126.604963780311}, {
       2584.883513211886, -7126.604962344}, {
       2584.881870636578, -7126.604962344}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0576904562777`, -7126.604963780311}, {
       3136.0614638313286`, -7126.604963780311}, {
       3136.0614638313286`, -7126.604962344}, {
       3136.0576904562777`, -7126.604962344}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3622.8567283594225`, -7126.604963780311}, {
       3695.1039183544954`, -7126.604963780311}, {
       3695.1039183544954`, -7126.604962344}, {
       3622.8567283594225`, -7126.604962344}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7126.604963780311}, {
       4142.649334879302, -7126.604963780311}, {
       4142.649334879302, -7126.604962344}, {
       4116.638134409301, -7126.604962344}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999989915, -7126.604963780311}, {
       4700., -7126.604963780311}, {4700., -7126.604962344}, {
       4699.99999989915, -7126.604962344}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1300.9875323940187`, -7126.604963780311}, {
      1329.1189097508893`, -7126.604963780311}, {
      1329.1189097508893`, -7126.604962344}, {
      1300.9875323940187`, -7126.604962344}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816674389767`, -7126.604962703078}, \
{1601.2816681571321`, -7126.604962344}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816674389767`, -7126.604962703078}, 
       7.181554319826643*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1329.1189104690447`, -7126.604963421233}, {
       1601.2816674389767`, -7126.604963421233}, {
       1601.2816674389767`, -7126.604962703078}, {
       1329.1189104690447`, -7126.604962703078}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1329.1189104690447`, -7126.604963421233}, 
       7.181554319826643*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.1189097508893`, -7126.604963780311}, \
{1329.1189104690447`, -7126.604963421233}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7136.365162431445}, {
        100.10201925340914`, -7136.365162431445}, {
        100.10201925340914`, -7126.604963780311}, {
        100, -7126.604963780311}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7136.365162431445}, {
       1422.9159599263076`, -7136.365162431445}, {
       1422.9159599263076`, -7126.604963780311}, {
       600.1417346874258, -7126.604963780311}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7136.365162431445}, {
       1601.2816685074768`, -7136.365162431445}, {
       1601.2816685074768`, -7126.604963780311}, {
       1601.2816681571321`, -7126.604963780311}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7136.365162431445}, {
       2652.515533653241, -7136.365162431445}, {
       2652.515533653241, -7126.604963780311}, {
       2601.7869630871865`, -7126.604963780311}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7136.365162431445}, {
       2584.883513211886, -7136.365162431445}, {
       2584.883513211886, -7126.604963780311}, {
       2584.881870636578, -7126.604963780311}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0576904562777`, -7136.365162431445}, {
       3136.0614638313286`, -7136.365162431445}, {
       3136.0614638313286`, -7126.604963780311}, {
       3136.0576904562777`, -7126.604963780311}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.7368276849897`, -7136.365162431445}, {
       3695.103918354495, -7136.365162431445}, {
       3695.103918354495, -7126.604963780311}, {
       3627.7368276849897`, -7126.604963780311}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4116.638134409301, -7136.365162431445}, {
       4142.649334879302, -7136.365162431445}, {
       4142.649334879302, -7126.604963780311}, {
       4116.638134409301, -7126.604963780311}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999989915, -7136.365162431445}, {
       4700., -7136.365162431445}, {4700., -7126.604963780311}, {
       4699.99999989915, -7126.604963780311}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1300.9875323940187`, -7136.365162431445}, {
      1329.1189104690447`, -7136.365162431445}, {
      1329.1189104690447`, -7126.604963780311}, {
      1300.9875323940187`, -7126.604963780311}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3622.8567283594225`, -7129.045013443094}, \
{3627.7368276849897`, -7126.604963780311}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3622.8567283594225`, -7129.045013443094}, 4.880099325567382, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1333.999009794612, -7133.925112768661}, {
       3622.8567283594225`, -7133.925112768661}, {
       3622.8567283594225`, -7129.045013443094}, {
       1333.999009794612, -7129.045013443094}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1333.999009794612, -7133.925112768661}, 4.880099325567382, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.1189104690447`, -7136.365162431445}, \
{1333.999009794612, -7133.925112768661}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.679621158977}, {
        100.10201925340914`, -7150.679621158977}, {
        100.10201925340914`, -7136.365162431445}, {
        100, -7136.365162431445}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.679621158977}, {
       1422.9159599263076`, -7150.679621158977}, {
       1422.9159599263076`, -7136.365162431445}, {
       600.1417346874258, -7136.365162431445}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.679621158977}, {
       1333.999009794612, -7150.679621158977}, {
       1333.999009794612, -7136.365162431445}, {
       1300.9875323940187`, -7136.365162431445}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.679621158977}, {
       1601.2816685074768`, -7150.679621158977}, {
       1601.2816685074768`, -7136.365162431445}, {
       1601.2816681571321`, -7136.365162431445}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7150.679621158977}, {
       2584.883513211886, -7150.679621158977}, {
       2584.883513211886, -7136.365162431445}, {
       2584.881870636578, -7136.365162431445}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0576904562777`, -7150.679621158977}, {
       3136.0614638313286`, -7150.679621158977}, {
       3136.0614638313286`, -7136.365162431445}, {
       3136.0576904562777`, -7136.365162431445}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.7368276849897`, -7150.679621158977}, {
       3695.103918354495, -7150.679621158977}, {
       3695.103918354495, -7136.365162431445}, {
       3627.7368276849897`, -7136.365162431445}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.679621158977}, {
       4142.649334879302, -7150.679621158977}, {
       4142.649334879302, -7136.365162431445}, {
       4123.795363773067, -7136.365162431445}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999989915, -7150.679621158977}, {
       4700., -7150.679621158977}, {4700., -7136.365162431445}, {
       4699.99999989915, -7136.365162431445}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.7869630871865`, -7150.679621158977}, {
      2652.515533653241, -7150.679621158977}, {
      2652.515533653241, -7136.365162431445}, {
      2601.7869630871865`, -7136.365162431445}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4116.638134409301, -7139.943777113328}, \
{4123.795363773067, -7136.365162431445}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4116.638134409301, -7139.943777113328}, 7.157229363766071, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2659.6727630170076`, -7147.101006477094}, {
       4116.638134409301, -7147.101006477094}, {
       4116.638134409301, -7139.943777113328}, {
       2659.6727630170076`, -7139.943777113328}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2659.6727630170076`, -7147.101006477094}, 7.157229363766071, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.515533653241, -7150.679621158977}, \
{2659.6727630170076`, -7147.101006477094}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.685552432858}, {
        100.09905361646906`, -7150.685552432858}, {
        100.09905361646906`, -7150.679621158977}, {
        100, -7150.679621158977}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.685552432858}, {
       1422.9159599263076`, -7150.685552432858}, {
       1422.9159599263076`, -7150.679621158977}, {
       600.1417346874258, -7150.679621158977}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.685552432858}, {
       1333.999009794612, -7150.685552432858}, {
       1333.999009794612, -7150.679621158977}, {
       1300.9875323940187`, -7150.679621158977}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.685552432858}, {
       1601.2816685074768`, -7150.685552432858}, {
       1601.2816685074768`, -7150.679621158977}, {
       1601.2816681571321`, -7150.679621158977}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.685552432858}, {
       2659.6727630170076`, -7150.685552432858}, {
       2659.6727630170076`, -7150.679621158977}, {
       2601.7869630871865`, -7150.679621158977}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7150.685552432858}, {
       2584.883513211886, -7150.685552432858}, {
       2584.883513211886, -7150.679621158977}, {
       2584.881870636578, -7150.679621158977}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.7368276849897`, -7150.685552432858}, {
       3695.103918354495, -7150.685552432858}, {
       3695.103918354495, -7150.679621158977}, {
       3627.7368276849897`, -7150.679621158977}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.685552432858}, {
       4142.649334879302, -7150.685552432858}, {
       4142.649334879302, -7150.679621158977}, {
       4123.795363773067, -7150.679621158977}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999989915, -7150.685552432858}, {
       4700., -7150.685552432858}, {4700., -7150.679621158977}, {
       4699.99999989915, -7150.679621158977}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0576904562777`, -7150.685552432858}, {
      3136.0614638313286`, -7150.685552432858}, {
      3136.0614638313286`, -7150.679621158977}, {
      3136.0576904562777`, -7150.679621158977}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.09905361646906`, -7150.6811039774475`}, \
{100.10201925340914`, -7150.679621158977}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.10201925340914`, -7150.6811039774475`}, 
       0.0029656369400817414`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.10201925340914`, -7150.684069614387}, {
       3136.0547248193375`, -7150.684069614387}, {
       3136.0547248193375`, -7150.6811039774475`}, {
       100.10201925340914`, -7150.6811039774475`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0547248193375`, -7150.684069614387}, 
       0.0029656369400817414`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0547248193375`, -7150.685552432858}, \
{3136.0576904562777`, -7150.684069614387}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.698921381377}, {
        100.09905361646906`, -7150.698921381377}, {
        100.09905361646906`, -7150.685552432858}, {
        100, -7150.685552432858}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.698921381377}, {
       1422.9159599263076`, -7150.698921381377}, {
       1422.9159599263076`, -7150.685552432858}, {
       600.1417346874258, -7150.685552432858}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.698921381377}, {
       1333.999009794612, -7150.698921381377}, {
       1333.999009794612, -7150.685552432858}, {
       1300.9875323940187`, -7150.685552432858}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.698921381377}, {
       1601.2816685074768`, -7150.698921381377}, {
       1601.2816685074768`, -7150.685552432858}, {
       1601.2816681571321`, -7150.685552432858}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.698921381377}, {
       2659.6727630170076`, -7150.698921381377}, {
       2659.6727630170076`, -7150.685552432858}, {
       2601.7869630871865`, -7150.685552432858}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7150.698921381377}, {
       2584.883513211886, -7150.698921381377}, {
       2584.883513211886, -7150.685552432858}, {
       2584.881870636578, -7150.685552432858}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547248193375`, -7150.698921381377}, {
       3136.054779357069, -7150.698921381377}, {
       3136.054779357069, -7150.685552432858}, {
       3136.0547248193375`, -7150.685552432858}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.698921381377}, {
       4142.649334879302, -7150.698921381377}, {
       4142.649334879302, -7150.685552432858}, {
       4123.795363773067, -7150.685552432858}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999989915, -7150.698921381377}, {
       4700., -7150.698921381377}, {4700., -7150.685552432858}, {
       4699.99999989915, -7150.685552432858}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3627.7368276849897`, -7150.698921381377}, {
      3695.103918354495, -7150.698921381377}, {
      3695.103918354495, -7150.685552432858}, {
      3627.7368276849897`, -7150.685552432858}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054779357069, -7150.688894669987}, \
{3136.0614638313286`, -7150.685552432858}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0614638313286`, -7150.688894669987}, 0.00668447425952634, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0614638313286`, -7150.695579144247}, {
       3627.73014321073, -7150.695579144247}, {
       3627.73014321073, -7150.688894669987}, {
       3136.0614638313286`, -7150.688894669987}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3627.73014321073, -7150.695579144247}, 0.00668447425952634, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3627.73014321073, -7150.698921381377}, \
{3627.7368276849897`, -7150.695579144247}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.698921477129}, {
        100.09905361646906`, -7150.698921477129}, {
        100.09905361646906`, -7150.698921381377}, {
        100, -7150.698921381377}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.698921477129}, {
       1422.9159599263076`, -7150.698921477129}, {
       1422.9159599263076`, -7150.698921381377}, {
       600.1417346874258, -7150.698921381377}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.698921477129}, {
       1333.9990097467357`, -7150.698921477129}, {
       1333.9990097467357`, -7150.698921381377}, {
       1300.9875323940187`, -7150.698921381377}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.698921477129}, {
       1601.2816685074768`, -7150.698921477129}, {
       1601.2816685074768`, -7150.698921381377}, {
       1601.2816681571321`, -7150.698921381377}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.698921477129}, {
       2659.6727630170076`, -7150.698921477129}, {
       2659.6727630170076`, -7150.698921381377}, {
       2601.7869630871865`, -7150.698921381377}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7150.698921477129}, {
       2584.883513211886, -7150.698921477129}, {
       2584.883513211886, -7150.698921381377}, {
       2584.881870636578, -7150.698921381377}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547248193375`, -7150.698921477129}, {
       3136.054779357069, -7150.698921477129}, {
       3136.054779357069, -7150.698921381377}, {
       3136.0547248193375`, -7150.698921381377}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.698921477129}, {
       3695.103918354495, -7150.698921477129}, {
       3695.103918354495, -7150.698921381377}, {
       3627.73014321073, -7150.698921381377}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.698921477129}, {
       4142.649334879302, -7150.698921477129}, {
       4142.649334879302, -7150.698921381377}, {
       4123.795363773067, -7150.698921381377}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.99999989915, -7150.698921477129}, {
      4700., -7150.698921477129}, {4700., -7150.698921381377}, {
      4699.99999989915, -7150.698921381377}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1333.9990097467357`, -7150.698921405315}, \
{1333.999009794612, -7150.698921381377}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1333.999009794612, -7150.698921405315}, 4.787638591400287*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1333.999009794612, -7150.698921453191}, {
       4699.999999851273, -7150.698921453191}, {
       4699.999999851273, -7150.698921405315}, {
       1333.999009794612, -7150.698921405315}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999851273, -7150.698921453191}, 
       4.787638591400287*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999851273, -7150.698921477129}, \
{4699.99999989915, -7150.698921453191}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.698939350607}, {
        100.0990446797298, -7150.698939350607}, {
        100.0990446797298, -7150.698921477129}, {
        100, -7150.698921477129}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.698939350607}, {
       1422.9159599263076`, -7150.698939350607}, {
       1422.9159599263076`, -7150.698921477129}, {
       600.1417346874258, -7150.698921477129}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.698939350607}, {
       1333.9990097467357`, -7150.698939350607}, {
       1333.9990097467357`, -7150.698921477129}, {
       1300.9875323940187`, -7150.698921477129}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.698939350607}, {
       1601.2816685074768`, -7150.698939350607}, {
       1601.2816685074768`, -7150.698921477129}, {
       1601.2816681571321`, -7150.698921477129}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.698939350607}, {
       2659.6727630170076`, -7150.698939350607}, {
       2659.6727630170076`, -7150.698921477129}, {
       2601.7869630871865`, -7150.698921477129}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881870636578, -7150.698939350607}, {
       2584.883513211886, -7150.698939350607}, {
       2584.883513211886, -7150.698921477129}, {
       2584.881870636578, -7150.698921477129}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.698939350607}, {
       3695.103918354495, -7150.698939350607}, {
       3695.103918354495, -7150.698921477129}, {
       3627.73014321073, -7150.698921477129}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.698939350607}, {
       4142.649334879302, -7150.698939350607}, {
       4142.649334879302, -7150.698921477129}, {
       4123.795363773067, -7150.698921477129}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999851273, -7150.698939350607}, {
       4700., -7150.698939350607}, {4700., -7150.698921477129}, {
       4699.999999851273, -7150.698921477129}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0547248193375`, -7150.698939350607}, {
      3136.0547793570695`, -7150.698939350607}, {
      3136.0547793570695`, -7150.698921477129}, {
      3136.0547248193375`, -7150.698921477129}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0990446797298, -7150.698925945499}, \
{100.09905361646906`, -7150.698921477129}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.09905361646906`, -7150.698925945499}, 
       8.936739259389975*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.09905361646906`, -7150.698934882238}, {
       3136.0547158825984`, -7150.698934882238}, {
       3136.0547158825984`, -7150.698925945499}, {
       100.09905361646906`, -7150.698925945499}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0547158825984`, -7150.698934882238}, 
       8.936739259389975*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0547158825984`, -7150.698939350607}, \
{3136.0547248193375`, -7150.698934882238}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.70072848599}, {
        100.0990446797298, -7150.70072848599}, {
        100.0990446797298, -7150.698939350607}, {
        100, -7150.698939350607}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1417346874258, -7150.70072848599}, {
       1422.9159599263076`, -7150.70072848599}, {
       1422.9159599263076`, -7150.698939350607}, {
       600.1417346874258, -7150.698939350607}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.70072848599}, {
       1333.9990097467357`, -7150.70072848599}, {
       1333.9990097467357`, -7150.698939350607}, {
       1300.9875323940187`, -7150.698939350607}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.70072848599}, {
       1601.2816685074768`, -7150.70072848599}, {
       1601.2816685074768`, -7150.698939350607}, {
       1601.2816681571321`, -7150.698939350607}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882765204269, -7150.70072848599}, {
       2584.8835132118857`, -7150.70072848599}, {
       2584.8835132118857`, -7150.698939350607}, {
       2584.882765204269, -7150.698939350607}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.70072848599}, {
       3136.0547793570695`, -7150.70072848599}, {
       3136.0547793570695`, -7150.698939350607}, {
       3136.0547158825984`, -7150.698939350607}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.70072848599}, {
       3695.103918354495, -7150.70072848599}, {
       3695.103918354495, -7150.698939350607}, {
       3627.73014321073, -7150.698939350607}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.70072848599}, {
       4142.649334879302, -7150.70072848599}, {
       4142.649334879302, -7150.698939350607}, {
       4123.795363773067, -7150.698939350607}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999851273, -7150.70072848599}, {
       4700., -7150.70072848599}, {4700., -7150.698939350607}, {
       4699.999999851273, -7150.698939350607}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.7869630871865`, -7150.70072848599}, {
      2659.6727630170076`, -7150.70072848599}, {
      2659.6727630170076`, -7150.698939350607}, {
      2601.7869630871865`, -7150.698939350607}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881870636578, -7150.699386634453}, \
{2584.882765204269, -7150.698939350607}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881870636578, -7150.699386634453}, 0.0008945676915237412, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2659.673657584699, -7150.700281202145}, {
       2584.881870636578, -7150.700281202145}, {
       2584.881870636578, -7150.699386634453}, {
       2659.673657584699, -7150.699386634453}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2659.673657584699, -7150.700281202145}, 0.0008945676915237412, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2659.6727630170076`, -7150.70072848599}, \
{2659.673657584699, -7150.700281202145}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.700728681614}, {
        100.0990446797298, -7150.700728681614}, {
        100.0990446797298, -7150.70072848599}, {100, -7150.70072848599}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.700728681614}, {
       1333.9990097467357`, -7150.700728681614}, {
       1333.9990097467357`, -7150.70072848599}, {
       1300.9875323940187`, -7150.70072848599}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.700728681614}, {
       1601.2816685074768`, -7150.700728681614}, {
       1601.2816685074768`, -7150.70072848599}, {
       1601.2816681571321`, -7150.70072848599}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.700728681614}, {
       2659.673657584699, -7150.700728681614}, {
       2659.673657584699, -7150.70072848599}, {
       2601.7869630871865`, -7150.70072848599}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882765204269, -7150.700728681614}, {
       2584.8835132118857`, -7150.700728681614}, {
       2584.8835132118857`, -7150.70072848599}, {
       2584.882765204269, -7150.70072848599}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.700728681614}, {
       3136.0547793570695`, -7150.700728681614}, {
       3136.0547793570695`, -7150.70072848599}, {
       3136.0547158825984`, -7150.70072848599}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.700728681614}, {
       3695.103918354495, -7150.700728681614}, {
       3695.103918354495, -7150.70072848599}, {
       3627.73014321073, -7150.70072848599}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.700728681614}, {
       4142.649334879302, -7150.700728681614}, {
       4142.649334879302, -7150.70072848599}, {
       4123.795363773067, -7150.70072848599}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999949085, -7150.700728681614}, {
       4699.999999999999, -7150.700728681614}, {
       4699.999999999999, -7150.70072848599}, {
       4699.999999949085, -7150.70072848599}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1417346874258, -7150.700728681614}, {
      1422.9159599263076`, -7150.700728681614}, {
      1422.9159599263076`, -7150.70072848599}, {
      600.1417346874258, -7150.70072848599}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999851273, -7150.700728534896}, \
{4699.999999949085, -7150.70072848599}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999851273, -7150.700728534896}, 9.781188812411036*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1422.9159600241192`, -7150.700728632708}, {
       4699.999999851273, -7150.700728632708}, {
       4699.999999851273, -7150.700728534896}, {
       1422.9159600241192`, -7150.700728534896}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1422.9159600241192`, -7150.700728632708}, 
       9.781188812411036*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1422.9159599263076`, -7150.700728681614}, \
{1422.9159600241192`, -7150.700728632708}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.780982571965}, {
        100.0589177345546, -7150.780982571965}, {
        100.0589177345546, -7150.700728681614}, {
        100, -7150.700728681614}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.780982571965}, {
       1333.9990097467357`, -7150.780982571965}, {
       1333.9990097467357`, -7150.700728681614}, {
       1300.9875323940187`, -7150.700728681614}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.780982571965}, {
       1601.2816685074768`, -7150.780982571965}, {
       1601.2816685074768`, -7150.700728681614}, {
       1601.2816681571321`, -7150.700728681614}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.780982571965}, {
       2659.673657584699, -7150.780982571965}, {
       2659.673657584699, -7150.700728681614}, {
       2601.7869630871865`, -7150.700728681614}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882765204269, -7150.780982571965}, {
       2584.8835132118857`, -7150.780982571965}, {
       2584.8835132118857`, -7150.700728681614}, {
       2584.882765204269, -7150.700728681614}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.780982571965}, {
       3136.0547793570695`, -7150.780982571965}, {
       3136.0547793570695`, -7150.700728681614}, {
       3136.0547158825984`, -7150.700728681614}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.780982571965}, {
       3695.103918354495, -7150.780982571965}, {
       3695.103918354495, -7150.700728681614}, {
       3627.73014321073, -7150.700728681614}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.780982571965}, {
       4142.649334879302, -7150.780982571965}, {
       4142.649334879302, -7150.700728681614}, {
       4123.795363773067, -7150.700728681614}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999949085, -7150.780982571965}, {
       4699.999999999999, -7150.780982571965}, {
       4699.999999999999, -7150.700728681614}, {
       4699.999999949085, -7150.700728681614}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1417346874258, -7150.780982571965}, {
      1422.9159600241192`, -7150.780982571965}, {
      1422.9159600241192`, -7150.700728681614}, {
      600.1417346874258, -7150.700728681614}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0589177345546, -7150.720792154202}, \
{100.0990446797298, -7150.700728681614}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0990446797298, -7150.720792154202}, 0.04012694517521001, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0990446797298, -7150.760919099377}, {
       600.1016077422506, -7150.760919099377}, {
       600.1016077422506, -7150.720792154202}, {
       100.0990446797298, -7150.720792154202}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.1016077422506, -7150.760919099377}, 0.04012694517521001, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.1016077422506, -7150.780982571965}, \
{600.1417346874258, -7150.760919099377}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.78098258101}, {
        100.05891773003194`, -7150.78098258101}, {
        100.05891773003194`, -7150.780982571965}, {
        100, -7150.780982571965}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7150.78098258101}, {
       1422.9159600241192`, -7150.78098258101}, {
       1422.9159600241192`, -7150.780982571965}, {
       600.1016077422506, -7150.780982571965}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.78098258101}, {
       1333.9990097467357`, -7150.78098258101}, {
       1333.9990097467357`, -7150.780982571965}, {
       1300.9875323940187`, -7150.780982571965}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.78098258101}, {
       1601.2816685074768`, -7150.78098258101}, {
       1601.2816685074768`, -7150.780982571965}, {
       1601.2816681571321`, -7150.780982571965}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.78098258101}, {
       2659.673657584699, -7150.78098258101}, {
       2659.673657584699, -7150.780982571965}, {
       2601.7869630871865`, -7150.780982571965}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882765204269, -7150.78098258101}, {
       2584.8835132118857`, -7150.78098258101}, {
       2584.8835132118857`, -7150.780982571965}, {
       2584.882765204269, -7150.780982571965}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.78098258101}, {
       3136.0547793570695`, -7150.78098258101}, {
       3136.0547793570695`, -7150.780982571965}, {
       3136.0547158825984`, -7150.780982571965}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.78098258101}, {
       3695.103918354495, -7150.78098258101}, {
       3695.103918354495, -7150.780982571965}, {
       3627.73014321073, -7150.780982571965}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.78098258101}, {
       4142.649334879302, -7150.78098258101}, {
       4142.649334879302, -7150.780982571965}, {
       4123.795363773067, -7150.780982571965}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999949085, -7150.78098258101}, {
      4699.999999999999, -7150.78098258101}, {
      4699.999999999999, -7150.780982571965}, {
      4699.999999949085, -7150.780982571965}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.05891773003194`, -7150.780982574226}, \
{100.0589177345546, -7150.780982571965}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0589177345546, -7150.780982574226}, 
       4.5226579807702514`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0589177345546, -7150.780982578749}, {
       4699.999999944562, -7150.780982578749}, {
       4699.999999944562, -7150.780982574226}, {
       100.0589177345546, -7150.780982574226}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999944562, -7150.780982578749}, 
       4.5226579807702514`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999944562, -7150.78098258101}, \
{4699.999999949085, -7150.780982578749}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.781180301608}, {
        100.05881886973293`, -7150.781180301608}, {
        100.05881886973293`, -7150.78098258101}, {
        100, -7150.78098258101}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7150.781180301608}, {
       1422.9159600241192`, -7150.781180301608}, {
       1422.9159600241192`, -7150.78098258101}, {
       600.1016077422506, -7150.78098258101}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.781180301608}, {
       1333.9990097467357`, -7150.781180301608}, {
       1333.9990097467357`, -7150.78098258101}, {
       1300.9875323940187`, -7150.78098258101}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.781180301608}, {
       1601.2816685074768`, -7150.781180301608}, {
       1601.2816685074768`, -7150.78098258101}, {
       1601.2816681571321`, -7150.78098258101}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.781180301608}, {
       2659.673657584699, -7150.781180301608}, {
       2659.673657584699, -7150.78098258101}, {
       2601.7869630871865`, -7150.78098258101}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.781180301608}, {
       3136.0547793570695`, -7150.781180301608}, {
       3136.0547793570695`, -7150.78098258101}, {
       3136.0547158825984`, -7150.78098258101}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.781180301608}, {
       3695.103918354495, -7150.781180301608}, {
       3695.103918354495, -7150.78098258101}, {
       3627.73014321073, -7150.78098258101}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.781180301608}, {
       4142.649334879302, -7150.781180301608}, {
       4142.649334879302, -7150.78098258101}, {
       4123.795363773067, -7150.78098258101}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999944562, -7150.781180301608}, {
       4699.999999999999, -7150.781180301608}, {
       4699.999999999999, -7150.78098258101}, {
       4699.999999944562, -7150.78098258101}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.882765204269, -7150.781180301608}, {
      2584.8835132118857`, -7150.781180301608}, {
      2584.8835132118857`, -7150.78098258101}, {
      2584.882765204269, -7150.78098258101}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.05881886973293`, -7150.78103201116}, \
{100.05891773003194`, -7150.78098258101}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.05891773003194`, -7150.78103201116}, 
       0.00009886029900199242, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.05891773003194`, -7150.781130871459}, {
       2584.88266634397, -7150.781130871459}, {
       2584.88266634397, -7150.78103201116}, {
       100.05891773003194`, -7150.78103201116}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.88266634397, -7150.781130871459}, 
       0.00009886029900199242, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88266634397, -7150.781180301608}, \
{2584.882765204269, -7150.781130871459}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.781180398146}, {
        100.05881886973293`, -7150.781180398146}, {
        100.05881886973293`, -7150.781180301608}, {
        100, -7150.781180301608}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7150.781180398146}, {
       1422.9159600241192`, -7150.781180398146}, {
       1422.9159600241192`, -7150.781180301608}, {
       600.1016077422506, -7150.781180301608}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.781180398146}, {
       1333.9990097467357`, -7150.781180398146}, {
       1333.9990097467357`, -7150.781180301608}, {
       1300.9875323940187`, -7150.781180301608}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681571321`, -7150.781180398146}, {
       1601.2816685074768`, -7150.781180398146}, {
       1601.2816685074768`, -7150.781180301608}, {
       1601.2816681571321`, -7150.781180301608}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.781180398146}, {
       2659.673657584699, -7150.781180398146}, {
       2659.673657584699, -7150.781180301608}, {
       2601.7869630871865`, -7150.781180301608}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7150.781180398146}, {
       2584.8835132118857`, -7150.781180398146}, {
       2584.8835132118857`, -7150.781180301608}, {
       2584.88266634397, -7150.781180301608}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.781180398146}, {
       3136.0547793570695`, -7150.781180398146}, {
       3136.0547793570695`, -7150.781180301608}, {
       3136.0547158825984`, -7150.781180301608}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.781180398146}, {
       3695.103918354495, -7150.781180398146}, {
       3695.103918354495, -7150.781180301608}, {
       3627.73014321073, -7150.781180301608}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999283, -7150.781180398146}, {
       4699.999999999999, -7150.781180398146}, {
       4699.999999999999, -7150.781180301608}, {
       4699.99999999283, -7150.781180301608}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4123.795363773067, -7150.781180398146}, {
      4142.649334879302, -7150.781180398146}, {
      4142.649334879302, -7150.781180301608}, {
      4123.795363773067, -7150.781180301608}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999944562, -7150.781180325743}, \
{4699.99999999283, -7150.781180301608}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999944562, -7150.781180325743}, 4.826883569678252*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334927571, -7150.7811803740115`}, {
       4699.999999944562, -7150.7811803740115`}, {
       4699.999999944562, -7150.781180325743}, {
       4142.649334927571, -7150.781180325743}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334927571, -7150.7811803740115`}, 
       4.826883569678252*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334879302, -7150.781180398146}, \
{4142.649334927571, -7150.7811803740115`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7150.781180905841}, {
        100.05881861588537`, -7150.781180905841}, {
        100.05881861588537`, -7150.781180398146}, {
        100, -7150.781180398146}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7150.781180905841}, {
       1422.9159600241192`, -7150.781180905841}, {
       1422.9159600241192`, -7150.781180398146}, {
       600.1016077422506, -7150.781180398146}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7150.781180905841}, {
       1333.9990097467357`, -7150.781180905841}, {
       1333.9990097467357`, -7150.781180398146}, {
       1300.9875323940187`, -7150.781180398146}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7150.781180905841}, {
       2659.673657584699, -7150.781180905841}, {
       2659.673657584699, -7150.781180398146}, {
       2601.7869630871865`, -7150.781180398146}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7150.781180905841}, {
       2584.8835132118857`, -7150.781180905841}, {
       2584.8835132118857`, -7150.781180398146}, {
       2584.88266634397, -7150.781180398146}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7150.781180905841}, {
       3136.0547793570695`, -7150.781180905841}, {
       3136.0547793570695`, -7150.781180398146}, {
       3136.0547158825984`, -7150.781180398146}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7150.781180905841}, {
       3695.103918354495, -7150.781180905841}, {
       3695.103918354495, -7150.781180398146}, {
       3627.73014321073, -7150.781180398146}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.795363773067, -7150.781180905841}, {
       4142.649334927571, -7150.781180905841}, {
       4142.649334927571, -7150.781180398146}, {
       4123.795363773067, -7150.781180398146}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999283, -7150.781180905841}, {
       4699.999999999999, -7150.781180905841}, {
       4699.999999999999, -7150.781180398146}, {
       4699.99999999283, -7150.781180398146}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681571321`, -7150.781180905841}, {
      1601.281668507477, -7150.781180905841}, {
      1601.281668507477, -7150.781180398146}, {
      1601.2816681571321`, -7150.781180398146}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.05881861588537`, -7150.781180525069}, \
{100.05881886973293`, -7150.781180398146}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.05881886973293`, -7150.781180525069}, 
       2.538475642199489*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.05881886973293`, -7150.781180778918}, {
       1601.2816679032846`, -7150.781180778918}, {
       1601.2816679032846`, -7150.781180525069}, {
       100.05881886973293`, -7150.781180525069}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816679032846`, -7150.781180778918}, 
       2.538475642199489*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816679032846`, -7150.781180905841}, \
{1601.2816681571321`, -7150.781180778918}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7172.309971943076}, {
        100.05881861588537`, -7172.309971943076}, {
        100.05881861588537`, -7150.781180905841}, {
        100, -7150.781180905841}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7172.309971943076}, {
       1412.1515645055022`, -7172.309971943076}, {
       1412.1515645055022`, -7150.781180905841}, {
       600.1016077422506, -7150.781180905841}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1300.9875323940187`, -7172.309971943076}, {
       1333.9990097467357`, -7172.309971943076}, {
       1333.9990097467357`, -7150.781180905841}, {
       1300.9875323940187`, -7150.781180905841}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816679032846`, -7172.309971943076}, {
       1601.281668507477, -7172.309971943076}, {
       1601.281668507477, -7150.781180905841}, {
       1601.2816679032846`, -7150.781180905841}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7172.309971943076}, {
       2659.673657584699, -7172.309971943076}, {
       2659.673657584699, -7150.781180905841}, {
       2601.7869630871865`, -7150.781180905841}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7172.309971943076}, {
       2584.8835132118857`, -7172.309971943076}, {
       2584.8835132118857`, -7150.781180905841}, {
       2584.88266634397, -7150.781180905841}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7172.309971943076}, {
       3136.0547793570695`, -7172.309971943076}, {
       3136.0547793570695`, -7150.781180905841}, {
       3136.0547158825984`, -7150.781180905841}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7172.309971943076}, {
       3695.103918354495, -7172.309971943076}, {
       3695.103918354495, -7150.781180905841}, {
       3627.73014321073, -7150.781180905841}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999283, -7172.309971943076}, {
       4699.999999999999, -7172.309971943076}, {
       4699.999999999999, -7150.781180905841}, {
       4699.99999999283, -7150.781180905841}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4123.795363773067, -7172.309971943076}, {
      4142.6493349275715`, -7172.309971943076}, {
      4142.6493349275715`, -7150.781180905841}, {
      4123.795363773067, -7150.781180905841}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1412.1515645055022`, -7156.16337866515}, \
{1422.9159600241192`, -7150.781180905841}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1422.9159600241192`, -7156.16337866515}, 10.76439551861716, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1422.9159600241192`, -7166.927774183767}, {
       4113.03096825445, -7166.927774183767}, {
       4113.03096825445, -7156.16337866515}, {
       1422.9159600241192`, -7156.16337866515}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4113.03096825445, -7166.927774183767}, 10.76439551861716, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4113.03096825445, -7172.309971943076}, \
{4123.795363773067, -7166.927774183767}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7219.882832649582}, {
        100.05881861588537`, -7219.882832649582}, {
        100.05881861588537`, -7172.309971943076}, {
        100, -7172.309971943076}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7219.882832649582}, {
       1333.9990097467357`, -7219.882832649582}, {
       1333.9990097467357`, -7172.309971943076}, {
       1324.773962747272, -7172.309971943076}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816679032846`, -7219.882832649582}, {
       1601.281668507477, -7219.882832649582}, {
       1601.281668507477, -7172.309971943076}, {
       1601.2816679032846`, -7172.309971943076}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7219.882832649582}, {
       2659.673657584699, -7219.882832649582}, {
       2659.673657584699, -7172.309971943076}, {
       2601.7869630871865`, -7172.309971943076}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7219.882832649582}, {
       2584.8835132118857`, -7219.882832649582}, {
       2584.8835132118857`, -7172.309971943076}, {
       2584.88266634397, -7172.309971943076}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7219.882832649582}, {
       3136.0547793570695`, -7219.882832649582}, {
       3136.0547793570695`, -7172.309971943076}, {
       3136.0547158825984`, -7172.309971943076}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7219.882832649582}, {
       3695.103918354495, -7219.882832649582}, {
       3695.103918354495, -7172.309971943076}, {
       3627.73014321073, -7172.309971943076}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.03096825445, -7219.882832649582}, {
       4142.6493349275715`, -7219.882832649582}, {
       4142.6493349275715`, -7172.309971943076}, {
       4113.03096825445, -7172.309971943076}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999283, -7219.882832649582}, {
       4699.999999999999, -7219.882832649582}, {
       4699.999999999999, -7172.309971943076}, {
       4699.99999999283, -7172.309971943076}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1016077422506, -7219.882832649582}, {
      1412.1515645055022`, -7219.882832649582}, {
      1412.1515645055022`, -7172.309971943076}, {
      600.1016077422506, -7172.309971943076}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1300.9875323940187`, -7184.203187119702}, \
{1324.773962747272, -7172.309971943076}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1300.9875323940187`, -7184.203187119702}, 23.786430353253216`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1435.9379948587552`, -7207.989617472956}, {
       1300.9875323940187`, -7207.989617472956}, {
       1300.9875323940187`, -7184.203187119702}, {
       1435.9379948587552`, -7184.203187119702}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1435.9379948587552`, -7207.989617472956}, 23.786430353253216`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1412.1515645055022`, -7219.882832649582}, \
{1435.9379948587552`, -7207.989617472956}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7219.882832651891}, {
        100.05881861588537`, -7219.882832651891}, {
        100.05881861588537`, -7219.882832649582}, {
        100, -7219.882832649582}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7219.882832651891}, {
       1435.9379948587552`, -7219.882832651891}, {
       1435.9379948587552`, -7219.882832649582}, {
       600.1016077422506, -7219.882832649582}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7219.882832651891}, {
       1333.9990097467357`, -7219.882832651891}, {
       1333.9990097467357`, -7219.882832649582}, {
       1324.773962747272, -7219.882832649582}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816679032846`, -7219.882832651891}, {
       1601.281668507477, -7219.882832651891}, {
       1601.281668507477, -7219.882832649582}, {
       1601.2816679032846`, -7219.882832649582}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7219.882832651891}, {
       2659.673657584699, -7219.882832651891}, {
       2659.673657584699, -7219.882832649582}, {
       2601.7869630871865`, -7219.882832649582}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7219.882832651891}, {
       2584.8835132118857`, -7219.882832651891}, {
       2584.8835132118857`, -7219.882832649582}, {
       2584.88266634397, -7219.882832649582}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7219.882832651891}, {
       3136.0547793570695`, -7219.882832651891}, {
       3136.0547793570695`, -7219.882832649582}, {
       3136.0547158825984`, -7219.882832649582}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7219.882832651891}, {
       3695.103918354495, -7219.882832651891}, {
       3695.103918354495, -7219.882832649582}, {
       3627.73014321073, -7219.882832649582}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999993985, -7219.882832651891}, {
       4699.999999999999, -7219.882832651891}, {
       4699.999999999999, -7219.882832649582}, {
       4699.999999993985, -7219.882832649582}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4113.03096825445, -7219.882832651891}, {
      4142.6493349275715`, -7219.882832651891}, {
      4142.6493349275715`, -7219.882832649582}, {
      4113.03096825445, -7219.882832649582}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99999999283, -7219.88283265016}, \
{4699.999999993985, -7219.882832649582}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99999999283, -7219.88283265016}, 1.1540506136270424`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928726, -7219.882832651314}, {
       4699.99999999283, -7219.882832651314}, {
       4699.99999999283, -7219.88283265016}, {
       4142.649334928726, -7219.88283265016}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928726, -7219.882832651314}, 
       1.1540506136270424`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.6493349275715`, -7219.882832651891}, \
{4142.649334928726, -7219.882832651314}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7219.882832991114}, {
        100.05881861588537`, -7219.882832991114}, {
        100.05881861588537`, -7219.882832651891}, {
        100, -7219.882832651891}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7219.882832991114}, {
       1435.9379948587552`, -7219.882832991114}, {
       1435.9379948587552`, -7219.882832651891}, {
       600.1016077422506, -7219.882832651891}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7219.882832991114}, {
       1333.999009577124, -7219.882832991114}, {
       1333.999009577124, -7219.882832651891}, {
       1324.773962747272, -7219.882832651891}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7219.882832991114}, {
       2659.673657584699, -7219.882832991114}, {
       2659.673657584699, -7219.882832651891}, {
       2601.7869630871865`, -7219.882832651891}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7219.882832991114}, {
       2584.8835132118857`, -7219.882832991114}, {
       2584.8835132118857`, -7219.882832651891}, {
       2584.88266634397, -7219.882832651891}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7219.882832991114}, {
       3136.0547793570695`, -7219.882832991114}, {
       3136.0547793570695`, -7219.882832651891}, {
       3136.0547158825984`, -7219.882832651891}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3627.73014321073, -7219.882832991114}, {
       3695.103918354495, -7219.882832991114}, {
       3695.103918354495, -7219.882832651891}, {
       3627.73014321073, -7219.882832651891}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.03096825445, -7219.882832991114}, {
       4142.649334928726, -7219.882832991114}, {
       4142.649334928726, -7219.882832651891}, {
       4113.03096825445, -7219.882832651891}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999993985, -7219.882832991114}, {
       4699.999999999999, -7219.882832991114}, {
       4699.999999999999, -7219.882832651891}, {
       4699.999999993985, -7219.882832651891}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816679032846`, -7219.882832991114}, {
      1601.281668507477, -7219.882832991114}, {
      1601.281668507477, -7219.882832651891}, {
      1601.2816679032846`, -7219.882832651891}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1333.999009577124, -7219.882832736696}, \
{1333.9990097467357`, -7219.882832651891}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1333.9990097467357`, -7219.882832736696}, 
       1.6961168155854248`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1333.9990097467357`, -7219.882832906308}, {
       1601.281667733673, -7219.882832906308}, {
       1601.281667733673, -7219.882832736696}, {
       1333.9990097467357`, -7219.882832736696}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281667733673, -7219.882832906308}, 
       1.6961168155854248`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281667733673, -7219.882832991114}, \
{1601.2816679032846`, -7219.882832906308}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7305.125512440495}, {
        100.05881861588537`, -7305.125512440495}, {
        100.05881861588537`, -7219.882832991114}, {
        100, -7219.882832991114}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7305.125512440495}, {
       1435.9379948587552`, -7305.125512440495}, {
       1435.9379948587552`, -7219.882832991114}, {
       600.1016077422506, -7219.882832991114}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7305.125512440495}, {
       1333.999009577124, -7305.125512440495}, {
       1333.999009577124, -7219.882832991114}, {
       1324.773962747272, -7219.882832991114}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7305.125512440495}, {
       1601.281668507477, -7305.125512440495}, {
       1601.281668507477, -7219.882832991114}, {
       1601.281667733673, -7219.882832991114}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7305.125512440495}, {
       2617.0523178600083`, -7305.125512440495}, {
       2617.0523178600083`, -7219.882832991114}, {
       2601.7869630871865`, -7219.882832991114}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7305.125512440495}, {
       2584.8835132118857`, -7305.125512440495}, {
       2584.8835132118857`, -7219.882832991114}, {
       2584.88266634397, -7219.882832991114}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7305.125512440495}, {
       3136.0547793570695`, -7305.125512440495}, {
       3136.0547793570695`, -7219.882832991114}, {
       3136.0547158825984`, -7219.882832991114}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.03096825445, -7305.125512440495}, {
       4142.649334928726, -7305.125512440495}, {
       4142.649334928726, -7219.882832991114}, {
       4113.03096825445, -7219.882832991114}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999993985, -7305.125512440495}, {
       4699.999999999999, -7305.125512440495}, {
       4699.999999999999, -7219.882832991114}, {
       4699.999999993985, -7219.882832991114}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3627.73014321073, -7305.125512440495}, {
      3695.103918354495, -7305.125512440495}, {
      3695.103918354495, -7219.882832991114}, {
      3627.73014321073, -7219.882832991114}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2617.0523178600083`, -7241.193502853459}, \
{2659.673657584699, -7219.882832991114}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2659.673657584699, -7241.193502853459}, 42.62133972469055, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2659.673657584699, -7283.81484257815}, {
       3585.1088034860395`, -7283.81484257815}, {
       3585.1088034860395`, -7241.193502853459}, {
       2659.673657584699, -7241.193502853459}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3585.1088034860395`, -7283.81484257815}, 42.62133972469055, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3585.1088034860395`, -7305.125512440495}, \
{3627.73014321073, -7283.81484257815}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7305.169204747769}, {
       1435.9379948587552`, -7305.169204747769}, {
       1435.9379948587552`, -7305.125512440495}, {
       600.1016077422506, -7305.125512440495}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7305.169204747769}, {
       1333.999009577124, -7305.169204747769}, {
       1333.999009577124, -7305.125512440495}, {
       1324.773962747272, -7305.125512440495}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7305.169204747769}, {
       1601.281668507477, -7305.169204747769}, {
       1601.281668507477, -7305.125512440495}, {
       1601.281667733673, -7305.125512440495}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7305.169204747769}, {
       2617.0523178600083`, -7305.169204747769}, {
       2617.0523178600083`, -7305.125512440495}, {
       2601.7869630871865`, -7305.125512440495}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7305.169204747769}, {
       2584.8835132118857`, -7305.169204747769}, {
       2584.8835132118857`, -7305.125512440495}, {
       2584.88266634397, -7305.125512440495}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7305.169204747769}, {
       3136.0547793570695`, -7305.169204747769}, {
       3136.0547793570695`, -7305.125512440495}, {
       3136.0547158825984`, -7305.125512440495}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1306496396764`, -7305.169204747769}, {
       3695.103918354495, -7305.169204747769}, {
       3695.103918354495, -7305.125512440495}, {
       3585.1306496396764`, -7305.125512440495}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.03096825445, -7305.169204747769}, {
       4142.649334928726, -7305.169204747769}, {
       4142.649334928726, -7305.125512440495}, {
       4113.03096825445, -7305.125512440495}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999993985, -7305.169204747769}, {
       4699.999999999999, -7305.169204747769}, {
       4699.999999999999, -7305.125512440495}, {
       4699.999999993985, -7305.125512440495}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7305.169204747769}, {
       100.05881861588537`, -7305.169204747769}, {
       100.05881861588537`, -7305.125512440495}, {
       100, -7305.125512440495}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3585.1088034860395`, -7305.136435517314}, \
{3585.1306496396764`, -7305.125512440495}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3585.1088034860395`, -7305.136435517314}, 
       0.021846153636854486`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.08066476952223`, -7305.158281670951}, {
       3585.1088034860395`, -7305.158281670951}, {
       3585.1088034860395`, -7305.136435517314}, {
       100.08066476952223`, -7305.136435517314}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.08066476952223`, -7305.158281670951}, 
       0.021846153636854486`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.05881861588537`, -7305.169204747769}, \
{100.08066476952223`, -7305.158281670951}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7305.16995428376}, {
        100.08066476952223`, -7305.16995428376}, {
        100.08066476952223`, -7305.169204747769}, {
        100, -7305.169204747769}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7305.16995428376}, {
       1435.9379948587552`, -7305.16995428376}, {
       1435.9379948587552`, -7305.169204747769}, {
       600.1016077422506, -7305.169204747769}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7305.16995428376}, {
       1333.999009577124, -7305.16995428376}, {
       1333.999009577124, -7305.169204747769}, {
       1324.773962747272, -7305.169204747769}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7305.16995428376}, {
       1601.281668507477, -7305.16995428376}, {
       1601.281668507477, -7305.169204747769}, {
       1601.281667733673, -7305.169204747769}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7305.16995428376}, {
       2617.0523178600083`, -7305.16995428376}, {
       2617.0523178600083`, -7305.169204747769}, {
       2601.7869630871865`, -7305.169204747769}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7305.16995428376}, {
       3136.0547793570695`, -7305.16995428376}, {
       3136.0547793570695`, -7305.169204747769}, {
       3136.0547158825984`, -7305.169204747769}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1306496396764`, -7305.16995428376}, {
       3695.103918354495, -7305.16995428376}, {
       3695.103918354495, -7305.169204747769}, {
       3585.1306496396764`, -7305.169204747769}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.031343022445, -7305.16995428376}, {
       4142.649334928725, -7305.16995428376}, {
       4142.649334928725, -7305.169204747769}, {
       4113.031343022445, -7305.169204747769}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999993985, -7305.16995428376}, {
       4699.999999999999, -7305.16995428376}, {
       4699.999999999999, -7305.169204747769}, {
       4699.999999993985, -7305.169204747769}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88266634397, -7305.16995428376}, {
      2584.8835132118857`, -7305.16995428376}, {
      2584.8835132118857`, -7305.169204747769}, {
      2584.88266634397, -7305.169204747769}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4113.03096825445, -7305.1693921317665`}, \
{4113.031343022445, -7305.169204747769}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4113.03096825445, -7305.1693921317665`}, 
       0.00037476799517459803`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883887979881, -7305.169766899762}, {
       4113.03096825445, -7305.169766899762}, {
       4113.03096825445, -7305.1693921317665`}, {
       2584.883887979881, -7305.1693921317665`}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883887979881, -7305.169766899762}, 
       0.00037476799517459803`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8835132118857`, -7305.16995428376}, \
{2584.883887979881, -7305.169766899762}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7305.169954288789}, {
        100.08066476952223`, -7305.169954288789}, {
        100.08066476952223`, -7305.16995428376}, {
        100, -7305.16995428376}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7305.169954288789}, {
       1435.9379948562405`, -7305.169954288789}, {
       1435.9379948562405`, -7305.16995428376}, {
       600.1016077422506, -7305.16995428376}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7305.169954288789}, {
       1333.999009577124, -7305.169954288789}, {
       1333.999009577124, -7305.16995428376}, {
       1324.773962747272, -7305.16995428376}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7305.169954288789}, {
       1601.281668507477, -7305.169954288789}, {
       1601.281668507477, -7305.16995428376}, {
       1601.281667733673, -7305.16995428376}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7305.169954288789}, {
       2617.0523178600083`, -7305.169954288789}, {
       2617.0523178600083`, -7305.16995428376}, {
       2601.7869630871865`, -7305.16995428376}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7305.169954288789}, {
       2584.883887979881, -7305.169954288789}, {
       2584.883887979881, -7305.16995428376}, {
       2584.88266634397, -7305.16995428376}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7305.169954288789}, {
       3136.0547793570695`, -7305.169954288789}, {
       3136.0547793570695`, -7305.16995428376}, {
       3136.0547158825984`, -7305.16995428376}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1306496396764`, -7305.169954288789}, {
       3695.103918354495, -7305.169954288789}, {
       3695.103918354495, -7305.16995428376}, {
       3585.1306496396764`, -7305.16995428376}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4113.031343022445, -7305.169954288789}, {
       4142.649334928725, -7305.169954288789}, {
       4142.649334928725, -7305.16995428376}, {
       4113.031343022445, -7305.16995428376}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999993985, -7305.169954288789}, {
      4699.999999999999, -7305.169954288789}, {
      4699.999999999999, -7305.16995428376}, {
      4699.999999993985, -7305.16995428376}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1435.9379948562405`, -7305.1699542850165`}, \
{1435.9379948587552`, -7305.16995428376}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1435.9379948587552`, -7305.1699542850165`}, 
       2.5149574121076124`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1435.9379948587552`, -7305.169954287531}, {
       4699.99999999147, -7305.169954287531}, {
       4699.99999999147, -7305.1699542850165`}, {
       1435.9379948587552`, -7305.1699542850165`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99999999147, -7305.169954287531}, 
       2.5149574121076124`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99999999147, -7305.169954288789}, \
{4699.999999993985, -7305.169954287531}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7322.04027417995}, {
        100.08066476952223`, -7322.04027417995}, {
        100.08066476952223`, -7305.169954288789}, {
        100, -7305.169954288789}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7322.04027417995}, {
       1435.9379948562405`, -7322.04027417995}, {
       1435.9379948562405`, -7305.169954288789}, {
       600.1016077422506, -7305.169954288789}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7322.04027417995}, {
       1601.281668507477, -7322.04027417995}, {
       1601.281668507477, -7305.169954288789}, {
       1601.281667733673, -7305.169954288789}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7322.04027417995}, {
       2617.0523178600083`, -7322.04027417995}, {
       2617.0523178600083`, -7305.169954288789}, {
       2601.7869630871865`, -7305.169954288789}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7322.04027417995}, {
       2584.883887979881, -7322.04027417995}, {
       2584.883887979881, -7305.169954288789}, {
       2584.88266634397, -7305.169954288789}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7322.04027417995}, {
       3136.0547793570695`, -7322.04027417995}, {
       3136.0547793570695`, -7305.169954288789}, {
       3136.0547158825984`, -7305.169954288789}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1306496396764`, -7322.04027417995}, {
       3695.103918354495, -7322.04027417995}, {
       3695.103918354495, -7305.169954288789}, {
       3585.1306496396764`, -7305.169954288789}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7322.04027417995}, {
       4142.649334928725, -7322.04027417995}, {
       4142.649334928725, -7305.169954288789}, {
       4121.466502968025, -7305.169954288789}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999147, -7322.04027417995}, {
       4699.999999999999, -7322.04027417995}, {
       4699.999999999999, -7305.169954288789}, {
       4699.99999999147, -7305.169954288789}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773962747272, -7322.04027417995}, {
      1333.999009577124, -7322.04027417995}, {
      1333.999009577124, -7305.169954288789}, {
      1324.773962747272, -7305.169954288789}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4113.031343022445, -7309.387534261579}, \
{4121.466502968025, -7305.169954288789}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4113.031343022445, -7309.387534261579}, 8.435159945580537, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1342.4341695227047`, -7317.82269420716}, {
       4113.031343022445, -7317.82269420716}, {
       4113.031343022445, -7309.387534261579}, {
       1342.4341695227047`, -7309.387534261579}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1342.4341695227047`, -7317.82269420716}, 8.435159945580537, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1333.999009577124, -7322.04027417995}, \
{1342.4341695227047`, -7317.82269420716}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7322.140035579192}, {
       1435.9379948562405`, -7322.140035579192}, {
       1435.9379948562405`, -7322.04027417995}, {
       600.1016077422506, -7322.04027417995}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7322.140035579192}, {
       1342.4341695227047`, -7322.140035579192}, {
       1342.4341695227047`, -7322.04027417995}, {
       1324.773962747272, -7322.04027417995}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7322.140035579192}, {
       1601.281668507477, -7322.140035579192}, {
       1601.281668507477, -7322.04027417995}, {
       1601.281667733673, -7322.04027417995}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7322.140035579192}, {
       2617.0523178600083`, -7322.140035579192}, {
       2617.0523178600083`, -7322.04027417995}, {
       2601.7869630871865`, -7322.04027417995}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7322.140035579192}, {
       2584.883887979881, -7322.140035579192}, {
       2584.883887979881, -7322.04027417995}, {
       2584.88266634397, -7322.04027417995}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7322.140035579192}, {
       3136.0547793570695`, -7322.140035579192}, {
       3136.0547793570695`, -7322.04027417995}, {
       3136.0547158825984`, -7322.04027417995}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1805303392975`, -7322.140035579192}, {
       3695.103918354495, -7322.140035579192}, {
       3695.103918354495, -7322.04027417995}, {
       3585.1805303392975`, -7322.04027417995}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7322.140035579192}, {
       4142.649334928725, -7322.140035579192}, {
       4142.649334928725, -7322.04027417995}, {
       4121.466502968025, -7322.04027417995}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.99999999147, -7322.140035579192}, {
       4699.999999999999, -7322.140035579192}, {
       4699.999999999999, -7322.04027417995}, {
       4699.99999999147, -7322.04027417995}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7322.140035579192}, {
       100.08066476952223`, -7322.140035579192}, {
       100.08066476952223`, -7322.04027417995}, {
       100, -7322.04027417995}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3585.1306496396764`, -7322.065214529761}, \
{3585.1805303392975`, -7322.04027417995}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3585.1306496396764`, -7322.065214529761}, 0.04988069962104326, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.13054546914327`, -7322.115095229382}, {
       3585.1306496396764`, -7322.115095229382}, {
       3585.1306496396764`, -7322.065214529761}, {
       100.13054546914327`, -7322.065214529761}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.13054546914327`, -7322.115095229382}, 0.04988069962104326, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.08066476952223`, -7322.140035579192}, \
{100.13054546914327`, -7322.115095229382}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7322.140035593918}, {
       1435.9379948562405`, -7322.140035593918}, {
       1435.9379948562405`, -7322.140035579192}, {
       600.1016077422506, -7322.140035579192}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7322.140035593918}, {
       1342.4341695227047`, -7322.140035593918}, {
       1342.4341695227047`, -7322.140035579192}, {
       1324.773962747272, -7322.140035579192}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7322.140035593918}, {
       1601.281668507477, -7322.140035593918}, {
       1601.281668507477, -7322.140035579192}, {
       1601.281667733673, -7322.140035579192}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7322.140035593918}, {
       2617.0523178600083`, -7322.140035593918}, {
       2617.0523178600083`, -7322.140035579192}, {
       2601.7869630871865`, -7322.140035579192}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7322.140035593918}, {
       2584.883887979881, -7322.140035593918}, {
       2584.883887979881, -7322.140035579192}, {
       2584.88266634397, -7322.140035579192}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0547158825984`, -7322.140035593918}, {
       3136.0547793570695`, -7322.140035593918}, {
       3136.0547793570695`, -7322.140035579192}, {
       3136.0547158825984`, -7322.140035579192}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1805303392975`, -7322.140035593918}, {
       3695.103918354495, -7322.140035593918}, {
       3695.103918354495, -7322.140035579192}, {
       3585.1805303392975`, -7322.140035579192}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7322.140035593918}, {
       4142.649334928725, -7322.140035593918}, {
       4142.649334928725, -7322.140035579192}, {
       4121.466502968025, -7322.140035579192}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7322.140035593918}, {
       4699.999999999999, -7322.140035593918}, {
       4699.999999999999, -7322.140035579192}, {
       4699.999999998832, -7322.140035579192}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7322.140035593918}, {
       100.13054546914327`, -7322.140035593918}, {
       100.13054546914327`, -7322.140035579192}, {
       100, -7322.140035579192}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.99999999147, -7322.140035582874}, \
{4699.999999998832, -7322.140035579192}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.99999999147, -7322.140035582874}, 7.3627207055417195`*^-9,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.13054547650599`, -7322.140035590236}, {
       4699.99999999147, -7322.140035590236}, {
       4699.99999999147, -7322.140035582874}, {
       100.13054547650599`, -7322.140035582874}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.13054547650599`, -7322.140035590236}, 
       7.3627207055417195`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.13054546914327`, -7322.140035593918}, \
{100.13054547650599`, -7322.140035590236}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7322.140122325469}, {
        100.13050211073043`, -7322.140122325469}, {
        100.13050211073043`, -7322.140035593918}, {
        100, -7322.140035593918}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7322.140122325469}, {
       1435.9379948562405`, -7322.140122325469}, {
       1435.9379948562405`, -7322.140035593918}, {
       600.1016077422506, -7322.140035593918}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7322.140122325469}, {
       1342.4341695227047`, -7322.140122325469}, {
       1342.4341695227047`, -7322.140035593918}, {
       1324.773962747272, -7322.140035593918}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7322.140122325469}, {
       1601.281668507477, -7322.140122325469}, {
       1601.281668507477, -7322.140035593918}, {
       1601.281667733673, -7322.140035593918}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.7869630871865`, -7322.140122325469}, {
       2617.0523178600083`, -7322.140122325469}, {
       2617.0523178600083`, -7322.140035593918}, {
       2601.7869630871865`, -7322.140035593918}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7322.140122325469}, {
       2584.883887979881, -7322.140122325469}, {
       2584.883887979881, -7322.140035593918}, {
       2584.88266634397, -7322.140035593918}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1805303392975`, -7322.140122325469}, {
       3695.103918354495, -7322.140122325469}, {
       3695.103918354495, -7322.140035593918}, {
       3585.1805303392975`, -7322.140035593918}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7322.140122325469}, {
       4142.649334928725, -7322.140122325469}, {
       4142.649334928725, -7322.140035593918}, {
       4121.466502968025, -7322.140035593918}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7322.140122325469}, {
       4699.999999999999, -7322.140122325469}, {
       4699.999999999999, -7322.140035593918}, {
       4699.999999998832, -7322.140035593918}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0547158825984`, -7322.140122325469}, {
      3136.054779357069, -7322.140122325469}, {
      3136.054779357069, -7322.140035593918}, {
      3136.0547158825984`, -7322.140035593918}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.13050211073043`, -7322.140057276805}, \
{100.13054547650599`, -7322.140035593918}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.13054547650599`, -7322.140057276805}, 
       0.00004336577555996292, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.13054547650599`, -7322.140100642581}, {
       3136.054672516823, -7322.140100642581}, {
       3136.054672516823, -7322.140057276805}, {
       100.13054547650599`, -7322.140057276805}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054672516823, -7322.140100642581}, 
       0.00004336577555996292, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054672516823, -7322.140122325469}, \
{3136.0547158825984`, -7322.140100642581}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7322.14012267449}, {
        100.13050211073043`, -7322.14012267449}, {
        100.13050211073043`, -7322.140122325469}, {
        100, -7322.140122325469}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7322.14012267449}, {
       1435.9379948562405`, -7322.14012267449}, {
       1435.9379948562405`, -7322.140122325469}, {
       600.1016077422506, -7322.140122325469}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7322.14012267449}, {
       1342.4341695227047`, -7322.14012267449}, {
       1342.4341695227047`, -7322.140122325469}, {
       1324.773962747272, -7322.140122325469}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7322.14012267449}, {
       1601.281668332966, -7322.14012267449}, {
       1601.281668332966, -7322.140122325469}, {
       1601.281667733673, -7322.140122325469}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7322.14012267449}, {
       2584.883887979881, -7322.14012267449}, {
       2584.883887979881, -7322.140122325469}, {
       2584.88266634397, -7322.140122325469}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054672516823, -7322.14012267449}, {
       3136.054779357069, -7322.14012267449}, {
       3136.054779357069, -7322.140122325469}, {
       3136.054672516823, -7322.140122325469}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3585.1805303392975`, -7322.14012267449}, {
       3695.103918354495, -7322.14012267449}, {
       3695.103918354495, -7322.140122325469}, {
       3585.1805303392975`, -7322.140122325469}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7322.14012267449}, {
       4142.649334928725, -7322.14012267449}, {
       4142.649334928725, -7322.140122325469}, {
       4121.466502968025, -7322.140122325469}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7322.14012267449}, {
       4699.999999999999, -7322.14012267449}, {
       4699.999999999999, -7322.140122325469}, {
       4699.999999998832, -7322.140122325469}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.7869630871865`, -7322.14012267449}, {
      2617.0523178600088`, -7322.14012267449}, {
      2617.0523178600088`, -7322.140122325469}, {
      2601.7869630871865`, -7322.140122325469}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668332966, -7322.140122412724}, \
{1601.281668507477, -7322.140122325469}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668507477, -7322.140122412724}, 
       1.7451079718398993`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668507477, -7322.140122587235}, {
       2601.786962912676, -7322.140122587235}, {
       2601.786962912676, -7322.140122412724}, {
       1601.281668507477, -7322.140122412724}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2601.786962912676, -7322.140122587235}, 
       1.7451079718398993`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2601.786962912676, -7322.14012267449}, \
{2601.7869630871865`, -7322.140122587235}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.367913437568}, {
        100.13050211073043`, -7343.367913437568}, {
        100.13050211073043`, -7322.14012267449}, {
        100, -7322.14012267449}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.367913437568}, {
       1342.4341695227047`, -7343.367913437568}, {
       1342.4341695227047`, -7322.14012267449}, {
       1324.773962747272, -7322.14012267449}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7343.367913437568}, {
       1601.281668332966, -7343.367913437568}, {
       1601.281668332966, -7322.14012267449}, {
       1601.281667733673, -7322.14012267449}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.367913437568}, {
       2617.0523178600088`, -7343.367913437568}, {
       2617.0523178600088`, -7322.14012267449}, {
       2601.786962912676, -7322.14012267449}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7343.367913437568}, {
       2584.883887979881, -7343.367913437568}, {
       2584.883887979881, -7322.14012267449}, {
       2584.88266634397, -7322.14012267449}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054672516823, -7343.367913437568}, {
       3136.054779357069, -7343.367913437568}, {
       3136.054779357069, -7322.14012267449}, {
       3136.054672516823, -7322.14012267449}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.367913437568}, {
       3695.1039183544954`, -7343.367913437568}, {
       3695.1039183544954`, -7322.14012267449}, {
       3595.7944257208364`, -7322.14012267449}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7343.367913437568}, {
       4142.649334928725, -7343.367913437568}, {
       4142.649334928725, -7322.14012267449}, {
       4121.466502968025, -7322.14012267449}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.367913437568}, {
       4699.999999999999, -7343.367913437568}, {
       4699.999999999999, -7322.14012267449}, {
       4699.999999998832, -7322.14012267449}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1016077422506, -7343.367913437568}, {
      1435.9379948562405`, -7343.367913437568}, {
      1435.9379948562405`, -7322.14012267449}, {
      600.1016077422506, -7322.14012267449}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3585.1805303392975`, -7327.44707036526}, \
{3595.7944257208364`, -7322.14012267449}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3585.1805303392975`, -7327.44707036526}, 10.613895381538825`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1446.5518902377792`, -7338.0609657467985`}, {
       3585.1805303392975`, -7338.0609657467985`}, {
       3585.1805303392975`, -7327.44707036526}, {
       1446.5518902377792`, -7327.44707036526}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1446.5518902377792`, -7338.0609657467985`}, 
       10.613895381538825`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1435.9379948562405`, -7343.367913437568}, \
{1446.5518902377792`, -7338.0609657467985`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.36796266306}, {
        100.13050211073043`, -7343.36796266306}, {
        100.13050211073043`, -7343.367913437568}, {
        100, -7343.367913437568}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.36796266306}, {
       1446.551865625033, -7343.36796266306}, {
       1446.551865625033, -7343.367913437568}, {
       600.1016077422506, -7343.367913437568}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.36796266306}, {
       1342.4341695227047`, -7343.36796266306}, {
       1342.4341695227047`, -7343.367913437568}, {
       1324.773962747272, -7343.367913437568}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7343.36796266306}, {
       1601.281668332966, -7343.36796266306}, {
       1601.281668332966, -7343.367913437568}, {
       1601.281667733673, -7343.367913437568}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.36796266306}, {
       2617.0523178600088`, -7343.36796266306}, {
       2617.0523178600088`, -7343.367913437568}, {
       2601.786962912676, -7343.367913437568}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7343.36796266306}, {
       2584.883887979881, -7343.36796266306}, {
       2584.883887979881, -7343.367913437568}, {
       2584.88266634397, -7343.367913437568}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.36796266306}, {
       3695.1039183544954`, -7343.36796266306}, {
       3695.1039183544954`, -7343.367913437568}, {
       3595.7944257208364`, -7343.367913437568}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.466502968025, -7343.36796266306}, {
       4142.649334928725, -7343.36796266306}, {
       4142.649334928725, -7343.367913437568}, {
       4121.466502968025, -7343.367913437568}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.36796266306}, {
       4699.999999999999, -7343.36796266306}, {
       4699.999999999999, -7343.367913437568}, {
       4699.999999998832, -7343.367913437568}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054672516823, -7343.36796266306}, {
      3136.054779357069, -7343.36796266306}, {
      3136.054779357069, -7343.367913437568}, {
      3136.054672516823, -7343.367913437568}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1446.551865625033, -7343.367925743941}, \
{1446.5518902377792`, -7343.367913437568}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1446.5518902377792`, -7343.367925743941}, 
       0.000024612746043633447`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1446.5518902377792`, -7343.367950356687}, {
       3136.054647904077, -7343.367950356687}, {
       3136.054647904077, -7343.367925743941}, {
       1446.5518902377792`, -7343.367925743941}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054647904077, -7343.367950356687}, 
       0.000024612746043633447`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054647904077, -7343.36796266306}, \
{3136.054672516823, -7343.367950356687}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.493501883339}, {
        100.06773250059098`, -7343.493501883339}, {
        100.06773250059098`, -7343.36796266306}, {
        100, -7343.36796266306}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493501883339}, {
       1446.551865625033, -7343.493501883339}, {
       1446.551865625033, -7343.36796266306}, {
       600.1016077422506, -7343.36796266306}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.493501883339}, {
       1342.4341695227047`, -7343.493501883339}, {
       1342.4341695227047`, -7343.36796266306}, {
       1324.773962747272, -7343.36796266306}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7343.493501883339}, {
       1601.281668332966, -7343.493501883339}, {
       1601.281668332966, -7343.36796266306}, {
       1601.281667733673, -7343.36796266306}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493501883339}, {
       2617.0523178600088`, -7343.493501883339}, {
       2617.0523178600088`, -7343.36796266306}, {
       2601.786962912676, -7343.36796266306}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7343.493501883339}, {
       2584.883887979881, -7343.493501883339}, {
       2584.883887979881, -7343.36796266306}, {
       2584.88266634397, -7343.36796266306}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054647904077, -7343.493501883339}, {
       3136.054779357069, -7343.493501883339}, {
       3136.054779357069, -7343.36796266306}, {
       3136.054647904077, -7343.36796266306}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493501883339}, {
       3695.1039183544954`, -7343.493501883339}, {
       3695.1039183544954`, -7343.36796266306}, {
       3595.7944257208364`, -7343.36796266306}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.493501883339}, {
       4699.999999999999, -7343.493501883339}, {
       4699.999999999999, -7343.36796266306}, {
       4699.999999998832, -7343.36796266306}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4121.466502968025, -7343.493501883339}, {
      4142.649334928725, -7343.493501883339}, {
      4142.649334928725, -7343.36796266306}, {
      4121.466502968025, -7343.36796266306}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06773250059098`, -7343.39934746813}, \
{100.13050211073043`, -7343.36796266306}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.13050211073043`, -7343.39934746813}, 0.06276961013944499, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.13050211073043`, -7343.462117078269}, {
       4121.403733357886, -7343.462117078269}, {
       4121.403733357886, -7343.39934746813}, {
       100.13050211073043`, -7343.39934746813}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4121.403733357886, -7343.462117078269}, 0.06276961013944499, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4121.403733357886, -7343.493501883339}, \
{4121.466502968025, -7343.462117078269}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.4935680418175`}, {
        100.06773250059098`, -7343.4935680418175`}, {
        100.06773250059098`, -7343.493501883339}, {
        100, -7343.493501883339}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.4935680418175`}, {
       1342.4341695227047`, -7343.4935680418175`}, {
       1342.4341695227047`, -7343.493501883339}, {
       1324.773962747272, -7343.493501883339}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7343.4935680418175`}, {
       1601.281668332966, -7343.4935680418175`}, {
       1601.281668332966, -7343.493501883339}, {
       1601.281667733673, -7343.493501883339}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.4935680418175`}, {
       2617.0523178600088`, -7343.4935680418175`}, {
       2617.0523178600088`, -7343.493501883339}, {
       2601.786962912676, -7343.493501883339}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88266634397, -7343.4935680418175`}, {
       2584.883887979881, -7343.4935680418175`}, {
       2584.883887979881, -7343.493501883339}, {
       2584.88266634397, -7343.493501883339}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.4935680418175`}, {
       3136.0547793570695`, -7343.4935680418175`}, {
       3136.0547793570695`, -7343.493501883339}, {
       3136.054680983316, -7343.493501883339}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.4935680418175`}, {
       3695.1039183544954`, -7343.4935680418175`}, {
       3695.1039183544954`, -7343.493501883339}, {
       3595.7944257208364`, -7343.493501883339}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.4935680418175`}, {
       4142.649334928725, -7343.4935680418175`}, {
       4142.649334928725, -7343.493501883339}, {
       4121.403733357886, -7343.493501883339}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.4935680418175`}, {
       4699.999999999999, -7343.4935680418175`}, {
       4699.999999999999, -7343.493501883339}, {
       4699.999999998832, -7343.493501883339}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1016077422506, -7343.4935680418175`}, {
      1446.551865625033, -7343.4935680418175`}, {
      1446.551865625033, -7343.493501883339}, {
      600.1016077422506, -7343.493501883339}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054647904077, -7343.493518422959}, \
{3136.054680983316, -7343.493501883339}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054647904077, -7343.493518422959}, 0.00003307923887388832,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1446.551898704272, -7343.493551502198}, {
       3136.054647904077, -7343.493551502198}, {
       3136.054647904077, -7343.493518422959}, {
       1446.551898704272, -7343.493518422959}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1446.551898704272, -7343.493551502198}, 0.00003307923887388832,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1446.551865625033, -7343.4935680418175`}, \
{1446.551898704272, -7343.493551502198}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.493778125177}, {
        100.06762745891123`, -7343.493778125177}, {
        100.06762745891123`, -7343.4935680418175`}, {
        100, -7343.4935680418175`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493778125177}, {
       1446.551898704272, -7343.493778125177}, {
       1446.551898704272, -7343.4935680418175`}, {
       600.1016077422506, -7343.4935680418175`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.493778125177}, {
       1342.4341695227047`, -7343.493778125177}, {
       1342.4341695227047`, -7343.4935680418175`}, {
       1324.773962747272, -7343.4935680418175`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281667733673, -7343.493778125177}, {
       1601.281668332966, -7343.493778125177}, {
       1601.281668332966, -7343.4935680418175`}, {
       1601.281667733673, -7343.4935680418175`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493778125177}, {
       2617.0523178600088`, -7343.493778125177}, {
       2617.0523178600088`, -7343.4935680418175`}, {
       2601.786962912676, -7343.4935680418175`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.493778125177}, {
       3136.0547793570695`, -7343.493778125177}, {
       3136.0547793570695`, -7343.4935680418175`}, {
       3136.054680983316, -7343.4935680418175`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493778125177}, {
       3695.1039183544954`, -7343.493778125177}, {
       3695.1039183544954`, -7343.4935680418175`}, {
       3595.7944257208364`, -7343.4935680418175`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.493778125177}, {
       4142.649334928725, -7343.493778125177}, {
       4142.649334928725, -7343.4935680418175`}, {
       4121.403733357886, -7343.4935680418175`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.493778125177}, {
       4699.999999999999, -7343.493778125177}, {
       4699.999999999999, -7343.4935680418175`}, {
       4699.999999998832, -7343.4935680418175`}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88266634397, -7343.493778125177}, {
      2584.8838879798805`, -7343.493778125177}, {
      2584.8838879798805`, -7343.4935680418175`}, {
      2584.88266634397, -7343.4935680418175`}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06762745891123`, -7343.493620562658}, \
{100.06773250059098`, -7343.4935680418175`}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06773250059098`, -7343.493620562658}, 
       0.00010504167974275226`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06773250059098`, -7343.493725604338}, {
       2584.88256130229, -7343.493725604338}, {
       2584.88256130229, -7343.493620562658}, {
       100.06773250059098`, -7343.493620562658}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.88256130229, -7343.493725604338}, 
       0.00010504167974275226`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88256130229, -7343.493778125177}, \
{2584.88266634397, -7343.493725604338}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.4937783534815`}, {
       1446.551898704272, -7343.4937783534815`}, {
       1446.551898704272, -7343.493778125177}, {
       600.1016077422506, -7343.493778125177}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.4937783534815`}, {
       1342.4341695227047`, -7343.4937783534815`}, {
       1342.4341695227047`, -7343.493778125177}, {
       1324.773962747272, -7343.493778125177}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816678478248`, -7343.4937783534815`}, {
       1601.281668332966, -7343.4937783534815`}, {
       1601.281668332966, -7343.493778125177}, {
       1601.2816678478248`, -7343.493778125177}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.4937783534815`}, {
       2617.0523178600088`, -7343.4937783534815`}, {
       2617.0523178600088`, -7343.493778125177}, {
       2601.786962912676, -7343.493778125177}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7343.4937783534815`}, {
       2584.8838879798805`, -7343.4937783534815`}, {
       2584.8838879798805`, -7343.493778125177}, {
       2584.88256130229, -7343.493778125177}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.4937783534815`}, {
       3136.0547793570695`, -7343.4937783534815`}, {
       3136.0547793570695`, -7343.493778125177}, {
       3136.054680983316, -7343.493778125177}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.4937783534815`}, {
       3695.1039183544954`, -7343.4937783534815`}, {
       3695.1039183544954`, -7343.493778125177}, {
       3595.7944257208364`, -7343.493778125177}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.4937783534815`}, {
       4142.649334928725, -7343.4937783534815`}, {
       4142.649334928725, -7343.493778125177}, {
       4121.403733357886, -7343.493778125177}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998832, -7343.4937783534815`}, {
       4699.999999999999, -7343.4937783534815`}, {
       4699.999999999999, -7343.493778125177}, {
       4699.999999998832, -7343.493778125177}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7343.4937783534815`}, {
       100.06762745891123`, -7343.4937783534815`}, {
       100.06762745891123`, -7343.493778125177}, {
       100, -7343.493778125177}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281667733673, -7343.493778182254}, \
{1601.2816678478248`, -7343.493778125177}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281667733673, -7343.493778182254}, 
       1.1415183200457734`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06762757306308`, -7343.493778296405}, {
       1601.281667733673, -7343.493778296405}, {
       1601.281667733673, -7343.493778182254}, {
       100.06762757306308`, -7343.493778182254}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06762757306308`, -7343.493778296405}, 
       1.1415183200457734`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06762745891123`, -7343.4937783534815`}, \
{100.06762757306308`, -7343.493778296405}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493778353617}, {
       1446.551898704272, -7343.493778353617}, {
       1446.551898704272, -7343.4937783534815`}, {
       600.1016077422506, -7343.4937783534815`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.493778353617}, {
       1342.4341695227047`, -7343.493778353617}, {
       1342.4341695227047`, -7343.4937783534815`}, {
       1324.773962747272, -7343.4937783534815`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816678478248`, -7343.493778353617}, {
       1601.281668332966, -7343.493778353617}, {
       1601.281668332966, -7343.4937783534815`}, {
       1601.2816678478248`, -7343.4937783534815`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493778353617}, {
       2617.0523178600088`, -7343.493778353617}, {
       2617.0523178600088`, -7343.4937783534815`}, {
       2601.786962912676, -7343.4937783534815`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7343.493778353617}, {
       2584.8838879798805`, -7343.493778353617}, {
       2584.8838879798805`, -7343.4937783534815`}, {
       2584.88256130229, -7343.4937783534815`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.493778353617}, {
       3136.0547793570695`, -7343.493778353617}, {
       3136.0547793570695`, -7343.4937783534815`}, {
       3136.054680983316, -7343.4937783534815`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493778353617}, {
       3695.1039183544954`, -7343.493778353617}, {
       3695.1039183544954`, -7343.4937783534815`}, {
       3595.7944257208364`, -7343.4937783534815`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.493778353617}, {
       4142.649334928725, -7343.493778353617}, {
       4142.649334928725, -7343.4937783534815`}, {
       4121.403733357886, -7343.4937783534815`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999989, -7343.493778353617}, {
       4699.999999999999, -7343.493778353617}, {
       4699.999999999999, -7343.4937783534815`}, {
       4699.9999999989, -7343.4937783534815`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7343.493778353617}, {
       100.06762757306308`, -7343.493778353617}, {
       100.06762757306308`, -7343.4937783534815`}, {
       100, -7343.4937783534815`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999998832, -7343.493778353515}, \
{4699.9999999989, -7343.4937783534815`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999998832, -7343.493778353515}, 6.787865140668015*^-11,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06762757313095`, -7343.493778353583}, {
       4699.999999998832, -7343.493778353583}, {
       4699.999999998832, -7343.493778353515}, {
       100.06762757313095`, -7343.493778353515}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06762757313095`, -7343.493778353583}, 
       6.787865140668015*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.06762757306308`, -7343.493778353617}, \
{100.06762757313095`, -7343.493778353583}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.493778353629}, {
        100.06762757313095`, -7343.493778353629}, {
        100.06762757313095`, -7343.493778353617}, {
        100, -7343.493778353617}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493778353629}, {
       1446.551898704272, -7343.493778353629}, {
       1446.551898704272, -7343.493778353617}, {
       600.1016077422506, -7343.493778353617}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7343.493778353629}, {
       1342.4341695227047`, -7343.493778353629}, {
       1342.4341695227047`, -7343.493778353617}, {
       1324.773962747272, -7343.493778353617}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816678478248`, -7343.493778353629}, {
       1601.281668332966, -7343.493778353629}, {
       1601.281668332966, -7343.493778353617}, {
       1601.2816678478248`, -7343.493778353617}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493778353629}, {
       2617.0523178600088`, -7343.493778353629}, {
       2617.0523178600088`, -7343.493778353617}, {
       2601.786962912676, -7343.493778353617}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7343.493778353629}, {
       2584.8838879798805`, -7343.493778353629}, {
       2584.8838879798805`, -7343.493778353617}, {
       2584.88256130229, -7343.493778353617}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.493778353629}, {
       3136.0547793570636`, -7343.493778353629}, {
       3136.0547793570636`, -7343.493778353617}, {
       3136.054680983316, -7343.493778353617}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493778353629}, {
       3695.1039183544954`, -7343.493778353629}, {
       3695.1039183544954`, -7343.493778353617}, {
       3595.7944257208364`, -7343.493778353617}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.493778353629}, {
       4142.649334928725, -7343.493778353629}, {
       4142.649334928725, -7343.493778353617}, {
       4121.403733357886, -7343.493778353617}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.9999999989, -7343.493778353629}, {
      4700., -7343.493778353629}, {4700., -7343.493778353617}, {
      4699.9999999989, -7343.493778353617}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0547793570636`, -7343.49377835362}, \
{3136.0547793570695`, -7343.493778353617}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0547793570695`, -7343.49377835362}, 
       5.849230740748736*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0547793570695`, -7343.493778353626}, {
       4699.999999998895, -7343.493778353626}, {
       4699.999999998895, -7343.49377835362}, {
       3136.0547793570695`, -7343.49377835362}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999998895, -7343.493778353626}, 
       5.849230740748736*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999998895, -7343.493778353629}, \
{4699.9999999989, -7343.493778353626}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.493778677304}, {
        100.06762757313095`, -7343.493778677304}, {
        100.06762757313095`, -7343.493778353629}, {
        100, -7343.493778353629}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493778677304}, {
       1446.551898704272, -7343.493778677304}, {
       1446.551898704272, -7343.493778353629}, {
       600.1016077422506, -7343.493778353629}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816680096626`, -7343.493778677304}, {
       1601.281668332966, -7343.493778677304}, {
       1601.281668332966, -7343.493778353629}, {
       1601.2816680096626`, -7343.493778353629}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493778677304}, {
       2617.0523178600088`, -7343.493778677304}, {
       2617.0523178600088`, -7343.493778353629}, {
       2601.786962912676, -7343.493778353629}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7343.493778677304}, {
       2584.8838879798805`, -7343.493778677304}, {
       2584.8838879798805`, -7343.493778353629}, {
       2584.88256130229, -7343.493778353629}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.493778677304}, {
       3136.0547793570636`, -7343.493778677304}, {
       3136.0547793570636`, -7343.493778353629}, {
       3136.054680983316, -7343.493778353629}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493778677304}, {
       3695.1039183544954`, -7343.493778677304}, {
       3695.1039183544954`, -7343.493778353629}, {
       3595.7944257208364`, -7343.493778353629}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.493778677304}, {
       4142.649334928725, -7343.493778677304}, {
       4142.649334928725, -7343.493778353629}, {
       4121.403733357886, -7343.493778353629}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998895, -7343.493778677304}, {
       4700., -7343.493778677304}, {4700., -7343.493778353629}, {
       4699.999999998895, -7343.493778353629}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773962747272, -7343.493778677304}, {
      1342.4341695227047`, -7343.493778677304}, {
      1342.4341695227047`, -7343.493778353629}, {
      1324.773962747272, -7343.493778353629}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816678478248`, -7343.4937784345475`}, \
{1601.2816680096626`, -7343.493778353629}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816678478248`, -7343.4937784345475`}, 
       1.6183774039545108`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1342.4341696845424`, -7343.493778596386}, {
       1601.2816678478248`, -7343.493778596386}, {
       1601.2816678478248`, -7343.4937784345475`}, {
       1342.4341696845424`, -7343.4937784345475`}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1342.4341696845424`, -7343.493778596386}, 
       1.6183774039545108`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1342.4341695227047`, -7343.493778677304}, \
{1342.4341696845424`, -7343.493778596386}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7343.493779028345}, {
        100.06762757313095`, -7343.493779028345}, {
        100.06762757313095`, -7343.493778677304}, {
        100, -7343.493778677304}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7343.493779028345}, {
       1446.551898704272, -7343.493779028345}, {
       1446.551898704272, -7343.493778677304}, {
       600.1016077422506, -7343.493778677304}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7343.493779028345}, {
       1601.2816683329663`, -7343.493779028345}, {
       1601.2816683329663`, -7343.493778677304}, {
       1601.2816681851828`, -7343.493778677304}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7343.493779028345}, {
       2617.0523178600088`, -7343.493779028345}, {
       2617.0523178600088`, -7343.493778677304}, {
       2601.786962912676, -7343.493778677304}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7343.493779028345}, {
       2584.8838879798805`, -7343.493779028345}, {
       2584.8838879798805`, -7343.493778677304}, {
       2584.88256130229, -7343.493778677304}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7343.493779028345}, {
       3136.0547793570636`, -7343.493779028345}, {
       3136.0547793570636`, -7343.493778677304}, {
       3136.054680983316, -7343.493778677304}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7343.493779028345}, {
       3695.1039183544954`, -7343.493779028345}, {
       3695.1039183544954`, -7343.493778677304}, {
       3595.7944257208364`, -7343.493778677304}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4121.403733357886, -7343.493779028345}, {
       4142.649334928725, -7343.493779028345}, {
       4142.649334928725, -7343.493778677304}, {
       4121.403733357886, -7343.493778677304}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998895, -7343.493779028345}, {
       4700., -7343.493779028345}, {4700., -7343.493778677304}, {
       4699.999999998895, -7343.493778677304}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773962747272, -7343.493779028345}, {
      1342.4341696845424`, -7343.493779028345}, {
      1342.4341696845424`, -7343.493778677304}, {
      1324.773962747272, -7343.493778677304}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816680096626`, -7343.493778765064}, \
{1601.2816681851828`, -7343.493778677304}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816680096626`, -7343.493778765064}, 
       1.7552010454900507`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1342.4341698600624`, -7343.493778940585}, {
       1601.2816680096626`, -7343.493778940585}, {
       1601.2816680096626`, -7343.493778765064}, {
       1342.4341698600624`, -7343.493778765064}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1342.4341698600624`, -7343.493778940585}, 
       1.7552010454900507`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1342.4341696845424`, -7343.493779028345}, \
{1342.4341698600624`, -7343.493778940585}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.057107573276}, {
        100.06762757313095`, -7383.057107573276}, {
        100.06762757313095`, -7343.493779028345}, {
        100, -7343.493779028345}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.057107573276}, {
       1426.770234431806, -7383.057107573276}, {
       1426.770234431806, -7343.493779028345}, {
       600.1016077422506, -7343.493779028345}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.057107573276}, {
       1342.4341698600624`, -7383.057107573276}, {
       1342.4341698600624`, -7343.493779028345}, {
       1324.773962747272, -7343.493779028345}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.057107573276}, {
       1601.2816683329663`, -7383.057107573276}, {
       1601.2816683329663`, -7343.493779028345}, {
       1601.2816681851828`, -7343.493779028345}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7383.057107573276}, {
       2617.0523178600088`, -7383.057107573276}, {
       2617.0523178600088`, -7343.493779028345}, {
       2601.786962912676, -7343.493779028345}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.057107573276}, {
       2584.8838879798805`, -7383.057107573276}, {
       2584.8838879798805`, -7343.493779028345}, {
       2584.88256130229, -7343.493779028345}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7383.057107573276}, {
       3136.0547793570636`, -7383.057107573276}, {
       3136.0547793570636`, -7343.493779028345}, {
       3136.054680983316, -7343.493779028345}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.057107573276}, {
       3695.1039183544954`, -7383.057107573276}, {
       3695.1039183544954`, -7343.493779028345}, {
       3595.7944257208364`, -7343.493779028345}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998895, -7383.057107573276}, {
       4700., -7383.057107573276}, {4700., -7343.493779028345}, {
       4699.999999998895, -7343.493779028345}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4121.403733357886, -7383.057107573276}, {
      4142.649334928726, -7383.057107573276}, {
      4142.649334928726, -7343.493779028345}, {
      4121.403733357886, -7343.493779028345}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1426.770234431806, -7353.384611164577}, 
       {1446.551898704272, -7343.493779028345}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1446.551898704272, -7353.384611164577}, 19.781664272465807`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1446.551898704272, -7373.166275437043}, {
       4101.622069085421, -7373.166275437043}, {
       4101.622069085421, -7353.384611164577}, {
       1446.551898704272, -7353.384611164577}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4101.622069085421, -7373.166275437043}, 19.781664272465807`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4101.622069085421, -7383.057107573276}, \
{4121.403733357886, -7373.166275437043}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.057107575415}, {
        100.06762757313095`, -7383.057107575415}, {
        100.06762757313095`, -7383.057107573276}, {
        100, -7383.057107573276}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.057107575415}, {
       1426.770234431806, -7383.057107575415}, {
       1426.770234431806, -7383.057107573276}, {
       600.1016077422506, -7383.057107573276}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.057107575415}, {
       1342.4341698600624`, -7383.057107575415}, {
       1342.4341698600624`, -7383.057107573276}, {
       1324.773962747272, -7383.057107573276}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.057107575415}, {
       1601.2816683329663`, -7383.057107575415}, {
       1601.2816683329663`, -7383.057107573276}, {
       1601.2816681851828`, -7383.057107573276}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7383.057107575415}, {
       2617.0523178600088`, -7383.057107575415}, {
       2617.0523178600088`, -7383.057107573276}, {
       2601.786962912676, -7383.057107573276}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.057107575415}, {
       2584.883887978811, -7383.057107575415}, {
       2584.883887978811, -7383.057107573276}, {
       2584.88256130229, -7383.057107573276}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054680983316, -7383.057107575415}, {
       3136.0547793570636`, -7383.057107575415}, {
       3136.0547793570636`, -7383.057107573276}, {
       3136.054680983316, -7383.057107573276}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.057107575415}, {
       3695.1039183544954`, -7383.057107575415}, {
       3695.1039183544954`, -7383.057107573276}, {
       3595.7944257208364`, -7383.057107573276}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.057107575415}, {
       4142.649334928726, -7383.057107575415}, {
       4142.649334928726, -7383.057107573276}, {
       4101.622069085421, -7383.057107573276}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999998895, -7383.057107575415}, {
      4699.999999999999, -7383.057107575415}, {
      4699.999999999999, -7383.057107573276}, {
      4699.999999998895, -7383.057107573276}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883887978811, -7383.057107573811}, \
{2584.8838879798805`, -7383.057107573276}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8838879798805`, -7383.057107573811}, 
       1.069421177998442*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8838879798805`, -7383.05710757488}, {
       4699.999999997825, -7383.05710757488}, {
       4699.999999997825, -7383.057107573811}, {
       2584.8838879798805`, -7383.057107573811}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999997825, -7383.05710757488}, 1.069421177998442*^-9, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999997825, -7383.057107575415}, \
{4699.999999998895, -7383.05710757488}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.057107592372}, {
        100.06762757313095`, -7383.057107592372}, {
        100.06762757313095`, -7383.057107575415}, {
        100, -7383.057107575415}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.057107592372}, {
       1426.770234431806, -7383.057107592372}, {
       1426.770234431806, -7383.057107575415}, {
       600.1016077422506, -7383.057107575415}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.057107592372}, {
       1342.4341698600624`, -7383.057107592372}, {
       1342.4341698600624`, -7383.057107575415}, {
       1324.773962747272, -7383.057107575415}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.057107592372}, {
       1601.2816683244878`, -7383.057107592372}, {
       1601.2816683244878`, -7383.057107575415}, {
       1601.2816681851828`, -7383.057107575415}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7383.057107592372}, {
       2617.0523178600088`, -7383.057107592372}, {
       2617.0523178600088`, -7383.057107575415}, {
       2601.786962912676, -7383.057107575415}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.057107592372}, {
       2584.883887978811, -7383.057107592372}, {
       2584.883887978811, -7383.057107575415}, {
       2584.88256130229, -7383.057107575415}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.057107592372}, {
       3695.1039183544954`, -7383.057107592372}, {
       3695.1039183544954`, -7383.057107575415}, {
       3595.7944257208364`, -7383.057107575415}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.057107592372}, {
       4142.649334928726, -7383.057107592372}, {
       4142.649334928726, -7383.057107575415}, {
       4101.622069085421, -7383.057107575415}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999997825, -7383.057107592372}, {
       4699.999999999999, -7383.057107592372}, {
       4699.999999999999, -7383.057107575415}, {
       4699.999999997825, -7383.057107575415}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054680983316, -7383.057107592372}, {
      3136.0547793570636`, -7383.057107592372}, {
      3136.0547793570636`, -7383.057107575415}, {
      3136.054680983316, -7383.057107575415}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816683244878`, -7383.057107579654}, \
{1601.2816683329663`, -7383.057107575415}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816683329663`, -7383.057107579654}, 
       8.478403694224562*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816683329663`, -7383.057107588133}, {
       3136.0546809748375`, -7383.057107588133}, {
       3136.0546809748375`, -7383.057107579654}, {
       1601.2816683329663`, -7383.057107579654}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0546809748375`, -7383.057107588133}, 
       8.478403694224562*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0546809748375`, -7383.057107592372}, \
{3136.054680983316, -7383.057107588133}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.05710759596}, {
        100.06762757313095`, -7383.05710759596}, {
        100.06762757313095`, -7383.057107592372}, {
        100, -7383.057107592372}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.05710759596}, {
       1426.770234431806, -7383.05710759596}, {
       1426.770234431806, -7383.057107592372}, {
       600.1016077422506, -7383.057107592372}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.05710759596}, {
       1342.4341698600624`, -7383.05710759596}, {
       1342.4341698600624`, -7383.057107592372}, {
       1324.773962747272, -7383.057107592372}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.05710759596}, {
       1601.2816683244878`, -7383.05710759596}, {
       1601.2816683244878`, -7383.057107592372}, {
       1601.2816681851828`, -7383.057107592372}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7383.05710759596}, {
       2617.0523178600088`, -7383.05710759596}, {
       2617.0523178600088`, -7383.057107592372}, {
       2601.786962912676, -7383.057107592372}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.05710759596}, {
       2584.883887978811, -7383.05710759596}, {
       2584.883887978811, -7383.057107592372}, {
       2584.88256130229, -7383.057107592372}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.05710759596}, {
       3695.1039183544954`, -7383.05710759596}, {
       3695.1039183544954`, -7383.057107592372}, {
       3595.7944257208364`, -7383.057107592372}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.05710759596}, {
       4142.649334928726, -7383.05710759596}, {
       4142.649334928726, -7383.057107592372}, {
       4101.622069085421, -7383.057107592372}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999619, -7383.05710759596}, {
       4699.999999999999, -7383.05710759596}, {
       4699.999999999999, -7383.057107592372}, {
       4699.999999999619, -7383.057107592372}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0546809748375`, -7383.05710759596}, {
      3136.0547793570636`, -7383.05710759596}, {
      3136.0547793570636`, -7383.057107592372}, {
      3136.0546809748375`, -7383.057107592372}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999997825, -7383.0571075932685`}, \
{4699.999999999619, -7383.057107592372}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999997825, -7383.0571075932685`}, 
       1.7939620114174595`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0547793588576`, -7383.057107595063}, {
       4699.999999997825, -7383.057107595063}, {
       4699.999999997825, -7383.0571075932685`}, {
       3136.0547793588576`, -7383.0571075932685`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0547793588576`, -7383.057107595063}, 
       1.7939620114174595`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0547793570636`, -7383.05710759596}, 
       {3136.0547793588576`, -7383.057107595063}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.057107596173}, {
        100.06762757313095`, -7383.057107596173}, {
        100.06762757313095`, -7383.05710759596}, {
        100, -7383.05710759596}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.057107596173}, {
       1426.770234431806, -7383.057107596173}, {
       1426.770234431806, -7383.05710759596}, {
       600.1016077422506, -7383.05710759596}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.057107596173}, {
       1342.4341698600624`, -7383.057107596173}, {
       1342.4341698600624`, -7383.05710759596}, {
       1324.773962747272, -7383.05710759596}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.057107596173}, {
       1601.2816683244878`, -7383.057107596173}, {
       1601.2816683244878`, -7383.05710759596}, {
       1601.2816681851828`, -7383.05710759596}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962912676, -7383.057107596173}, {
       2617.0523178600088`, -7383.057107596173}, {
       2617.0523178600088`, -7383.05710759596}, {
       2601.786962912676, -7383.05710759596}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.057107596173}, {
       2584.883887978811, -7383.057107596173}, {
       2584.883887978811, -7383.05710759596}, {
       2584.88256130229, -7383.05710759596}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546809748375`, -7383.057107596173}, {
       3136.0547793588576`, -7383.057107596173}, {
       3136.0547793588576`, -7383.05710759596}, {
       3136.0546809748375`, -7383.05710759596}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.057107596173}, {
       3695.103918354388, -7383.057107596173}, {
       3695.103918354388, -7383.05710759596}, {
       3595.7944257208364`, -7383.05710759596}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.057107596173}, {
       4142.649334928726, -7383.057107596173}, {
       4142.649334928726, -7383.05710759596}, {
       4101.622069085421, -7383.05710759596}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999619, -7383.057107596173}, {
      4699.999999999999, -7383.057107596173}, {
      4699.999999999999, -7383.05710759596}, {
      4699.999999999619, -7383.05710759596}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.103918354388, -7383.057107596012}, \
{3695.1039183544954`, -7383.05710759596}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3695.1039183544954`, -7383.057107596012}, 
       1.0704834121384371`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3695.1039183544954`, -7383.05710759612}, {
       4699.999999999512, -7383.05710759612}, {
       4699.999999999512, -7383.057107596012}, {
       3695.1039183544954`, -7383.057107596012}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999512, -7383.05710759612}, 
       1.0704834121384371`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999512, -7383.057107596173}, \
{4699.999999999619, -7383.05710759612}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.057107642998}, {
        100.06762757313095`, -7383.057107642998}, {
        100.06762757313095`, -7383.057107596173}, {
        100, -7383.057107596173}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.1016077422506, -7383.057107642998}, {
       1426.770234431806, -7383.057107642998}, {
       1426.770234431806, -7383.057107596173}, {
       600.1016077422506, -7383.057107596173}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.057107642998}, {
       1342.4341698600624`, -7383.057107642998}, {
       1342.4341698600624`, -7383.057107596173}, {
       1324.773962747272, -7383.057107596173}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.057107642998}, {
       2617.0523178600088`, -7383.057107642998}, {
       2617.0523178600088`, -7383.057107596173}, {
       2601.786962936088, -7383.057107596173}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.057107642998}, {
       2584.883887978811, -7383.057107642998}, {
       2584.883887978811, -7383.057107596173}, {
       2584.88256130229, -7383.057107596173}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546809748375`, -7383.057107642998}, {
       3136.0547793588576`, -7383.057107642998}, {
       3136.0547793588576`, -7383.057107596173}, {
       3136.0546809748375`, -7383.057107596173}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.057107642998}, {
       3695.103918354388, -7383.057107642998}, {
       3695.103918354388, -7383.057107596173}, {
       3595.7944257208364`, -7383.057107596173}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.057107642998}, {
       4142.649334928726, -7383.057107642998}, {
       4142.649334928726, -7383.057107596173}, {
       4101.622069085421, -7383.057107596173}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.057107642998}, {
       4699.999999999999, -7383.057107642998}, {
       4699.999999999999, -7383.057107596173}, {
       4699.999999999512, -7383.057107596173}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7383.057107642998}, {
      1601.2816683244878`, -7383.057107642998}, {
      1601.2816683244878`, -7383.057107596173}, {
      1601.2816681851828`, -7383.057107596173}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2601.786962912676, -7383.0571076078795`}, \
{2601.786962936088, -7383.057107596173}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2601.786962912676, -7383.0571076078795`}, 
       2.3411989761789098`*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816683478998`, -7383.057107631292}, {
       2601.786962912676, -7383.057107631292}, {
       2601.786962912676, -7383.0571076078795`}, {
       1601.2816683478998`, -7383.0571076078795`}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816683478998`, -7383.057107631292}, 
       2.3411989761789098`*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816683244878`, -7383.057107642998}, \
{1601.2816683478998`, -7383.057107631292}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.094352870168}, {
        100.04900495954591`, -7383.094352870168}, {
        100.04900495954591`, -7383.057107642998}, {
        100, -7383.057107642998}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.094352870168}, {
       1342.4341698600624`, -7383.094352870168}, {
       1342.4341698600624`, -7383.057107642998}, {
       1324.773962747272, -7383.057107642998}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.094352870168}, {
       1601.2816683478998`, -7383.094352870168}, {
       1601.2816683478998`, -7383.057107642998}, {
       1601.2816681851828`, -7383.057107642998}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.094352870168}, {
       2617.0523178600088`, -7383.094352870168}, {
       2617.0523178600088`, -7383.057107642998}, {
       2601.786962936088, -7383.057107642998}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.094352870168}, {
       2584.883887978811, -7383.094352870168}, {
       2584.883887978811, -7383.057107642998}, {
       2584.88256130229, -7383.057107642998}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546809748375`, -7383.094352870168}, {
       3136.0547793588576`, -7383.094352870168}, {
       3136.0547793588576`, -7383.057107642998}, {
       3136.0546809748375`, -7383.057107642998}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.094352870168}, {
       3695.103918354388, -7383.094352870168}, {
       3695.103918354388, -7383.057107642998}, {
       3595.7944257208364`, -7383.057107642998}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.094352870168}, {
       4142.649334928726, -7383.094352870168}, {
       4142.649334928726, -7383.057107642998}, {
       4101.622069085421, -7383.057107642998}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.094352870168}, {
       4699.999999999999, -7383.094352870168}, {
       4699.999999999999, -7383.057107642998}, {
       4699.999999999512, -7383.057107642998}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.1016077422506, -7383.094352870168}, {
      1426.770234431806, -7383.094352870168}, {
      1426.770234431806, -7383.057107642998}, {
      600.1016077422506, -7383.057107642998}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.04900495954591`, -7383.066418949791}, \
{100.06762757313095`, -7383.057107642998}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06762757313095`, -7383.066418949791}, 
       0.018622613585034323`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06762757313095`, -7383.085041563376}, {
       600.0829851286655, -7383.085041563376}, {
       600.0829851286655, -7383.066418949791}, {
       100.06762757313095`, -7383.066418949791}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0829851286655, -7383.085041563376}, 
       0.018622613585034323`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0829851286655, -7383.094352870168}, \
{600.1016077422506, -7383.085041563376}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.094410536337}, {
        100.04900495954591`, -7383.094410536337}, {
        100.04900495954591`, -7383.094352870168}, {
        100, -7383.094352870168}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.094410536337}, {
       1426.7702055987215`, -7383.094410536337}, {
       1426.7702055987215`, -7383.094352870168}, {
       600.0829851286655, -7383.094352870168}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.094410536337}, {
       1342.4341698600624`, -7383.094410536337}, {
       1342.4341698600624`, -7383.094352870168}, {
       1324.773962747272, -7383.094352870168}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.094410536337}, {
       1601.2816683478998`, -7383.094410536337}, {
       1601.2816683478998`, -7383.094352870168}, {
       1601.2816681851828`, -7383.094352870168}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.094410536337}, {
       2617.0523178600088`, -7383.094410536337}, {
       2617.0523178600088`, -7383.094352870168}, {
       2601.786962936088, -7383.094352870168}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.094410536337}, {
       2584.883887978811, -7383.094410536337}, {
       2584.883887978811, -7383.094352870168}, {
       2584.88256130229, -7383.094352870168}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.094410536337}, {
       3695.103918354388, -7383.094410536337}, {
       3695.103918354388, -7383.094352870168}, {
       3595.7944257208364`, -7383.094352870168}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.094410536337}, {
       4142.649334928726, -7383.094410536337}, {
       4142.649334928726, -7383.094352870168}, {
       4101.622069085421, -7383.094352870168}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.094410536337}, {
       4699.999999999999, -7383.094410536337}, {
       4699.999999999999, -7383.094352870168}, {
       4699.999999999512, -7383.094352870168}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0546809748375`, -7383.094410536337}, {
      3136.0547793588576`, -7383.094410536337}, {
      3136.0547793588576`, -7383.094352870168}, {
      3136.0546809748375`, -7383.094352870168}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1426.7702055987215`, -7383.094367286711}, \
{1426.770234431806, -7383.094352870168}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1426.770234431806, -7383.094367286711}, 0.00002883308445120238,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1426.770234431806, -7383.0943961197945`}, {
       3136.054652141753, -7383.0943961197945`}, {
       3136.054652141753, -7383.094367286711}, {
       1426.770234431806, -7383.094367286711}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054652141753, -7383.0943961197945`}, 
       0.00002883308445120238, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054652141753, -7383.094410536337}, \
{3136.0546809748375`, -7383.0943961197945`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.094434150866}, {
        100.04900495954591`, -7383.094434150866}, {
        100.04900495954591`, -7383.094410536337}, {
        100, -7383.094410536337}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.094434150866}, {
       1342.4341698600624`, -7383.094434150866}, {
       1342.4341698600624`, -7383.094410536337}, {
       1324.773962747272, -7383.094410536337}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.094434150866}, {
       1601.2816683478998`, -7383.094434150866}, {
       1601.2816683478998`, -7383.094410536337}, {
       1601.2816681851828`, -7383.094410536337}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.094434150866}, {
       2617.0523178600088`, -7383.094434150866}, {
       2617.0523178600088`, -7383.094410536337}, {
       2601.786962936088, -7383.094410536337}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88256130229, -7383.094434150866}, {
       2584.883887978811, -7383.094434150866}, {
       2584.883887978811, -7383.094410536337}, {
       2584.88256130229, -7383.094410536337}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546639490176`, -7383.094434150866}, {
       3136.0547793588576`, -7383.094434150866}, {
       3136.0547793588576`, -7383.094410536337}, {
       3136.0546639490176`, -7383.094410536337}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.094434150866}, {
       3695.103918354388, -7383.094434150866}, {
       3695.103918354388, -7383.094410536337}, {
       3595.7944257208364`, -7383.094410536337}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.094434150866}, {
       4142.649334928726, -7383.094434150866}, {
       4142.649334928726, -7383.094410536337}, {
       4101.622069085421, -7383.094410536337}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.094434150866}, {
       4699.999999999999, -7383.094434150866}, {
       4699.999999999999, -7383.094410536337}, {
       4699.999999999512, -7383.094410536337}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7383.094434150866}, {
      1426.7702055987215`, -7383.094434150866}, {
      1426.7702055987215`, -7383.094410536337}, {
      600.0829851286655, -7383.094410536337}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054652141753, -7383.094416439969}, \
{3136.0546639490176`, -7383.094410536337}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054652141753, -7383.094416439969}, 0.00001180726460473617,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1426.7702174059864`, -7383.094428247234}, {
       3136.054652141753, -7383.094428247234}, {
       3136.054652141753, -7383.094416439969}, {
       1426.7702174059864`, -7383.094416439969}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1426.7702174059864`, -7383.094428247234}, 
       0.00001180726460473617, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1426.7702055987215`, -7383.094434150866}, \
{1426.7702174059864`, -7383.094428247234}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.095886110292}, {
        100.0482789798328, -7383.095886110292}, {
        100.0482789798328, -7383.094434150866}, {
        100, -7383.094434150866}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.095886110292}, {
       1426.7702174059864`, -7383.095886110292}, {
       1426.7702174059864`, -7383.094434150866}, {
       600.0829851286655, -7383.094434150866}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.095886110292}, {
       1342.4341698600624`, -7383.095886110292}, {
       1342.4341698600624`, -7383.094434150866}, {
       1324.773962747272, -7383.094434150866}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.095886110292}, {
       1601.2816683478998`, -7383.095886110292}, {
       1601.2816683478998`, -7383.094434150866}, {
       1601.2816681851828`, -7383.094434150866}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.095886110292}, {
       2617.0523178600088`, -7383.095886110292}, {
       2617.0523178600088`, -7383.094434150866}, {
       2601.786962936088, -7383.094434150866}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546639490176`, -7383.095886110292}, {
       3136.0547793588576`, -7383.095886110292}, {
       3136.0547793588576`, -7383.094434150866}, {
       3136.0546639490176`, -7383.094434150866}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944257208364`, -7383.095886110292}, {
       3695.103918354388, -7383.095886110292}, {
       3695.103918354388, -7383.094434150866}, {
       3595.7944257208364`, -7383.094434150866}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.095886110292}, {
       4142.649334928726, -7383.095886110292}, {
       4142.649334928726, -7383.094434150866}, {
       4101.622069085421, -7383.094434150866}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.095886110292}, {
       4699.999999999999, -7383.095886110292}, {
       4699.999999999999, -7383.094434150866}, {
       4699.999999999512, -7383.094434150866}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88256130229, -7383.095886110292}, {
      2584.8838879788113`, -7383.095886110292}, {
      2584.8838879788113`, -7383.094434150866}, {
      2584.88256130229, -7383.094434150866}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0482789798328, -7383.094797140722}, \
{100.04900495954591`, -7383.094434150866}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.04900495954591`, -7383.094797140722}, 
       0.0007259797131180055, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.04900495954591`, -7383.095523120435}, {
       2584.881835322577, -7383.095523120435}, {
       2584.881835322577, -7383.094797140722}, {
       100.04900495954591`, -7383.094797140722}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881835322577, -7383.095523120435}, 
       0.0007259797131180055, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881835322577, -7383.095886110292}, \
{2584.88256130229, -7383.095523120435}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.095970931182}, {
        100.0482789798328, -7383.095970931182}, {
        100.0482789798328, -7383.095886110292}, {
        100, -7383.095886110292}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.095970931182}, {
       1426.7702174059864`, -7383.095970931182}, {
       1426.7702174059864`, -7383.095886110292}, {
       600.0829851286655, -7383.095886110292}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.095970931182}, {
       1342.4341698600624`, -7383.095970931182}, {
       1342.4341698600624`, -7383.095886110292}, {
       1324.773962747272, -7383.095886110292}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.095970931182}, {
       1601.2816683478998`, -7383.095970931182}, {
       1601.2816683478998`, -7383.095886110292}, {
       1601.2816681851828`, -7383.095886110292}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.095970931182}, {
       2617.0523178600088`, -7383.095970931182}, {
       2617.0523178600088`, -7383.095886110292}, {
       2601.786962936088, -7383.095886110292}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881835322577, -7383.095970931182}, {
       2584.8838879788113`, -7383.095970931182}, {
       2584.8838879788113`, -7383.095886110292}, {
       2584.881835322577, -7383.095886110292}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944681312815`, -7383.095970931182}, {
       3695.103918354388, -7383.095970931182}, {
       3695.103918354388, -7383.095886110292}, {
       3595.7944681312815`, -7383.095886110292}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.095970931182}, {
       4142.649334928726, -7383.095970931182}, {
       4142.649334928726, -7383.095886110292}, {
       4101.622069085421, -7383.095886110292}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.095970931182}, {
       4699.999999999999, -7383.095970931182}, {
       4699.999999999999, -7383.095886110292}, {
       4699.999999999512, -7383.095886110292}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0546639490176`, -7383.095970931182}, {
      3136.0547793588576`, -7383.095970931182}, {
      3136.0547793588576`, -7383.095886110292}, {
      3136.0546639490176`, -7383.095886110292}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3595.7944257208364`, -7383.0959073155145`}, \
{3595.7944681312815`, -7383.095886110292}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3595.7944257208364`, -7383.0959073155145`}, 
       0.00004241044508401451, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548217693026`, -7383.095949725959}, {
       3595.7944257208364`, -7383.095949725959}, {
       3595.7944257208364`, -7383.0959073155145`}, {
       3136.0548217693026`, -7383.0959073155145`}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548217693026`, -7383.095949725959}, 
       0.00004241044508401451, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0547793588576`, -7383.095970931182}, \
{3136.0548217693026`, -7383.095949725959}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.0981160436595`}, {
        100.0482789798328, -7383.0981160436595`}, {
        100.0482789798328, -7383.095970931182}, {
        100, -7383.095970931182}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.0981160436595`}, {
       1426.7702174059864`, -7383.0981160436595`}, {
       1426.7702174059864`, -7383.095970931182}, {
       600.0829851286655, -7383.095970931182}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.0981160436595`}, {
       1342.4330973038238`, -7383.0981160436595`}, {
       1342.4330973038238`, -7383.095970931182}, {
       1324.773962747272, -7383.095970931182}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.0981160436595`}, {
       1601.2816683478998`, -7383.0981160436595`}, {
       1601.2816683478998`, -7383.095970931182}, {
       1601.2816681851828`, -7383.095970931182}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.0981160436595`}, {
       2617.0523178600088`, -7383.0981160436595`}, {
       2617.0523178600088`, -7383.095970931182}, {
       2601.786962936088, -7383.095970931182}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0546639490176`, -7383.0981160436595`}, {
       3136.0548217693026`, -7383.0981160436595`}, {
       3136.0548217693026`, -7383.095970931182}, {
       3136.0546639490176`, -7383.095970931182}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944681312815`, -7383.0981160436595`}, {
       3695.103918354388, -7383.0981160436595`}, {
       3695.103918354388, -7383.095970931182}, {
       3595.7944681312815`, -7383.095970931182}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.0981160436595`}, {
       4142.649334928726, -7383.0981160436595`}, {
       4142.649334928726, -7383.095970931182}, {
       4101.622069085421, -7383.095970931182}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.0981160436595`}, {
       4699.999999999999, -7383.0981160436595`}, {
       4699.999999999999, -7383.095970931182}, {
       4699.999999999512, -7383.095970931182}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881835322577, -7383.0981160436595`}, {
      2584.883887978811, -7383.0981160436595`}, {
      2584.883887978811, -7383.095970931182}, {
      2584.881835322577, -7383.095970931182}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1342.4330973038238`, -7383.096507209301}, \
{1342.4341698600624`, -7383.095970931182}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1342.4341698600624`, -7383.096507209301}, 
       0.0010725562386668967`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1342.4341698600624`, -7383.09757976554}, {
       2584.880762766338, -7383.09757976554}, {
       2584.880762766338, -7383.096507209301}, {
       1342.4341698600624`, -7383.096507209301}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.880762766338, -7383.09757976554}, 
       0.0010725562386668967`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.880762766338, -7383.0981160436595`}, \
{2584.881835322577, -7383.09757976554}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.098405751123}, {
        100.0482789798328, -7383.098405751123}, {
        100.0482789798328, -7383.0981160436595`}, {
        100, -7383.0981160436595`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.098405751123}, {
       1426.7702174059864`, -7383.098405751123}, {
       1426.7702174059864`, -7383.0981160436595`}, {
       600.0829851286655, -7383.0981160436595`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.098405751123}, {
       1342.4330973038238`, -7383.098405751123}, {
       1342.4330973038238`, -7383.0981160436595`}, {
       1324.773962747272, -7383.0981160436595`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.098405751123}, {
       1601.2816683478998`, -7383.098405751123}, {
       1601.2816683478998`, -7383.0981160436595`}, {
       1601.2816681851828`, -7383.0981160436595`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7383.098405751123}, {
       2584.883887978811, -7383.098405751123}, {
       2584.883887978811, -7383.0981160436595`}, {
       2584.880762766338, -7383.0981160436595`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7383.098405751123}, {
       3136.0548217693026`, -7383.098405751123}, {
       3136.0548217693026`, -7383.0981160436595`}, {
       3136.0548088027494`, -7383.0981160436595`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.7944681312815`, -7383.098405751123}, {
       3695.103918354388, -7383.098405751123}, {
       3695.103918354388, -7383.0981160436595`}, {
       3595.7944681312815`, -7383.0981160436595`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.098405751123}, {
       4142.649334928726, -7383.098405751123}, {
       4142.649334928726, -7383.0981160436595`}, {
       4101.622069085421, -7383.0981160436595`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.098405751123}, {
       4699.999999999999, -7383.098405751123}, {
       4699.999999999999, -7383.0981160436595`}, {
       4699.999999999512, -7383.0981160436595`}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.786962936088, -7383.098405751123}, {
      2617.0523178600088`, -7383.098405751123}, {
      2617.0523178600088`, -7383.0981160436595`}, {
      2601.786962936088, -7383.0981160436595`}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0546639490176`, -7383.098188470525}, \
{3136.0548088027494`, -7383.0981160436595`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0546639490176`, -7383.098188470525}, 
       0.00014485373181493395`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2617.0524627137406`, -7383.0983333242575`}, {
       3136.0546639490176`, -7383.0983333242575`}, {
       3136.0546639490176`, -7383.098188470525}, {
       2617.0524627137406`, -7383.098188470525}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2617.0524627137406`, -7383.0983333242575`}, 
       0.00014485373181493395`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2617.0523178600088`, -7383.098405751123}, \
{2617.0524627137406`, -7383.0983333242575`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.098896662083}, {
        100.0482789798328, -7383.098896662083}, {
        100.0482789798328, -7383.098405751123}, {
        100, -7383.098405751123}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.098896662083}, {
       1426.7702174059864`, -7383.098896662083}, {
       1426.7702174059864`, -7383.098405751123}, {
       600.0829851286655, -7383.098405751123}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.098896662083}, {
       1342.4330973038238`, -7383.098896662083}, {
       1342.4330973038238`, -7383.098405751123}, {
       1324.773962747272, -7383.098405751123}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.098896662083}, {
       1601.2816683478998`, -7383.098896662083}, {
       1601.2816683478998`, -7383.098405751123}, {
       1601.2816681851828`, -7383.098405751123}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2601.786962936088, -7383.098896662083}, {
       2617.0524627137406`, -7383.098896662083}, {
       2617.0524627137406`, -7383.098405751123}, {
       2601.786962936088, -7383.098405751123}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7383.098896662083}, {
       2584.883642523331, -7383.098896662083}, {
       2584.883642523331, -7383.098405751123}, {
       2584.880762766338, -7383.098405751123}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7383.098896662083}, {
       3136.0548217693026`, -7383.098896662083}, {
       3136.0548217693026`, -7383.098405751123}, {
       3136.0548088027494`, -7383.098405751123}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.098896662083}, {
       4142.649334928726, -7383.098896662083}, {
       4142.649334928726, -7383.098405751123}, {
       4101.622069085421, -7383.098405751123}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.098896662083}, {
       4699.999999999999, -7383.098896662083}, {
       4699.999999999999, -7383.098405751123}, {
       4699.999999999512, -7383.098405751123}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3595.7944681312815`, -7383.098896662083}, {
      3695.103918354388, -7383.098896662083}, {
      3695.103918354388, -7383.098405751123}, {
      3595.7944681312815`, -7383.098405751123}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883642523331, -7383.098528478863}, \
{2584.883887978811, -7383.098405751123}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883887978811, -7383.098528478863}, 0.0002454554797262226, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883887978811, -7383.098773934343}, {
       3595.794222675802, -7383.098773934343}, {
       3595.794222675802, -7383.098528478863}, {
       2584.883887978811, -7383.098528478863}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3595.794222675802, -7383.098773934343}, 
       0.0002454554797262226, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3595.794222675802, -7383.098896662083}, \
{3595.7944681312815`, -7383.098773934343}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7383.098896970706}, {
        100.0482789798328, -7383.098896970706}, {
        100.0482789798328, -7383.098896662083}, {
        100, -7383.098896662083}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7383.098896970706}, {
       1426.7702174059864`, -7383.098896970706}, {
       1426.7702174059864`, -7383.098896662083}, {
       600.0829851286655, -7383.098896662083}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7383.098896970706}, {
       1342.4330973038238`, -7383.098896970706}, {
       1342.4330973038238`, -7383.098896662083}, {
       1324.773962747272, -7383.098896662083}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7383.098896970706}, {
       1601.2816681935883`, -7383.098896970706}, {
       1601.2816681935883`, -7383.098896662083}, {
       1601.2816681851828`, -7383.098896662083}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7383.098896970706}, {
       2584.883642523331, -7383.098896970706}, {
       2584.883642523331, -7383.098896662083}, {
       2584.880762766338, -7383.098896662083}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7383.098896970706}, {
       3136.0548217693026`, -7383.098896970706}, {
       3136.0548217693026`, -7383.098896662083}, {
       3136.0548088027494`, -7383.098896662083}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7383.098896970706}, {
       3695.103918354388, -7383.098896970706}, {
       3695.103918354388, -7383.098896662083}, {
       3595.794222675802, -7383.098896662083}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7383.098896970706}, {
       4142.649334928726, -7383.098896970706}, {
       4142.649334928726, -7383.098896662083}, {
       4101.622069085421, -7383.098896662083}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7383.098896970706}, {
       4699.999999999999, -7383.098896970706}, {
       4699.999999999999, -7383.098896662083}, {
       4699.999999999512, -7383.098896662083}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.786962936088, -7383.098896970706}, {
      2617.0524627137406`, -7383.098896970706}, {
      2617.0524627137406`, -7383.098896662083}, {
      2601.786962936088, -7383.098896662083}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681935883`, -7383.098896739239}, \
{1601.2816683478998`, -7383.098896662083}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816683478998`, -7383.098896739239}, 
       1.5431154136795737`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816683478998`, -7383.09889689355}, {
       2601.7869627817763`, -7383.09889689355}, {
       2601.7869627817763`, -7383.098896739239}, {
       1601.2816683478998`, -7383.098896739239}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2601.7869627817763`, -7383.09889689355}, 
       1.5431154136795737`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2601.7869627817763`, -7383.098896970706}, \
{2601.786962936088, -7383.09889689355}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7397.265883585583}, {
        100.0482789798328, -7397.265883585583}, {
        100.0482789798328, -7383.098896970706}, {
        100, -7383.098896970706}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7397.265883585583}, {
       1419.6867240985478`, -7397.265883585583}, {
       1419.6867240985478`, -7383.098896970706}, {
       600.0829851286655, -7383.098896970706}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7397.265883585583}, {
       1342.4330973038238`, -7397.265883585583}, {
       1342.4330973038238`, -7383.098896970706}, {
       1324.773962747272, -7383.098896970706}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7397.265883585583}, {
       1601.2816681935883`, -7397.265883585583}, {
       1601.2816681935883`, -7383.098896970706}, {
       1601.2816681851828`, -7383.098896970706}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7397.265883585583}, {
       2584.883642523331, -7397.265883585583}, {
       2584.883642523331, -7383.098896970706}, {
       2584.880762766338, -7383.098896970706}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7397.265883585583}, {
       3136.0548217693026`, -7397.265883585583}, {
       3136.0548217693026`, -7383.098896970706}, {
       3136.0548088027494`, -7383.098896970706}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7397.265883585583}, {
       3695.103918354388, -7397.265883585583}, {
       3695.103918354388, -7383.098896970706}, {
       3595.794222675802, -7383.098896970706}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7397.265883585583}, {
       4142.649334928726, -7397.265883585583}, {
       4142.649334928726, -7383.098896970706}, {
       4101.622069085421, -7383.098896970706}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999512, -7397.265883585583}, {
       4699.999999999999, -7397.265883585583}, {
       4699.999999999999, -7383.098896970706}, {
       4699.999999999512, -7383.098896970706}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2601.7869627817763`, -7397.265883585583}, {
      2617.0524627137406`, -7397.265883585583}, {
      2617.0524627137406`, -7383.098896970706}, {
      2601.7869627817763`, -7383.098896970706}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1419.6867240985478`, -7386.640643624425}, \
{1426.7702174059864`, -7383.098896970706}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1426.7702174059864`, -7386.640643624425}, 7.083493307438475, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1426.7702174059864`, -7393.7241369318635`}, {
       2594.703469474338, -7393.7241369318635`}, {
       2594.703469474338, -7386.640643624425}, {
       1426.7702174059864`, -7386.640643624425}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2594.703469474338, -7393.7241369318635`}, 7.083493307438475, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2594.703469474338, -7397.265883585583}, \
{2601.7869627817763`, -7393.7241369318635`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7397.26588358567}, {
       1419.6867240985478`, -7397.26588358567}, {
       1419.6867240985478`, -7397.265883585583}, {
       600.0829851286655, -7397.265883585583}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7397.26588358567}, {
       1342.4330973038238`, -7397.26588358567}, {
       1342.4330973038238`, -7397.265883585583}, {
       1324.773962747272, -7397.265883585583}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7397.26588358567}, {
       1601.2816681935883`, -7397.26588358567}, {
       1601.2816681935883`, -7397.265883585583}, {
       1601.2816681851828`, -7397.265883585583}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7397.26588358567}, {
       2617.0524627137406`, -7397.26588358567}, {
       2617.0524627137406`, -7397.265883585583}, {
       2594.703469474338, -7397.265883585583}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7397.26588358567}, {
       2584.883642523331, -7397.26588358567}, {
       2584.883642523331, -7397.265883585583}, {
       2584.880762766338, -7397.265883585583}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7397.26588358567}, {
       3136.0548217693026`, -7397.26588358567}, {
       3136.0548217693026`, -7397.265883585583}, {
       3136.0548088027494`, -7397.265883585583}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7397.26588358567}, {
       3695.103918354388, -7397.26588358567}, {
       3695.103918354388, -7397.265883585583}, {
       3595.794222675802, -7397.265883585583}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4101.622069085421, -7397.26588358567}, {
       4142.649334928726, -7397.26588358567}, {
       4142.649334928726, -7397.265883585583}, {
       4101.622069085421, -7397.265883585583}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999555, -7397.26588358567}, {
       4699.999999999999, -7397.26588358567}, {
       4699.999999999999, -7397.265883585583}, {
       4699.999999999555, -7397.265883585583}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7397.26588358567}, {
       100.0482789798328, -7397.26588358567}, {
       100.0482789798328, -7397.265883585583}, {
       100, -7397.265883585583}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999512, -7397.265883585605}, \
{4699.999999999555, -7397.265883585583}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999512, -7397.265883585605}, 4.374795176719905*^-11,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.04827897987654`, -7397.265883585648}, {
       4699.999999999512, -7397.265883585648}, {
       4699.999999999512, -7397.265883585605}, {
       100.04827897987654`, -7397.265883585605}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.04827897987654`, -7397.265883585648}, 
       4.374795176719905*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0482789798328, -7397.26588358567}, \
{100.04827897987654`, -7397.265883585648}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7441.096098496102}, {
        100.04827897987654`, -7441.096098496102}, {
        100.04827897987654`, -7397.26588358567}, {
        100, -7397.26588358567}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7441.096098496102}, {
       1419.6867240985478`, -7441.096098496102}, {
       1419.6867240985478`, -7397.26588358567}, {
       600.0829851286655, -7397.26588358567}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7441.096098496102}, {
       1342.4330973038238`, -7441.096098496102}, {
       1342.4330973038238`, -7397.26588358567}, {
       1324.773962747272, -7397.26588358567}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7441.096098496102}, {
       1601.2816681935883`, -7441.096098496102}, {
       1601.2816681935883`, -7397.26588358567}, {
       1601.2816681851828`, -7397.26588358567}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7441.096098496102}, {
       2584.883642523331, -7441.096098496102}, {
       2584.883642523331, -7397.26588358567}, {
       2584.880762766338, -7397.26588358567}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7441.096098496102}, {
       3136.0548217693026`, -7441.096098496102}, {
       3136.0548217693026`, -7397.26588358567}, {
       3136.0548088027494`, -7397.26588358567}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7441.096098496102}, {
       3695.103918354388, -7441.096098496102}, {
       3695.103918354388, -7397.26588358567}, {
       3595.794222675802, -7397.26588358567}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.537176540636, -7441.096098496102}, {
       4142.649334928725, -7441.096098496102}, {
       4142.649334928725, -7397.26588358567}, {
       4123.537176540636, -7397.26588358567}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999555, -7441.096098496102}, {
       4699.999999999999, -7441.096098496102}, {
       4699.999999999999, -7397.26588358567}, {
       4699.999999999555, -7397.26588358567}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2594.703469474338, -7441.096098496102}, {
      2617.0524627137406`, -7441.096098496102}, {
      2617.0524627137406`, -7397.26588358567}, {
      2594.703469474338, -7397.26588358567}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4101.622069085421, -7408.223437313278}, \
{4123.537176540636, -7397.26588358567}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4101.622069085421, -7408.223437313278}, 21.915107455216003`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.9675701689566`, -7430.138544768494}, {
       4101.622069085421, -7430.138544768494}, {
       4101.622069085421, -7408.223437313278}, {
       2638.9675701689566`, -7408.223437313278}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.9675701689566`, -7430.138544768494}, 21.915107455216003`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2617.0524627137406`, -7441.096098496102}, \
{2638.9675701689566`, -7430.138544768494}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7441.096098496314}, {
        100.04827897987654`, -7441.096098496314}, {
        100.04827897987654`, -7441.096098496102}, {
        100, -7441.096098496102}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7441.096098496314}, {
       1419.6867240985478`, -7441.096098496314}, {
       1419.6867240985478`, -7441.096098496102}, {
       600.0829851286655, -7441.096098496102}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7441.096098496314}, {
       1342.4330973038238`, -7441.096098496314}, {
       1342.4330973038238`, -7441.096098496102}, {
       1324.773962747272, -7441.096098496102}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7441.096098496314}, {
       1601.2816681935883`, -7441.096098496314}, {
       1601.2816681935883`, -7441.096098496102}, {
       1601.2816681851828`, -7441.096098496102}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7441.096098496314}, {
       2638.96757016885, -7441.096098496314}, {
       2638.96757016885, -7441.096098496102}, {
       2594.703469474338, -7441.096098496102}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880762766338, -7441.096098496314}, {
       2584.883642523331, -7441.096098496314}, {
       2584.883642523331, -7441.096098496102}, {
       2584.880762766338, -7441.096098496102}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7441.096098496314}, {
       3136.0548217693026`, -7441.096098496314}, {
       3136.0548217693026`, -7441.096098496102}, {
       3136.0548088027494`, -7441.096098496102}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7441.096098496314}, {
       3695.103918354388, -7441.096098496314}, {
       3695.103918354388, -7441.096098496102}, {
       3595.794222675802, -7441.096098496102}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.537176540636, -7441.096098496314}, {
       4142.649334928725, -7441.096098496314}, {
       4142.649334928725, -7441.096098496102}, {
       4123.537176540636, -7441.096098496102}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999555, -7441.096098496314}, {
      4699.999999999998, -7441.096098496314}, {
      4699.999999999998, -7441.096098496102}, {
      4699.999999999555, -7441.096098496102}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2638.96757016885, -7441.096098496155}, \
{2638.9675701689566`, -7441.096098496102}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.9675701689566`, -7441.096098496155}, 
       1.0607366752363522`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.9675701689566`, -7441.096098496261}, {
       4699.999999999449, -7441.096098496261}, {
       4699.999999999449, -7441.096098496155}, {
       2638.9675701689566`, -7441.096098496155}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999449, -7441.096098496261}, 
       1.0607366752363522`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999449, -7441.096098496314}, \
{4699.999999999555, -7441.096098496261}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7441.096529787959}, {
        100.04827897987654`, -7441.096529787959}, {
        100.04827897987654`, -7441.096098496314}, {
        100, -7441.096098496314}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7441.096529787959}, {
       1419.6867240985478`, -7441.096529787959}, {
       1419.6867240985478`, -7441.096098496314}, {
       600.0829851286655, -7441.096098496314}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7441.096529787959}, {
       1342.4330973038238`, -7441.096529787959}, {
       1342.4330973038238`, -7441.096098496314}, {
       1324.773962747272, -7441.096098496314}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7441.096529787959}, {
       1601.2816681935883`, -7441.096529787959}, {
       1601.2816681935883`, -7441.096098496314}, {
       1601.2816681851828`, -7441.096098496314}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7441.096529787959}, {
       2584.883642523331, -7441.096529787959}, {
       2584.883642523331, -7441.096098496314}, {
       2584.880978412161, -7441.096098496314}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7441.096529787959}, {
       3136.0548217693026`, -7441.096529787959}, {
       3136.0548217693026`, -7441.096098496314}, {
       3136.0548088027494`, -7441.096098496314}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.794222675802, -7441.096529787959}, {
       3695.103918354388, -7441.096529787959}, {
       3695.103918354388, -7441.096098496314}, {
       3595.794222675802, -7441.096098496314}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.537176540636, -7441.096529787959}, {
       4142.649334928725, -7441.096529787959}, {
       4142.649334928725, -7441.096098496314}, {
       4123.537176540636, -7441.096098496314}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999449, -7441.096529787959}, {
       4699.999999999998, -7441.096529787959}, {
       4699.999999999998, -7441.096098496314}, {
       4699.999999999449, -7441.096098496314}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2594.703469474338, -7441.096529787959}, {
      2638.96757016885, -7441.096529787959}, {
      2638.96757016885, -7441.096098496314}, {
      2594.703469474338, -7441.096098496314}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.880762766338, -7441.0962063192255`}, \
{2584.880978412161, -7441.096098496314}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.880762766338, -7441.0962063192255`}, 
       0.0002156458225470101, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.967785814673, -7441.096421965048}, {
       2584.880762766338, -7441.096421965048}, {
       2584.880762766338, -7441.0962063192255`}, {
       2638.967785814673, -7441.0962063192255`}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.967785814673, -7441.096421965048}, 0.0002156458225470101, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2638.96757016885, -7441.096529787959}, \
{2638.967785814673, -7441.096421965048}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7441.0965410300205`}, {
        100.04827897987654`, -7441.0965410300205`}, {
        100.04827897987654`, -7441.096529787959}, {
        100, -7441.096529787959}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7441.0965410300205`}, {
       1419.6867240985478`, -7441.0965410300205`}, {
       1419.6867240985478`, -7441.096529787959}, {
       600.0829851286655, -7441.096529787959}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7441.0965410300205`}, {
       1342.4330973038238`, -7441.0965410300205`}, {
       1342.4330973038238`, -7441.096529787959}, {
       1324.773962747272, -7441.096529787959}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7441.0965410300205`}, {
       1601.2816681935883`, -7441.0965410300205`}, {
       1601.2816681935883`, -7441.096529787959}, {
       1601.2816681851828`, -7441.096529787959}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7441.0965410300205`}, {
       2638.967785814673, -7441.0965410300205`}, {
       2638.967785814673, -7441.096529787959}, {
       2594.703469474338, -7441.096529787959}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7441.0965410300205`}, {
       2584.883642523331, -7441.0965410300205`}, {
       2584.883642523331, -7441.096529787959}, {
       2584.880978412161, -7441.096529787959}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7441.0965410300205`}, {
       3136.054816148272, -7441.0965410300205`}, {
       3136.054816148272, -7441.096529787959}, {
       3136.0548088027494`, -7441.096529787959}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.537176540636, -7441.0965410300205`}, {
       4142.649334928725, -7441.0965410300205`}, {
       4142.649334928725, -7441.096529787959}, {
       4123.537176540636, -7441.096529787959}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999449, -7441.0965410300205`}, {
       4699.999999999998, -7441.0965410300205`}, {
       4699.999999999998, -7441.096529787959}, {
       4699.999999999449, -7441.096529787959}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3595.794222675802, -7441.0965410300205`}, {
      3695.103918354388, -7441.0965410300205`}, {
      3695.103918354388, -7441.096529787959}, {
      3595.794222675802, -7441.096529787959}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054816148272, -7441.096532598474}, \
{3136.0548217693026`, -7441.096529787959}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548217693026`, -7441.096532598474}, 
       5.621030615983008*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548217693026`, -7441.096538219505}, {
       3595.7942170547713`, -7441.096538219505}, {
       3595.7942170547713`, -7441.096532598474}, {
       3136.0548217693026`, -7441.096532598474}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3595.7942170547713`, -7441.096538219505}, 
       5.621030615983008*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3595.7942170547713`, -7441.0965410300205`}, \
{3595.794222675802, -7441.096538219505}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7441.136456102418}, {
       1419.6867240985478`, -7441.136456102418}, {
       1419.6867240985478`, -7441.0965410300205`}, {
       600.0829851286655, -7441.0965410300205`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7441.136456102418}, {
       1342.4330973038238`, -7441.136456102418}, {
       1342.4330973038238`, -7441.0965410300205`}, {
       1324.773962747272, -7441.0965410300205`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7441.136456102418}, {
       1601.2816681935883`, -7441.136456102418}, {
       1601.2816681935883`, -7441.0965410300205`}, {
       1601.2816681851828`, -7441.0965410300205`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7441.136456102418}, {
       2638.967785814673, -7441.136456102418}, {
       2638.967785814673, -7441.0965410300205`}, {
       2594.703469474338, -7441.0965410300205`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7441.136456102418}, {
       2584.883642523331, -7441.136456102418}, {
       2584.883642523331, -7441.0965410300205`}, {
       2584.880978412161, -7441.0965410300205`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7441.136456102418}, {
       3136.054816148272, -7441.136456102418}, {
       3136.054816148272, -7441.0965410300205`}, {
       3136.0548088027494`, -7441.0965410300205`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.81417459097, -7441.136456102418}, {
       3695.103918354388, -7441.136456102418}, {
       3695.103918354388, -7441.0965410300205`}, {
       3595.81417459097, -7441.0965410300205`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4123.537176540636, -7441.136456102418}, {
       4142.649334928725, -7441.136456102418}, {
       4142.649334928725, -7441.0965410300205`}, {
       4123.537176540636, -7441.0965410300205`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999449, -7441.136456102418}, {
       4699.999999999998, -7441.136456102418}, {
       4699.999999999998, -7441.0965410300205`}, {
       4699.999999999449, -7441.0965410300205`}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7441.136456102418}, {
       100.04827897987654`, -7441.136456102418}, {
       100.04827897987654`, -7441.0965410300205`}, {
       100, -7441.0965410300205`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3595.7942170547713`, -7441.10651979812}, \
{3595.81417459097, -7441.0965410300205`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3595.7942170547713`, -7441.10651979812}, 0.019957536198983238`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06823651607553`, -7441.126477334319}, {
       3595.7942170547713`, -7441.126477334319}, {
       3595.7942170547713`, -7441.10651979812}, {
       100.06823651607553`, -7441.10651979812}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06823651607553`, -7441.126477334319}, 
       0.019957536198983238`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.04827897987654`, -7441.136456102418}, \
{100.06823651607553`, -7441.126477334319}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7443.590772353553}, {
        100.06823651607553`, -7443.590772353553}, {
        100.06823651607553`, -7441.136456102418}, {
        100, -7441.136456102418}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7443.590772353553}, {
       1342.4330973038238`, -7443.590772353553}, {
       1342.4330973038238`, -7441.136456102418}, {
       1324.773962747272, -7441.136456102418}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7443.590772353553}, {
       1601.2816681935883`, -7443.590772353553}, {
       1601.2816681935883`, -7441.136456102418}, {
       1601.2816681851828`, -7441.136456102418}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7443.590772353553}, {
       2638.967785814673, -7443.590772353553}, {
       2638.967785814673, -7441.136456102418}, {
       2594.703469474338, -7441.136456102418}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7443.590772353553}, {
       2584.883642523331, -7443.590772353553}, {
       2584.883642523331, -7441.136456102418}, {
       2584.880978412161, -7441.136456102418}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7443.590772353553}, {
       3136.054816148272, -7443.590772353553}, {
       3136.054816148272, -7441.136456102418}, {
       3136.0548088027494`, -7441.136456102418}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.81417459097, -7443.590772353553}, {
       3695.103918354388, -7443.590772353553}, {
       3695.103918354388, -7441.136456102418}, {
       3595.81417459097, -7441.136456102418}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.7643346662035`, -7443.590772353553}, {
       4142.649334928725, -7443.590772353553}, {
       4142.649334928725, -7441.136456102418}, {
       4124.7643346662035`, -7441.136456102418}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999449, -7443.590772353553}, {
       4699.999999999998, -7443.590772353553}, {
       4699.999999999998, -7441.136456102418}, {
       4699.999999999449, -7441.136456102418}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7443.590772353553}, {
      1419.6867240985478`, -7443.590772353553}, {
      1419.6867240985478`, -7441.136456102418}, {
      600.0829851286655, -7441.136456102418}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4123.537176540636, -7441.7500351652025`}, \
{4124.7643346662035`, -7441.136456102418}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4123.537176540636, -7441.7500351652025`}, 1.227158125567204, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1420.913882224115, -7442.97719329077}, {
       4123.537176540636, -7442.97719329077}, {
       4123.537176540636, -7441.7500351652025`}, {
       1420.913882224115, -7441.7500351652025`}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1420.913882224115, -7442.97719329077}, 1.227158125567204, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1419.6867240985478`, -7443.590772353553}, \
{1420.913882224115, -7442.97719329077}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7443.590772354601}, {
        100.06823651607553`, -7443.590772354601}, {
        100.06823651607553`, -7443.590772353553}, {
        100, -7443.590772353553}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7443.590772354601}, {
       1420.913882224115, -7443.590772354601}, {
       1420.913882224115, -7443.590772353553}, {
       600.0829851286655, -7443.590772353553}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7443.590772354601}, {
       1342.4330973033, -7443.590772354601}, {
       1342.4330973033, -7443.590772353553}, {
       1324.773962747272, -7443.590772353553}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7443.590772354601}, {
       1601.2816681935883`, -7443.590772354601}, {
       1601.2816681935883`, -7443.590772353553}, {
       1601.2816681851828`, -7443.590772353553}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7443.590772354601}, {
       2638.967785814673, -7443.590772354601}, {
       2638.967785814673, -7443.590772353553}, {
       2594.703469474338, -7443.590772353553}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7443.590772354601}, {
       2584.883642523331, -7443.590772354601}, {
       2584.883642523331, -7443.590772353553}, {
       2584.880978412161, -7443.590772353553}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7443.590772354601}, {
       3136.054816148272, -7443.590772354601}, {
       3136.054816148272, -7443.590772353553}, {
       3136.0548088027494`, -7443.590772353553}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.81417459097, -7443.590772354601}, {
       3695.103918354388, -7443.590772354601}, {
       3695.103918354388, -7443.590772353553}, {
       3595.81417459097, -7443.590772353553}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.7643346662035`, -7443.590772354601}, {
       4142.649334928725, -7443.590772354601}, {
       4142.649334928725, -7443.590772353553}, {
       4124.7643346662035`, -7443.590772353553}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999449, -7443.590772354601}, {
      4699.999999999998, -7443.590772354601}, {
      4699.999999999998, -7443.590772353553}, {
      4699.999999999449, -7443.590772353553}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1342.4330973033, -7443.590772353815}, \
{1342.4330973038238`, -7443.590772353553}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1342.4330973038238`, -7443.590772353815}, 
       5.237321628824632*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1342.4330973038238`, -7443.590772354339}, {
       4699.999999998925, -7443.590772354339}, {
       4699.999999998925, -7443.590772353815}, {
       1342.4330973038238`, -7443.590772353815}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999998925, -7443.590772354339}, 
       5.237321628824632*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999998925, -7443.590772354601}, \
{4699.999999999449, -7443.590772354339}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7443.590772362292}, {
        100.06823651607553`, -7443.590772362292}, {
        100.06823651607553`, -7443.590772354601}, {
        100, -7443.590772354601}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7443.590772362292}, {
       1420.913882224115, -7443.590772362292}, {
       1420.913882224115, -7443.590772354601}, {
       600.0829851286655, -7443.590772354601}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7443.590772362292}, {
       1342.4330973033, -7443.590772362292}, {
       1342.4330973033, -7443.590772354601}, {
       1324.773962747272, -7443.590772354601}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7443.590772362292}, {
       2638.967785814673, -7443.590772362292}, {
       2638.967785814673, -7443.590772354601}, {
       2594.703469474338, -7443.590772354601}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7443.590772362292}, {
       2584.883642523331, -7443.590772362292}, {
       2584.883642523331, -7443.590772354601}, {
       2584.880978412161, -7443.590772354601}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7443.590772362292}, {
       3136.054816148272, -7443.590772362292}, {
       3136.054816148272, -7443.590772354601}, {
       3136.0548088027494`, -7443.590772354601}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3595.814174594816, -7443.590772362292}, {
       3695.103918354388, -7443.590772362292}, {
       3695.103918354388, -7443.590772354601}, {
       3595.814174594816, -7443.590772354601}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.7643346662035`, -7443.590772362292}, {
       4142.649334928725, -7443.590772362292}, {
       4142.649334928725, -7443.590772354601}, {
       4124.7643346662035`, -7443.590772354601}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998925, -7443.590772362292}, {
       4699.999999999998, -7443.590772362292}, {
       4699.999999999998, -7443.590772354601}, {
       4699.999999998925, -7443.590772354601}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7443.590772362292}, {
      1601.2816681935883`, -7443.590772362292}, {
      1601.2816681935883`, -7443.590772354601}, {
      1601.2816681851828`, -7443.590772354601}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3595.81417459097, -7443.590772356523}, \
{3595.814174594816, -7443.590772354601}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3595.81417459097, -7443.590772356523}, 3.845954599798005*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681974343`, -7443.59077236037}, {
       3595.81417459097, -7443.59077236037}, {
       3595.81417459097, -7443.590772356523}, {
       1601.2816681974343`, -7443.590772356523}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681974343`, -7443.59077236037}, 3.845954599798005*^-9,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681935883`, -7443.590772362292}, \
{1601.2816681974343`, -7443.59077236037}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7447.798019890215}, {
        100.06823651607553`, -7447.798019890215}, {
        100.06823651607553`, -7443.590772362292}, {
        100, -7443.590772362292}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7447.798019890215}, {
       1418.8102584601538`, -7447.798019890215}, {
       1418.8102584601538`, -7443.590772362292}, {
       600.0829851286655, -7443.590772362292}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7447.798019890215}, {
       1342.4330973033, -7447.798019890215}, {
       1342.4330973033, -7443.590772362292}, {
       1324.773962747272, -7443.590772362292}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7447.798019890215}, {
       1601.2816681974343`, -7447.798019890215}, {
       1601.2816681974343`, -7443.590772362292}, {
       1601.2816681851828`, -7443.590772362292}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7447.798019890215}, {
       2638.967785814673, -7447.798019890215}, {
       2638.967785814673, -7443.590772362292}, {
       2594.703469474338, -7443.590772362292}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7447.798019890215}, {
       2584.883642523331, -7447.798019890215}, {
       2584.883642523331, -7443.590772362292}, {
       2584.880978412161, -7443.590772362292}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7447.798019890215}, {
       3136.054816148272, -7447.798019890215}, {
       3136.054816148272, -7443.590772362292}, {
       3136.0548088027494`, -7443.590772362292}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.7643346662035`, -7447.798019890215}, {
       4142.649334928725, -7447.798019890215}, {
       4142.649334928725, -7443.590772362292}, {
       4124.7643346662035`, -7443.590772362292}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998925, -7447.798019890215}, {
       4699.999999999998, -7447.798019890215}, {
       4699.999999999998, -7443.590772362292}, {
       4699.999999998925, -7443.590772362292}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3595.814174594816, -7447.798019890215}, {
      3695.103918354388, -7447.798019890215}, {
      3695.103918354388, -7443.590772362292}, {
      3595.814174594816, -7443.590772362292}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1418.8102584601538`, -7444.642584244273}, \
{1420.913882224115, -7443.590772362292}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1420.913882224115, -7444.642584244273}, 2.1036237639612807`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1420.913882224115, -7446.746208008234}, {
       3593.7105508308546`, -7446.746208008234}, {
       3593.7105508308546`, -7444.642584244273}, {
       1420.913882224115, -7444.642584244273}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3593.7105508308546`, -7446.746208008234}, 
       2.1036237639612807`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3593.7105508308546`, -7447.798019890215}, \
{3595.814174594816, -7446.746208008234}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7447.897586252215}, {
        100.01845333507548`, -7447.897586252215}, {
        100.01845333507548`, -7447.798019890215}, {
        100, -7447.798019890215}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7447.897586252215}, {
       1418.8102584601538`, -7447.897586252215}, {
       1418.8102584601538`, -7447.798019890215}, {
       600.0829851286655, -7447.798019890215}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7447.897586252215}, {
       1342.4330973033, -7447.897586252215}, {
       1342.4330973033, -7447.798019890215}, {
       1324.773962747272, -7447.798019890215}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7447.897586252215}, {
       1601.2816681974343`, -7447.897586252215}, {
       1601.2816681974343`, -7447.798019890215}, {
       1601.2816681851828`, -7447.798019890215}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7447.897586252215}, {
       2638.967785814673, -7447.897586252215}, {
       2638.967785814673, -7447.798019890215}, {
       2594.703469474338, -7447.798019890215}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7447.897586252215}, {
       2584.883642523331, -7447.897586252215}, {
       2584.883642523331, -7447.798019890215}, {
       2584.880978412161, -7447.798019890215}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7447.897586252215}, {
       3136.054816148272, -7447.897586252215}, {
       3136.054816148272, -7447.798019890215}, {
       3136.0548088027494`, -7447.798019890215}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7105508308546`, -7447.897586252215}, {
       3695.103918354388, -7447.897586252215}, {
       3695.103918354388, -7447.798019890215}, {
       3593.7105508308546`, -7447.798019890215}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998925, -7447.897586252215}, {
       4699.999999999998, -7447.897586252215}, {
       4699.999999999998, -7447.798019890215}, {
       4699.999999998925, -7447.798019890215}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4124.7643346662035`, -7447.897586252215}, {
      4142.649334928725, -7447.897586252215}, {
      4142.649334928725, -7447.798019890215}, {
      4124.7643346662035`, -7447.798019890215}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.01845333507548`, -7447.8229114807145`}, \
{100.06823651607553`, -7447.798019890215}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.06823651607553`, -7447.8229114807145`}, 
       0.04978318100004489, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.06823651607553`, -7447.872694661714}, {
       4124.714551485204, -7447.872694661714}, {
       4124.714551485204, -7447.8229114807145`}, {
       100.06823651607553`, -7447.8229114807145`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4124.714551485204, -7447.872694661714}, 0.04978318100004489, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4124.714551485204, -7447.897586252215}, \
{4124.7643346662035`, -7447.872694661714}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7447.897589295347}, {
        100.01845333507548`, -7447.897589295347}, {
        100.01845333507548`, -7447.897586252215}, {
        100, -7447.897586252215}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7447.897589295347}, {
       1418.8102584601538`, -7447.897589295347}, {
       1418.8102584601538`, -7447.897586252215}, {
       600.0829851286655, -7447.897586252215}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7447.897589295347}, {
       1342.4330973033, -7447.897589295347}, {
       1342.4330973033, -7447.897586252215}, {
       1324.773962747272, -7447.897586252215}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7447.897589295347}, {
       1601.2816681974343`, -7447.897589295347}, {
       1601.2816681974343`, -7447.897586252215}, {
       1601.2816681851828`, -7447.897586252215}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2594.703469474338, -7447.897589295347}, {
       2638.967785814673, -7447.897589295347}, {
       2638.967785814673, -7447.897586252215}, {
       2594.703469474338, -7447.897586252215}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7447.897589295347}, {
       2584.883642523331, -7447.897589295347}, {
       2584.883642523331, -7447.897586252215}, {
       2584.880978412161, -7447.897586252215}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7105523524206`, -7447.897589295347}, {
       3695.1039183543876`, -7447.897589295347}, {
       3695.1039183543876`, -7447.897586252215}, {
       3593.7105523524206`, -7447.897586252215}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7447.897589295347}, {
       4142.649334928725, -7447.897589295347}, {
       4142.649334928725, -7447.897586252215}, {
       4124.714551485204, -7447.897586252215}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998925, -7447.897589295347}, {
       4699.999999999998, -7447.897589295347}, {
       4699.999999999998, -7447.897586252215}, {
       4699.999999998925, -7447.897586252215}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548088027494`, -7447.897589295347}, {
      3136.054816148272, -7447.897589295347}, {
      3136.054816148272, -7447.897586252215}, {
      3136.0548088027494`, -7447.897586252215}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3593.7105508308546`, -7447.897587012998}, \
{3593.7105523524206`, -7447.897586252215}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3593.7105508308546`, -7447.897587012998}, 
       1.5215661350364737`*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054817669838, -7447.8975885345635`}, {
       3593.7105508308546`, -7447.8975885345635`}, {
       3593.7105508308546`, -7447.897587012998}, {
       3136.054817669838, -7447.897587012998}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054817669838, -7447.8975885345635`}, 
       1.5215661350364737`*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054816148272, -7447.897589295347}, \
{3136.054817669838, -7447.8975885345635`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.385531956377}, {
        100.01845333507548`, -7472.385531956377}, {
        100.01845333507548`, -7447.897589295347}, {
        100, -7447.897589295347}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.385531956377}, {
       1418.8102584601538`, -7472.385531956377}, {
       1418.8102584601538`, -7447.897589295347}, {
       600.0829851286655, -7447.897589295347}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.385531956377}, {
       1601.2816681974343`, -7472.385531956377}, {
       1601.2816681974343`, -7447.897589295347}, {
       1601.2816681851828`, -7447.897589295347}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.947440804853, -7472.385531956377}, {
       2638.9677858146733`, -7472.385531956377}, {
       2638.9677858146733`, -7447.897589295347}, {
       2606.947440804853, -7447.897589295347}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.385531956377}, {
       2584.883642523331, -7472.385531956377}, {
       2584.883642523331, -7447.897589295347}, {
       2584.880978412161, -7447.897589295347}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.385531956377}, {
       3136.054817669838, -7472.385531956377}, {
       3136.054817669838, -7447.897589295347}, {
       3136.0548088027494`, -7447.897589295347}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7105523524206`, -7472.385531956377}, {
       3695.1039183543876`, -7472.385531956377}, {
       3695.1039183543876`, -7447.897589295347}, {
       3593.7105523524206`, -7447.897589295347}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.385531956377}, {
       4142.649334928725, -7472.385531956377}, {
       4142.649334928725, -7447.897589295347}, {
       4124.714551485204, -7447.897589295347}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999998925, -7472.385531956377}, {
       4699.999999999998, -7472.385531956377}, {
       4699.999999999998, -7447.897589295347}, {
       4699.999999998925, -7447.897589295347}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773962747272, -7472.385531956377}, {
      1342.4330973033, -7472.385531956377}, {
      1342.4330973033, -7447.897589295347}, {
      1324.773962747272, -7447.897589295347}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2594.703469474338, -7454.019574960605}, \
{2606.947440804853, -7447.897589295347}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2594.703469474338, -7454.019574960605}, 12.243971330515063`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1354.6770686338152`, -7466.263546291119}, {
       2594.703469474338, -7466.263546291119}, {
       2594.703469474338, -7454.019574960605}, {
       1354.6770686338152`, -7454.019574960605}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1354.6770686338152`, -7466.263546291119}, 12.243971330515063`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1342.4330973033, -7472.385531956377}, \
{1354.6770686338152`, -7466.263546291119}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.385531957018}, {
        100.01845333507548`, -7472.385531957018}, {
        100.01845333507548`, -7472.385531956377}, {
        100, -7472.385531956377}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.385531957018}, {
       1418.8102584601538`, -7472.385531957018}, {
       1418.8102584601538`, -7472.385531956377}, {
       600.0829851286655, -7472.385531956377}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.385531957018}, {
       1354.6770686338152`, -7472.385531957018}, {
       1354.6770686338152`, -7472.385531956377}, {
       1324.773962747272, -7472.385531956377}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.947440804853, -7472.385531957018}, {
       2638.9677858146733`, -7472.385531957018}, {
       2638.9677858146733`, -7472.385531956377}, {
       2606.947440804853, -7472.385531956377}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.385531957018}, {
       2584.883642523331, -7472.385531957018}, {
       2584.883642523331, -7472.385531956377}, {
       2584.880978412161, -7472.385531956377}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.385531957018}, {
       3136.054817669838, -7472.385531957018}, {
       3136.054817669838, -7472.385531956377}, {
       3136.0548088027494`, -7472.385531956377}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7105523524206`, -7472.385531957018}, {
       3695.1039183543876`, -7472.385531957018}, {
       3695.1039183543876`, -7472.385531956377}, {
       3593.7105523524206`, -7472.385531956377}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.385531957018}, {
       4142.649334928725, -7472.385531957018}, {
       4142.649334928725, -7472.385531956377}, {
       4124.714551485204, -7472.385531956377}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999246, -7472.385531957018}, {
       4699.999999999999, -7472.385531957018}, {
       4699.999999999999, -7472.385531956377}, {
       4699.999999999246, -7472.385531956377}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7472.385531957018}, {
      1601.2816681974343`, -7472.385531957018}, {
      1601.2816681974343`, -7472.385531956377}, {
      1601.2816681851828`, -7472.385531956377}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999998925, -7472.385531956537}, \
{4699.999999999246, -7472.385531956377}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999998925, -7472.385531956537}, 
       3.2061178455390437`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668197755, -7472.385531956858}, {
       4699.999999998925, -7472.385531956858}, {
       4699.999999998925, -7472.385531956537}, {
       1601.281668197755, -7472.385531956537}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668197755, -7472.385531956858}, 
       3.2061178455390437`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681974343`, -7472.385531957018}, \
{1601.281668197755, -7472.385531956858}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.385531957169}, {
        100.01845333507548`, -7472.385531957169}, {
        100.01845333507548`, -7472.385531957018}, {
        100, -7472.385531957018}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.385531957169}, {
       1418.8102584601538`, -7472.385531957169}, {
       1418.8102584601538`, -7472.385531957018}, {
       600.0829851286655, -7472.385531957018}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.385531957169}, {
       1354.6770686338152`, -7472.385531957169}, {
       1354.6770686338152`, -7472.385531957018}, {
       1324.773962747272, -7472.385531957018}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.385531957169}, {
       1601.281668197755, -7472.385531957169}, {
       1601.281668197755, -7472.385531957018}, {
       1601.2816681851828`, -7472.385531957018}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.947440804853, -7472.385531957169}, {
       2638.9677858146733`, -7472.385531957169}, {
       2638.9677858146733`, -7472.385531957018}, {
       2606.947440804853, -7472.385531957018}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.385531957169}, {
       2584.883642523331, -7472.385531957169}, {
       2584.883642523331, -7472.385531957018}, {
       2584.880978412161, -7472.385531957018}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.385531957169}, {
       3136.054817669838, -7472.385531957169}, {
       3136.054817669838, -7472.385531957018}, {
       3136.0548088027494`, -7472.385531957018}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7105523524206`, -7472.385531957169}, {
       3695.103918354312, -7472.385531957169}, {
       3695.103918354312, -7472.385531957018}, {
       3593.7105523524206`, -7472.385531957018}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.385531957169}, {
       4142.649334928725, -7472.385531957169}, {
       4142.649334928725, -7472.385531957018}, {
       4124.714551485204, -7472.385531957018}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999246, -7472.385531957169}, {
      4699.999999999999, -7472.385531957169}, {
      4699.999999999999, -7472.385531957018}, {
      4699.999999999246, -7472.385531957018}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.103918354312, -7472.385531957056}, \
{3695.1039183543876`, -7472.385531957018}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3695.1039183543876`, -7472.385531957056}, 
       7.568997916983501*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3695.1039183543876`, -7472.385531957131}, {
       4699.9999999991705`, -7472.385531957131}, {
       4699.9999999991705`, -7472.385531957056}, {
       3695.1039183543876`, -7472.385531957056}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999991705`, -7472.385531957131}, 
       7.568997916983501*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999991705`, -7472.385531957169}, \
{4699.999999999246, -7472.385531957131}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.385542515486}, {
        100.01845333507548`, -7472.385542515486}, {
        100.01845333507548`, -7472.385531957169}, {
        100, -7472.385531957169}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.385542515486}, {
       1418.8102584601538`, -7472.385542515486}, {
       1418.8102584601538`, -7472.385531957169}, {
       600.0829851286655, -7472.385531957169}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.385542515486}, {
       1354.6770686338152`, -7472.385542515486}, {
       1354.6770686338152`, -7472.385531957169}, {
       1324.773962747272, -7472.385531957169}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.385542515486}, {
       1601.281668197755, -7472.385542515486}, {
       1601.281668197755, -7472.385531957169}, {
       1601.2816681851828`, -7472.385531957169}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.947440804853, -7472.385542515486}, {
       2638.9677858146733`, -7472.385542515486}, {
       2638.9677858146733`, -7472.385531957169}, {
       2606.947440804853, -7472.385531957169}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.385542515486}, {
       2584.883642523331, -7472.385542515486}, {
       2584.883642523331, -7472.385531957169}, {
       2584.880978412161, -7472.385531957169}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.385542515486}, {
       3136.05481239068, -7472.385542515486}, {
       3136.05481239068, -7472.385531957169}, {
       3136.0548088027494`, -7472.385531957169}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.385542515486}, {
       4142.649334928725, -7472.385542515486}, {
       4142.649334928725, -7472.385531957169}, {
       4124.714551485204, -7472.385531957169}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999991705`, -7472.385542515486}, {
       4699.999999999999, -7472.385542515486}, {
       4699.999999999999, -7472.385531957169}, {
       4699.9999999991705`, -7472.385531957169}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3593.7105523524206`, -7472.385542515486}, {
      3695.103918354312, -7472.385542515486}, {
      3695.103918354312, -7472.385531957169}, {
      3593.7105523524206`, -7472.385531957169}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05481239068, -7472.385534596749}, \
{3136.054817669838, -7472.385531957169}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054817669838, -7472.385534596749}, 5.279158233170107*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054817669838, -7472.385539875907}, {
       3593.710547073262, -7472.385539875907}, {
       3593.710547073262, -7472.385534596749}, {
       3136.054817669838, -7472.385534596749}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3593.710547073262, -7472.385539875907}, 
       5.279158233170107*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3593.710547073262, -7472.385542515486}, \
{3593.7105523524206`, -7472.385539875907}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.3855425164}, {
        100.01845333507548`, -7472.3855425164}, {
        100.01845333507548`, -7472.385542515486}, {
        100, -7472.385542515486}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.3855425164}, {
       1418.8102584601538`, -7472.3855425164}, {
       1418.8102584601538`, -7472.385542515486}, {
       600.0829851286655, -7472.385542515486}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.3855425164}, {
       1354.6770686338152`, -7472.3855425164}, {
       1354.6770686338152`, -7472.385542515486}, {
       1324.773962747272, -7472.385542515486}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.947440804853, -7472.3855425164}, {
       2638.9677858146733`, -7472.3855425164}, {
       2638.9677858146733`, -7472.385542515486}, {
       2606.947440804853, -7472.385542515486}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.3855425164}, {
       2584.883642523331, -7472.3855425164}, {
       2584.883642523331, -7472.385542515486}, {
       2584.880978412161, -7472.385542515486}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.3855425164}, {
       3136.05481239068, -7472.3855425164}, {
       3136.05481239068, -7472.385542515486}, {
       3136.0548088027494`, -7472.385542515486}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7472.3855425164}, {
       3695.103918354312, -7472.3855425164}, {
       3695.103918354312, -7472.385542515486}, {
       3593.710547073262, -7472.385542515486}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.3855425164}, {
       4142.649334928725, -7472.3855425164}, {
       4142.649334928725, -7472.385542515486}, {
       4124.714551485204, -7472.385542515486}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7472.3855425164}, {
       4699.999999999998, -7472.3855425164}, {
       4699.999999999998, -7472.385542515486}, {
       4699.999999999627, -7472.385542515486}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7472.3855425164}, {
      1601.281668197755, -7472.3855425164}, {
      1601.281668197755, -7472.385542515486}, {
      1601.2816681851828`, -7472.385542515486}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999991705`, -7472.385542515715}, \
{4699.999999999627, -7472.385542515486}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999991705`, -7472.385542515715}, 
       4.5682719401105634`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681982117`, -7472.385542516172}, {
       4699.9999999991705`, -7472.385542516172}, {
       4699.9999999991705`, -7472.385542515715}, {
       1601.2816681982117`, -7472.385542515715}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681982117`, -7472.385542516172}, 
       4.5682719401105634`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668197755, -7472.3855425164}, \
{1601.2816681982117`, -7472.385542516172}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.385542520372}, {
        100.01845333507548`, -7472.385542520372}, {
        100.01845333507548`, -7472.3855425164}, {100, -7472.3855425164}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.385542520372}, {
       1418.8102584601538`, -7472.385542520372}, {
       1418.8102584601538`, -7472.3855425164}, {
       600.0829851286655, -7472.3855425164}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.385542520372}, {
       1354.6770686338152`, -7472.385542520372}, {
       1354.6770686338152`, -7472.3855425164}, {
       1324.773962747272, -7472.3855425164}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.385542520372}, {
       1601.2816681962258`, -7472.385542520372}, {
       1601.2816681962258`, -7472.3855425164}, {
       1601.2816681851828`, -7472.3855425164}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.880978412161, -7472.385542520372}, {
       2584.883642523331, -7472.385542520372}, {
       2584.883642523331, -7472.3855425164}, {
       2584.880978412161, -7472.3855425164}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.385542520372}, {
       3136.05481239068, -7472.385542520372}, {
       3136.05481239068, -7472.3855425164}, {
       3136.0548088027494`, -7472.3855425164}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7472.385542520372}, {
       3695.103918354312, -7472.385542520372}, {
       3695.103918354312, -7472.3855425164}, {
       3593.710547073262, -7472.3855425164}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.385542520372}, {
       4142.649334928725, -7472.385542520372}, {
       4142.649334928725, -7472.3855425164}, {
       4124.714551485204, -7472.3855425164}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7472.385542520372}, {
       4699.999999999998, -7472.385542520372}, {
       4699.999999999998, -7472.3855425164}, {
       4699.999999999627, -7472.3855425164}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2606.947440804853, -7472.385542520372}, {
      2638.9677858146733`, -7472.385542520372}, {
      2638.9677858146733`, -7472.3855425164}, {
      2606.947440804853, -7472.3855425164}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681962258`, -7472.385542517393}, \
{1601.2816681982117`, -7472.3855425164}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681982117`, -7472.385542517393}, 
       1.9859121996817196`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681982117`, -7472.385542519379}, {
       2606.9474408028673`, -7472.385542519379}, {
       2606.9474408028673`, -7472.385542517393}, {
       1601.2816681982117`, -7472.385542517393}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2606.9474408028673`, -7472.385542519379}, 
       1.9859121996817196`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2606.9474408028673`, -7472.385542520372}, \
{2606.947440804853, -7472.385542519379}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.389165890301}, {
        100.01845333507548`, -7472.389165890301}, {
        100.01845333507548`, -7472.385542520372}, {
        100, -7472.385542520372}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.389165890301}, {
       1418.8102584601538`, -7472.389165890301}, {
       1418.8102584601538`, -7472.385542520372}, {
       600.0829851286655, -7472.385542520372}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.389165890301}, {
       1354.6770686338152`, -7472.389165890301}, {
       1354.6770686338152`, -7472.385542520372}, {
       1324.773962747272, -7472.385542520372}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.389165890301}, {
       1601.2816681962258`, -7472.389165890301}, {
       1601.2816681962258`, -7472.385542520372}, {
       1601.2816681851828`, -7472.385542520372}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7472.389165890301}, {
       2584.883642523331, -7472.389165890301}, {
       2584.883642523331, -7472.385542520372}, {
       2584.8827900971255`, -7472.385542520372}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.389165890301}, {
       3136.05481239068, -7472.389165890301}, {
       3136.05481239068, -7472.385542520372}, {
       3136.0548088027494`, -7472.385542520372}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7472.389165890301}, {
       3695.103918354312, -7472.389165890301}, {
       3695.103918354312, -7472.385542520372}, {
       3593.710547073262, -7472.385542520372}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.389165890301}, {
       4142.649334928725, -7472.389165890301}, {
       4142.649334928725, -7472.385542520372}, {
       4124.714551485204, -7472.385542520372}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7472.389165890301}, {
       4699.999999999998, -7472.389165890301}, {
       4699.999999999998, -7472.385542520372}, {
       4699.999999999627, -7472.385542520372}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2606.9474408028673`, -7472.389165890301}, {
      2638.9677858146733`, -7472.389165890301}, {
      2638.9677858146733`, -7472.385542520372}, {
      2606.9474408028673`, -7472.385542520372}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.880978412161, -7472.386448362854}, \
{2584.8827900971255`, -7472.385542520372}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.880978412161, -7472.386448362854}, 0.001811684964765217, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.969597499638, -7472.388260047819}, {
       2584.880978412161, -7472.388260047819}, {
       2584.880978412161, -7472.386448362854}, {
       2638.969597499638, -7472.386448362854}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.969597499638, -7472.388260047819}, 0.001811684964765217, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2638.9677858146733`, -7472.389165890301}, \
{2638.969597499638, -7472.388260047819}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.419010134369}, {
        100.00353121304167`, -7472.419010134369}, {
        100.00353121304167`, -7472.389165890301}, {
        100, -7472.389165890301}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.419010134369}, {
       1418.8102584601538`, -7472.419010134369}, {
       1418.8102584601538`, -7472.389165890301}, {
       600.0829851286655, -7472.389165890301}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.419010134369}, {
       1354.6770686338152`, -7472.419010134369}, {
       1354.6770686338152`, -7472.389165890301}, {
       1324.773962747272, -7472.389165890301}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.419010134369}, {
       1601.2816681962258`, -7472.419010134369}, {
       1601.2816681962258`, -7472.389165890301}, {
       1601.2816681851828`, -7472.389165890301}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7472.419010134369}, {
       2584.883642523331, -7472.419010134369}, {
       2584.883642523331, -7472.389165890301}, {
       2584.8827900971255`, -7472.389165890301}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548088027494`, -7472.419010134369}, {
       3136.05481239068, -7472.419010134369}, {
       3136.05481239068, -7472.389165890301}, {
       3136.0548088027494`, -7472.389165890301}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7472.419010134369}, {
       3695.103918354312, -7472.419010134369}, {
       3695.103918354312, -7472.389165890301}, {
       3593.710547073262, -7472.389165890301}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.419010134369}, {
       4142.649334928725, -7472.419010134369}, {
       4142.649334928725, -7472.389165890301}, {
       4124.714551485204, -7472.389165890301}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7472.419010134369}, {
       4699.999999999998, -7472.419010134369}, {
       4699.999999999998, -7472.389165890301}, {
       4699.999999999627, -7472.389165890301}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2606.9474408028673`, -7472.419010134369}, {
      2638.9695974996375`, -7472.419010134369}, {
      2638.9695974996375`, -7472.389165890301}, {
      2606.9474408028673`, -7472.389165890301}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00353121304167`, -7472.3966269513185`}, \
{100.01845333507548`, -7472.389165890301}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.01845333507548`, -7472.3966269513185`}, 
       0.014922122033809639`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.01845333507548`, -7472.411549073352}, {
       2606.9325186808333`, -7472.411549073352}, {
       2606.9325186808333`, -7472.3966269513185`}, {
       100.01845333507548`, -7472.3966269513185`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2606.9325186808333`, -7472.411549073352}, 
       0.014922122033809639`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2606.9325186808333`, -7472.419010134369}, \
{2606.9474408028673`, -7472.411549073352}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7472.419010985374}, {
        100.00353121304167`, -7472.419010985374}, {
        100.00353121304167`, -7472.419010134369}, {
        100, -7472.419010134369}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7472.419010985374}, {
       1418.8102584601538`, -7472.419010985374}, {
       1418.8102584601538`, -7472.419010134369}, {
       600.0829851286655, -7472.419010134369}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7472.419010985374}, {
       1354.6770686338152`, -7472.419010985374}, {
       1354.6770686338152`, -7472.419010134369}, {
       1324.773962747272, -7472.419010134369}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7472.419010985374}, {
       1601.2816681962258`, -7472.419010985374}, {
       1601.2816681962258`, -7472.419010134369}, {
       1601.2816681851828`, -7472.419010134369}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2606.9325186808333`, -7472.419010985374}, {
       2638.9695974996375`, -7472.419010985374}, {
       2638.9695974996375`, -7472.419010134369}, {
       2606.9325186808333`, -7472.419010134369}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7472.419010985374}, {
       2584.8836420978287`, -7472.419010985374}, {
       2584.8836420978287`, -7472.419010134369}, {
       2584.8827900971255`, -7472.419010134369}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7472.419010985374}, {
       3695.103918354312, -7472.419010985374}, {
       3695.103918354312, -7472.419010134369}, {
       3593.710547073262, -7472.419010134369}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7472.419010985374}, {
       4142.649334928725, -7472.419010985374}, {
       4142.649334928725, -7472.419010134369}, {
       4124.714551485204, -7472.419010134369}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7472.419010985374}, {
       4699.999999999998, -7472.419010985374}, {
       4699.999999999998, -7472.419010134369}, {
       4699.999999999627, -7472.419010134369}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548088027494`, -7472.419010985374}, {
      3136.0548123906797`, -7472.419010985374}, {
      3136.0548123906797`, -7472.419010134369}, {
      3136.0548088027494`, -7472.419010134369}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8836420978287`, -7472.419010347121}, \
{2584.883642523331, -7472.419010134369}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883642523331, -7472.419010347121}, 
       4.2550244150128877`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883642523331, -7472.419010772624}, {
       3136.054808377247, -7472.419010772624}, {
       3136.054808377247, -7472.419010347121}, {
       2584.883642523331, -7472.419010347121}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054808377247, -7472.419010772624}, 
       4.2550244150128877`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054808377247, -7472.419010985374}, \
{3136.0548088027494`, -7472.419010772624}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.563207598125}, {
        100.00353121304167`, -7513.563207598125}, {
        100.00353121304167`, -7472.419010985374}, {
        100, -7472.419010985374}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.563207598125}, {
       1398.2381601537784`, -7513.563207598125}, {
       1398.2381601537784`, -7472.419010985374}, {
       600.0829851286655, -7472.419010985374}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.563207598125}, {
       1354.6770686338152`, -7513.563207598125}, {
       1354.6770686338152`, -7472.419010985374}, {
       1324.773962747272, -7472.419010985374}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.563207598125}, {
       1601.2816681962258`, -7513.563207598125}, {
       1601.2816681962258`, -7472.419010985374}, {
       1601.2816681851828`, -7472.419010985374}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.563207598125}, {
       2584.8836420978287`, -7513.563207598125}, {
       2584.8836420978287`, -7472.419010985374}, {
       2584.8827900971255`, -7472.419010985374}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054808377247, -7513.563207598125}, {
       3136.0548123906797`, -7513.563207598125}, {
       3136.0548123906797`, -7472.419010985374}, {
       3136.054808377247, -7472.419010985374}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7513.563207598125}, {
       3695.103918354312, -7513.563207598125}, {
       3695.103918354312, -7472.419010985374}, {
       3593.710547073262, -7472.419010985374}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714551485204, -7513.563207598125}, {
       4142.649334928725, -7513.563207598125}, {
       4142.649334928725, -7472.419010985374}, {
       4124.714551485204, -7472.419010985374}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7513.563207598125}, {
       4699.999999999998, -7513.563207598125}, {
       4699.999999999998, -7472.419010985374}, {
       4699.999999999627, -7472.419010985374}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2606.9325186808333`, -7513.563207598125}, {
      2638.969597499638, -7513.563207598125}, {
      2638.969597499638, -7472.419010985374}, {
      2606.9325186808333`, -7472.419010985374}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1398.2381601537784`, -7482.705060138562}, \
{1418.8102584601538`, -7472.419010985374}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1418.8102584601538`, -7482.705060138562}, 20.572098306375338`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1418.8102584601538`, -7503.277158444937}, {
       2586.360420374458, -7503.277158444937}, {
       2586.360420374458, -7482.705060138562}, {
       1418.8102584601538`, -7482.705060138562}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2586.360420374458, -7503.277158444937}, 20.572098306375338`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2586.360420374458, -7513.563207598125}, \
{2606.9325186808333`, -7503.277158444937}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.563210860863}, {
        100.00353121304167`, -7513.563210860863}, {
        100.00353121304167`, -7513.563207598125}, {
        100, -7513.563207598125}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.563210860863}, {
       1398.2381601537784`, -7513.563210860863}, {
       1398.2381601537784`, -7513.563207598125}, {
       600.0829851286655, -7513.563207598125}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.563210860863}, {
       1354.6770686338152`, -7513.563210860863}, {
       1354.6770686338152`, -7513.563207598125}, {
       1324.773962747272, -7513.563207598125}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.563210860863}, {
       1601.2816681962258`, -7513.563210860863}, {
       1601.2816681962258`, -7513.563207598125}, {
       1601.2816681851828`, -7513.563207598125}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7513.563210860863}, {
       2638.969597499638, -7513.563210860863}, {
       2638.969597499638, -7513.563207598125}, {
       2586.360420374458, -7513.563207598125}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.563210860863}, {
       2584.8836420978287`, -7513.563210860863}, {
       2584.8836420978287`, -7513.563207598125}, {
       2584.8827900971255`, -7513.563207598125}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054808377247, -7513.563210860863}, {
       3136.0548107593104`, -7513.563210860863}, {
       3136.0548107593104`, -7513.563207598125}, {
       3136.054808377247, -7513.563207598125}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.710547073262, -7513.563210860863}, {
       3695.103918354312, -7513.563210860863}, {
       3695.103918354312, -7513.563207598125}, {
       3593.710547073262, -7513.563207598125}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7513.563210860863}, {
       4699.999999999998, -7513.563210860863}, {
       4699.999999999998, -7513.563207598125}, {
       4699.999999999627, -7513.563207598125}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4124.714551485204, -7513.563210860863}, {
      4142.649334928725, -7513.563210860863}, {
      4142.649334928725, -7513.563207598125}, {
      4124.714551485204, -7513.563207598125}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107593104`, -7513.563208413809}, \
{3136.0548123906797`, -7513.563207598125}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548123906797`, -7513.563208413809}, 
       1.6313694958636875`*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548123906797`, -7513.5632100451785`}, {
       4124.714549853834, -7513.5632100451785`}, {
       4124.714549853834, -7513.563208413809}, {
       3136.0548123906797`, -7513.563208413809}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4124.714549853834, -7513.5632100451785`}, 
       1.6313694958636875`*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4124.714549853834, -7513.563210860863}, \
{4124.714551485204, -7513.5632100451785`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.567769965787}, {
        100.00125166057975`, -7513.567769965787}, {
        100.00125166057975`, -7513.563210860863}, {
        100, -7513.563210860863}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.567769965787}, {
       1398.2381601537784`, -7513.567769965787}, {
       1398.2381601537784`, -7513.563210860863}, {
       600.0829851286655, -7513.563210860863}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.567769965787}, {
       1354.6770686338152`, -7513.567769965787}, {
       1354.6770686338152`, -7513.563210860863}, {
       1324.773962747272, -7513.563210860863}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.567769965787}, {
       1601.2816681962258`, -7513.567769965787}, {
       1601.2816681962258`, -7513.563210860863}, {
       1601.2816681851828`, -7513.563210860863}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7513.567769965787}, {
       2638.969597499638, -7513.567769965787}, {
       2638.969597499638, -7513.563210860863}, {
       2586.360420374458, -7513.563210860863}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.567769965787}, {
       2584.8836420978287`, -7513.567769965787}, {
       2584.8836420978287`, -7513.563210860863}, {
       2584.8827900971255`, -7513.563210860863}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054808377247, -7513.567769965787}, {
       3136.0548107593104`, -7513.567769965787}, {
       3136.0548107593104`, -7513.563210860863}, {
       3136.054808377247, -7513.563210860863}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714549853834, -7513.567769965787}, {
       4142.649334928725, -7513.567769965787}, {
       4142.649334928725, -7513.563210860863}, {
       4124.714549853834, -7513.563210860863}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999627, -7513.567769965787}, {
       4699.999999999998, -7513.567769965787}, {
       4699.999999999998, -7513.563210860863}, {
       4699.999999999627, -7513.563210860863}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3593.710547073262, -7513.567769965787}, {
      3695.103918354312, -7513.567769965787}, {
      3695.103918354312, -7513.563210860863}, {
      3593.710547073262, -7513.563210860863}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00125166057975`, -7513.564350637094}, \
{100.00353121304167`, -7513.563210860863}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00353121304167`, -7513.564350637094}, 
       0.0022795524619166454`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00353121304167`, -7513.566630189556}, {
       3593.7082675208003`, -7513.566630189556}, {
       3593.7082675208003`, -7513.564350637094}, {
       100.00353121304167`, -7513.564350637094}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3593.7082675208003`, -7513.566630189556}, 
       0.0022795524619166454`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3593.7082675208003`, -7513.567769965787}, \
{3593.710547073262, -7513.566630189556}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.567769966438}, {
        100.00125166057975`, -7513.567769966438}, {
        100.00125166057975`, -7513.567769965787}, {
        100, -7513.567769965787}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.567769966438}, {
       1398.2381601537784`, -7513.567769966438}, {
       1398.2381601537784`, -7513.567769965787}, {
       600.0829851286655, -7513.567769965787}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.567769966438}, {
       1354.6770686338152`, -7513.567769966438}, {
       1354.6770686338152`, -7513.567769965787}, {
       1324.773962747272, -7513.567769965787}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.567769966438}, {
       1601.2816681962258`, -7513.567769966438}, {
       1601.2816681962258`, -7513.567769965787}, {
       1601.2816681851828`, -7513.567769965787}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.567769966438}, {
       2584.8836420978287`, -7513.567769966438}, {
       2584.8836420978287`, -7513.567769965787}, {
       2584.8827900971255`, -7513.567769965787}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054808377247, -7513.567769966438}, {
       3136.0548107593104`, -7513.567769966438}, {
       3136.0548107593104`, -7513.567769965787}, {
       3136.054808377247, -7513.567769965787}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7513.567769966438}, {
       3695.103918354312, -7513.567769966438}, {
       3695.103918354312, -7513.567769965787}, {
       3593.7082675208003`, -7513.567769965787}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714549853834, -7513.567769966438}, {
       4142.649334928725, -7513.567769966438}, {
       4142.649334928725, -7513.567769965787}, {
       4124.714549853834, -7513.567769965787}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999953, -7513.567769966438}, {4699.999999999999,
        -7513.567769966438}, {4699.999999999999, -7513.567769965787}, {
       4699.999999999953, -7513.567769965787}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2586.360420374458, -7513.567769966438}, {
      2638.969597499638, -7513.567769966438}, {
      2638.969597499638, -7513.567769965787}, {
      2586.360420374458, -7513.567769965787}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999627, -7513.56776996595}, \
{4699.999999999953, -7513.567769965787}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999627, -7513.56776996595}, 3.255260377207297*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.9695974999636`, -7513.567769966276}, {
       4699.999999999627, -7513.567769966276}, {
       4699.999999999627, -7513.56776996595}, {
       2638.9695974999636`, -7513.56776996595}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.9695974999636`, -7513.567769966276}, 
       3.255260377207297*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2638.969597499638, -7513.567769966438}, \
{2638.9695974999636`, -7513.567769966276}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.567769966461}, {
        100.00125166057975`, -7513.567769966461}, {
        100.00125166057975`, -7513.567769966438}, {
        100, -7513.567769966438}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.567769966461}, {
       1398.2381601537784`, -7513.567769966461}, {
       1398.2381601537784`, -7513.567769966438}, {
       600.0829851286655, -7513.567769966438}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.567769966461}, {
       1354.6770686338152`, -7513.567769966461}, {
       1354.6770686338152`, -7513.567769966438}, {
       1324.773962747272, -7513.567769966438}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7513.567769966461}, {
       2638.9695974999636`, -7513.567769966461}, {
       2638.9695974999636`, -7513.567769966438}, {
       2586.360420374458, -7513.567769966438}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.567769966461}, {
       2584.8836420978287`, -7513.567769966461}, {
       2584.8836420978287`, -7513.567769966438}, {
       2584.8827900971255`, -7513.567769966438}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054808377247, -7513.567769966461}, {
       3136.0548107593104`, -7513.567769966461}, {
       3136.0548107593104`, -7513.567769966438}, {
       3136.054808377247, -7513.567769966438}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7513.567769966461}, {
       3695.103918354312, -7513.567769966461}, {
       3695.103918354312, -7513.567769966438}, {
       3593.7082675208003`, -7513.567769966438}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714549853834, -7513.567769966461}, {
       4142.649334928725, -7513.567769966461}, {
       4142.649334928725, -7513.567769966438}, {
       4124.714549853834, -7513.567769966438}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999964, -7513.567769966461}, {
       4699.999999999998, -7513.567769966461}, {
       4699.999999999998, -7513.567769966438}, {
       4699.999999999964, -7513.567769966438}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7513.567769966461}, {
      1601.2816681962258`, -7513.567769966461}, {
      1601.2816681962258`, -7513.567769966438}, {
      1601.2816681851828`, -7513.567769966438}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999953, -7513.567769966444}, \
{4699.999999999964, -7513.567769966438}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999953, -7513.567769966444}, 1.128547193256859*^-11,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668196237, -7513.567769966456}, {
       4699.999999999953, -7513.567769966456}, {
       4699.999999999953, -7513.567769966444}, {
       1601.281668196237, -7513.567769966444}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668196237, -7513.567769966456}, 1.128547193256859*^-11,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681962258`, -7513.567769966461}, \
{1601.281668196237, -7513.567769966456}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.5677699897415`}, {
        100.00125166057975`, -7513.5677699897415`}, {
        100.00125166057975`, -7513.567769966461}, {
        100, -7513.567769966461}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.5677699897415`}, {
       1398.2381601537784`, -7513.5677699897415`}, {
       1398.2381601537784`, -7513.567769966461}, {
       600.0829851286655, -7513.567769966461}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.5677699897415`}, {
       1354.6770686338152`, -7513.5677699897415`}, {
       1354.6770686338152`, -7513.567769966461}, {
       1324.773962747272, -7513.567769966461}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.5677699897415`}, {
       1601.281668196237, -7513.5677699897415`}, {
       1601.281668196237, -7513.567769966461}, {
       1601.2816681851828`, -7513.567769966461}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7513.5677699897415`}, {
       2638.9695974999636`, -7513.5677699897415`}, {
       2638.9695974999636`, -7513.567769966461}, {
       2586.360420374458, -7513.567769966461}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.5677699897415`}, {
       2584.883642086189, -7513.5677699897415`}, {
       2584.883642086189, -7513.567769966461}, {
       2584.8827900971255`, -7513.567769966461}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7513.5677699897415`}, {
       3695.103918354312, -7513.5677699897415`}, {
       3695.103918354312, -7513.567769966461}, {
       3593.7082675208003`, -7513.567769966461}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714549853834, -7513.5677699897415`}, {
       4142.649334928725, -7513.5677699897415`}, {
       4142.649334928725, -7513.567769966461}, {
       4124.714549853834, -7513.567769966461}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999964, -7513.5677699897415`}, {
       4699.999999999998, -7513.5677699897415`}, {
       4699.999999999998, -7513.567769966461}, {
       4699.999999999964, -7513.567769966461}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054808377247, -7513.5677699897415`}, {
      3136.05481075931, -7513.5677699897415`}, {
      3136.05481075931, -7513.567769966461}, {
      3136.054808377247, -7513.567769966461}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883642086189, -7513.567769972282}, \
{2584.8836420978287`, -7513.567769966461}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8836420978287`, -7513.567769972282}, 
       1.1639962447297279`*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8836420978287`, -7513.567769983922}, {
       3136.0548083656067`, -7513.567769983922}, {
       3136.0548083656067`, -7513.567769972282}, {
       2584.8836420978287`, -7513.567769972282}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548083656067`, -7513.567769983922}, 
       1.1639962447297279`*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548083656067`, -7513.5677699897415`}, \
{3136.054808377247, -7513.567769983922}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7513.567769989808}, {
        100.00125166057975`, -7513.567769989808}, {
        100.00125166057975`, -7513.5677699897415`}, {
        100, -7513.5677699897415`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7513.567769989808}, {
       1398.2381601537784`, -7513.567769989808}, {
       1398.2381601537784`, -7513.5677699897415`}, {
       600.0829851286655, -7513.5677699897415`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7513.567769989808}, {
       1354.6770686338152`, -7513.567769989808}, {
       1354.6770686338152`, -7513.5677699897415`}, {
       1324.773962747272, -7513.5677699897415`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7513.567769989808}, {
       1601.281668196237, -7513.567769989808}, {
       1601.281668196237, -7513.5677699897415`}, {
       1601.2816681851828`, -7513.5677699897415`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7513.567769989808}, {
       2638.9695974999636`, -7513.567769989808}, {
       2638.9695974999636`, -7513.5677699897415`}, {
       2586.360420374458, -7513.5677699897415`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7513.567769989808}, {
       2584.883642086189, -7513.567769989808}, {
       2584.883642086189, -7513.5677699897415`}, {
       2584.8827900971255`, -7513.5677699897415`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7513.567769989808}, {
       3136.05481075931, -7513.567769989808}, {
       3136.05481075931, -7513.5677699897415`}, {
       3136.0548083656067`, -7513.5677699897415`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7513.567769989808}, {
       3695.103918354279, -7513.567769989808}, {
       3695.103918354279, -7513.5677699897415`}, {
       3593.7082675208003`, -7513.5677699897415`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4124.714549853834, -7513.567769989808}, {
       4142.649334928725, -7513.567769989808}, {
       4142.649334928725, -7513.5677699897415`}, {
       4124.714549853834, -7513.5677699897415`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999964, -7513.567769989808}, {
      4699.999999999999, -7513.567769989808}, {
      4699.999999999999, -7513.5677699897415`}, {
      4699.999999999964, -7513.5677699897415`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.103918354279, -7513.567769989758}, \
{3695.103918354312, -7513.5677699897415`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3695.103918354312, -7513.567769989758}, 3.318400546853809*^-11,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3695.103918354312, -7513.5677699897915`}, {
       4699.999999999931, -7513.5677699897915`}, {
       4699.999999999931, -7513.567769989758}, {
       3695.103918354312, -7513.567769989758}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999931, -7513.5677699897915`}, 
       3.318400546853809*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999931, -7513.567769989808}, \
{4699.999999999964, -7513.5677699897915`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7527.940505594652}, {
        100.00125166057975`, -7527.940505594652}, {
        100.00125166057975`, -7513.567769989808}, {
        100, -7513.567769989808}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7527.940505594652}, {
       1354.6770686338152`, -7527.940505594652}, {
       1354.6770686338152`, -7513.567769989808}, {
       1324.773962747272, -7513.567769989808}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7527.940505594652}, {
       1601.281668196237, -7527.940505594652}, {
       1601.281668196237, -7513.567769989808}, {
       1601.2816681851828`, -7513.567769989808}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7527.940505594652}, {
       2638.9695974999636`, -7527.940505594652}, {
       2638.9695974999636`, -7513.567769989808}, {
       2586.360420374458, -7513.567769989808}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7527.940505594652}, {
       2584.883642086189, -7527.940505594652}, {
       2584.883642086189, -7513.567769989808}, {
       2584.8827900971255`, -7513.567769989808}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7527.940505594652}, {
       3136.05481075931, -7527.940505594652}, {
       3136.05481075931, -7513.567769989808}, {
       3136.0548083656067`, -7513.567769989808}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7527.940505594652}, {
       3695.103918354279, -7527.940505594652}, {
       3695.103918354279, -7513.567769989808}, {
       3593.7082675208003`, -7513.567769989808}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7527.940505594652}, {
       4142.649334928725, -7527.940505594652}, {
       4142.649334928725, -7513.567769989808}, {
       4131.900917656256, -7513.567769989808}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999931, -7527.940505594652}, {
       4699.999999999999, -7527.940505594652}, {
       4699.999999999999, -7513.567769989808}, {
       4699.999999999931, -7513.567769989808}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7527.940505594652}, {
      1398.2381601537784`, -7527.940505594652}, {
      1398.2381601537784`, -7513.567769989808}, {
      600.0829851286655, -7513.567769989808}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4124.714549853834, -7517.160953891019}, \
{4131.900917656256, -7513.567769989808}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4124.714549853834, -7517.160953891019}, 7.186367802422033, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1405.4245279562006`, -7524.347321693441}, {
       4124.714549853834, -7524.347321693441}, {
       4124.714549853834, -7517.160953891019}, {
       1405.4245279562006`, -7517.160953891019}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1405.4245279562006`, -7524.347321693441}, 7.186367802422033, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1398.2381601537784`, -7527.940505594652}, \
{1405.4245279562006`, -7524.347321693441}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7527.9405055946545`}, {
        100.00125166057828`, -7527.9405055946545`}, {
        100.00125166057828`, -7527.940505594652}, {
        100, -7527.940505594652}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7527.9405055946545`}, {
       1405.4245279562006`, -7527.9405055946545`}, {
       1405.4245279562006`, -7527.940505594652}, {
       600.0829851286655, -7527.940505594652}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7527.9405055946545`}, {
       1354.6770686338152`, -7527.9405055946545`}, {
       1354.6770686338152`, -7527.940505594652}, {
       1324.773962747272, -7527.940505594652}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7527.9405055946545`}, {
       1601.281668196237, -7527.9405055946545`}, {
       1601.281668196237, -7527.940505594652}, {
       1601.2816681851828`, -7527.940505594652}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420374458, -7527.9405055946545`}, {
       2638.9695974999636`, -7527.9405055946545`}, {
       2638.9695974999636`, -7527.940505594652}, {
       2586.360420374458, -7527.940505594652}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7527.9405055946545`}, {
       2584.883642086189, -7527.9405055946545`}, {
       2584.883642086189, -7527.940505594652}, {
       2584.8827900971255`, -7527.940505594652}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7527.9405055946545`}, {
       3136.05481075931, -7527.9405055946545`}, {
       3136.05481075931, -7527.940505594652}, {
       3136.0548083656067`, -7527.940505594652}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7527.9405055946545`}, {
       3695.103918354279, -7527.9405055946545`}, {
       3695.103918354279, -7527.940505594652}, {
       3593.7082675208003`, -7527.940505594652}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7527.9405055946545`}, {
       4142.649334928725, -7527.9405055946545`}, {
       4142.649334928725, -7527.940505594652}, {
       4131.900917656256, -7527.940505594652}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999931, -7527.9405055946545`}, {
      4699.999999999998, -7527.9405055946545`}, {
      4699.999999999998, -7527.940505594652}, {
      4699.999999999931, -7527.940505594652}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00125166057828`, -7527.940505594653}, \
{100.00125166057975`, -7527.940505594652}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00125166057975`, -7527.940505594653}, 
       1.4841759598652592`*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00125166057975`, -7527.940505594654}, {
       4699.999999999929, -7527.940505594654}, {
       4699.999999999929, -7527.940505594653}, {
       100.00125166057975`, -7527.940505594653}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999929, -7527.940505594654}, 
       1.4841759598652592`*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999929, -7527.9405055946545`}, \
{4699.999999999931, -7527.940505594654}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7527.940505608137}, {
        100.00125166057828`, -7527.940505608137}, {
        100.00125166057828`, -7527.9405055946545`}, {
        100, -7527.9405055946545`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7527.940505608137}, {
       1405.4245279562006`, -7527.940505608137}, {
       1405.4245279562006`, -7527.9405055946545`}, {
       600.0829851286655, -7527.9405055946545`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7527.940505608137}, {
       1354.6770686338152`, -7527.940505608137}, {
       1354.6770686338152`, -7527.9405055946545`}, {
       1324.773962747272, -7527.9405055946545`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420381199, -7527.940505608137}, {
       2638.969597499963, -7527.940505608137}, {
       2638.969597499963, -7527.9405055946545`}, {
       2586.360420381199, -7527.9405055946545`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7527.940505608137}, {
       2584.883642086189, -7527.940505608137}, {
       2584.883642086189, -7527.9405055946545`}, {
       2584.8827900971255`, -7527.9405055946545`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7527.940505608137}, {
       3136.05481075931, -7527.940505608137}, {
       3136.05481075931, -7527.9405055946545`}, {
       3136.0548083656067`, -7527.9405055946545`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3593.7082675208003`, -7527.940505608137}, {
       3695.103918354279, -7527.940505608137}, {
       3695.103918354279, -7527.9405055946545`}, {
       3593.7082675208003`, -7527.9405055946545`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7527.940505608137}, {
       4142.649334928725, -7527.940505608137}, {
       4142.649334928725, -7527.9405055946545`}, {
       4131.900917656256, -7527.9405055946545`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999929, -7527.940505608137}, {
       4699.999999999998, -7527.940505608137}, {
       4699.999999999998, -7527.9405055946545`}, {
       4699.999999999929, -7527.9405055946545`}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7527.940505608137}, {
      1601.281668196237, -7527.940505608137}, {
      1601.281668196237, -7527.9405055946545`}, {
      1601.2816681851828`, -7527.9405055946545`}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2586.360420374458, -7527.940505598025}, \
{2586.360420381199, -7527.9405055946545`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2586.360420374458, -7527.940505598025}, 
       6.7413036942304365`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816682029784`, -7527.940505604766}, {
       2586.360420374458, -7527.940505604766}, {
       2586.360420374458, -7527.940505598025}, {
       1601.2816682029784`, -7527.940505598025}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816682029784`, -7527.940505604766}, 
       6.7413036942304365`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668196237, -7527.940505608137}, \
{1601.2816682029784`, -7527.940505604766}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008190744697}, {
        100.00125166057828`, -7536.008190744697}, {
        100.00125166057828`, -7527.940505608137}, {
        100, -7527.940505608137}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008190744697}, {
       1354.6770686338152`, -7536.008190744697}, {
       1354.6770686338152`, -7527.940505608137}, {
       1324.773962747272, -7527.940505608137}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008190744697}, {
       1601.2816682029784`, -7536.008190744697}, {
       1601.2816682029784`, -7527.940505608137}, {
       1601.2816681851828`, -7527.940505608137}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420381199, -7536.008190744697}, {
       2638.969597499963, -7536.008190744697}, {
       2638.969597499963, -7527.940505608137}, {
       2586.360420381199, -7527.940505608137}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008190744697}, {
       2584.883642086189, -7536.008190744697}, {
       2584.883642086189, -7527.940505608137}, {
       2584.8827900971255`, -7527.940505608137}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7536.008190744697}, {
       3136.05481075931, -7536.008190744697}, {
       3136.05481075931, -7527.940505608137}, {
       3136.0548083656067`, -7527.940505608137}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.74211008908, -7536.008190744697}, {
       3695.103918354279, -7536.008190744697}, {
       3695.103918354279, -7527.940505608137}, {
       3597.74211008908, -7527.940505608137}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008190744697}, {
       4142.649334928725, -7536.008190744697}, {
       4142.649334928725, -7527.940505608137}, {
       4131.900917656256, -7527.940505608137}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999929, -7536.008190744697}, {
       4699.999999999998, -7536.008190744697}, {
       4699.999999999998, -7527.940505608137}, {
       4699.999999999929, -7527.940505608137}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7536.008190744697}, {
      1405.4245279562006`, -7536.008190744697}, {
      1405.4245279562006`, -7527.940505608137}, {
      600.0829851286655, -7527.940505608137}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3593.7082675208003`, -7529.957426892277}, \
{3597.74211008908, -7527.940505608137}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3593.7082675208003`, -7529.957426892277}, 4.033842568279709, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1409.4583705244802`, -7533.991269460556}, {
       3593.7082675208003`, -7533.991269460556}, {
       3593.7082675208003`, -7529.957426892277}, {
       1409.4583705244802`, -7529.957426892277}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1409.4583705244802`, -7533.991269460556}, 4.033842568279709, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1405.4245279562006`, -7536.008190744697}, \
{1409.4583705244802`, -7533.991269460556}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008190763994}, {
        100.00125166057828`, -7536.008190763994}, {
        100.00125166057828`, -7536.008190744697}, {
        100, -7536.008190744697}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008190763994}, {
       1409.4583705244802`, -7536.008190763994}, {
       1409.4583705244802`, -7536.008190744697}, {
       600.0829851286655, -7536.008190744697}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008190763994}, {
       1354.6770686338152`, -7536.008190763994}, {
       1354.6770686338152`, -7536.008190744697}, {
       1324.773962747272, -7536.008190744697}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008190763994}, {
       2638.9695974999636`, -7536.008190763994}, {
       2638.9695974999636`, -7536.008190744697}, {
       2586.360420390848, -7536.008190744697}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008190763994}, {
       2584.883642086189, -7536.008190763994}, {
       2584.883642086189, -7536.008190744697}, {
       2584.8827900971255`, -7536.008190744697}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7536.008190763994}, {
       3136.05481075931, -7536.008190763994}, {
       3136.05481075931, -7536.008190744697}, {
       3136.0548083656067`, -7536.008190744697}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.74211008908, -7536.008190763994}, {
       3695.103918354279, -7536.008190763994}, {
       3695.103918354279, -7536.008190744697}, {
       3597.74211008908, -7536.008190744697}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008190763994}, {
       4142.649334928725, -7536.008190763994}, {
       4142.649334928725, -7536.008190744697}, {
       4131.900917656256, -7536.008190744697}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999929, -7536.008190763994}, {
       4699.999999999998, -7536.008190763994}, {
       4699.999999999998, -7536.008190744697}, {
       4699.999999999929, -7536.008190744697}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7536.008190763994}, {
      1601.2816682029784`, -7536.008190763994}, {
      1601.2816682029784`, -7536.008190744697}, {
      1601.2816681851828`, -7536.008190744697}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2586.360420381199, -7536.008190749521}, \
{2586.360420390848, -7536.008190744697}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2586.360420381199, -7536.008190749521}, 9.648620155563938*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668212627, -7536.00819075917}, {
       2586.360420381199, -7536.00819075917}, {
       2586.360420381199, -7536.008190749521}, {
       1601.281668212627, -7536.008190749521}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668212627, -7536.00819075917}, 9.648620155563938*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816682029784`, -7536.008190763994}, \
{1601.281668212627, -7536.00819075917}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008272472823}, {
        100.00125166057828`, -7536.008272472823}, {
        100.00125166057828`, -7536.008190763994}, {
        100, -7536.008190763994}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008272472823}, {
       1409.4583705244802`, -7536.008272472823}, {
       1409.4583705244802`, -7536.008190763994}, {
       600.0829851286655, -7536.008190763994}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008272472823}, {
       1354.6770686338152`, -7536.008272472823}, {
       1354.6770686338152`, -7536.008190763994}, {
       1324.773962747272, -7536.008190763994}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008272472823}, {
       1601.281668212627, -7536.008272472823}, {
       1601.281668212627, -7536.008190763994}, {
       1601.2816681851828`, -7536.008190763994}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008272472823}, {
       2638.9695974999636`, -7536.008272472823}, {
       2638.9695974999636`, -7536.008190763994}, {
       2586.360420390848, -7536.008190763994}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008272472823}, {
       2584.8836012317747`, -7536.008272472823}, {
       2584.8836012317747`, -7536.008190763994}, {
       2584.8827900971255`, -7536.008190763994}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7536.008272472823}, {
       3136.05481075931, -7536.008272472823}, {
       3136.05481075931, -7536.008190763994}, {
       3136.0548083656067`, -7536.008190763994}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008272472823}, {
       4142.649334928725, -7536.008272472823}, {
       4142.649334928725, -7536.008190763994}, {
       4131.900917656256, -7536.008190763994}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999929, -7536.008272472823}, {
       4699.999999999998, -7536.008272472823}, {
       4699.999999999998, -7536.008190763994}, {
       4699.999999999929, -7536.008190763994}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3597.74211008908, -7536.008272472823}, {
      3695.103918354279, -7536.008272472823}, {
      3695.103918354279, -7536.008190763994}, {
      3597.74211008908, -7536.008190763994}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8836012317747`, -7536.008211191202}, \
{2584.883642086189, -7536.008190763994}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883642086189, -7536.008211191202}, 
       0.000040854414296776355`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883642086189, -7536.008252045615}, {
       3597.742069234666, -7536.008252045615}, {
       3597.742069234666, -7536.008211191202}, {
       2584.883642086189, -7536.008211191202}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3597.742069234666, -7536.008252045615}, 
       0.000040854414296776355`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3597.742069234666, -7536.008272472823}, \
{3597.74211008908, -7536.008252045615}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008272472849}, {
        100.00125166057828`, -7536.008272472849}, {
        100.00125166057828`, -7536.008272472823}, {
        100, -7536.008272472823}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008272472849}, {
       1409.4583705244802`, -7536.008272472849}, {
       1409.4583705244802`, -7536.008272472823}, {
       600.0829851286655, -7536.008272472823}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008272472849}, {
       1354.6770686338152`, -7536.008272472849}, {
       1354.6770686338152`, -7536.008272472823}, {
       1324.773962747272, -7536.008272472823}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008272472849}, {
       1601.281668212627, -7536.008272472849}, {
       1601.281668212627, -7536.008272472823}, {
       1601.2816681851828`, -7536.008272472823}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008272472849}, {
       2638.9695974999636`, -7536.008272472849}, {
       2638.9695974999636`, -7536.008272472823}, {
       2586.360420390848, -7536.008272472823}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008272472849}, {
       2584.8836012317615`, -7536.008272472849}, {
       2584.8836012317615`, -7536.008272472823}, {
       2584.8827900971255`, -7536.008272472823}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548083656067`, -7536.008272472849}, {
       3136.05481075931, -7536.008272472849}, {
       3136.05481075931, -7536.008272472823}, {
       3136.0548083656067`, -7536.008272472823}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008272472849}, {
       3695.103918354279, -7536.008272472849}, {
       3695.103918354279, -7536.008272472823}, {
       3597.742069234666, -7536.008272472823}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008272472849}, {
       4142.649334928725, -7536.008272472849}, {
       4142.649334928725, -7536.008272472823}, {
       4131.900917656256, -7536.008272472823}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999929, -7536.008272472849}, {
      4699.999999999999, -7536.008272472849}, {
      4699.999999999999, -7536.008272472823}, {
      4699.999999999929, -7536.008272472823}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8836012317615`, -7536.008272472829}, \
{2584.8836012317747`, -7536.008272472823}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8836012317747`, -7536.008272472829}, 
       1.3068487349077572`*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8836012317747`, -7536.008272472843}, {
       4699.999999999916, -7536.008272472843}, {
       4699.999999999916, -7536.008272472829}, {
       2584.8836012317747`, -7536.008272472829}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999916, -7536.008272472843}, 
       1.3068487349077572`*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999916, -7536.008272472849}, \
{4699.999999999929, -7536.008272472843}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008276071363}, {
       1409.4583705244802`, -7536.008276071363}, {
       1409.4583705244802`, -7536.008272472849}, {
       600.0829851286655, -7536.008272472849}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008276071363}, {
       1354.6770686338152`, -7536.008276071363}, {
       1354.6770686338152`, -7536.008272472849}, {
       1324.773962747272, -7536.008272472849}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008276071363}, {
       1601.281668212627, -7536.008276071363}, {
       1601.281668212627, -7536.008272472849}, {
       1601.2816681851828`, -7536.008272472849}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008276071363}, {
       2638.9695974999636`, -7536.008276071363}, {
       2638.9695974999636`, -7536.008272472849}, {
       2586.360420390848, -7536.008272472849}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008276071363}, {
       2584.8836012317615`, -7536.008276071363}, {
       2584.8836012317615`, -7536.008272472849}, {
       2584.8827900971255`, -7536.008272472849}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548101648637`, -7536.008276071363}, {
       3136.0548107593104`, -7536.008276071363}, {
       3136.0548107593104`, -7536.008272472849}, {
       3136.0548101648637`, -7536.008272472849}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008276071363}, {
       3695.103918354279, -7536.008276071363}, {
       3695.103918354279, -7536.008272472849}, {
       3597.742069234666, -7536.008272472849}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008276071363}, {
       4142.649334928725, -7536.008276071363}, {
       4142.649334928725, -7536.008272472849}, {
       4131.900917656256, -7536.008272472849}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999916, -7536.008276071363}, {
       4699.999999999999, -7536.008276071363}, {
       4699.999999999999, -7536.008272472849}, {
       4699.999999999916, -7536.008272472849}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7536.008276071363}, {
       100.00125166057828`, -7536.008276071363}, {
       100.00125166057828`, -7536.008272472849}, {
       100, -7536.008272472849}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548083656067`, -7536.008273372478}, \
{3136.0548101648637`, -7536.008272472849}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548083656067`, -7536.008273372478}, 
       1.7992568121181398`*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00125345983508`, -7536.008275171735}, {
       3136.0548083656067`, -7536.008275171735}, {
       3136.0548083656067`, -7536.008273372478}, {
       100.00125345983508`, -7536.008273372478}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00125345983508`, -7536.008275171735}, 
       1.7992568121181398`*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00125166057828`, -7536.008276071363}, \
{100.00125345983508`, -7536.008275171735}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.00827607152}, {
        100.00125345983508`, -7536.00827607152}, {
        100.00125345983508`, -7536.008276071363}, {
        100, -7536.008276071363}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.00827607152}, {
       1409.4583705244802`, -7536.00827607152}, {
       1409.4583705244802`, -7536.008276071363}, {
       600.0829851286655, -7536.008276071363}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.00827607152}, {
       1354.6770686338152`, -7536.00827607152}, {
       1354.6770686338152`, -7536.008276071363}, {
       1324.773962747272, -7536.008276071363}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.00827607152}, {
       1601.281668212627, -7536.00827607152}, {
       1601.281668212627, -7536.008276071363}, {
       1601.2816681851828`, -7536.008276071363}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.00827607152}, {
       2638.9695974999636`, -7536.00827607152}, {
       2638.9695974999636`, -7536.008276071363}, {
       2586.360420390848, -7536.008276071363}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.00827607152}, {
       2584.8836012317615`, -7536.00827607152}, {
       2584.8836012317615`, -7536.008276071363}, {
       2584.8827900971255`, -7536.008276071363}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.00827607152}, {
       3695.103918354279, -7536.00827607152}, {
       3695.103918354279, -7536.008276071363}, {
       3597.742069234666, -7536.008276071363}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.00827607152}, {
       4142.649334928725, -7536.00827607152}, {
       4142.649334928725, -7536.008276071363}, {
       4131.900917656256, -7536.008276071363}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999995, -7536.00827607152}, {
       4699.999999999999, -7536.00827607152}, {
       4699.999999999999, -7536.008276071363}, {
       4699.999999999995, -7536.008276071363}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548101648637`, -7536.00827607152}, {
      3136.0548107593104`, -7536.00827607152}, {
      3136.0548107593104`, -7536.008276071363}, {
      3136.0548101648637`, -7536.008276071363}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999916, -7536.008276071402}, \
{4699.999999999995, -7536.008276071363}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999916, -7536.008276071402}, 7.877531382051219*^-11,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810759389, -7536.008276071481}, {
       4699.999999999916, -7536.008276071481}, {
       4699.999999999916, -7536.008276071402}, {
       3136.054810759389, -7536.008276071402}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810759389, -7536.008276071481}, 7.877531382051219*^-11,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107593104`, -7536.00827607152}, \
{3136.054810759389, -7536.008276071481}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008276071526}, {
        100.00125345983508`, -7536.008276071526}, {
        100.00125345983508`, -7536.00827607152}, {
        100, -7536.00827607152}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008276071526}, {
       1409.4583705244802`, -7536.008276071526}, {
       1409.4583705244802`, -7536.00827607152}, {
       600.0829851286655, -7536.00827607152}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008276071526}, {
       1354.6770686338152`, -7536.008276071526}, {
       1354.6770686338152`, -7536.00827607152}, {
       1324.773962747272, -7536.00827607152}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008276071526}, {
       1601.281668212627, -7536.008276071526}, {
       1601.281668212627, -7536.00827607152}, {
       1601.2816681851828`, -7536.00827607152}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008276071526}, {
       2638.9695974999636`, -7536.008276071526}, {
       2638.9695974999636`, -7536.00827607152}, {
       2586.360420390848, -7536.00827607152}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008276071526}, {
       2584.8836012317615`, -7536.008276071526}, {
       2584.8836012317615`, -7536.00827607152}, {
       2584.8827900971255`, -7536.00827607152}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008276071526}, {
       3695.103918354279, -7536.008276071526}, {
       3695.103918354279, -7536.00827607152}, {
       3597.742069234666, -7536.00827607152}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008276071526}, {
       4142.649334928725, -7536.008276071526}, {
       4142.649334928725, -7536.00827607152}, {
       4131.900917656256, -7536.00827607152}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -7536.008276071526}, {
       4699.999999999999, -7536.008276071526}, {
       4699.999999999999, -7536.00827607152}, {
       4699.999999999998, -7536.00827607152}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548101648637`, -7536.008276071526}, {
      3136.054810759389, -7536.008276071526}, {
      3136.054810759389, -7536.00827607152}, {
      3136.0548101648637`, -7536.00827607152}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999995, -7536.008276071521}, \
{4699.999999999998, -7536.00827607152}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999995, -7536.008276071521}, 
       2.9372203983740736`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548107593922`, -7536.008276071524}, {
       4699.999999999995, -7536.008276071524}, {
       4699.999999999995, -7536.008276071521}, {
       3136.0548107593922`, -7536.008276071521}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548107593922`, -7536.008276071524}, 
       2.9372203983740736`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810759389, -7536.008276071526}, \
{3136.0548107593922`, -7536.008276071524}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008276071526}, {
        100.00125345983508`, -7536.008276071526}, {
        100.00125345983508`, -7536.008276071526}, {
        100, -7536.008276071526}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008276071526}, {
       1409.4583705244802`, -7536.008276071526}, {
       1409.4583705244802`, -7536.008276071526}, {
       600.0829851286655, -7536.008276071526}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008276071526}, {
       1354.6770686338152`, -7536.008276071526}, {
       1354.6770686338152`, -7536.008276071526}, {
       1324.773962747272, -7536.008276071526}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008276071526}, {
       2638.9695974999636`, -7536.008276071526}, {
       2638.9695974999636`, -7536.008276071526}, {
       2586.360420390848, -7536.008276071526}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008276071526}, {
       2584.8836012317615`, -7536.008276071526}, {
       2584.8836012317615`, -7536.008276071526}, {
       2584.8827900971255`, -7536.008276071526}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548101648637`, -7536.008276071526}, {
       3136.0548107593922`, -7536.008276071526}, {
       3136.0548107593922`, -7536.008276071526}, {
       3136.0548101648637`, -7536.008276071526}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008276071526}, {
       3695.103918354279, -7536.008276071526}, {
       3695.103918354279, -7536.008276071526}, {
       3597.742069234666, -7536.008276071526}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008276071526}, {
       4142.649334928725, -7536.008276071526}, {
       4142.649334928725, -7536.008276071526}, {
       4131.900917656256, -7536.008276071526}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -7536.008276071526}, {
       4699.999999999999, -7536.008276071526}, {
       4699.999999999999, -7536.008276071526}, {
       4699.999999999998, -7536.008276071526}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681851828`, -7536.008276071526}, {
      1601.281668212627, -7536.008276071526}, {
      1601.281668212627, -7536.008276071526}, {
      1601.2816681851828`, -7536.008276071526}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -7536.008276071526}, \
{4699.999999999998, -7536.008276071526}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -7536.008276071526}, 4.231667716826512*^-14,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668212627, -7536.008276071526}, {
       4699.999999999998, -7536.008276071526}, {
       4699.999999999998, -7536.008276071526}, {
       1601.281668212627, -7536.008276071526}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668212627, -7536.008276071526}, 4.231667716826512*^-14,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668212627, -7536.008276071526}, \
{1601.281668212627, -7536.008276071526}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008276071527}, {
        100.00125345983508`, -7536.008276071527}, {
        100.00125345983508`, -7536.008276071526}, {
        100, -7536.008276071526}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7536.008276071527}, {
       1409.4583705244802`, -7536.008276071527}, {
       1409.4583705244802`, -7536.008276071526}, {
       600.0829851286655, -7536.008276071526}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008276071527}, {
       1354.6770686338152`, -7536.008276071527}, {
       1354.6770686338152`, -7536.008276071526}, {
       1324.773962747272, -7536.008276071526}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008276071527}, {
       1601.281668212627, -7536.008276071527}, {
       1601.281668212627, -7536.008276071526}, {
       1601.2816681851828`, -7536.008276071526}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008276071527}, {
       2638.9695974999636`, -7536.008276071527}, {
       2638.9695974999636`, -7536.008276071526}, {
       2586.360420390848, -7536.008276071526}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008276071527}, {
       2584.8836012317615`, -7536.008276071527}, {
       2584.8836012317615`, -7536.008276071526}, {
       2584.8827900971255`, -7536.008276071526}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548101648637`, -7536.008276071527}, {
       3136.0548107593913`, -7536.008276071527}, {
       3136.0548107593913`, -7536.008276071526}, {
       3136.0548101648637`, -7536.008276071526}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008276071527}, {
       3695.103918354279, -7536.008276071527}, {
       3695.103918354279, -7536.008276071526}, {
       3597.742069234666, -7536.008276071526}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008276071527}, {
       4142.649334928725, -7536.008276071527}, {
       4142.649334928725, -7536.008276071526}, {
       4131.900917656256, -7536.008276071526}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -7536.008276071527}, {
      4699.999999999998, -7536.008276071527}, {
      4699.999999999998, -7536.008276071526}, {
      4699.999999999998, -7536.008276071526}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107593913`, -7536.008276071526}, \
{3136.0548107593922`, -7536.008276071526}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548107593922`, -7536.008276071526}, 
       6.549101255029715*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548107593922`, -7536.008276071527}, {
       4699.999999999997, -7536.008276071527}, {
       4699.999999999997, -7536.008276071526}, {
       3136.0548107593922`, -7536.008276071526}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999997, -7536.008276071527}, 
       6.549101255029715*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999997, -7536.008276071527}, \
{4699.999999999998, -7536.008276071527}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7536.008276612513}, {
        100.00125345983508`, -7536.008276612513}, {
        100.00125345983508`, -7536.008276071527}, {
        100, -7536.008276071527}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7536.008276612513}, {
       1354.6770686338152`, -7536.008276612513}, {
       1354.6770686338152`, -7536.008276071527}, {
       1324.773962747272, -7536.008276071527}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7536.008276612513}, {
       1601.281668212627, -7536.008276612513}, {
       1601.281668212627, -7536.008276071527}, {
       1601.2816681851828`, -7536.008276071527}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7536.008276612513}, {
       2638.9695974999636`, -7536.008276612513}, {
       2638.9695974999636`, -7536.008276071527}, {
       2586.360420390848, -7536.008276071527}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7536.008276612513}, {
       2584.8836012317615`, -7536.008276612513}, {
       2584.8836012317615`, -7536.008276071527}, {
       2584.8827900971255`, -7536.008276071527}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810435357, -7536.008276612513}, {
       3136.0548107593913`, -7536.008276612513}, {
       3136.0548107593913`, -7536.008276071527}, {
       3136.054810435357, -7536.008276071527}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3597.742069234666, -7536.008276612513}, {
       3695.103918354279, -7536.008276612513}, {
       3695.103918354279, -7536.008276071527}, {
       3597.742069234666, -7536.008276071527}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7536.008276612513}, {
       4142.649334928725, -7536.008276612513}, {
       4142.649334928725, -7536.008276071527}, {
       4131.900917656256, -7536.008276071527}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -7536.008276612513}, {
       4699.999999999998, -7536.008276612513}, {
       4699.999999999998, -7536.008276071527}, {
       4699.999999999997, -7536.008276071527}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7536.008276612513}, {
      1409.4583705244802`, -7536.008276612513}, {
      1409.4583705244802`, -7536.008276071527}, {
      600.0829851286655, -7536.008276071527}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548101648637`, -7536.008276206773}, \
{3136.054810435357, -7536.008276071527}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548101648637`, -7536.008276206773}, 
       2.704932651671767*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1409.4583707949735`, -7536.008276477267}, {
       3136.0548101648637`, -7536.008276477267}, {
       3136.0548101648637`, -7536.008276206773}, {
       1409.4583707949735`, -7536.008276206773}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1409.4583707949735`, -7536.008276477267}, 
       2.704932651671767*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1409.4583705244802`, -7536.008276612513}, \
{1409.4583707949735`, -7536.008276477267}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.315633148959}, {
        100.00125345983508`, -7542.315633148959}, {
        100.00125345983508`, -7536.008276612513}, {
        100, -7536.008276612513}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.315633148959}, {
       1409.4583707949735`, -7542.315633148959}, {
       1409.4583707949735`, -7536.008276612513}, {
       600.0829851286655, -7536.008276612513}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7542.315633148959}, {
       1354.6770686338152`, -7542.315633148959}, {
       1354.6770686338152`, -7536.008276612513}, {
       1324.773962747272, -7536.008276612513}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.315633148959}, {
       1601.281668212627, -7542.315633148959}, {
       1601.281668212627, -7536.008276612513}, {
       1601.2816681851828`, -7536.008276612513}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.315633148959}, {
       2635.8159192317407`, -7542.315633148959}, {
       2635.8159192317407`, -7536.008276612513}, {
       2586.360420390848, -7536.008276612513}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.315633148959}, {
       2584.8836012317615`, -7542.315633148959}, {
       2584.8836012317615`, -7536.008276612513}, {
       2584.8827900971255`, -7536.008276612513}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810435357, -7542.315633148959}, {
       3136.0548107593913`, -7542.315633148959}, {
       3136.0548107593913`, -7536.008276612513}, {
       3136.054810435357, -7536.008276612513}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.315633148959}, {
       4142.649334928725, -7542.315633148959}, {
       4142.649334928725, -7536.008276612513}, {
       4131.900917656256, -7536.008276612513}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -7542.315633148959}, {
       4699.999999999998, -7542.315633148959}, {
       4699.999999999998, -7536.008276612513}, {
       4699.999999999997, -7536.008276612513}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3597.742069234666, -7542.315633148959}, {
      3695.103918354279, -7542.315633148959}, {
      3695.103918354279, -7536.008276612513}, {
      3597.742069234666, -7536.008276612513}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2635.8159192317407`, -7537.585115746625}, \
{2638.9695974999636`, -7536.008276612513}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2638.9695974999636`, -7537.585115746625}, 3.1536782682227553`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2638.9695974999636`, -7540.738794014847}, {
       3594.588390966443, -7540.738794014847}, {
       3594.588390966443, -7537.585115746625}, {
       2638.9695974999636`, -7537.585115746625}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3594.588390966443, -7540.738794014847}, 3.1536782682227553`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3594.588390966443, -7542.315633148959}, \
{3597.742069234666, -7540.738794014847}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.3156333874695`}, {
        100.00125345983508`, -7542.3156333874695`}, {
        100.00125345983508`, -7542.315633148959}, {
        100, -7542.315633148959}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.3156333874695`}, {
       1409.4583707949735`, -7542.3156333874695`}, {
       1409.4583707949735`, -7542.315633148959}, {
       600.0829851286655, -7542.315633148959}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7542.3156333874695`}, {
       1354.6770686338152`, -7542.3156333874695`}, {
       1354.6770686338152`, -7542.315633148959}, {
       1324.773962747272, -7542.315633148959}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.3156333874695`}, {
       1601.281668212627, -7542.3156333874695`}, {
       1601.281668212627, -7542.315633148959}, {
       1601.2816681851828`, -7542.315633148959}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.3156333874695`}, {
       2635.8159192317407`, -7542.3156333874695`}, {
       2635.8159192317407`, -7542.315633148959}, {
       2586.360420390848, -7542.315633148959}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.3156333874695`}, {
       2584.8836012317615`, -7542.3156333874695`}, {
       2584.8836012317615`, -7542.315633148959}, {
       2584.8827900971255`, -7542.315633148959}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.3156333874695`}, {
       3695.1039183542784`, -7542.3156333874695`}, {
       3695.1039183542784`, -7542.315633148959}, {
       3594.5883910856983`, -7542.315633148959}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.3156333874695`}, {
       4142.649334928725, -7542.3156333874695`}, {
       4142.649334928725, -7542.315633148959}, {
       4131.900917656256, -7542.315633148959}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -7542.3156333874695`}, {
       4699.999999999998, -7542.3156333874695`}, {
       4699.999999999998, -7542.315633148959}, {
       4699.999999999997, -7542.315633148959}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810435357, -7542.3156333874695`}, {
      3136.0548107593913`, -7542.3156333874695`}, {
      3136.0548107593913`, -7542.315633148959}, {
      3136.054810435357, -7542.315633148959}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3594.588390966443, -7542.315633208586}, \
{3594.5883910856983`, -7542.315633148959}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3594.588390966443, -7542.315633208586}, 
       1.1925542552837518`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810878647, -7542.315633327842}, {
       3594.588390966443, -7542.315633327842}, {
       3594.588390966443, -7542.315633208586}, {
       3136.054810878647, -7542.315633208586}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810878647, -7542.315633327842}, 
       1.1925542552837518`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107593913`, -7542.3156333874695`}, \
{3136.054810878647, -7542.315633327842}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.315633387471}, {
        100.00125345983508`, -7542.315633387471}, {
        100.00125345983508`, -7542.3156333874695`}, {
        100, -7542.3156333874695`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.315633387471}, {
       1409.4583707949735`, -7542.315633387471}, {
       1409.4583707949735`, -7542.3156333874695`}, {
       600.0829851286655, -7542.3156333874695`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773962747272, -7542.315633387471}, {
       1354.6770686338152`, -7542.315633387471}, {
       1354.6770686338152`, -7542.3156333874695`}, {
       1324.773962747272, -7542.3156333874695`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.315633387471}, {
       1601.281668212627, -7542.315633387471}, {
       1601.281668212627, -7542.3156333874695`}, {
       1601.2816681851828`, -7542.3156333874695`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.315633387471}, {
       2635.8159192317407`, -7542.315633387471}, {
       2635.8159192317407`, -7542.3156333874695`}, {
       2586.360420390848, -7542.3156333874695`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.315633387471}, {
       2584.8836012317615`, -7542.315633387471}, {
       2584.8836012317615`, -7542.3156333874695`}, {
       2584.8827900971255`, -7542.3156333874695`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810435357, -7542.315633387471}, {
       3136.054810878647, -7542.315633387471}, {
       3136.054810878647, -7542.3156333874695`}, {
       3136.054810435357, -7542.3156333874695`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.315633387471}, {
       3695.1039183542775`, -7542.315633387471}, {
       3695.1039183542775`, -7542.3156333874695`}, {
       3594.5883910856983`, -7542.3156333874695`}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.315633387471}, {
       4142.649334928725, -7542.315633387471}, {
       4142.649334928725, -7542.3156333874695`}, {
       4131.900917656256, -7542.3156333874695`}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999997, -7542.315633387471}, {
      4699.999999999998, -7542.315633387471}, {
      4699.999999999998, -7542.3156333874695`}, {
      4699.999999999997, -7542.3156333874695`}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.1039183542775`, -7542.31563338747}, \
{3695.1039183542784`, -7542.3156333874695`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3695.1039183542784`, -7542.31563338747}, 
       8.969956423948694*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3695.1039183542784`, -7542.315633387471}, {
       4699.999999999996, -7542.315633387471}, {
       4699.999999999996, -7542.31563338747}, {
       3695.1039183542784`, -7542.31563338747}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999996, -7542.315633387471}, 
       8.969956423948694*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999996, -7542.315633387471}, \
{4699.999999999997, -7542.315633387471}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.317396306719}, {
        100.00037200021099`, -7542.317396306719}, {
        100.00037200021099`, -7542.315633387471}, {
        100, -7542.315633387471}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.317396306719}, {
       1409.4583707949735`, -7542.317396306719}, {
       1409.4583707949735`, -7542.315633387471}, {
       600.0829851286655, -7542.315633387471}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.317396306719}, {
       1601.281668212627, -7542.317396306719}, {
       1601.281668212627, -7542.315633387471}, {
       1601.2816681851828`, -7542.315633387471}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.317396306719}, {
       2635.8159192317407`, -7542.317396306719}, {
       2635.8159192317407`, -7542.315633387471}, {
       2586.360420390848, -7542.315633387471}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.317396306719}, {
       2584.8836012317615`, -7542.317396306719}, {
       2584.8836012317615`, -7542.315633387471}, {
       2584.8827900971255`, -7542.315633387471}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810435357, -7542.317396306719}, {
       3136.054810878647, -7542.317396306719}, {
       3136.054810878647, -7542.315633387471}, {
       3136.054810435357, -7542.315633387471}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.317396306719}, {
       3695.1039183542775`, -7542.317396306719}, {
       3695.1039183542775`, -7542.315633387471}, {
       3594.5883910856983`, -7542.315633387471}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.317396306719}, {
       4142.649334928725, -7542.317396306719}, {
       4142.649334928725, -7542.315633387471}, {
       4131.900917656256, -7542.315633387471}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999996, -7542.317396306719}, {
       4699.999999999998, -7542.317396306719}, {
       4699.999999999998, -7542.315633387471}, {
       4699.999999999996, -7542.315633387471}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773962747272, -7542.317396306719}, {
      1354.6770686338152`, -7542.317396306719}, {
      1354.6770686338152`, -7542.315633387471}, {
      1324.773962747272, -7542.315633387471}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00037200021099`, -7542.316074117283}, \
{100.00125345983508`, -7542.315633387471}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00125345983508`, -7542.316074117283}, 
       0.0008814596240936032, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00125345983508`, -7542.316955576907}, {
       1324.773081287648, -7542.316955576907}, {
       1324.773081287648, -7542.316074117283}, {
       100.00125345983508`, -7542.316074117283}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1324.773081287648, -7542.316955576907}, 
       0.0008814596240936032, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1324.773081287648, -7542.317396306719}, \
{1324.773962747272, -7542.316955576907}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.317396306722}, {
        100.00037200021099`, -7542.317396306722}, {
        100.00037200021099`, -7542.317396306719}, {
        100, -7542.317396306719}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.317396306722}, {
       1409.4583707949735`, -7542.317396306722}, {
       1409.4583707949735`, -7542.317396306719}, {
       600.0829851286655, -7542.317396306719}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7542.317396306722}, {
       1354.6770686338152`, -7542.317396306722}, {
       1354.6770686338152`, -7542.317396306719}, {
       1324.773081287648, -7542.317396306719}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.317396306722}, {
       1601.281668212627, -7542.317396306722}, {
       1601.281668212627, -7542.317396306719}, {
       1601.2816681851828`, -7542.317396306719}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.317396306722}, {
       2635.8159192317407`, -7542.317396306722}, {
       2635.8159192317407`, -7542.317396306719}, {
       2586.360420390848, -7542.317396306719}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.317396306722}, {
       2584.8836012317615`, -7542.317396306722}, {
       2584.8836012317615`, -7542.317396306719}, {
       2584.8827900971255`, -7542.317396306719}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810435357, -7542.317396306722}, {
       3136.054810878645, -7542.317396306722}, {
       3136.054810878645, -7542.317396306719}, {
       3136.054810435357, -7542.317396306719}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.317396306722}, {
       3695.1039183542775`, -7542.317396306722}, {
       3695.1039183542775`, -7542.317396306719}, {
       3594.5883910856983`, -7542.317396306719}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.317396306722}, {
       4142.649334928725, -7542.317396306722}, {
       4142.649334928725, -7542.317396306719}, {
       4131.900917656256, -7542.317396306719}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999996, -7542.317396306722}, {
      4699.999999999998, -7542.317396306722}, {
      4699.999999999998, -7542.317396306719}, {
      4699.999999999996, -7542.317396306719}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810878645, -7542.317396306719}, \
{3136.054810878647, -7542.317396306719}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810878647, -7542.317396306719}, 
       1.5620494168552677`*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810878647, -7542.317396306721}, {
       4699.9999999999945`, -7542.317396306721}, {
       4699.9999999999945`, -7542.317396306719}, {
       3136.054810878647, -7542.317396306719}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999999945`, -7542.317396306721}, 
       1.5620494168552677`*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999999945`, -7542.317396306722}, \
{4699.999999999996, -7542.317396306721}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.317397010625}, {
        100.00037200021099`, -7542.317397010625}, {
        100.00037200021099`, -7542.317396306722}, {
        100, -7542.317396306722}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.317397010625}, {
       1409.4583707949735`, -7542.317397010625}, {
       1409.4583707949735`, -7542.317396306722}, {
       600.0829851286655, -7542.317396306722}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7542.317397010625}, {
       1354.6770686338152`, -7542.317397010625}, {
       1354.6770686338152`, -7542.317396306722}, {
       1324.773081287648, -7542.317396306722}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.317397010625}, {
       1601.281668212627, -7542.317397010625}, {
       1601.281668212627, -7542.317396306722}, {
       1601.2816681851828`, -7542.317396306722}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.317397010625}, {
       2635.8159192317407`, -7542.317397010625}, {
       2635.8159192317407`, -7542.317396306722}, {
       2586.360420390848, -7542.317396306722}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7542.317397010625}, {
       2584.88360087981, -7542.317397010625}, {
       2584.88360087981, -7542.317396306722}, {
       2584.8827900971255`, -7542.317396306722}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.317397010625}, {
       3695.1039183542775`, -7542.317397010625}, {
       3695.1039183542775`, -7542.317396306722}, {
       3594.5883910856983`, -7542.317396306722}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.317397010625}, {
       4142.649334928725, -7542.317397010625}, {
       4142.649334928725, -7542.317396306722}, {
       4131.900917656256, -7542.317396306722}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7542.317397010625}, {
       4699.999999999998, -7542.317397010625}, {
       4699.999999999998, -7542.317396306722}, {
       4699.9999999999945`, -7542.317396306722}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810435357, -7542.317397010625}, {
      3136.054810878645, -7542.317397010625}, {
      3136.054810878645, -7542.317396306722}, {
      3136.054810435357, -7542.317396306722}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88360087981, -7542.317396482698}, \
{2584.8836012317615`, -7542.317396306722}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8836012317615`, -7542.317396482698}, 
       3.5195155842516677`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8836012317615`, -7542.31739683465}, {
       3136.0548100834053`, -7542.31739683465}, {
       3136.0548100834053`, -7542.317396482698}, {
       2584.8836012317615`, -7542.317396482698}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548100834053`, -7542.31739683465}, 
       3.5195155842516677`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548100834053`, -7542.317397010625}, \
{3136.054810435357, -7542.31739683465}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7542.317397010629}, {
        100.00037200021099`, -7542.317397010629}, {
        100.00037200021099`, -7542.317397010625}, {
        100, -7542.317397010625}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7542.317397010629}, {
       1409.4583707949735`, -7542.317397010629}, {
       1409.4583707949735`, -7542.317397010625}, {
       600.0829851286655, -7542.317397010625}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7542.317397010629}, {
       1354.6770686338152`, -7542.317397010629}, {
       1354.6770686338152`, -7542.317397010625}, {
       1324.773081287648, -7542.317397010625}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7542.317397010629}, {
       1601.281668212627, -7542.317397010629}, {
       1601.281668212627, -7542.317397010625}, {
       1601.2816681851828`, -7542.317397010625}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7542.317397010629}, {
       2635.8159192317407`, -7542.317397010629}, {
       2635.8159192317407`, -7542.317397010625}, {
       2586.360420390848, -7542.317397010625}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548100834053`, -7542.317397010629}, {
       3136.054810878645, -7542.317397010629}, {
       3136.054810878645, -7542.317397010625}, {
       3136.0548100834053`, -7542.317397010625}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3594.5883910856983`, -7542.317397010629}, {
       3695.1039183542775`, -7542.317397010629}, {
       3695.1039183542775`, -7542.317397010625}, {
       3594.5883910856983`, -7542.317397010625}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7542.317397010629}, {
       4142.649334928725, -7542.317397010629}, {
       4142.649334928725, -7542.317397010625}, {
       4131.900917656256, -7542.317397010625}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999996, -7542.317397010629}, {
       4699.999999999998, -7542.317397010629}, {
       4699.999999999998, -7542.317397010625}, {
       4699.999999999996, -7542.317397010625}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8827900971255`, -7542.317397010629}, {
      2584.88360087981, -7542.317397010629}, {
      2584.88360087981, -7542.317397010625}, {
      2584.8827900971255`, -7542.317397010625}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999999945`, -7542.317397010626}, \
{4699.999999999996, -7542.317397010625}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999999945`, -7542.317397010626}, 
       1.6702129108969285`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8836008798116`, -7542.317397010628}, {
       4699.9999999999945`, -7542.317397010628}, {
       4699.9999999999945`, -7542.317397010626}, {
       2584.8836008798116`, -7542.317397010626}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8836008798116`, -7542.317397010628}, 
       1.6702129108969285`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88360087981, -7542.317397010629}, \
{2584.8836008798116`, -7542.317397010628}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7657.291031802428}, {
        100.00037200021099`, -7657.291031802428}, {
        100.00037200021099`, -7542.317397010629}, {
        100, -7542.317397010629}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7657.291031802428}, {
       1351.971553399074, -7657.291031802428}, {
       1351.971553399074, -7542.317397010629}, {
       600.0829851286655, -7542.317397010629}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7657.291031802428}, {
       1354.6770686338152`, -7657.291031802428}, {
       1354.6770686338152`, -7542.317397010629}, {
       1324.773081287648, -7542.317397010629}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7657.291031802428}, {
       1601.281668212627, -7657.291031802428}, {
       1601.281668212627, -7542.317397010629}, {
       1601.2816681851828`, -7542.317397010629}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7657.291031802428}, {
       2635.8159192317407`, -7657.291031802428}, {
       2635.8159192317407`, -7542.317397010629}, {
       2586.360420390848, -7542.317397010629}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7657.291031802428}, {
       2584.8836008798116`, -7657.291031802428}, {
       2584.8836008798116`, -7542.317397010629}, {
       2584.8827900971255`, -7542.317397010629}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548100834053`, -7657.291031802428}, {
       3136.054810878645, -7657.291031802428}, {
       3136.054810878645, -7542.317397010629}, {
       3136.0548100834053`, -7542.317397010629}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7657.291031802428}, {
       4142.649334928725, -7657.291031802428}, {
       4142.649334928725, -7542.317397010629}, {
       4131.900917656256, -7542.317397010629}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999996, -7657.291031802428}, {
       4699.999999999998, -7657.291031802428}, {
       4699.999999999998, -7542.317397010629}, {
       4699.999999999996, -7542.317397010629}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3594.5883910856983`, -7657.291031802428}, {
      3695.1039183542775`, -7657.291031802428}, {
      3695.1039183542775`, -7542.317397010629}, {
      3594.5883910856983`, -7542.317397010629}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1351.971553399074, -7571.060805708579}, \
{1409.4583707949735`, -7542.317397010629}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1409.4583707949735`, -7571.060805708579}, 57.48681739589932, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1409.4583707949735`, -7628.547623104479}, {
       3537.101573689799, -7628.547623104479}, {
       3537.101573689799, -7571.060805708579}, {
       1409.4583707949735`, -7571.060805708579}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3537.101573689799, -7628.547623104479}, 57.48681739589932, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3537.101573689799, -7657.291031802428}, \
{3594.5883910856983`, -7628.547623104479}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7657.291031802429}, {
        100.00037200021099`, -7657.291031802429}, {
        100.00037200021099`, -7657.291031802428}, {
        100, -7657.291031802428}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7657.291031802429}, {
       1351.971553399074, -7657.291031802429}, {
       1351.971553399074, -7657.291031802428}, {
       600.0829851286655, -7657.291031802428}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7657.291031802429}, {
       1354.6770686338152`, -7657.291031802429}, {
       1354.6770686338152`, -7657.291031802428}, {
       1324.773081287648, -7657.291031802428}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7657.291031802429}, {
       1601.281668212627, -7657.291031802429}, {
       1601.281668212627, -7657.291031802428}, {
       1601.2816681851828`, -7657.291031802428}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2586.360420390848, -7657.291031802429}, {
       2635.8159192317407`, -7657.291031802429}, {
       2635.8159192317407`, -7657.291031802428}, {
       2586.360420390848, -7657.291031802428}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7657.291031802429}, {
       2584.8836008798116`, -7657.291031802429}, {
       2584.8836008798116`, -7657.291031802428}, {
       2584.8827900971255`, -7657.291031802428}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548100834053`, -7657.291031802429}, {
       3136.054810878645, -7657.291031802429}, {
       3136.054810878645, -7657.291031802428}, {
       3136.0548100834053`, -7657.291031802428}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7657.291031802429}, {
       3695.1039183542775`, -7657.291031802429}, {
       3695.1039183542775`, -7657.291031802428}, {
       3537.101573689799, -7657.291031802428}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7657.291031802429}, {
       4142.649334928724, -7657.291031802429}, {
       4142.649334928724, -7657.291031802428}, {
       4131.900917656256, -7657.291031802428}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999996, -7657.291031802429}, {
      4699.999999999998, -7657.291031802429}, {
      4699.999999999998, -7657.291031802428}, {
      4699.999999999996, -7657.291031802428}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928724, -7657.291031802428}, \
{4142.649334928725, -7657.291031802428}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928725, -7657.291031802428}, 6.685247769169753*^-13,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928725, -7657.291031802429}, {
       4699.999999999995, -7657.291031802429}, {
       4699.999999999995, -7657.291031802428}, {
       4142.649334928725, -7657.291031802428}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999995, -7657.291031802429}, 
       6.685247769169753*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999995, -7657.291031802429}, \
{4699.999999999996, -7657.291031802429}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7723.877601978471}, {
        100.00037200021099`, -7723.877601978471}, {
        100.00037200021099`, -7657.291031802429}, {
        100, -7657.291031802429}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7723.877601978471}, {
       1354.6770686338152`, -7723.877601978471}, {
       1354.6770686338152`, -7657.291031802429}, {
       1324.773081287648, -7657.291031802429}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7723.877601978471}, {
       1601.281668212627, -7723.877601978471}, {
       1601.281668212627, -7657.291031802429}, {
       1601.2816681851828`, -7657.291031802429}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7723.877601978471}, {
       2635.8159192317407`, -7723.877601978471}, {
       2635.8159192317407`, -7657.291031802429}, {
       2619.653705478869, -7657.291031802429}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7723.877601978471}, {
       2584.8836008798116`, -7723.877601978471}, {
       2584.8836008798116`, -7657.291031802429}, {
       2584.8827900971255`, -7657.291031802429}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548100834053`, -7723.877601978471}, {
       3136.054810878645, -7723.877601978471}, {
       3136.054810878645, -7657.291031802429}, {
       3136.0548100834053`, -7657.291031802429}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7723.877601978471}, {
       3695.1039183542775`, -7723.877601978471}, {
       3695.1039183542775`, -7657.291031802429}, {
       3537.101573689799, -7657.291031802429}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7723.877601978471}, {
       4142.649334928724, -7723.877601978471}, {
       4142.649334928724, -7657.291031802429}, {
       4131.900917656256, -7657.291031802429}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999995, -7723.877601978471}, {
       4699.999999999998, -7723.877601978471}, {
       4699.999999999998, -7657.291031802429}, {
       4699.999999999995, -7657.291031802429}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7723.877601978471}, {
      1351.971553399074, -7723.877601978471}, {
      1351.971553399074, -7657.291031802429}, {
      600.0829851286655, -7657.291031802429}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2586.360420390848, -7673.937674346439}, \
{2619.653705478869, -7657.291031802429}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2586.360420390848, -7673.937674346439}, 33.29328508802111, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1385.2648384870952`, -7707.230959434461}, {
       2586.360420390848, -7707.230959434461}, {
       2586.360420390848, -7673.937674346439}, {
       1385.2648384870952`, -7673.937674346439}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1385.2648384870952`, -7707.230959434461}, 33.29328508802111, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1351.971553399074, -7723.877601978471}, \
{1385.2648384870952`, -7707.230959434461}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7723.877601978473}, {
        100.00037200021099`, -7723.877601978473}, {
        100.00037200021099`, -7723.877601978471}, {
        100, -7723.877601978471}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7723.877601978473}, {
       1385.2648384870952`, -7723.877601978473}, {
       1385.2648384870952`, -7723.877601978471}, {
       600.0829851286655, -7723.877601978471}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7723.877601978473}, {
       1354.6770686338152`, -7723.877601978473}, {
       1354.6770686338152`, -7723.877601978471}, {
       1324.773081287648, -7723.877601978471}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7723.877601978473}, {
       1601.2816682126258`, -7723.877601978473}, {
       1601.2816682126258`, -7723.877601978471}, {
       1601.2816681851828`, -7723.877601978471}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7723.877601978473}, {
       2635.8159192317407`, -7723.877601978473}, {
       2635.8159192317407`, -7723.877601978471}, {
       2619.653705478869, -7723.877601978471}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7723.877601978473}, {
       2584.8836008798116`, -7723.877601978473}, {
       2584.8836008798116`, -7723.877601978471}, {
       2584.8827900971255`, -7723.877601978471}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548100834053`, -7723.877601978473}, {
       3136.054810878645, -7723.877601978473}, {
       3136.054810878645, -7723.877601978471}, {
       3136.0548100834053`, -7723.877601978471}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7723.877601978473}, {
       3695.1039183542775`, -7723.877601978473}, {
       3695.1039183542775`, -7723.877601978471}, {
       3537.101573689799, -7723.877601978471}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7723.877601978473}, {
       4142.649334928724, -7723.877601978473}, {
       4142.649334928724, -7723.877601978471}, {
       4131.900917656256, -7723.877601978471}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999995, -7723.877601978473}, {
      4699.999999999998, -7723.877601978473}, {
      4699.999999999998, -7723.877601978471}, {
      4699.999999999995, -7723.877601978471}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816682126258`, -7723.877601978471}, \
{1601.281668212627, -7723.877601978471}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668212627, -7723.877601978471}, 1.062062662112822*^-12,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668212627, -7723.877601978472}, {
       4699.9999999999945`, -7723.877601978472}, {
       4699.9999999999945`, -7723.877601978471}, {
       1601.281668212627, -7723.877601978471}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999999945`, -7723.877601978472}, 
       1.062062662112822*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999999945`, -7723.877601978473}, \
{4699.999999999995, -7723.877601978472}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7723.877602388996}, {
        100.00037200021099`, -7723.877602388996}, {
        100.00037200021099`, -7723.877601978473}, {
        100, -7723.877601978473}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7723.877602388996}, {
       1385.2648384870952`, -7723.877602388996}, {
       1385.2648384870952`, -7723.877601978473}, {
       600.0829851286655, -7723.877601978473}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7723.877602388996}, {
       1601.2816682126258`, -7723.877602388996}, {
       1601.2816682126258`, -7723.877601978473}, {
       1601.2816681851828`, -7723.877601978473}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7723.877602388996}, {
       2635.8159192317407`, -7723.877602388996}, {
       2635.8159192317407`, -7723.877601978473}, {
       2619.653705478869, -7723.877601978473}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7723.877602388996}, {
       2584.8836008798116`, -7723.877602388996}, {
       2584.8836008798116`, -7723.877601978473}, {
       2584.8827900971255`, -7723.877601978473}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810288667, -7723.877602388996}, {
       3136.054810878645, -7723.877602388996}, {
       3136.054810878645, -7723.877601978473}, {
       3136.054810288667, -7723.877601978473}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7723.877602388996}, {
       3695.1039183542775`, -7723.877602388996}, {
       3695.1039183542775`, -7723.877601978473}, {
       3537.101573689799, -7723.877601978473}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7723.877602388996}, {
       4142.649334928724, -7723.877602388996}, {
       4142.649334928724, -7723.877601978473}, {
       4131.900917656256, -7723.877601978473}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7723.877602388996}, {
       4699.999999999998, -7723.877602388996}, {
       4699.999999999998, -7723.877601978473}, {
       4699.9999999999945`, -7723.877601978473}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773081287648, -7723.877602388996}, {
      1354.6770686338152`, -7723.877602388996}, {
      1354.6770686338152`, -7723.877601978473}, {
      1324.773081287648, -7723.877601978473}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548100834053`, -7723.877602081104}, \
{3136.054810288667, -7723.877601978473}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548100834053`, -7723.877602081104}, 
       2.0526171450978603`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1354.677068839077, -7723.877602286365}, {
       3136.0548100834053`, -7723.877602286365}, {
       3136.0548100834053`, -7723.877602081104}, {
       1354.677068839077, -7723.877602081104}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1354.677068839077, -7723.877602286365}, 
       2.0526171450978603`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1354.6770686338152`, -7723.877602388996}, \
{1354.677068839077, -7723.877602286365}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7723.877602794035}, {
        100.00037200021099`, -7723.877602794035}, {
        100.00037200021099`, -7723.877602388996}, {
        100, -7723.877602388996}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7723.877602794035}, {
       1385.2648384870952`, -7723.877602794035}, {
       1385.2648384870952`, -7723.877602388996}, {
       600.0829851286655, -7723.877602388996}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7723.877602794035}, {
       1354.677068839077, -7723.877602794035}, {
       1354.677068839077, -7723.877602388996}, {
       1324.773081287648, -7723.877602388996}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7723.877602794035}, {
       1601.2816682126258`, -7723.877602794035}, {
       1601.2816682126258`, -7723.877602388996}, {
       1601.2816681851828`, -7723.877602388996}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7723.877602794035}, {
       2635.8159192317407`, -7723.877602794035}, {
       2635.8159192317407`, -7723.877602388996}, {
       2619.653705478869, -7723.877602388996}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548104911863`, -7723.877602794035}, {
       3136.0548108786447`, -7723.877602794035}, {
       3136.0548108786447`, -7723.877602388996}, {
       3136.0548104911863`, -7723.877602388996}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7723.877602794035}, {
       3695.1039183542775`, -7723.877602794035}, {
       3695.1039183542775`, -7723.877602388996}, {
       3537.101573689799, -7723.877602388996}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4131.900917656256, -7723.877602794035}, {
       4142.649334928724, -7723.877602794035}, {
       4142.649334928724, -7723.877602388996}, {
       4131.900917656256, -7723.877602388996}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7723.877602794035}, {
       4699.999999999998, -7723.877602794035}, {
       4699.999999999998, -7723.877602388996}, {
       4699.9999999999945`, -7723.877602388996}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8827900971255`, -7723.877602794035}, {
      2584.8836008798116`, -7723.877602794035}, {
      2584.8836008798116`, -7723.877602388996}, {
      2584.8827900971255`, -7723.877602388996}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810288667, -7723.877602490255}, \
{3136.0548104911863`, -7723.877602388996}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810288667, -7723.877602490255}, 2.025196782194156*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8836010823316`, -7723.877602692775}, {
       3136.054810288667, -7723.877602692775}, {
       3136.054810288667, -7723.877602490255}, {
       2584.8836010823316`, -7723.877602490255}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8836010823316`, -7723.877602692775}, 
       2.025196782194156*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8836008798116`, -7723.877602794035}, \
{2584.8836010823316`, -7723.877602692775}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7733.357282985663}, {
        100.00037200021099`, -7733.357282985663}, {
        100.00037200021099`, -7723.877602794035}, {
        100, -7723.877602794035}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7733.357282985663}, {
       1354.677068839077, -7733.357282985663}, {
       1354.677068839077, -7723.877602794035}, {
       1324.773081287648, -7723.877602794035}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7733.357282985663}, {
       1601.2816682126258`, -7733.357282985663}, {
       1601.2816682126258`, -7723.877602794035}, {
       1601.2816681851828`, -7723.877602794035}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7733.357282985663}, {
       2635.8159192317407`, -7733.357282985663}, {
       2635.8159192317407`, -7723.877602794035}, {
       2619.653705478869, -7723.877602794035}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7733.357282985663}, {
       2584.8836010823316`, -7733.357282985663}, {
       2584.8836010823316`, -7723.877602794035}, {
       2584.8827900971255`, -7723.877602794035}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548104911863`, -7733.357282985663}, {
       3136.0548108786447`, -7733.357282985663}, {
       3136.0548108786447`, -7723.877602794035}, {
       3136.0548104911863`, -7723.877602794035}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7733.357282985663}, {
       3695.1039183542775`, -7733.357282985663}, {
       3695.1039183542775`, -7723.877602794035}, {
       3537.101573689799, -7723.877602794035}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6407577520695`, -7733.357282985663}, {
       4142.649334928724, -7733.357282985663}, {
       4142.649334928724, -7723.877602794035}, {
       4136.6407577520695`, -7723.877602794035}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7733.357282985663}, {
       4699.999999999998, -7733.357282985663}, {
       4699.999999999998, -7723.877602794035}, {
       4699.9999999999945`, -7723.877602794035}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -7733.357282985663}, {
      1385.2648384870952`, -7733.357282985663}, {
      1385.2648384870952`, -7723.877602794035}, {
      600.0829851286655, -7723.877602794035}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4131.900917656256, -7726.247522841942}, 
       {4136.6407577520695`, -7723.877602794035}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4131.900917656256, -7726.247522841942}, 4.739840095813948, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1390.004678582909, -7730.987362937756}, {
       4131.900917656256, -7730.987362937756}, {
       4131.900917656256, -7726.247522841942}, {
       1390.004678582909, -7726.247522841942}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1390.004678582909, -7730.987362937756}, 4.739840095813948, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1385.2648384870952`, -7733.357282985663}, \
{1390.004678582909, -7730.987362937756}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7733.357283675652}, {
       1390.004678582909, -7733.357283675652}, {
       1390.004678582909, -7733.357282985663}, {
       600.0829851286655, -7733.357282985663}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7733.357283675652}, {
       1354.677068839077, -7733.357283675652}, {
       1354.677068839077, -7733.357282985663}, {
       1324.773081287648, -7733.357282985663}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7733.357283675652}, {
       1601.2816682126258`, -7733.357283675652}, {
       1601.2816682126258`, -7733.357282985663}, {
       1601.2816681851828`, -7733.357282985663}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7733.357283675652}, {
       2635.8159192317407`, -7733.357283675652}, {
       2635.8159192317407`, -7733.357282985663}, {
       2619.653705478869, -7733.357282985663}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7733.357283675652}, {
       2584.8836010823316`, -7733.357283675652}, {
       2584.8836010823316`, -7733.357282985663}, {
       2584.8827900971255`, -7733.357282985663}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810836181, -7733.357283675652}, {
       3136.0548108786447`, -7733.357283675652}, {
       3136.0548108786447`, -7733.357282985663}, {
       3136.054810836181, -7733.357282985663}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7733.357283675652}, {
       3695.1039183542775`, -7733.357283675652}, {
       3695.1039183542775`, -7733.357282985663}, {
       3537.101573689799, -7733.357282985663}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6407577520695`, -7733.357283675652}, {
       4142.649334928724, -7733.357283675652}, {
       4142.649334928724, -7733.357282985663}, {
       4136.6407577520695`, -7733.357282985663}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7733.357283675652}, {
       4699.999999999998, -7733.357283675652}, {
       4699.999999999998, -7733.357282985663}, {
       4699.9999999999945`, -7733.357282985663}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -7733.357283675652}, {
       100.00037200021099`, -7733.357283675652}, {
       100.00037200021099`, -7733.357282985663}, {
       100, -7733.357282985663}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548104911863`, -7733.3572831581605`}, \
{3136.054810836181, -7733.357282985663}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548104911863`, -7733.3572831581605`}, 
       3.4499437964501995`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00037234520538`, -7733.357283503155}, {
       3136.0548104911863`, -7733.357283503155}, {
       3136.0548104911863`, -7733.3572831581605`}, {
       100.00037234520538`, -7733.3572831581605`}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00037234520538`, -7733.357283503155}, 
       3.4499437964501995`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00037200021099`, -7733.357283675652}, \
{100.00037234520538`, -7733.357283503155}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7733.3572837540605`}, {
        100.00037234520538`, -7733.3572837540605`}, {
        100.00037234520538`, -7733.357283675652}, {
        100, -7733.357283675652}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7733.3572837540605`}, {
       1390.004678582909, -7733.3572837540605`}, {
       1390.004678582909, -7733.357283675652}, {
       600.0829851286655, -7733.357283675652}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7733.3572837540605`}, {
       1354.677068839077, -7733.3572837540605`}, {
       1354.677068839077, -7733.357283675652}, {
       1324.773081287648, -7733.357283675652}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7733.3572837540605`}, {
       1601.2816682126258`, -7733.3572837540605`}, {
       1601.2816682126258`, -7733.357283675652}, {
       1601.2816681851828`, -7733.357283675652}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7733.3572837540605`}, {
       2635.8159191925365`, -7733.3572837540605`}, {
       2635.8159191925365`, -7733.357283675652}, {
       2619.653705478869, -7733.357283675652}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7733.3572837540605`}, {
       2584.8836010823316`, -7733.3572837540605`}, {
       2584.8836010823316`, -7733.357283675652}, {
       2584.8827900971255`, -7733.357283675652}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7733.3572837540605`}, {
       3695.1039183542775`, -7733.3572837540605`}, {
       3695.1039183542775`, -7733.357283675652}, {
       3537.101573689799, -7733.357283675652}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6407577520695`, -7733.3572837540605`}, {
       4142.649334928724, -7733.3572837540605`}, {
       4142.649334928724, -7733.357283675652}, {
       4136.6407577520695`, -7733.357283675652}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.9999999999945`, -7733.3572837540605`}, {
       4699.999999999998, -7733.3572837540605`}, {
       4699.999999999998, -7733.357283675652}, {
       4699.9999999999945`, -7733.357283675652}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810836181, -7733.3572837540605`}, {
      3136.0548108786447`, -7733.3572837540605`}, {
      3136.0548108786447`, -7733.357283675652}, {
      3136.054810836181, -7733.357283675652}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2635.8159191925365`, -7733.357283695254}, \
{2635.8159192317407`, -7733.357283675652}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2635.8159192317407`, -7733.357283695254}, 
       3.920416944205608*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2635.8159192317407`, -7733.357283734458}, {
       3136.0548107969767`, -7733.357283734458}, {
       3136.0548107969767`, -7733.357283695254}, {
       2635.8159192317407`, -7733.357283695254}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548107969767`, -7733.357283734458}, 
       3.920416944205608*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107969767`, -7733.3572837540605`}, \
{3136.054810836181, -7733.357283734458}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7733.357283754067}, {
        100.00037234520538`, -7733.357283754067}, {
        100.00037234520538`, -7733.3572837540605`}, {
        100, -7733.3572837540605`}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7733.357283754067}, {
       1390.004678582909, -7733.357283754067}, {
       1390.004678582909, -7733.3572837540605`}, {
       600.0829851286655, -7733.3572837540605`}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7733.357283754067}, {
       1354.677068839077, -7733.357283754067}, {
       1354.677068839077, -7733.3572837540605`}, {
       1324.773081287648, -7733.3572837540605`}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7733.357283754067}, {
       1601.2816682126258`, -7733.357283754067}, {
       1601.2816682126258`, -7733.3572837540605`}, {
       1601.2816681851828`, -7733.3572837540605`}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7733.357283754067}, {
       2635.8159191925365`, -7733.357283754067}, {
       2635.8159191925365`, -7733.3572837540605`}, {
       2619.653705478869, -7733.3572837540605`}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7733.357283754067}, {
       2584.8836010823316`, -7733.357283754067}, {
       2584.8836010823316`, -7733.3572837540605`}, {
       2584.8827900971255`, -7733.3572837540605`}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -7733.357283754067}, {
       3136.0548108786447`, -7733.357283754067}, {
       3136.0548108786447`, -7733.3572837540605`}, {
       3136.0548107969767`, -7733.3572837540605`}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3537.101573689799, -7733.357283754067}, {
       3695.1039183542775`, -7733.357283754067}, {
       3695.1039183542775`, -7733.3572837540605`}, {
       3537.101573689799, -7733.3572837540605`}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -7733.357283754067}, {
       4699.999999999999, -7733.357283754067}, {
       4699.999999999999, -7733.3572837540605`}, {
       4699.999999999998, -7733.3572837540605`}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4136.6407577520695`, -7733.357283754067}, {
      4142.649334928724, -7733.357283754067}, {
      4142.649334928724, -7733.3572837540605`}, {
      4136.6407577520695`, -7733.3572837540605`}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.9999999999945`, -7733.357283754061}, \
{4699.999999999998, -7733.3572837540605`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.9999999999945`, -7733.357283754061}, 
       3.3611404780945556`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.6493349287275`, -7733.357283754065}, {
       4699.9999999999945`, -7733.357283754065}, {
       4699.9999999999945`, -7733.357283754061}, {
       4142.6493349287275`, -7733.357283754061}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.6493349287275`, -7733.357283754065}, 
       3.3611404780945556`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928724, -7733.357283754067}, \
{4142.6493349287275`, -7733.357283754065}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -7765.509766345843}, {
        100.00037234520538`, -7765.509766345843}, {
        100.00037234520538`, -7733.357283754067}, {
        100, -7733.357283754067}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -7765.509766345843}, {
       1390.004678582909, -7765.509766345843}, {
       1390.004678582909, -7733.357283754067}, {
       600.0829851286655, -7733.357283754067}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -7765.509766345843}, {
       1338.6008275431889`, -7765.509766345843}, {
       1338.6008275431889`, -7733.357283754067}, {
       1324.773081287648, -7733.357283754067}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -7765.509766345843}, {
       1601.2816682126258`, -7765.509766345843}, {
       1601.2816682126258`, -7733.357283754067}, {
       1601.2816681851828`, -7733.357283754067}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -7765.509766345843}, {
       2635.8159191925365`, -7765.509766345843}, {
       2635.8159191925365`, -7733.357283754067}, {
       2619.653705478869, -7733.357283754067}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -7765.509766345843}, {
       2584.8836010823316`, -7765.509766345843}, {
       2584.8836010823316`, -7733.357283754067}, {
       2584.8827900971255`, -7733.357283754067}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -7765.509766345843}, {
       3136.0548108786447`, -7765.509766345843}, {
       3136.0548108786447`, -7733.357283754067}, {
       3136.0548107969767`, -7733.357283754067}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6407577520695`, -7765.509766345843}, {
       4142.6493349287275`, -7765.509766345843}, {
       4142.6493349287275`, -7733.357283754067}, {
       4136.6407577520695`, -7733.357283754067}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -7765.509766345843}, {
       4699.999999999999, -7765.509766345843}, {
       4699.999999999999, -7733.357283754067}, {
       4699.999999999998, -7733.357283754067}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3537.101573689799, -7765.509766345843}, {
      3695.103918354278, -7765.509766345843}, {
      3695.103918354278, -7733.357283754067}, {
      3537.101573689799, -7733.357283754067}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1338.6008275431889`, -7741.395404402011}, \
{1354.677068839077, -7733.357283754067}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1354.677068839077, -7741.395404402011}, 16.07624129588809, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1354.677068839077, -7757.471645697899}, {
       3521.025332393911, -7757.471645697899}, {
       3521.025332393911, -7741.395404402011}, {
       1354.677068839077, -7741.395404402011}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3521.025332393911, -7757.471645697899}, 16.07624129588809, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3521.025332393911, -7765.509766345843}, \
{3537.101573689799, -7757.471645697899}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.520741047158}, {
        100.00037234520538`, -8058.520741047158}, {
        100.00037234520538`, -7765.509766345843}, {
        100, -7765.509766345843}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.520741047158}, {
       1243.4991912322516`, -8058.520741047158}, {
       1243.4991912322516`, -7765.509766345843}, {
       600.0829851286655, -7765.509766345843}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -8058.520741047158}, {
       1338.6008275431889`, -8058.520741047158}, {
       1338.6008275431889`, -7765.509766345843}, {
       1324.773081287648, -7765.509766345843}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.520741047158}, {
       1601.2816682126258`, -8058.520741047158}, {
       1601.2816682126258`, -7765.509766345843}, {
       1601.2816681851828`, -7765.509766345843}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.520741047158}, {
       2635.8159191925365`, -8058.520741047158}, {
       2635.8159191925365`, -7765.509766345843}, {
       2619.653705478869, -7765.509766345843}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.520741047158}, {
       2584.8836010823316`, -8058.520741047158}, {
       2584.8836010823316`, -7765.509766345843}, {
       2584.8827900971255`, -7765.509766345843}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -8058.520741047158}, {
       3136.0548108786447`, -8058.520741047158}, {
       3136.0548108786447`, -7765.509766345843}, {
       3136.0548107969767`, -7765.509766345843}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6407577520695`, -8058.520741047158}, {
       4142.6493349287275`, -8058.520741047158}, {
       4142.6493349287275`, -7765.509766345843}, {
       4136.6407577520695`, -7765.509766345843}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.520741047158}, {
       4699.999999999999, -8058.520741047158}, {
       4699.999999999999, -7765.509766345843}, {
       4699.999999999998, -7765.509766345843}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3521.025332393911, -8058.520741047158}, {
      3695.103918354278, -8058.520741047158}, {
      3695.103918354278, -7765.509766345843}, {
      3521.025332393911, -7765.509766345843}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1243.4991912322516`, -7838.762510021172}, \
{1390.004678582909, -7765.509766345843}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1390.004678582909, -7838.762510021172}, 146.50548735065743`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1390.004678582909, -7985.267997371829}, {
       3374.5198450432536`, -7985.267997371829}, {
       3374.5198450432536`, -7838.762510021172}, {
       1390.004678582909, -7838.762510021172}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3374.5198450432536`, -7985.267997371829}, 
       146.50548735065743`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3374.5198450432536`, -8058.520741047158}, \
{3521.025332393911, -7985.267997371829}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.521097498755}, {
        100.00019411940653`, -8058.521097498755}, {
        100.00019411940653`, -8058.520741047158}, {
        100, -8058.520741047158}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.521097498755}, {
       1243.4991912322516`, -8058.521097498755}, {
       1243.4991912322516`, -8058.520741047158}, {
       600.0829851286655, -8058.520741047158}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -8058.521097498755}, {
       1338.6008275431889`, -8058.521097498755}, {
       1338.6008275431889`, -8058.520741047158}, {
       1324.773081287648, -8058.520741047158}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.521097498755}, {
       1601.2816682126258`, -8058.521097498755}, {
       1601.2816682126258`, -8058.520741047158}, {
       1601.2816681851828`, -8058.520741047158}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.521097498755}, {
       2635.8159191925365`, -8058.521097498755}, {
       2635.8159191925365`, -8058.520741047158}, {
       2619.653705478869, -8058.520741047158}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.521097498755}, {
       2584.8836010823316`, -8058.521097498755}, {
       2584.8836010823316`, -8058.520741047158}, {
       2584.8827900971255`, -8058.520741047158}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -8058.521097498755}, {
       3136.0548108786447`, -8058.521097498755}, {
       3136.0548108786447`, -8058.520741047158}, {
       3136.0548107969767`, -8058.520741047158}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3374.5198450432536`, -8058.521097498755}, {
       3695.103918354278, -8058.521097498755}, {
       3695.103918354278, -8058.520741047158}, {
       3374.5198450432536`, -8058.520741047158}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.521097498755}, {
       4699.999999999999, -8058.521097498755}, {
       4699.999999999999, -8058.520741047158}, {
       4699.999999999998, -8058.520741047158}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4136.6407577520695`, -8058.521097498755}, {
      4142.6493349287275`, -8058.521097498755}, {
      4142.6493349287275`, -8058.520741047158}, {
      4136.6407577520695`, -8058.520741047158}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00019411940653`, -8058.520830160057}, \
{100.00037234520538`, -8058.520741047158}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00037234520538`, -8058.520830160057}, 
       0.00017822579883968956`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00037234520538`, -8058.521008385856}, {
       4136.640579526271, -8058.521008385856}, {
       4136.640579526271, -8058.520830160057}, {
       100.00037234520538`, -8058.520830160057}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.640579526271, -8058.521008385856}, 
       0.00017822579883968956`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.640579526271, -8058.521097498755}, \
{4136.6407577520695`, -8058.521008385856}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.864042712934}, {
        100.00019411940653`, -8058.864042712934}, {
        100.00019411940653`, -8058.521097498755}, {
        100, -8058.521097498755}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.864042712934}, {
       1243.4991912322516`, -8058.864042712934}, {
       1243.4991912322516`, -8058.521097498755}, {
       600.0829851286655, -8058.521097498755}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.864042712934}, {
       1601.2816682126258`, -8058.864042712934}, {
       1601.2816682126258`, -8058.521097498755}, {
       1601.2816681851828`, -8058.521097498755}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.864042712934}, {
       2635.8159191925365`, -8058.864042712934}, {
       2635.8159191925365`, -8058.521097498755}, {
       2619.653705478869, -8058.521097498755}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.864042712934}, {
       2584.8836010823316`, -8058.864042712934}, {
       2584.8836010823316`, -8058.521097498755}, {
       2584.8827900971255`, -8058.521097498755}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -8058.864042712934}, {
       3136.0548108786447`, -8058.864042712934}, {
       3136.0548108786447`, -8058.521097498755}, {
       3136.0548107969767`, -8058.521097498755}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3374.691317650343, -8058.864042712934}, {
       3695.103918354278, -8058.864042712934}, {
       3695.103918354278, -8058.521097498755}, {
       3374.691317650343, -8058.521097498755}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640579526271, -8058.864042712934}, {
       4142.6493349287275`, -8058.864042712934}, {
       4142.6493349287275`, -8058.521097498755}, {
       4136.640579526271, -8058.521097498755}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.864042712934}, {
       4699.999999999999, -8058.864042712934}, {
       4699.999999999999, -8058.521097498755}, {
       4699.999999999998, -8058.521097498755}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773081287648, -8058.864042712934}, {
      1338.6008275431889`, -8058.864042712934}, {
      1338.6008275431889`, -8058.521097498755}, {
      1324.773081287648, -8058.521097498755}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3374.5198450432536`, -8058.6068338023}, \
{3374.691317650343, -8058.521097498755}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3374.5198450432536`, -8058.6068338023}, 0.17147260708936685`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1338.7723001502782`, -8058.778306409389}, {
       3374.5198450432536`, -8058.778306409389}, {
       3374.5198450432536`, -8058.6068338023}, {
       1338.7723001502782`, -8058.6068338023}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1338.7723001502782`, -8058.778306409389}, 0.17147260708936685`,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1338.6008275431889`, -8058.864042712934}, \
{1338.7723001502782`, -8058.778306409389}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.864538183167}, {
        100.00019411940653`, -8058.864538183167}, {
        100.00019411940653`, -8058.864042712934}, {
        100, -8058.864042712934}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.864538183167}, {
       1243.4991912322516`, -8058.864538183167}, {
       1243.4991912322516`, -8058.864042712934}, {
       600.0829851286655, -8058.864042712934}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.773081287648, -8058.864538183167}, {
       1338.7723001502782`, -8058.864538183167}, {
       1338.7723001502782`, -8058.864042712934}, {
       1324.773081287648, -8058.864042712934}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.864538183167}, {
       1601.2816682126258`, -8058.864538183167}, {
       1601.2816682126258`, -8058.864042712934}, {
       1601.2816681851828`, -8058.864042712934}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.864538183167}, {
       2635.8159191925365`, -8058.864538183167}, {
       2635.8159191925365`, -8058.864042712934}, {
       2619.653705478869, -8058.864042712934}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548107969767`, -8058.864538183167}, {
       3136.0548108786447`, -8058.864538183167}, {
       3136.0548108786447`, -8058.864042712934}, {
       3136.0548107969767`, -8058.864042712934}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3374.691317650343, -8058.864538183167}, {
       3695.103918354278, -8058.864538183167}, {
       3695.103918354278, -8058.864042712934}, {
       3374.691317650343, -8058.864042712934}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8058.864538183167}, {
       4142.6493349287275`, -8058.864538183167}, {
       4142.6493349287275`, -8058.864042712934}, {
       4136.640827261387, -8058.864042712934}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.864538183167}, {
       4699.999999999999, -8058.864538183167}, {
       4699.999999999999, -8058.864042712934}, {
       4699.999999999998, -8058.864042712934}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8827900971255`, -8058.864538183167}, {
      2584.8836010823316`, -8058.864538183167}, {
      2584.8836010823316`, -8058.864042712934}, {
      2584.8827900971255`, -8058.864042712934}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.640579526271, -8058.864166580493}, \
{4136.640827261387, -8058.864042712934}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.640579526271, -8058.864166580493}, 0.0002477351161797851, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8838488174474`, -8058.864414315609}, {
       4136.640579526271, -8058.864414315609}, {
       4136.640579526271, -8058.864166580493}, {
       2584.8838488174474`, -8058.864166580493}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8838488174474`, -8058.864414315609}, 
       0.0002477351161797851, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8836010823316`, -8058.864538183167}, \
{2584.8838488174474`, -8058.864414315609}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.864538343969}, {
        100.00019411940653`, -8058.864538343969}, {
        100.00019411940653`, -8058.864538183167}, {
        100, -8058.864538183167}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.864538343969}, {
       1243.4991912322516`, -8058.864538343969}, {
       1243.4991912322516`, -8058.864538183167}, {
       600.0829851286655, -8058.864538183167}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.864538343969}, {
       1601.2816682126258`, -8058.864538343969}, {
       1601.2816682126258`, -8058.864538183167}, {
       1601.2816681851828`, -8058.864538183167}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.864538343969}, {
       2635.8159191925365`, -8058.864538343969}, {
       2635.8159191925365`, -8058.864538183167}, {
       2619.653705478869, -8058.864538183167}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.864538343969}, {
       2584.8838488174474`, -8058.864538343969}, {
       2584.8838488174474`, -8058.864538183167}, {
       2584.8827900971255`, -8058.864538183167}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8058.864538343969}, {
       3136.054810878645, -8058.864538343969}, {
       3136.054810878645, -8058.864538183167}, {
       3136.054810877378, -8058.864538183167}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3374.691317650343, -8058.864538343969}, {
       3695.103918354278, -8058.864538343969}, {
       3695.103918354278, -8058.864538183167}, {
       3374.691317650343, -8058.864538183167}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8058.864538343969}, {
       4142.6493349287275`, -8058.864538343969}, {
       4142.6493349287275`, -8058.864538183167}, {
       4136.640827261387, -8058.864538183167}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.864538343969}, {
       4699.999999999999, -8058.864538343969}, {
       4699.999999999999, -8058.864538183167}, {
       4699.999999999998, -8058.864538183167}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.773081287648, -8058.864538343969}, {
      1338.7723001502782`, -8058.864538343969}, {
      1338.7723001502782`, -8058.864538183167}, {
      1324.773081287648, -8058.864538183167}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548107969767`, -8058.864538223367}, \
{3136.054810877378, -8058.864538183167}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548107969767`, -8058.864538223367}, 
       8.040092682626526*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1338.772300230679, -8058.864538303768}, {
       3136.0548107969767`, -8058.864538303768}, {
       3136.0548107969767`, -8058.864538223367}, {
       1338.772300230679, -8058.864538223367}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1338.772300230679, -8058.864538303768}, 8.040092682626526*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1338.7723001502782`, -8058.864538343969}, \
{1338.772300230679, -8058.864538303768}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.864824264972}, {
       1243.4991912322516`, -8058.864824264972}, {
       1243.4991912322516`, -8058.864538343969}, {
       600.0829851286655, -8058.864538343969}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7732242481497`, -8058.864824264972}, {
       1338.772300230679, -8058.864824264972}, {
       1338.772300230679, -8058.864538343969}, {
       1324.7732242481497`, -8058.864538343969}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.864824264972}, {
       1601.2816682126258`, -8058.864824264972}, {
       1601.2816682126258`, -8058.864538343969}, {
       1601.2816681851828`, -8058.864538343969}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.864824264972}, {
       2635.8159191925365`, -8058.864824264972}, {
       2635.8159191925365`, -8058.864538343969}, {
       2619.653705478869, -8058.864538343969}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.864824264972}, {
       2584.8838488174474`, -8058.864824264972}, {
       2584.8838488174474`, -8058.864538343969}, {
       2584.8827900971255`, -8058.864538343969}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8058.864824264972}, {
       3136.054810878645, -8058.864824264972}, {
       3136.054810878645, -8058.864538343969}, {
       3136.054810877378, -8058.864538343969}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3374.691317650343, -8058.864824264972}, {
       3695.103918354278, -8058.864824264972}, {
       3695.103918354278, -8058.864538343969}, {
       3374.691317650343, -8058.864538343969}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8058.864824264972}, {
       4142.6493349287275`, -8058.864824264972}, {
       4142.6493349287275`, -8058.864538343969}, {
       4136.640827261387, -8058.864538343969}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.864824264972}, {
       4699.999999999999, -8058.864824264972}, {
       4699.999999999999, -8058.864538343969}, {
       4699.999999999998, -8058.864538343969}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8058.864824264972}, {
       100.00019411940653`, -8058.864824264972}, {
       100.00019411940653`, -8058.864538343969}, {
       100, -8058.864538343969}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1324.773081287648, -8058.86460982422}, \
{1324.7732242481497`, -8058.864538343969}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1324.773081287648, -8058.86460982422}, 0.000142960501871109, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0003370799084, -8058.8647527847215`}, {
       1324.773081287648, -8058.8647527847215`}, {
       1324.773081287648, -8058.86460982422}, {
       100.0003370799084, -8058.86460982422}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0003370799084, -8058.8647527847215`}, 0.000142960501871109,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00019411940653`, -8058.864824264972}, \
{100.0003370799084, -8058.8647527847215`}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8058.86482430974}, {
        100.0003370799084, -8058.86482430974}, {
        100.0003370799084, -8058.864824264972}, {
        100, -8058.864824264972}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8058.86482430974}, {
       1243.4991912322516`, -8058.86482430974}, {
       1243.4991912322516`, -8058.864824264972}, {
       600.0829851286655, -8058.864824264972}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7732242481497`, -8058.86482430974}, {
       1338.772300230679, -8058.86482430974}, {
       1338.772300230679, -8058.864824264972}, {
       1324.7732242481497`, -8058.864824264972}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8058.86482430974}, {
       1601.2816681902423`, -8058.86482430974}, {
       1601.2816681902423`, -8058.864824264972}, {
       1601.2816681851828`, -8058.864824264972}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8058.86482430974}, {
       2635.8159191925365`, -8058.86482430974}, {
       2635.8159191925365`, -8058.864824264972}, {
       2619.653705478869, -8058.864824264972}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8058.86482430974}, {
       2584.8838488174474`, -8058.86482430974}, {
       2584.8838488174474`, -8058.864824264972}, {
       2584.8827900971255`, -8058.864824264972}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8058.86482430974}, {
       3136.054810878645, -8058.86482430974}, {
       3136.054810878645, -8058.864824264972}, {
       3136.054810877378, -8058.864824264972}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8058.86482430974}, {
       4142.6493349287275`, -8058.86482430974}, {
       4142.6493349287275`, -8058.864824264972}, {
       4136.640827261387, -8058.864824264972}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8058.86482430974}, {
       4699.999999999999, -8058.86482430974}, {
       4699.999999999999, -8058.864824264972}, {
       4699.999999999998, -8058.864824264972}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3374.691317650343, -8058.86482430974}, {
      3695.103918354278, -8058.86482430974}, {
      3695.103918354278, -8058.864824264972}, {
      3374.691317650343, -8058.864824264972}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681902423`, -8058.864824276164}, \
{1601.2816682126258`, -8058.864824264972}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816682126258`, -8058.864824276164}, 
       2.238373756767389*^-8, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816682126258`, -8058.864824298547}, {
       3374.6913176279595`, -8058.864824298547}, {
       3374.6913176279595`, -8058.864824276164}, {
       1601.2816682126258`, -8058.864824276164}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3374.6913176279595`, -8058.864824298547}, 
       2.238373756767389*^-8, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3374.6913176279595`, -8058.86482430974}, \
{3374.691317650343, -8058.864824298547}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8084.224351770441}, {
        100.0003370799084, -8084.224351770441}, {
        100.0003370799084, -8058.86482430974}, {100, -8058.86482430974}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8084.224351770441}, {
       1243.4991912322516`, -8084.224351770441}, {
       1243.4991912322516`, -8058.86482430974}, {
       600.0829851286655, -8058.86482430974}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8084.224351770441}, {
       1601.2816681902423`, -8084.224351770441}, {
       1601.2816681902423`, -8058.86482430974}, {
       1601.2816681851828`, -8058.86482430974}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8084.224351770441}, {
       2635.8159191925365`, -8084.224351770441}, {
       2635.8159191925365`, -8058.86482430974}, {
       2619.653705478869, -8058.86482430974}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8084.224351770441}, {
       2584.8838488174474`, -8084.224351770441}, {
       2584.8838488174474`, -8058.86482430974}, {
       2584.8827900971255`, -8058.86482430974}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8084.224351770441}, {
       3136.054810878645, -8084.224351770441}, {
       3136.054810878645, -8058.86482430974}, {
       3136.054810877378, -8058.86482430974}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3387.37108135831, -8084.224351770441}, {
       3695.1039183542784`, -8084.224351770441}, {
       3695.1039183542784`, -8058.86482430974}, {
       3387.37108135831, -8058.86482430974}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8084.224351770441}, {
       4142.6493349287275`, -8084.224351770441}, {
       4142.6493349287275`, -8058.86482430974}, {
       4136.640827261387, -8058.86482430974}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8084.224351770441}, {
       4699.999999999999, -8084.224351770441}, {
       4699.999999999999, -8058.86482430974}, {
       4699.999999999998, -8058.86482430974}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7732242481497`, -8084.224351770441}, {
      1338.772300230679, -8084.224351770441}, {
      1338.772300230679, -8058.86482430974}, {
      1324.7732242481497`, -8058.86482430974}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3374.6913176279595`, -8065.204706174915}, \
{3387.37108135831, -8058.86482430974}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3374.6913176279595`, -8065.204706174915}, 12.679763730350553`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1351.4520639610296`, -8077.884469905266}, {
       3374.6913176279595`, -8077.884469905266}, {
       3374.6913176279595`, -8065.204706174915}, {
       1351.4520639610296`, -8065.204706174915}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1351.4520639610296`, -8077.884469905266}, 12.679763730350553`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1338.772300230679, -8084.224351770441}, \
{1351.4520639610296`, -8077.884469905266}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8155.440981478819}, {
        100.0003370799084, -8155.440981478819}, {
        100.0003370799084, -8084.224351770441}, {
        100, -8084.224351770441}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8155.440981478819}, {
       1207.890876378063, -8155.440981478819}, {
       1207.890876378063, -8084.224351770441}, {
       600.0829851286655, -8084.224351770441}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7732242481497`, -8155.440981478819}, {
       1351.4520639610296`, -8155.440981478819}, {
       1351.4520639610296`, -8084.224351770441}, {
       1324.7732242481497`, -8084.224351770441}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8155.440981478819}, {
       1601.2816681902423`, -8155.440981478819}, {
       1601.2816681902423`, -8084.224351770441}, {
       1601.2816681851828`, -8084.224351770441}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8155.440981478819}, {
       2635.8159191925365`, -8155.440981478819}, {
       2635.8159191925365`, -8084.224351770441}, {
       2619.653705478869, -8084.224351770441}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8155.440981478819}, {
       2584.8838488174474`, -8155.440981478819}, {
       2584.8838488174474`, -8084.224351770441}, {
       2584.8827900971255`, -8084.224351770441}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8155.440981478819}, {
       3136.054810878645, -8155.440981478819}, {
       3136.054810878645, -8084.224351770441}, {
       3136.054810877378, -8084.224351770441}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8155.440981478819}, {
       4142.6493349287275`, -8155.440981478819}, {
       4142.6493349287275`, -8084.224351770441}, {
       4136.640827261387, -8084.224351770441}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8155.440981478819}, {
       4699.999999999999, -8155.440981478819}, {
       4699.999999999999, -8084.224351770441}, {
       4699.999999999998, -8084.224351770441}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3387.37108135831, -8155.440981478819}, {
      3695.103918354278, -8155.440981478819}, {
      3695.103918354278, -8084.224351770441}, {
      3387.37108135831, -8084.224351770441}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{1207.890876378063, -8102.028509197536}, \
{1243.4991912322516`, -8084.224351770441}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1243.4991912322516`, -8102.028509197536}, 35.608314854188734`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1243.4991912322516`, -8137.636824051724}, {
       3351.7627665041214`, -8137.636824051724}, {
       3351.7627665041214`, -8102.028509197536}, {
       1243.4991912322516`, -8102.028509197536}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3351.7627665041214`, -8137.636824051724}, 
       35.608314854188734`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3351.7627665041214`, -8155.440981478819}, \
{3387.37108135831, -8137.636824051724}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.19710553873}, {
        100.0003370799084, -8619.19710553873}, {
        100.0003370799084, -8155.44098147882}, {100, -8155.44098147882}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.19710553873}, {
       976.0128143481079, -8619.19710553873}, {
       976.0128143481079, -8155.44098147882}, {
       600.0829851286655, -8155.44098147882}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7732242481497`, -8619.19710553873}, {
       1351.4520639610296`, -8619.19710553873}, {
       1351.4520639610296`, -8155.44098147882}, {
       1324.7732242481497`, -8155.44098147882}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.19710553873}, {
       1601.2816681902423`, -8619.19710553873}, {
       1601.2816681902423`, -8155.44098147882}, {
       1601.2816681851828`, -8155.44098147882}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.19710553873}, {
       2635.8159191925365`, -8619.19710553873}, {
       2635.8159191925365`, -8155.44098147882}, {
       2619.653705478869, -8155.44098147882}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8619.19710553873}, {
       2584.8838488174474`, -8619.19710553873}, {
       2584.8838488174474`, -8155.44098147882}, {
       2584.8827900971255`, -8155.44098147882}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.19710553873}, {
       3136.054810878645, -8619.19710553873}, {
       3136.054810878645, -8155.44098147882}, {
       3136.054810877378, -8155.44098147882}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8619.19710553873}, {
       4142.6493349287275`, -8619.19710553873}, {
       4142.6493349287275`, -8155.44098147882}, {
       4136.640827261387, -8155.44098147882}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.19710553873}, {
       4699.999999999999, -8619.19710553873}, {
       4699.999999999999, -8155.44098147882}, {
       4699.999999999998, -8155.44098147882}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3351.762766504121, -8619.19710553873}, {
      3695.103918354278, -8619.19710553873}, {
      3695.103918354278, -8155.44098147882}, {
      3351.762766504121, -8155.44098147882}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{976.0128143481079, -8271.380012493797}, \
{1207.890876378063, -8155.44098147882}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{1207.890876378063, -8271.380012493797}, 231.87806202995512`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1207.890876378063, -8503.258074523752}, {
       3119.884704474166, -8503.258074523752}, {
       3119.884704474166, -8271.380012493797}, {
       1207.890876378063, -8271.380012493797}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3119.884704474166, -8503.258074523752}, 231.87806202995512`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3119.884704474166, -8619.19710553873}, \
{3351.762766504121, -8503.258074523752}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.197631784948}, {
       976.0128143481079, -8619.197631784948}, {
       976.0128143481079, -8619.19710553873}, {
       600.0829851286655, -8619.19710553873}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.197631784948}, {
       1351.4520639610296`, -8619.197631784948}, {
       1351.4520639610296`, -8619.19710553873}, {
       1324.7734873712586`, -8619.19710553873}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.197631784948}, {
       1601.2816681902423`, -8619.197631784948}, {
       1601.2816681902423`, -8619.19710553873}, {
       1601.2816681851828`, -8619.19710553873}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.197631784948}, {
       2635.8159191925365`, -8619.197631784948}, {
       2635.8159191925365`, -8619.19710553873}, {
       2619.653705478869, -8619.19710553873}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8619.197631784948}, {
       2584.8838488174474`, -8619.197631784948}, {
       2584.8838488174474`, -8619.19710553873}, {
       2584.8827900971255`, -8619.19710553873}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.197631784948}, {
       3136.054810878645, -8619.197631784948}, {
       3136.054810878645, -8619.19710553873}, {
       3136.054810877378, -8619.19710553873}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.884704474166, -8619.197631784948}, {
       3695.103918354278, -8619.197631784948}, {
       3695.103918354278, -8619.19710553873}, {
       3119.884704474166, -8619.19710553873}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640827261387, -8619.197631784948}, {
       4142.6493349287275`, -8619.197631784948}, {
       4142.6493349287275`, -8619.19710553873}, {
       4136.640827261387, -8619.19710553873}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.197631784948}, {
       4699.999999999999, -8619.197631784948}, {
       4699.999999999999, -8619.19710553873}, {
       4699.999999999998, -8619.19710553873}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8619.197631784948}, {
       100.0003370799084, -8619.197631784948}, {
       100.0003370799084, -8619.19710553873}, {100, -8619.19710553873}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1324.7732242481497`, -8619.197237100285}, \
{1324.7734873712586`, -8619.19710553873}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1324.7732242481497`, -8619.197237100285}, 
       0.00026312310880342724`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0006002030172, -8619.197500223394}, {
       1324.7732242481497`, -8619.197500223394}, {
       1324.7732242481497`, -8619.197237100285}, {
       100.0006002030172, -8619.197237100285}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0006002030172, -8619.197500223394}, 
       0.00026312310880342724`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0003370799084, -8619.197631784948}, \
{100.0006002030172, -8619.197500223394}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.198358573016}, {
        100.00023680898352`, -8619.198358573016}, {
        100.00023680898352`, -8619.197631784948}, {
        100, -8619.197631784948}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.198358573016}, {
       976.0128143481079, -8619.198358573016}, {
       976.0128143481079, -8619.197631784948}, {
       600.0829851286655, -8619.197631784948}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.198358573016}, {
       1351.4520639610296`, -8619.198358573016}, {
       1351.4520639610296`, -8619.197631784948}, {
       1324.7734873712586`, -8619.197631784948}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.198358573016}, {
       1601.2816681902423`, -8619.198358573016}, {
       1601.2816681902423`, -8619.197631784948}, {
       1601.2816681851828`, -8619.197631784948}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.198358573016}, {
       2635.8159191925365`, -8619.198358573016}, {
       2635.8159191925365`, -8619.197631784948}, {
       2619.653705478869, -8619.197631784948}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8619.198358573016}, {
       2584.8838488174474`, -8619.198358573016}, {
       2584.8838488174474`, -8619.197631784948}, {
       2584.8827900971255`, -8619.197631784948}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.198358573016}, {
       3136.054810878645, -8619.198358573016}, {
       3136.054810878645, -8619.197631784948}, {
       3136.054810877378, -8619.197631784948}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.884704474166, -8619.198358573016}, {
       3695.103918354278, -8619.198358573016}, {
       3695.103918354278, -8619.197631784948}, {
       3119.884704474166, -8619.197631784948}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.198358573016}, {
       4699.999999999999, -8619.198358573016}, {
       4699.999999999999, -8619.197631784948}, {
       4699.999999999998, -8619.197631784948}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4136.640827261387, -8619.198358573016}, {
      4142.6493349287275`, -8619.198358573016}, {
      4142.6493349287275`, -8619.197631784948}, {
      4136.640827261387, -8619.197631784948}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00023680898352`, -8619.197813481966}, \
{100.0006002030172, -8619.197631784948}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0006002030172, -8619.197813481966}, 0.0003633940336929733, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0006002030172, -8619.198176876}, {
       4136.640463867353, -8619.198176876}, {
       4136.640463867353, -8619.197813481966}, {
       100.0006002030172, -8619.197813481966}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.640463867353, -8619.198176876}, 0.0003633940336929733, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.640463867353, -8619.198358573016}, \
{4136.640827261387, -8619.198176876}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.199069982116}, {
        100.00023680898352`, -8619.199069982116}, {
        100.00023680898352`, -8619.198358573016}, {
        100, -8619.198358573016}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.199069982116}, {
       976.0128143481079, -8619.199069982116}, {
       976.0128143481079, -8619.198358573016}, {
       600.0829851286655, -8619.198358573016}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.199069982116}, {
       1351.4520639610296`, -8619.199069982116}, {
       1351.4520639610296`, -8619.198358573016}, {
       1324.7734873712586`, -8619.198358573016}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.199069982116}, {
       1601.2816681902423`, -8619.199069982116}, {
       1601.2816681902423`, -8619.198358573016}, {
       1601.2816681851828`, -8619.198358573016}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.199069982116}, {
       2635.8159191925365`, -8619.199069982116}, {
       2635.8159191925365`, -8619.198358573016}, {
       2619.653705478869, -8619.198358573016}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.199069982116}, {
       3136.054810878645, -8619.199069982116}, {
       3136.054810878645, -8619.198358573016}, {
       3136.054810877378, -8619.198358573016}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.884704474166, -8619.199069982116}, {
       3695.103918354278, -8619.199069982116}, {
       3695.103918354278, -8619.198358573016}, {
       3119.884704474166, -8619.198358573016}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640819571903, -8619.199069982116}, {
       4142.6493349287275`, -8619.199069982116}, {
       4142.6493349287275`, -8619.198358573016}, {
       4136.640819571903, -8619.198358573016}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.199069982116}, {
       4699.999999999999, -8619.199069982116}, {
       4699.999999999999, -8619.198358573016}, {
       4699.999999999998, -8619.198358573016}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8827900971255`, -8619.199069982116}, {
      2584.8838488174474`, -8619.199069982116}, {
      2584.8838488174474`, -8619.198358573016}, {
      2584.8827900971255`, -8619.198358573016}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.640463867353, -8619.19853642529}, \
{4136.640819571903, -8619.198358573016}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.640463867353, -8619.19853642529}, 0.0003557045501275931, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8842045219976`, -8619.198892129842}, {
       4136.640463867353, -8619.198892129842}, {
       4136.640463867353, -8619.19853642529}, {
       2584.8842045219976`, -8619.19853642529}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8842045219976`, -8619.198892129842}, 
       0.0003557045501275931, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8838488174474`, -8619.199069982116}, \
{2584.8842045219976`, -8619.198892129842}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.201248862733}, {
        100.00023680898352`, -8619.201248862733}, {
        100.00023680898352`, -8619.199069982116}, {
        100, -8619.199069982116}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.201248862733}, {
       976.0128143481079, -8619.201248862733}, {
       976.0128143481079, -8619.199069982116}, {
       600.0829851286655, -8619.199069982116}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.201248862733}, {
       1351.4520639610296`, -8619.201248862733}, {
       1351.4520639610296`, -8619.199069982116}, {
       1324.7734873712586`, -8619.199069982116}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.201248862733}, {
       1601.2816681902423`, -8619.201248862733}, {
       1601.2816681902423`, -8619.199069982116}, {
       1601.2816681851828`, -8619.199069982116}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.201248862733}, {
       2635.8159191925365`, -8619.201248862733}, {
       2635.8159191925365`, -8619.199069982116}, {
       2619.653705478869, -8619.199069982116}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8827900971255`, -8619.201248862733}, {
       2584.8831150816886`, -8619.201248862733}, {
       2584.8831150816886`, -8619.199069982116}, {
       2584.8827900971255`, -8619.199069982116}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.201248862733}, {
       3136.054810878645, -8619.201248862733}, {
       3136.054810878645, -8619.199069982116}, {
       3136.054810877378, -8619.199069982116}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640819571903, -8619.201248862733}, {
       4142.6493349287275`, -8619.201248862733}, {
       4142.6493349287275`, -8619.199069982116}, {
       4136.640819571903, -8619.199069982116}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.201248862733}, {
       4699.999999999999, -8619.201248862733}, {
       4699.999999999999, -8619.199069982116}, {
       4699.999999999998, -8619.199069982116}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3119.884704474166, -8619.201248862733}, {
      3695.103918354278, -8619.201248862733}, {
      3695.103918354278, -8619.199069982116}, {
      3119.884704474166, -8619.199069982116}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8831150816886`, -8619.19961470227}, \
{2584.8842045219976`, -8619.199069982116}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8842045219976`, -8619.19961470227}, 0.0010894403089596, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8842045219976`, -8619.200704142579}, {
       3119.883615033857, -8619.200704142579}, {
       3119.883615033857, -8619.19961470227}, {
       2584.8842045219976`, -8619.19961470227}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3119.883615033857, -8619.200704142579}, 0.0010894403089596, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3119.883615033857, -8619.201248862733}, \
{3119.884704474166, -8619.200704142579}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.201827594363}, {
        100.00023680898352`, -8619.201827594363}, {
        100.00023680898352`, -8619.201248862733}, {
        100, -8619.201248862733}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.201827594363}, {
       976.0125249822927, -8619.201827594363}, {
       976.0125249822927, -8619.201248862733}, {
       600.0829851286655, -8619.201248862733}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.201827594363}, {
       1351.4520639610296`, -8619.201827594363}, {
       1351.4520639610296`, -8619.201248862733}, {
       1324.7734873712586`, -8619.201248862733}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681851828`, -8619.201827594363}, {
       1601.2816681902423`, -8619.201827594363}, {
       1601.2816681902423`, -8619.201248862733}, {
       1601.2816681851828`, -8619.201248862733}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.201827594363}, {
       2635.8159191925365`, -8619.201827594363}, {
       2635.8159191925365`, -8619.201248862733}, {
       2619.653705478869, -8619.201248862733}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.201827594363}, {
       3136.054810878645, -8619.201827594363}, {
       3136.054810878645, -8619.201248862733}, {
       3136.054810877378, -8619.201248862733}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.883615033857, -8619.201827594363}, {
       3695.103918354278, -8619.201827594363}, {
       3695.103918354278, -8619.201248862733}, {
       3119.883615033857, -8619.201248862733}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640819571903, -8619.201827594363}, {
       4142.6493349287275`, -8619.201827594363}, {
       4142.6493349287275`, -8619.201248862733}, {
       4136.640819571903, -8619.201248862733}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.201827594363}, {
       4699.999999999999, -8619.201827594363}, {
       4699.999999999999, -8619.201248862733}, {
       4699.999999999998, -8619.201248862733}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8827900971255`, -8619.201827594363}, {
      2584.8831150816886`, -8619.201827594363}, {
      2584.8831150816886`, -8619.201248862733}, {
      2584.8827900971255`, -8619.201248862733}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{976.0125249822927, -8619.20139354564}, \
{976.0128143481079, -8619.201248862733}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{976.0128143481079, -8619.20139354564}, 0.0002893658151354398, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{976.0128143481079, -8619.201682911455}, {
       2584.8825007313103`, -8619.201682911455}, {
       2584.8825007313103`, -8619.20139354564}, {
       976.0128143481079, -8619.20139354564}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8825007313103`, -8619.201682911455}, 
       0.0002893658151354398, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8825007313103`, -8619.201827594363}, \
{2584.8827900971255`, -8619.201682911455}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.201827597182}, {
        100.00023680898352`, -8619.201827597182}, {
        100.00023680898352`, -8619.201827594363}, {
        100, -8619.201827594363}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.201827597182}, {
       1351.4520639610296`, -8619.201827597182}, {
       1351.4520639610296`, -8619.201827594363}, {
       1324.7734873712586`, -8619.201827594363}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8619.201827597182}, {
       1601.2816681902423`, -8619.201827597182}, {
       1601.2816681902423`, -8619.201827594363}, {
       1601.2816681865927`, -8619.201827594363}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.201827597182}, {
       2635.8159191925365`, -8619.201827597182}, {
       2635.8159191925365`, -8619.201827594363}, {
       2619.653705478869, -8619.201827594363}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8619.201827597182}, {
       2584.8831150816886`, -8619.201827597182}, {
       2584.8831150816886`, -8619.201827594363}, {
       2584.8825007313103`, -8619.201827594363}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.201827597182}, {
       3136.054810878645, -8619.201827597182}, {
       3136.054810878645, -8619.201827594363}, {
       3136.054810877378, -8619.201827594363}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.883615033857, -8619.201827597182}, {
       3695.103918354278, -8619.201827597182}, {
       3695.103918354278, -8619.201827594363}, {
       3119.883615033857, -8619.201827594363}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640819571903, -8619.201827597182}, {
       4142.6493349287275`, -8619.201827597182}, {
       4142.6493349287275`, -8619.201827594363}, {
       4136.640819571903, -8619.201827594363}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.201827597182}, {
       4699.999999999999, -8619.201827597182}, {
       4699.999999999999, -8619.201827594363}, {
       4699.999999999998, -8619.201827594363}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -8619.201827597182}, {
      976.0125249822927, -8619.201827597182}, {
      976.0125249822927, -8619.201827594363}, {
      600.0829851286655, -8619.201827594363}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681851828`, -8619.201827595067}, \
{1601.2816681865927`, -8619.201827594363}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681851828`, -8619.201827595067}, 
       1.4098365745489619`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{976.0125249837026, -8619.201827596477}, {
       1601.2816681851828`, -8619.201827596477}, {
       1601.2816681851828`, -8619.201827595067}, {
       976.0125249837026, -8619.201827595067}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{976.0125249837026, -8619.201827596477}, 
       1.4098365745489619`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{976.0125249822927, -8619.201827597182}, \
{976.0125249837026, -8619.201827596477}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.20205709226}, {
        100.0001220614447, -8619.20205709226}, {
        100.0001220614447, -8619.201827597182}, {
        100, -8619.201827597182}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.20205709226}, {
       976.0125249837026, -8619.20205709226}, {
       976.0125249837026, -8619.201827597182}, {
       600.0829851286655, -8619.201827597182}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.20205709226}, {
       1351.4520639610296`, -8619.20205709226}, {
       1351.4520639610296`, -8619.201827597182}, {
       1324.7734873712586`, -8619.201827597182}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8619.20205709226}, {
       1601.2816681902423`, -8619.20205709226}, {
       1601.2816681902423`, -8619.201827597182}, {
       1601.2816681865927`, -8619.201827597182}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.20205709226}, {
       2635.8159191925365`, -8619.20205709226}, {
       2635.8159191925365`, -8619.201827597182}, {
       2619.653705478869, -8619.201827597182}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8619.20205709226}, {
       2584.8831150816886`, -8619.20205709226}, {
       2584.8831150816886`, -8619.201827597182}, {
       2584.8825007313103`, -8619.201827597182}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.20205709226}, {
       3136.054810878645, -8619.20205709226}, {
       3136.054810878645, -8619.201827597182}, {
       3136.054810877378, -8619.201827597182}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.640819571903, -8619.20205709226}, {
       4142.6493349287275`, -8619.20205709226}, {
       4142.6493349287275`, -8619.201827597182}, {
       4136.640819571903, -8619.201827597182}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.20205709226}, {
       4699.999999999999, -8619.20205709226}, {
       4699.999999999999, -8619.201827597182}, {
       4699.999999999998, -8619.201827597182}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3119.883615033857, -8619.20205709226}, {
      3695.103918354278, -8619.20205709226}, {
      3695.103918354278, -8619.201827597182}, {
      3119.883615033857, -8619.201827597182}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0001220614447, -8619.201884970951}, \
{100.00023680898352`, -8619.201827597182}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00023680898352`, -8619.201884970951}, 
       0.00011474753881487461`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00023680898352`, -8619.20199971849}, {
       3119.8835002863184`, -8619.20199971849}, {
       3119.8835002863184`, -8619.201884970951}, {
       100.00023680898352`, -8619.201884970951}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3119.8835002863184`, -8619.20199971849}, 
       0.00011474753881487461`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3119.8835002863184`, -8619.20205709226}, \
{3119.883615033857, -8619.20199971849}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.20250625307}, {
        100.0001220614447, -8619.20250625307}, {
        100.0001220614447, -8619.20205709226}, {100, -8619.20205709226}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.20250625307}, {
       976.0125249837026, -8619.20250625307}, {
       976.0125249837026, -8619.20205709226}, {
       600.0829851286655, -8619.20205709226}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.20250625307}, {
       1351.4520639610296`, -8619.20250625307}, {
       1351.4520639610296`, -8619.20205709226}, {
       1324.7734873712586`, -8619.20205709226}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8619.20250625307}, {
       1601.2816681902423`, -8619.20250625307}, {
       1601.2816681902423`, -8619.20205709226}, {
       1601.2816681865927`, -8619.20205709226}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.20250625307}, {
       2635.8159191925365`, -8619.20250625307}, {
       2635.8159191925365`, -8619.20205709226}, {
       2619.653705478869, -8619.20205709226}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.20250625307}, {
       3136.054810878645, -8619.20250625307}, {
       3136.054810878645, -8619.20205709226}, {
       3136.054810877378, -8619.20205709226}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.8835002863184`, -8619.20250625307}, {
       3695.103918354278, -8619.20250625307}, {
       3695.103918354278, -8619.20205709226}, {
       3119.8835002863184`, -8619.20205709226}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8619.20250625307}, {
       4142.649334928727, -8619.20250625307}, {
       4142.649334928727, -8619.20205709226}, {
       4136.6410441523085`, -8619.20205709226}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.20250625307}, {
       4699.999999999999, -8619.20250625307}, {
       4699.999999999999, -8619.20205709226}, {
       4699.999999999998, -8619.20205709226}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8825007313103`, -8619.20250625307}, {
      2584.8831150816886`, -8619.20250625307}, {
      2584.8831150816886`, -8619.20205709226}, {
      2584.8825007313103`, -8619.20205709226}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.640819571903, -8619.202169382463}, \
{4136.6410441523085`, -8619.20205709226}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.640819571903, -8619.202169382463}, 
       0.00022458040548160993`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883339662094, -8619.202393962867}, {
       4136.640819571903, -8619.202393962867}, {
       4136.640819571903, -8619.202169382463}, {
       2584.883339662094, -8619.202169382463}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883339662094, -8619.202393962867}, 
       0.00022458040548160993`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8831150816886`, -8619.20250625307}, \
{2584.883339662094, -8619.202393962867}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8619.203581627624}, {
        100.0001220614447, -8619.203581627624}, {
        100.0001220614447, -8619.20250625307}, {100, -8619.20250625307}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8619.203581627624}, {
       976.0125249837026, -8619.203581627624}, {
       976.0125249837026, -8619.20250625307}, {
       600.0829851286655, -8619.20250625307}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8619.203581627624}, {
       1351.4520639610296`, -8619.203581627624}, {
       1351.4520639610296`, -8619.20250625307}, {
       1324.7734873712586`, -8619.20250625307}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8619.203581627624}, {
       1601.2816681902423`, -8619.203581627624}, {
       1601.2816681902423`, -8619.20250625307}, {
       1601.2816681865927`, -8619.20250625307}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8619.203581627624}, {
       2635.8159191925365`, -8619.203581627624}, {
       2635.8159191925365`, -8619.20250625307}, {
       2619.653705478869, -8619.20250625307}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8619.203581627624}, {
       3136.054810878645, -8619.203581627624}, {
       3136.054810878645, -8619.20250625307}, {
       3136.054810877378, -8619.20250625307}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3119.8840379735952`, -8619.203581627624}, {
       3695.103918354278, -8619.203581627624}, {
       3695.103918354278, -8619.20250625307}, {
       3119.8840379735952`, -8619.20250625307}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8619.203581627624}, {
       4142.649334928727, -8619.203581627624}, {
       4142.649334928727, -8619.20250625307}, {
       4136.6410441523085`, -8619.20250625307}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8619.203581627624}, {
       4699.999999999999, -8619.203581627624}, {
       4699.999999999999, -8619.20250625307}, {
       4699.999999999998, -8619.20250625307}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8825007313103`, -8619.203581627624}, {
      2584.883339662094, -8619.203581627624}, {
      2584.883339662094, -8619.20250625307}, {
      2584.8825007313103`, -8619.20250625307}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3119.8835002863184`, -8619.202775096708}, \
{3119.8840379735952`, -8619.20250625307}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3119.8835002863184`, -8619.202775096708}, 
       0.0005376872767214067, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883877349371, -8619.203312783986}, {
       3119.8835002863184`, -8619.203312783986}, {
       3119.8835002863184`, -8619.202775096708}, {
       2584.883877349371, -8619.202775096708}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883877349371, -8619.203312783986}, 0.0005376872767214067, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883339662094, -8619.203581627624}, \
{2584.883877349371, -8619.203312783986}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8662.091988205553}, {
        100.0001220614447, -8662.091988205553}, {
        100.0001220614447, -8619.203581627624}, {
        100, -8619.203581627624}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829851286655, -8662.091988205553}, {
       976.0125249837026, -8662.091988205553}, {
       976.0125249837026, -8619.203581627624}, {
       600.0829851286655, -8619.203581627624}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8662.091988205553}, {
       1330.007860672065, -8662.091988205553}, {
       1330.007860672065, -8619.203581627624}, {
       1324.7734873712586`, -8619.203581627624}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8662.091988205553}, {
       1601.2816681902423`, -8662.091988205553}, {
       1601.2816681902423`, -8619.203581627624}, {
       1601.2816681865927`, -8619.203581627624}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8662.091988205553}, {
       2635.8159191925365`, -8662.091988205553}, {
       2635.8159191925365`, -8619.203581627624}, {
       2619.653705478869, -8619.203581627624}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8662.091988205553}, {
       2584.883877349371, -8662.091988205553}, {
       2584.883877349371, -8619.203581627624}, {
       2584.8825007313103`, -8619.203581627624}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8662.091988205553}, {
       3136.054810878645, -8662.091988205553}, {
       3136.054810878645, -8619.203581627624}, {
       3136.054810877378, -8619.203581627624}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8662.091988205553}, {
       4142.649334928727, -8662.091988205553}, {
       4142.649334928727, -8619.203581627624}, {
       4136.6410441523085`, -8619.203581627624}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8662.091988205553}, {
       4699.999999999999, -8662.091988205553}, {
       4699.999999999999, -8619.203581627624}, {
       4699.999999999998, -8619.203581627624}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3119.8840379735952`, -8662.091988205553}, {
      3695.103918354278, -8662.091988205553}, {
      3695.103918354278, -8619.203581627624}, {
      3119.8840379735952`, -8619.203581627624}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1330.007860672065, -8629.925683272106}, \
{1351.4520639610296`, -8619.203581627624}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1351.4520639610296`, -8629.925683272106}, 21.44420328896468, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1351.4520639610296`, -8651.369886561071}, {
       3098.4398346846306`, -8651.369886561071}, {
       3098.4398346846306`, -8629.925683272106}, {
       1351.4520639610296`, -8629.925683272106}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3098.4398346846306`, -8651.369886561071}, 21.44420328896468, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3098.4398346846306`, -8662.091988205553}, \
{3119.8840379735952`, -8651.369886561071}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8662.092066156458}, {
        100.00008308599244`, -8662.092066156458}, {
        100.00008308599244`, -8662.091988205553}, {
        100, -8662.091988205553}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8662.092066156458}, {
       1330.007860672065, -8662.092066156458}, {
       1330.007860672065, -8662.091988205553}, {
       1324.7734873712586`, -8662.091988205553}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8662.092066156458}, {
       1601.2816681902423`, -8662.092066156458}, {
       1601.2816681902423`, -8662.091988205553}, {
       1601.2816681865927`, -8662.091988205553}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8662.092066156458}, {
       2635.8159191925365`, -8662.092066156458}, {
       2635.8159191925365`, -8662.091988205553}, {
       2619.653705478869, -8662.091988205553}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8662.092066156458}, {
       2584.883877349371, -8662.092066156458}, {
       2584.883877349371, -8662.091988205553}, {
       2584.8825007313103`, -8662.091988205553}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8662.092066156458}, {
       3136.054810878645, -8662.092066156458}, {
       3136.054810878645, -8662.091988205553}, {
       3136.054810877378, -8662.091988205553}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3098.4398346846306`, -8662.092066156458}, {
       3695.103918354278, -8662.092066156458}, {
       3695.103918354278, -8662.091988205553}, {
       3098.4398346846306`, -8662.091988205553}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8662.092066156458}, {
       4142.649334928727, -8662.092066156458}, {
       4142.649334928727, -8662.091988205553}, {
       4136.6410441523085`, -8662.091988205553}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8662.092066156458}, {
       4699.999999999999, -8662.092066156458}, {
       4699.999999999999, -8662.091988205553}, {
       4699.999999999998, -8662.091988205553}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829851286655, -8662.092066156458}, {
      976.0125249837025, -8662.092066156458}, {
      976.0125249837025, -8662.091988205553}, {
      600.0829851286655, -8662.091988205553}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00008308599244`, -8662.09200769328}, \
{100.0001220614447, -8662.091988205553}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0001220614447, -8662.09200769328}, 0.00003897545225470573, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0001220614447, -8662.092046668731}, {
       600.0829461532132, -8662.092046668731}, {
       600.0829461532132, -8662.09200769328}, {
       100.0001220614447, -8662.09200769328}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0829461532132, -8662.092046668731}, 
       0.00003897545225470573, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0829461532132, -8662.092066156458}, \
{600.0829851286655, -8662.092046668731}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8662.092078092131}, {
       976.0125249837026, -8662.092078092131}, {
       976.0125249837026, -8662.092066156458}, {
       600.0829521210504, -8662.092066156458}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8662.092078092131}, {
       1330.007860672065, -8662.092078092131}, {
       1330.007860672065, -8662.092066156458}, {
       1324.7734873712586`, -8662.092066156458}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8662.092078092131}, {
       1601.2816681902423`, -8662.092078092131}, {
       1601.2816681902423`, -8662.092066156458}, {
       1601.2816681865927`, -8662.092066156458}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8662.092078092131}, {
       2635.8159191925365`, -8662.092078092131}, {
       2635.8159191925365`, -8662.092066156458}, {
       2619.653705478869, -8662.092066156458}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8662.092078092131}, {
       2584.883877349371, -8662.092078092131}, {
       2584.883877349371, -8662.092066156458}, {
       2584.8825007313103`, -8662.092066156458}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8662.092078092131}, {
       3136.054810878645, -8662.092078092131}, {
       3136.054810878645, -8662.092066156458}, {
       3136.054810877378, -8662.092066156458}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3098.4398346846306`, -8662.092078092131}, {
       3695.103918354278, -8662.092078092131}, {
       3695.103918354278, -8662.092066156458}, {
       3098.4398346846306`, -8662.092066156458}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8662.092078092131}, {
       4142.649334928727, -8662.092078092131}, {
       4142.649334928727, -8662.092066156458}, {
       4136.6410441523085`, -8662.092066156458}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8662.092078092131}, {
       4699.999999999999, -8662.092078092131}, {
       4699.999999999999, -8662.092066156458}, {
       4699.999999999998, -8662.092066156458}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8662.092078092131}, {
       100.00008308599244`, -8662.092078092131}, {
       100.00008308599244`, -8662.092066156458}, {
       100, -8662.092066156458}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0829461532132, -8662.092069140375}, \
{600.0829521210504, -8662.092066156458}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0829461532132, -8662.092069140375}, 5.967837138015476*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00008905382958`, -8662.092075108212}, {
       600.0829461532132, -8662.092075108212}, {
       600.0829461532132, -8662.092069140375}, {
       100.00008905382958`, -8662.092069140375}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00008905382958`, -8662.092075108212}, 
       5.967837138015476*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00008308599244`, -8662.092078092131}, \
{100.00008905382958`, -8662.092075108212}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8715.900073886993}, {
        100.00008905382958`, -8715.900073886993}, {
        100.00008905382958`, -8662.092078092131}, {
        100, -8662.092078092131}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8715.900073886993}, {
       949.1085270862718, -8715.900073886993}, {
       949.1085270862718, -8662.092078092131}, {
       600.0829521210504, -8662.092078092131}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8715.900073886993}, {
       1330.007860672065, -8715.900073886993}, {
       1330.007860672065, -8662.092078092131}, {
       1324.7734873712586`, -8662.092078092131}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8715.900073886993}, {
       1601.2816681902423`, -8715.900073886993}, {
       1601.2816681902423`, -8662.092078092131}, {
       1601.2816681865927`, -8662.092078092131}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8715.900073886993}, {
       2635.8159191925365`, -8715.900073886993}, {
       2635.8159191925365`, -8662.092078092131}, {
       2619.653705478869, -8662.092078092131}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007313103`, -8715.900073886993}, {
       2584.883877349371, -8715.900073886993}, {
       2584.883877349371, -8662.092078092131}, {
       2584.8825007313103`, -8662.092078092131}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8715.900073886993}, {
       3136.054810878645, -8715.900073886993}, {
       3136.054810878645, -8662.092078092131}, {
       3136.054810877378, -8662.092078092131}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8715.900073886993}, {
       4142.649334928727, -8715.900073886993}, {
       4142.649334928727, -8662.092078092131}, {
       4136.6410441523085`, -8662.092078092131}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8715.900073886993}, {
       4699.999999999999, -8715.900073886993}, {
       4699.999999999999, -8662.092078092131}, {
       4699.999999999998, -8662.092078092131}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3098.4398346846306`, -8715.900073886993}, {
      3695.1039183542784`, -8715.900073886993}, {
      3695.1039183542784`, -8662.092078092131}, {
      3098.4398346846306`, -8662.092078092131}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{949.1085270862718, -8675.544077040846}, \
{976.0125249837026, -8662.092078092131}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{976.0125249837026, -8675.544077040846}, 26.903997897430713`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{976.0125249837026, -8702.448074938276}, {
       3071.5358367872, -8702.448074938276}, {
       3071.5358367872, -8675.544077040846}, {
       976.0125249837026, -8675.544077040846}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3071.5358367872, -8702.448074938276}, 26.903997897430713`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3071.5358367872, -8715.900073886993}, \
{3098.4398346846306`, -8702.448074938276}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8715.900073888073}, {
        100.00008905382958`, -8715.900073888073}, {
        100.00008905382958`, -8715.900073886993}, {
        100, -8715.900073886993}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8715.900073888073}, {
       949.1085270862718, -8715.900073888073}, {
       949.1085270862718, -8715.900073886993}, {
       600.0829521210504, -8715.900073886993}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8715.900073888073}, {
       1330.007860672065, -8715.900073888073}, {
       1330.007860672065, -8715.900073886993}, {
       1324.7734873712586`, -8715.900073886993}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8715.900073888073}, {
       2635.8159191925365`, -8715.900073888073}, {
       2635.8159191925365`, -8715.900073886993}, {
       2619.653705478869, -8715.900073886993}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8715.900073888073}, {
       2584.883877349371, -8715.900073888073}, {
       2584.883877349371, -8715.900073886993}, {
       2584.8825007318505`, -8715.900073886993}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8715.900073888073}, {
       3136.054810878645, -8715.900073888073}, {
       3136.054810878645, -8715.900073886993}, {
       3136.054810877378, -8715.900073886993}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8715.900073888073}, {
       3695.1039183542784`, -8715.900073888073}, {
       3695.1039183542784`, -8715.900073886993}, {
       3071.5358367872, -8715.900073886993}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8715.900073888073}, {
       4142.649334928727, -8715.900073888073}, {
       4142.649334928727, -8715.900073886993}, {
       4136.6410441523085`, -8715.900073886993}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8715.900073888073}, {
       4699.999999999999, -8715.900073888073}, {
       4699.999999999999, -8715.900073886993}, {
       4699.999999999998, -8715.900073886993}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681865927`, -8715.900073888073}, {
      1601.2816681902423`, -8715.900073888073}, {
      1601.2816681902423`, -8715.900073886993}, {
      1601.2816681865927`, -8715.900073886993}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8825007313103`, -8715.900073887264}, \
{2584.8825007318505`, -8715.900073886993}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8825007313103`, -8715.900073887264}, 
       5.400937209252205*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681907825`, -8715.900073887804}, {
       2584.8825007313103`, -8715.900073887804}, {
       2584.8825007313103`, -8715.900073887264}, {
       1601.2816681907825`, -8715.900073887264}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681907825`, -8715.900073887804}, 
       5.400937209252205*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681902423`, -8715.900073888073}, \
{1601.2816681907825`, -8715.900073887804}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8715.900073888073}, {
        100.00008905382958`, -8715.900073888073}, {
        100.00008905382958`, -8715.900073888073}, {
        100, -8715.900073888073}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8715.900073888073}, {
       949.1085270862718, -8715.900073888073}, {
       949.1085270862718, -8715.900073888073}, {
       600.0829521210504, -8715.900073888073}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8715.900073888073}, {
       1330.007860672065, -8715.900073888073}, {
       1330.007860672065, -8715.900073888073}, {
       1324.7734873712586`, -8715.900073888073}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681865927`, -8715.900073888073}, {
       1601.2816681907825`, -8715.900073888073}, {
       1601.2816681907825`, -8715.900073888073}, {
       1601.2816681865927`, -8715.900073888073}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8715.900073888073}, {
       2635.8159191925365`, -8715.900073888073}, {
       2635.8159191925365`, -8715.900073888073}, {
       2619.653705478869, -8715.900073888073}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8715.900073888073}, {
       2584.883877349371, -8715.900073888073}, {
       2584.883877349371, -8715.900073888073}, {
       2584.8825007318505`, -8715.900073888073}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8715.900073888073}, {
       3136.054810878645, -8715.900073888073}, {
       3136.054810878645, -8715.900073888073}, {
       3136.054810877378, -8715.900073888073}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8715.900073888073}, {
       3695.1039183542784`, -8715.900073888073}, {
       3695.1039183542784`, -8715.900073888073}, {
       3071.5358367872, -8715.900073888073}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8715.900073888073}, {
       4142.649334928727, -8715.900073888073}, {
       4142.649334928727, -8715.900073888073}, {
       4136.6410441523085`, -8715.900073888073}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -8715.900073888073}, {
      4699.999999999999, -8715.900073888073}, {
      4699.999999999999, -8715.900073888073}, {
      4699.999999999998, -8715.900073888073}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883877349371, -8715.900073888073}, \
{2584.883877349371, -8715.900073888073}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883877349371, -8715.900073888073}, 
       1.5115122708280718`*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883877349371, -8715.900073888073}, {
       4699.999999999998, -8715.900073888073}, {
       4699.999999999998, -8715.900073888073}, {
       2584.883877349371, -8715.900073888073}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8715.900073888073}, 
       1.5115122708280718`*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8715.900073888073}, \
{4699.999999999998, -8715.900073888073}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8715.900073888373}, {
        100.00008905382958`, -8715.900073888373}, {
        100.00008905382958`, -8715.900073888073}, {
        100, -8715.900073888073}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8715.900073888373}, {
       949.1085270862718, -8715.900073888373}, {
       949.1085270862718, -8715.900073888073}, {
       600.0829521210504, -8715.900073888073}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8715.900073888373}, {
       1601.2816681907825`, -8715.900073888373}, {
       1601.2816681907825`, -8715.900073888073}, {
       1601.2816681867425`, -8715.900073888073}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8715.900073888373}, {
       2635.8159191925365`, -8715.900073888373}, {
       2635.8159191925365`, -8715.900073888073}, {
       2619.653705478869, -8715.900073888073}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8715.900073888373}, {
       2584.883877349371, -8715.900073888373}, {
       2584.883877349371, -8715.900073888073}, {
       2584.8825007318505`, -8715.900073888073}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8715.900073888373}, {
       3136.054810878645, -8715.900073888373}, {
       3136.054810878645, -8715.900073888073}, {
       3136.054810877378, -8715.900073888073}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8715.900073888373}, {
       3695.1039183542784`, -8715.900073888373}, {
       3695.1039183542784`, -8715.900073888073}, {
       3071.5358367872, -8715.900073888073}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4136.6410441523085`, -8715.900073888373}, {
       4142.649334928727, -8715.900073888373}, {
       4142.649334928727, -8715.900073888073}, {
       4136.6410441523085`, -8715.900073888073}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8715.900073888373}, {
       4699.999999999999, -8715.900073888373}, {
       4699.999999999999, -8715.900073888073}, {
       4699.999999999998, -8715.900073888073}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7734873712586`, -8715.900073888373}, {
      1330.007860672065, -8715.900073888373}, {
      1330.007860672065, -8715.900073888073}, {
      1324.7734873712586`, -8715.900073888073}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681865927`, -8715.900073888148}, \
{1601.2816681867425`, -8715.900073888073}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681865927`, -8715.900073888148}, 
       1.4976848044469627`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1330.0078606722147`, -8715.900073888299}, {
       1601.2816681865927`, -8715.900073888299}, {
       1601.2816681865927`, -8715.900073888148}, {
       1330.0078606722147`, -8715.900073888148}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1330.0078606722147`, -8715.900073888299}, 
       1.4976848044469627`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1330.007860672065, -8715.900073888373}, \
{1330.0078606722147`, -8715.900073888299}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8720.879331240796}, {
        100.00008905382958`, -8720.879331240796}, {
        100.00008905382958`, -8715.900073888373}, {
        100, -8715.900073888373}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.879331240796}, {
       949.1085270862718, -8720.879331240796}, {
       949.1085270862718, -8715.900073888373}, {
       600.0829521210504, -8715.900073888373}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8720.879331240796}, {
       1330.0078606722147`, -8720.879331240796}, {
       1330.0078606722147`, -8715.900073888373}, {
       1324.7734873712586`, -8715.900073888373}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8720.879331240796}, {
       1601.2816681907825`, -8720.879331240796}, {
       1601.2816681907825`, -8715.900073888373}, {
       1601.2816681867425`, -8715.900073888373}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8720.879331240796}, {
       2635.8159191925365`, -8720.879331240796}, {
       2635.8159191925365`, -8715.900073888373}, {
       2619.653705478869, -8715.900073888373}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.879331240796}, {
       2584.883877349371, -8720.879331240796}, {
       2584.883877349371, -8715.900073888373}, {
       2584.8825007318505`, -8715.900073888373}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.879331240796}, {
       3136.054810878645, -8720.879331240796}, {
       3136.054810878645, -8715.900073888373}, {
       3136.054810877378, -8715.900073888373}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.13067282852, -8720.879331240796}, {
       4142.649334928727, -8720.879331240796}, {
       4142.649334928727, -8715.900073888373}, {
       4139.13067282852, -8715.900073888373}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8720.879331240796}, {
       4699.999999999999, -8720.879331240796}, {
       4699.999999999999, -8715.900073888373}, {
       4699.999999999998, -8715.900073888373}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3071.5358367872, -8720.879331240796}, {
      3695.1039183542784`, -8720.879331240796}, {
      3695.1039183542784`, -8715.900073888373}, {
      3071.5358367872, -8715.900073888373}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4136.6410441523085`, -8717.144888226478}, \
{4139.13067282852, -8715.900073888373}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4136.6410441523085`, -8717.144888226478}, 2.4896286762118107`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3697.5935470304903`, -8719.63451690269}, {
       4136.6410441523085`, -8719.63451690269}, {
       4136.6410441523085`, -8717.144888226478}, {
       3697.5935470304903`, -8717.144888226478}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3697.5935470304903`, -8719.63451690269}, 2.4896286762118107`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3695.1039183542784`, -8720.879331240796}, \
{3697.5935470304903`, -8719.63451690269}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8720.879331248823}, {
        100.00008905382958`, -8720.879331248823}, {
        100.00008905382958`, -8720.879331240796}, {
        100, -8720.879331240796}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.879331248823}, {
       949.1085270862718, -8720.879331248823}, {
       949.1085270862718, -8720.879331240796}, {
       600.0829521210504, -8720.879331240796}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7734873712586`, -8720.879331248823}, {
       1330.0078606722147`, -8720.879331248823}, {
       1330.0078606722147`, -8720.879331240796}, {
       1324.7734873712586`, -8720.879331240796}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8720.879331248823}, {
       2635.8159191925365`, -8720.879331248823}, {
       2635.8159191925365`, -8720.879331240796}, {
       2619.653705478869, -8720.879331240796}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.879331248823}, {
       2584.883877349371, -8720.879331248823}, {
       2584.883877349371, -8720.879331240796}, {
       2584.8825007318505`, -8720.879331240796}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.879331248823}, {
       3136.054810878645, -8720.879331248823}, {
       3136.054810878645, -8720.879331240796}, {
       3136.054810877378, -8720.879331240796}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8720.879331248823}, {
       3697.5935470304903`, -8720.879331248823}, {
       3697.5935470304903`, -8720.879331240796}, {
       3071.5358367872, -8720.879331240796}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.1306728325335`, -8720.879331248823}, {
       4142.649334928727, -8720.879331248823}, {
       4142.649334928727, -8720.879331240796}, {
       4139.1306728325335`, -8720.879331240796}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8720.879331248823}, {
       4699.999999999999, -8720.879331248823}, {
       4699.999999999999, -8720.879331240796}, {
       4699.999999999998, -8720.879331240796}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681867425`, -8720.879331248823}, {
      1601.2816681907825`, -8720.879331248823}, {
      1601.2816681907825`, -8720.879331240796}, {
      1601.2816681867425`, -8720.879331240796}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.13067282852, -8720.879331242802}, \
{4139.1306728325335`, -8720.879331240796}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.13067282852, -8720.879331242802}, 4.013373554314505*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681947959`, -8720.879331246817}, {
       4139.13067282852, -8720.879331246817}, {
       4139.13067282852, -8720.879331242802}, {
       1601.2816681947959`, -8720.879331242802}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681947959`, -8720.879331246817}, 
       4.013373554314505*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681907825`, -8720.879331248823}, \
{1601.2816681947959`, -8720.879331246817}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.879362431491}, {
       949.1085270862718, -8720.879362431491}, {
       949.1085270862718, -8720.879331248823}, {
       600.0829521210504, -8720.879331248823}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8720.879362431491}, {
       1330.0078606722147`, -8720.879362431491}, {
       1330.0078606722147`, -8720.879331248823}, {
       1324.7735029625924`, -8720.879331248823}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8720.879362431491}, {
       1601.2816681947959`, -8720.879362431491}, {
       1601.2816681947959`, -8720.879331248823}, {
       1601.2816681867425`, -8720.879331248823}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8720.879362431491}, {
       2635.8159191925365`, -8720.879362431491}, {
       2635.8159191925365`, -8720.879331248823}, {
       2619.653705478869, -8720.879331248823}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.879362431491}, {
       2584.883877349371, -8720.879362431491}, {
       2584.883877349371, -8720.879331248823}, {
       2584.8825007318505`, -8720.879331248823}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.879362431491}, {
       3136.054810878645, -8720.879362431491}, {
       3136.054810878645, -8720.879331248823}, {
       3136.054810877378, -8720.879331248823}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8720.879362431491}, {
       3697.5935470304903`, -8720.879362431491}, {
       3697.5935470304903`, -8720.879331248823}, {
       3071.5358367872, -8720.879331248823}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.1306728325335`, -8720.879362431491}, {
       4142.649334928727, -8720.879362431491}, {
       4142.649334928727, -8720.879331248823}, {
       4139.1306728325335`, -8720.879331248823}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8720.879362431491}, {
       4699.999999999999, -8720.879362431491}, {
       4699.999999999999, -8720.879331248823}, {
       4699.999999999998, -8720.879331248823}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8720.879362431491}, {
       100.00008905382958`, -8720.879362431491}, {
       100.00008905382958`, -8720.879331248823}, {
       100, -8720.879331248823}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1324.7734873712586`, -8720.87933904449}, \
{1324.7735029625924`, -8720.879331248823}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1324.7734873712586`, -8720.87933904449}, 
       0.000015591333710446246`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00010464516329`, -8720.879354635825}, {
       1324.7734873712586`, -8720.879354635825}, {
       1324.7734873712586`, -8720.87933904449}, {
       100.00010464516329`, -8720.87933904449}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00010464516329`, -8720.879354635825}, 
       0.000015591333710446246`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00008905382958`, -8720.879362431491}, \
{100.00010464516329`, -8720.879354635825}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8720.879362431491}, {
        100.00010464516329`, -8720.879362431491}, {
        100.00010464516329`, -8720.879362431491}, {
        100, -8720.879362431491}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.879362431491}, {
       949.1085270862718, -8720.879362431491}, {
       949.1085270862718, -8720.879362431491}, {
       600.0829521210504, -8720.879362431491}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8720.879362431491}, {
       1330.0078606722147`, -8720.879362431491}, {
       1330.0078606722147`, -8720.879362431491}, {
       1324.7735029625924`, -8720.879362431491}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8720.879362431491}, {
       1601.2816681947959`, -8720.879362431491}, {
       1601.2816681947959`, -8720.879362431491}, {
       1601.2816681867425`, -8720.879362431491}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8720.879362431491}, {
       2635.815919192536, -8720.879362431491}, {
       2635.815919192536, -8720.879362431491}, {
       2619.653705478869, -8720.879362431491}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.879362431491}, {
       2584.883877349371, -8720.879362431491}, {
       2584.883877349371, -8720.879362431491}, {
       2584.8825007318505`, -8720.879362431491}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.879362431491}, {
       3136.054810878645, -8720.879362431491}, {
       3136.054810878645, -8720.879362431491}, {
       3136.054810877378, -8720.879362431491}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8720.879362431491}, {
       3697.5935470304903`, -8720.879362431491}, {
       3697.5935470304903`, -8720.879362431491}, {
       3071.5358367872, -8720.879362431491}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.1306728325335`, -8720.879362431491}, {
       4142.649334928727, -8720.879362431491}, {
       4142.649334928727, -8720.879362431491}, {
       4139.1306728325335`, -8720.879362431491}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -8720.879362431491}, {
      4699.999999999999, -8720.879362431491}, {
      4699.999999999999, -8720.879362431491}, {
      4699.999999999998, -8720.879362431491}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2635.815919192536, -8720.879362431491}, \
{2635.8159191925365`, -8720.879362431491}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2635.8159191925365`, -8720.879362431491}, 
       2.736947136481704*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2635.8159191925365`, -8720.879362431491}, {
       4699.999999999998, -8720.879362431491}, {
       4699.999999999998, -8720.879362431491}, {
       2635.8159191925365`, -8720.879362431491}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8720.879362431491}, 
       2.736947136481704*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8720.879362431491}, \
{4699.999999999998, -8720.879362431491}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8720.879455427466}, {
        100.00005814717574`, -8720.879455427466}, {
        100.00005814717574`, -8720.879362431491}, {
        100, -8720.879362431491}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.879455427466}, {
       949.1085270862718, -8720.879455427466}, {
       949.1085270862718, -8720.879362431491}, {
       600.0829521210504, -8720.879362431491}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8720.879455427466}, {
       1330.0078606722147`, -8720.879455427466}, {
       1330.0078606722147`, -8720.879362431491}, {
       1324.7735029625924`, -8720.879362431491}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8720.879455427466}, {
       1601.2816681947959`, -8720.879455427466}, {
       1601.2816681947959`, -8720.879362431491}, {
       1601.2816681867425`, -8720.879362431491}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705478869, -8720.879455427466}, {
       2635.815919192536, -8720.879455427466}, {
       2635.815919192536, -8720.879362431491}, {
       2619.653705478869, -8720.879362431491}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.879455427466}, {
       2584.883877349371, -8720.879455427466}, {
       2584.883877349371, -8720.879362431491}, {
       2584.8825007318505`, -8720.879362431491}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.879455427466}, {
       3136.054810878645, -8720.879455427466}, {
       3136.054810878645, -8720.879362431491}, {
       3136.054810877378, -8720.879362431491}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8720.879455427466}, {
       3697.5935470304903`, -8720.879455427466}, {
       3697.5935470304903`, -8720.879362431491}, {
       3071.5358367872, -8720.879362431491}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8720.879455427466}, {
       4699.999999999999, -8720.879455427466}, {
       4699.999999999999, -8720.879362431491}, {
       4699.999999999998, -8720.879362431491}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.1306728325335`, -8720.879455427466}, {
      4142.649334928727, -8720.879455427466}, {
      4142.649334928727, -8720.879362431491}, {
      4139.1306728325335`, -8720.879362431491}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00005814717574`, -8720.879385680486}, \
{100.00010464516329`, -8720.879362431491}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00010464516329`, -8720.879385680486}, 
       0.00004649798755614049, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00010464516329`, -8720.879432178474}, {
       4139.130626334546, -8720.879432178474}, {
       4139.130626334546, -8720.879385680486}, {
       100.00010464516329`, -8720.879385680486}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.130626334546, -8720.879432178474}, 
       0.00004649798755614049, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.130626334546, -8720.879455427466}, \
{4139.1306728325335`, -8720.879432178474}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8720.8794559205}, {
        100.0000579006586, -8720.8794559205}, {
        100.0000579006586, -8720.879455427466}, {
        100, -8720.879455427466}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8720.8794559205}, {
       949.1085270862718, -8720.8794559205}, {
       949.1085270862718, -8720.879455427466}, {
       600.0829521210504, -8720.879455427466}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8720.8794559205}, {
       1330.0078606722147`, -8720.8794559205}, {
       1330.0078606722147`, -8720.879455427466}, {
       1324.7735029625924`, -8720.879455427466}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8720.8794559205}, {
       1601.2816681947959`, -8720.8794559205}, {
       1601.2816681947959`, -8720.879455427466}, {
       1601.2816681867425`, -8720.879455427466}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8720.8794559205}, {
       2584.883877349371, -8720.8794559205}, {
       2584.883877349371, -8720.879455427466}, {
       2584.8825007318505`, -8720.879455427466}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8720.8794559205}, {
       3136.054810878645, -8720.8794559205}, {
       3136.054810878645, -8720.879455427466}, {
       3136.054810877378, -8720.879455427466}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8720.8794559205}, {
       3697.5935470304903`, -8720.8794559205}, {
       3697.5935470304903`, -8720.879455427466}, {
       3071.5358367872, -8720.879455427466}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.130626334546, -8720.8794559205}, {
       4142.649334928727, -8720.8794559205}, {
       4142.649334928727, -8720.879455427466}, {
       4139.130626334546, -8720.879455427466}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8720.8794559205}, {
       4699.999999999999, -8720.8794559205}, {
       4699.999999999999, -8720.879455427466}, {
       4699.999999999998, -8720.879455427466}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.653705478869, -8720.8794559205}, {
      2635.815919192536, -8720.8794559205}, {
      2635.815919192536, -8720.879455427466}, {
      2619.653705478869, -8720.879455427466}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000579006586, -8720.879455550725}, \
{100.00005814717574`, -8720.879455427466}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00005814717574`, -8720.879455550725}, 
       2.465171395573567*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00005814717574`, -8720.879455797241}, {
       2619.653705232352, -8720.879455797241}, {
       2619.653705232352, -8720.879455550725}, {
       100.00005814717574`, -8720.879455550725}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.653705232352, -8720.879455797241}, 
       2.465171395573567*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.653705232352, -8720.8794559205}, \
{2619.653705478869, -8720.879455797241}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8721.945461558807}, {
        100.0000579006586, -8721.945461558807}, {
        100.0000579006586, -8720.8794559205}, {100, -8720.8794559205}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8721.945461558807}, {
       1330.0078606722147`, -8721.945461558807}, {
       1330.0078606722147`, -8720.8794559205}, {
       1324.7735029625924`, -8720.8794559205}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8721.945461558807}, {
       1601.2816681947959`, -8721.945461558807}, {
       1601.2816681947959`, -8720.8794559205}, {
       1601.2816681867425`, -8720.8794559205}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705232352, -8721.945461558807}, {
       2635.815919192536, -8721.945461558807}, {
       2635.815919192536, -8720.8794559205}, {
       2619.653705232352, -8720.8794559205}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8721.945461558807}, {
       2584.883877349371, -8721.945461558807}, {
       2584.883877349371, -8720.8794559205}, {
       2584.8825007318505`, -8720.8794559205}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8721.945461558807}, {
       3136.054810878645, -8721.945461558807}, {
       3136.054810878645, -8720.8794559205}, {
       3136.054810877378, -8720.8794559205}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8721.945461558807}, {
       3697.5935470304903`, -8721.945461558807}, {
       3697.5935470304903`, -8720.8794559205}, {
       3071.5358367872, -8720.8794559205}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8721.945461558807}, {
       4142.649334928727, -8721.945461558807}, {
       4142.649334928727, -8720.8794559205}, {
       4139.6636291537, -8720.8794559205}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8721.945461558807}, {
       4699.999999999999, -8721.945461558807}, {
       4699.999999999999, -8720.8794559205}, {
       4699.999999999998, -8720.8794559205}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0829521210504, -8721.945461558807}, {
      949.1085270862718, -8721.945461558807}, {
      949.1085270862718, -8720.8794559205}, {
      600.0829521210504, -8720.8794559205}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.130626334546, -8721.145957330076}, \
{4139.6636291537, -8720.8794559205}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.130626334546, -8721.145957330076}, 0.5330028191536664, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{949.6415299054256, -8721.678960149231}, {
       4139.130626334546, -8721.678960149231}, {
       4139.130626334546, -8721.145957330076}, {
       949.6415299054256, -8721.145957330076}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{949.6415299054256, -8721.678960149231}, 0.5330028191536664, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{949.1085270862718, -8721.945461558807}, \
{949.6415299054256, -8721.678960149231}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8721.945461558807}, {
        100.0000579006586, -8721.945461558807}, {
        100.0000579006586, -8721.945461558807}, {
        100, -8721.945461558807}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8721.945461558807}, {
       949.6415299054256, -8721.945461558807}, {
       949.6415299054256, -8721.945461558807}, {
       600.0829521210504, -8721.945461558807}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8721.945461558807}, {
       1330.0078606722147`, -8721.945461558807}, {
       1330.0078606722147`, -8721.945461558807}, {
       1324.7735029625924`, -8721.945461558807}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8721.945461558807}, {
       1601.2816681947959`, -8721.945461558807}, {
       1601.2816681947959`, -8721.945461558807}, {
       1601.2816681867425`, -8721.945461558807}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705232352, -8721.945461558807}, {
       2635.815919192536, -8721.945461558807}, {
       2635.815919192536, -8721.945461558807}, {
       2619.653705232352, -8721.945461558807}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8825007318505`, -8721.945461558807}, {
       2584.883877349371, -8721.945461558807}, {
       2584.883877349371, -8721.945461558807}, {
       2584.8825007318505`, -8721.945461558807}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8721.945461558807}, {
       3136.054810878645, -8721.945461558807}, {
       3136.054810878645, -8721.945461558807}, {
       3136.054810877378, -8721.945461558807}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8721.945461558807}, {
       3697.5935470304903`, -8721.945461558807}, {
       3697.5935470304903`, -8721.945461558807}, {
       3071.5358367872, -8721.945461558807}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8721.945461558807}, {
       4142.649334928727, -8721.945461558807}, {
       4142.649334928727, -8721.945461558807}, {
       4139.6636291537, -8721.945461558807}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -8721.945461558807}, {
      4699.999999999999, -8721.945461558807}, {
      4699.999999999999, -8721.945461558807}, {
      4699.999999999998, -8721.945461558807}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2635.815919192536, -8721.945461558807}, \
{2635.815919192536, -8721.945461558807}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2635.815919192536, -8721.945461558807}, 
       2.6261284484986875`*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2635.815919192536, -8721.945461558807}, {
       4699.999999999998, -8721.945461558807}, {
       4699.999999999998, -8721.945461558807}, {
       2635.815919192536, -8721.945461558807}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8721.945461558807}, 
       2.6261284484986875`*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8721.945461558807}, \
{4699.999999999998, -8721.945461558807}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8721.945802998263}, {
        100.0000579006586, -8721.945802998263}, {
        100.0000579006586, -8721.945461558807}, {
        100, -8721.945461558807}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8721.945802998263}, {
       949.6415299054256, -8721.945802998263}, {
       949.6415299054256, -8721.945461558807}, {
       600.0829521210504, -8721.945461558807}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8721.945802998263}, {
       1330.007689952487, -8721.945802998263}, {
       1330.007689952487, -8721.945461558807}, {
       1324.7735029625924`, -8721.945461558807}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8721.945802998263}, {
       1601.2816681947959`, -8721.945802998263}, {
       1601.2816681947959`, -8721.945461558807}, {
       1601.2816681867425`, -8721.945461558807}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.653705232352, -8721.945802998263}, {
       2635.815919192536, -8721.945802998263}, {
       2635.815919192536, -8721.945461558807}, {
       2619.653705232352, -8721.945461558807}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8721.945802998263}, {
       3136.054810878645, -8721.945802998263}, {
       3136.054810878645, -8721.945461558807}, {
       3136.054810877378, -8721.945461558807}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8721.945802998263}, {
       3697.5935470304903`, -8721.945802998263}, {
       3697.5935470304903`, -8721.945461558807}, {
       3071.5358367872, -8721.945461558807}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8721.945802998263}, {
       4142.649334928727, -8721.945802998263}, {
       4142.649334928727, -8721.945461558807}, {
       4139.6636291537, -8721.945461558807}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8721.945802998263}, {
       4699.999999999999, -8721.945802998263}, {
       4699.999999999999, -8721.945461558807}, {
       4699.999999999998, -8721.945461558807}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8825007318505`, -8721.945802998263}, {
      2584.883877349371, -8721.945802998263}, {
      2584.883877349371, -8721.945461558807}, {
      2584.8825007318505`, -8721.945461558807}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1330.007689952487, -8721.945546918672}, \
{1330.0078606722147`, -8721.945461558807}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1330.0078606722147`, -8721.945546918672}, 
       0.00017071972785275284`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1330.0078606722147`, -8721.9457176384}, {
       2584.8823300121226`, -8721.9457176384}, {
       2584.8823300121226`, -8721.945546918672}, {
       1330.0078606722147`, -8721.945546918672}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8823300121226`, -8721.9457176384}, 
       0.00017071972785275284`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8823300121226`, -8721.945802998263}, \
{2584.8825007318505`, -8721.9457176384}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.451613773115}, {
        100.0000579006586, -8722.451613773115}, {
        100.0000579006586, -8721.945802998263}, {
        100, -8721.945802998263}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451613773115}, {
       949.6415299054256, -8722.451613773115}, {
       949.6415299054256, -8721.945802998263}, {
       600.0829521210504, -8721.945802998263}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451613773115}, {
       1329.754784565061, -8722.451613773115}, {
       1329.754784565061, -8721.945802998263}, {
       1324.7735029625924`, -8721.945802998263}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451613773115}, {
       1601.2816681947959`, -8722.451613773115}, {
       1601.2816681947959`, -8721.945802998263}, {
       1601.2816681867425`, -8721.945802998263}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8823300121226`, -8722.451613773115}, {
       2584.883877349371, -8722.451613773115}, {
       2584.883877349371, -8721.945802998263}, {
       2584.8823300121226`, -8721.945802998263}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8722.451613773115}, {
       3136.054810878645, -8722.451613773115}, {
       3136.054810878645, -8721.945802998263}, {
       3136.054810877378, -8721.945802998263}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451613773115}, {
       3697.5935470304903`, -8722.451613773115}, {
       3697.5935470304903`, -8721.945802998263}, {
       3071.5358367872, -8721.945802998263}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451613773115}, {
       4142.649334928727, -8722.451613773115}, {
       4142.649334928727, -8721.945802998263}, {
       4139.6636291537, -8721.945802998263}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.451613773115}, {
       4699.999999999999, -8722.451613773115}, {
       4699.999999999999, -8721.945802998263}, {
       4699.999999999998, -8721.945802998263}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.653705232352, -8722.451613773115}, {
      2635.815919192536, -8722.451613773115}, {
      2635.815919192536, -8721.945802998263}, {
      2619.653705232352, -8721.945802998263}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.754784565061, -8722.072255691977}, \
{1330.007689952487, -8721.945802998263}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1330.007689952487, -8722.072255691977}, 0.252905387425832, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1330.007689952487, -8722.325161079403}, {
       2619.400799844926, -8722.325161079403}, {
       2619.400799844926, -8722.072255691977}, {
       1330.007689952487, -8722.072255691977}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.400799844926, -8722.325161079403}, 0.252905387425832, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.400799844926, -8722.451613773115}, \
{2619.653705232352, -8722.325161079403}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.451613773115}, {
        100.0000579006586, -8722.451613773115}, {
        100.0000579006586, -8722.451613773115}, {
        100, -8722.451613773115}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451613773115}, {
       949.6415299054256, -8722.451613773115}, {
       949.6415299054256, -8722.451613773115}, {
       600.0829521210504, -8722.451613773115}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451613773115}, {
       1329.754784565061, -8722.451613773115}, {
       1329.754784565061, -8722.451613773115}, {
       1324.7735029625924`, -8722.451613773115}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451613773115}, {
       1601.2816681947959`, -8722.451613773115}, {
       1601.2816681947959`, -8722.451613773115}, {
       1601.2816681867425`, -8722.451613773115}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451613773115}, {
       2635.815919192536, -8722.451613773115}, {
       2635.815919192536, -8722.451613773115}, {
       2619.400799844926, -8722.451613773115}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810877378, -8722.451613773115}, {
       3136.054810878645, -8722.451613773115}, {
       3136.054810878645, -8722.451613773115}, {
       3136.054810877378, -8722.451613773115}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451613773115}, {
       3697.5935470304903`, -8722.451613773115}, {
       3697.5935470304903`, -8722.451613773115}, {
       3071.5358367872, -8722.451613773115}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451613773115}, {
       4142.649334928727, -8722.451613773115}, {
       4142.649334928727, -8722.451613773115}, {
       4139.6636291537, -8722.451613773115}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.451613773115}, {
       4699.999999999999, -8722.451613773115}, {
       4699.999999999999, -8722.451613773115}, {
       4699.999999999998, -8722.451613773115}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8823300121226`, -8722.451613773115}, {
      2584.883877349371, -8722.451613773115}, {
      2584.883877349371, -8722.451613773115}, {
      2584.8823300121226`, -8722.451613773115}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8722.451613773115}, \
{4699.999999999998, -8722.451613773115}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8722.451613773115}, 
       1.6775369544235507`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883877349371, -8722.451613773115}, {
       4699.999999999998, -8722.451613773115}, {
       4699.999999999998, -8722.451613773115}, {
       2584.883877349371, -8722.451613773115}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883877349371, -8722.451613773115}, 
       1.6775369544235507`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883877349371, -8722.451613773115}, \
{2584.883877349371, -8722.451613773115}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.4516137752}, {
        100.0000579006586, -8722.4516137752}, {
        100.0000579006586, -8722.451613773115}, {
        100, -8722.451613773115}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.4516137752}, {
       949.6415299054256, -8722.4516137752}, {
       949.6415299054256, -8722.451613773115}, {
       600.0829521210504, -8722.451613773115}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.4516137752}, {
       1329.754784565061, -8722.4516137752}, {
       1329.754784565061, -8722.451613773115}, {
       1324.7735029625924`, -8722.451613773115}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.4516137752}, {
       1601.2816681937531`, -8722.4516137752}, {
       1601.2816681937531`, -8722.451613773115}, {
       1601.2816681867425`, -8722.451613773115}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.4516137752}, {
       2635.815919192536, -8722.4516137752}, {
       2635.815919192536, -8722.451613773115}, {
       2619.400799844926, -8722.451613773115}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8823300121226`, -8722.4516137752}, {
       2584.883877349371, -8722.4516137752}, {
       2584.883877349371, -8722.451613773115}, {
       2584.8823300121226`, -8722.451613773115}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.4516137752}, {
       3697.5935470304903`, -8722.4516137752}, {
       3697.5935470304903`, -8722.451613773115}, {
       3071.5358367872, -8722.451613773115}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.4516137752}, {
       4142.649334928727, -8722.4516137752}, {
       4142.649334928727, -8722.451613773115}, {
       4139.6636291537, -8722.451613773115}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.4516137752}, {
       4699.999999999999, -8722.4516137752}, {
       4699.999999999999, -8722.451613773115}, {
       4699.999999999998, -8722.451613773115}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810877378, -8722.4516137752}, {
      3136.0548108786447`, -8722.4516137752}, {
      3136.0548108786447`, -8722.451613773115}, {
      3136.054810877378, -8722.451613773115}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681937531`, -8722.451613773635}, \
{1601.2816681947959`, -8722.451613773115}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681947959`, -8722.451613773635}, 
       1.0426057051270911`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681947959`, -8722.451613774678}, {
       3136.054810876335, -8722.451613774678}, {
       3136.054810876335, -8722.451613773635}, {
       1601.2816681947959`, -8722.451613773635}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810876335, -8722.451613774678}, 
       1.0426057051270911`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810876335, -8722.4516137752}, \
{3136.054810877378, -8722.451613774678}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.451613775202}, {
        100.0000579006586, -8722.451613775202}, {
        100.0000579006586, -8722.4516137752}, {100, -8722.4516137752}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451613775202}, {
       949.6415299054256, -8722.451613775202}, {
       949.6415299054256, -8722.4516137752}, {
       600.0829521210504, -8722.4516137752}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451613775202}, {
       1329.754784565061, -8722.451613775202}, {
       1329.754784565061, -8722.4516137752}, {
       1324.7735029625924`, -8722.4516137752}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451613775202}, {
       1601.2816681937531`, -8722.451613775202}, {
       1601.2816681937531`, -8722.4516137752}, {
       1601.2816681867425`, -8722.4516137752}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451613775202}, {
       2635.815919192536, -8722.451613775202}, {
       2635.815919192536, -8722.4516137752}, {
       2619.400799844926, -8722.4516137752}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8823300121226`, -8722.451613775202}, {
       2584.883877349371, -8722.451613775202}, {
       2584.883877349371, -8722.4516137752}, {
       2584.8823300121226`, -8722.4516137752}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810876335, -8722.451613775202}, {
       3136.0548108786443`, -8722.451613775202}, {
       3136.0548108786443`, -8722.4516137752}, {
       3136.054810876335, -8722.4516137752}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451613775202}, {
       3697.5935470304903`, -8722.451613775202}, {
       3697.5935470304903`, -8722.4516137752}, {
       3071.5358367872, -8722.4516137752}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451613775202}, {
       4142.649334928727, -8722.451613775202}, {
       4142.649334928727, -8722.4516137752}, {
       4139.6636291537, -8722.4516137752}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -8722.451613775202}, {
      4699.999999999999, -8722.451613775202}, {
      4699.999999999999, -8722.4516137752}, {
      4699.999999999998, -8722.4516137752}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108786443`, -8722.451613775202}, 
       {3136.0548108786447`, -8722.4516137752}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108786447`, -8722.451613775202}, 
       4.602234775196546*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108786447`, -8722.451613775202}, {
       4699.999999999997, -8722.451613775202}, {
       4699.999999999997, -8722.451613775202}, {
       3136.0548108786447`, -8722.451613775202}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999997, -8722.451613775202}, 
       4.602234775196546*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999997, -8722.451613775202}, \
{4699.999999999998, -8722.451613775202}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.451613778943}, {
        100.0000579006586, -8722.451613778943}, {
        100.0000579006586, -8722.451613775202}, {
        100, -8722.451613775202}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451613778943}, {
       949.6415299054256, -8722.451613778943}, {
       949.6415299054256, -8722.451613775202}, {
       600.0829521210504, -8722.451613775202}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451613778943}, {
       1329.754784565061, -8722.451613778943}, {
       1329.754784565061, -8722.451613775202}, {
       1324.7735029625924`, -8722.451613775202}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451613778943}, {
       1601.2816681918825`, -8722.451613778943}, {
       1601.2816681918825`, -8722.451613775202}, {
       1601.2816681867425`, -8722.451613775202}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451613778943}, {
       2635.815919192536, -8722.451613778943}, {
       2635.815919192536, -8722.451613775202}, {
       2619.400799844926, -8722.451613775202}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8823300121226`, -8722.451613778943}, {
       2584.883877349371, -8722.451613778943}, {
       2584.883877349371, -8722.451613775202}, {
       2584.8823300121226`, -8722.451613775202}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451613778943}, {
       3697.5935470304903`, -8722.451613778943}, {
       3697.5935470304903`, -8722.451613775202}, {
       3071.5358367872, -8722.451613775202}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451613778943}, {
       4142.649334928727, -8722.451613778943}, {
       4142.649334928727, -8722.451613775202}, {
       4139.6636291537, -8722.451613775202}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.451613778943}, {
       4699.999999999999, -8722.451613778943}, {
       4699.999999999999, -8722.451613775202}, {
       4699.999999999997, -8722.451613775202}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810876335, -8722.451613778943}, {
      3136.0548108786443`, -8722.451613778943}, {
      3136.0548108786443`, -8722.451613775202}, {
      3136.054810876335, -8722.451613775202}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681918825`, -8722.451613776137}, \
{1601.2816681937531`, -8722.451613775202}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681937531`, -8722.451613776137}, 
       1.870730181386993*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681937531`, -8722.451613778008}, {
       3136.0548108744642`, -8722.451613778008}, {
       3136.0548108744642`, -8722.451613776137}, {
       1601.2816681937531`, -8722.451613776137}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108744642`, -8722.451613778008}, 
       1.870730181386993*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108744642`, -8722.451613778943}, \
{3136.054810876335, -8722.451613778008}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451632519871}, {
       949.6415299054256, -8722.451632519871}, {
       949.6415299054256, -8722.451613778943}, {
       600.0829521210504, -8722.451613778943}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451632519871}, {
       1329.754784565061, -8722.451632519871}, {
       1329.754784565061, -8722.451613778943}, {
       1324.7735029625924`, -8722.451613778943}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451632519871}, {
       1601.2816681918825`, -8722.451632519871}, {
       1601.2816681918825`, -8722.451613778943}, {
       1601.2816681867425`, -8722.451613778943}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451632519871}, {
       2635.815919192536, -8722.451632519871}, {
       2635.815919192536, -8722.451613778943}, {
       2619.400799844926, -8722.451613778943}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882339382586, -8722.451632519871}, {
       2584.883877349371, -8722.451632519871}, {
       2584.883877349371, -8722.451613778943}, {
       2584.882339382586, -8722.451613778943}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.451632519871}, {
       3136.0548108786443`, -8722.451632519871}, {
       3136.0548108786443`, -8722.451613778943}, {
       3136.0548108744642`, -8722.451613778943}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451632519871}, {
       3697.5935470304903`, -8722.451632519871}, {
       3697.5935470304903`, -8722.451613778943}, {
       3071.5358367872, -8722.451613778943}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451632519871}, {
       4142.649334928727, -8722.451632519871}, {
       4142.649334928727, -8722.451613778943}, {
       4139.6636291537, -8722.451613778943}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.451632519871}, {
       4699.999999999999, -8722.451632519871}, {
       4699.999999999999, -8722.451613778943}, {
       4699.999999999997, -8722.451613778943}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.451632519871}, {
       100.0000579006586, -8722.451632519871}, {
       100.0000579006586, -8722.451613778943}, {
       100, -8722.451613778943}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8823300121226`, -8722.451618464176}, \
{2584.882339382586, -8722.451613778943}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8823300121226`, -8722.451618464176}, 
       9.370463483386328*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006727112208`, -8722.45162783464}, {
       2584.8823300121226`, -8722.45162783464}, {
       2584.8823300121226`, -8722.451618464176}, {
       100.00006727112208`, -8722.451618464176}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006727112208`, -8722.45162783464}, 9.370463483386328*^-6,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000579006586, -8722.451632519871}, \
{100.00006727112208`, -8722.45162783464}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451632519871}, {
       949.6415299054256, -8722.451632519871}, {
       949.6415299054256, -8722.451632519871}, {
       600.0829521210504, -8722.451632519871}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451632519871}, {
       1329.754784565061, -8722.451632519871}, {
       1329.754784565061, -8722.451632519871}, {
       1324.7735029625924`, -8722.451632519871}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451632519871}, {
       1601.2816681918825`, -8722.451632519871}, {
       1601.2816681918825`, -8722.451632519871}, {
       1601.2816681867425`, -8722.451632519871}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451632519871}, {
       2635.815919192536, -8722.451632519871}, {
       2635.815919192536, -8722.451632519871}, {
       2619.400799844926, -8722.451632519871}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882339382586, -8722.451632519871}, {
       2584.883877349371, -8722.451632519871}, {
       2584.883877349371, -8722.451632519871}, {
       2584.882339382586, -8722.451632519871}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.451632519871}, {
       3136.0548108786443`, -8722.451632519871}, {
       3136.0548108786443`, -8722.451632519871}, {
       3136.0548108744642`, -8722.451632519871}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451632519871}, {
       3697.5935470304903`, -8722.451632519871}, {
       3697.5935470304903`, -8722.451632519871}, {
       3071.5358367872, -8722.451632519871}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.6636291537, -8722.451632519871}, {
       4142.649334928727, -8722.451632519871}, {
       4142.649334928727, -8722.451632519871}, {
       4139.6636291537, -8722.451632519871}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.451632519871}, {
       4699.999999999998, -8722.451632519871}, {
       4699.999999999998, -8722.451632519871}, {
       4699.999999999997, -8722.451632519871}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.451632519871}, {
       100.00006727112208`, -8722.451632519871}, {
       100.00006727112208`, -8722.451632519871}, {
       100, -8722.451632519871}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999997, -8722.451632519871}, \
{4699.999999999997, -8722.451632519871}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999997, -8722.451632519871}, 
       1.9581481821246155`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006727112228`, -8722.451632519871}, {
       4699.999999999997, -8722.451632519871}, {
       4699.999999999997, -8722.451632519871}, {
       100.00006727112228`, -8722.451632519871}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006727112228`, -8722.451632519871}, 
       1.9581481821246155`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00006727112208`, -8722.451632519871}, \
{100.00006727112228`, -8722.451632519871}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.451632524526}, {
        100.00006727112228`, -8722.451632524526}, {
        100.00006727112228`, -8722.451632519871}, {
        100, -8722.451632519871}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.451632524526}, {
       949.6415299054256, -8722.451632524526}, {
       949.6415299054256, -8722.451632519871}, {
       600.0829521210504, -8722.451632519871}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.451632524526}, {
       1329.754784565061, -8722.451632524526}, {
       1329.754784565061, -8722.451632519871}, {
       1324.7735029625924`, -8722.451632519871}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.451632524526}, {
       1601.2816681918825`, -8722.451632524526}, {
       1601.2816681918825`, -8722.451632519871}, {
       1601.2816681867425`, -8722.451632519871}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.451632524526}, {
       2635.815919192536, -8722.451632524526}, {
       2635.815919192536, -8722.451632519871}, {
       2619.400799844926, -8722.451632519871}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.882339382586, -8722.451632524526}, {
       2584.883877349371, -8722.451632524526}, {
       2584.883877349371, -8722.451632519871}, {
       2584.882339382586, -8722.451632519871}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.451632524526}, {
       3136.054810876317, -8722.451632524526}, {
       3136.054810876317, -8722.451632519871}, {
       3136.0548108744642`, -8722.451632519871}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.451632524526}, {
       3697.5935470304903`, -8722.451632524526}, {
       3697.5935470304903`, -8722.451632519871}, {
       3071.5358367872, -8722.451632519871}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.451632524526}, {
       4699.999999999998, -8722.451632524526}, {
       4699.999999999998, -8722.451632519871}, {
       4699.999999999997, -8722.451632519871}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.6636291537, -8722.451632524526}, {
      4142.649334928727, -8722.451632524526}, {
      4142.649334928727, -8722.451632519871}, {
      4139.6636291537, -8722.451632519871}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810876317, -8722.451632521035}, \
{3136.0548108786443`, -8722.451632519871}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108786443`, -8722.451632521035}, 
       2.3273048300450638`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108786443`, -8722.451632523362}, {
       4139.663629151372, -8722.451632523362}, {
       4139.663629151372, -8722.451632521035}, {
       3136.0548108786443`, -8722.451632521035}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.663629151372, -8722.451632523362}, 
       2.3273048300450638`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.663629151372, -8722.451632524526}, \
{4139.6636291537, -8722.451632523362}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452561062186}, {
        100.00006727112228`, -8722.452561062186}, {
        100.00006727112228`, -8722.451632524526}, {
        100, -8722.451632524526}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452561062186}, {
       949.6410656365955, -8722.452561062186}, {
       949.6410656365955, -8722.451632524526}, {
       600.0829521210504, -8722.451632524526}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452561062186}, {
       1329.754784565061, -8722.452561062186}, {
       1329.754784565061, -8722.451632524526}, {
       1324.7735029625924`, -8722.451632524526}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452561062186}, {
       1601.2816681918825`, -8722.452561062186}, {
       1601.2816681918825`, -8722.451632524526}, {
       1601.2816681867425`, -8722.451632524526}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.452561062186}, {
       2635.815919192536, -8722.452561062186}, {
       2635.815919192536, -8722.451632524526}, {
       2619.400799844926, -8722.451632524526}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.452561062186}, {
       3136.054810876317, -8722.452561062186}, {
       3136.054810876317, -8722.451632524526}, {
       3136.0548108744642`, -8722.451632524526}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452561062186}, {
       3697.5935470304903`, -8722.452561062186}, {
       3697.5935470304903`, -8722.451632524526}, {
       3071.5358367872, -8722.451632524526}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452561062186}, {
       4142.649334928727, -8722.452561062186}, {
       4142.649334928727, -8722.451632524526}, {
       4139.663629151372, -8722.451632524526}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.452561062186}, {
       4699.999999999998, -8722.452561062186}, {
       4699.999999999998, -8722.451632524526}, {
       4699.999999999997, -8722.451632524526}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.882339382586, -8722.452561062186}, {
      2584.883877349371, -8722.452561062186}, {
      2584.883877349371, -8722.451632524526}, {
      2584.882339382586, -8722.451632524526}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{949.6410656365955, -8722.45186465894}, \
{949.6415299054256, -8722.451632524526}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{949.6415299054256, -8722.45186465894}, 0.00046426883007315745`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{949.6415299054256, -8722.452328927771}, {
       2584.881875113756, -8722.452328927771}, {
       2584.881875113756, -8722.45186465894}, {
       949.6415299054256, -8722.45186465894}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881875113756, -8722.452328927771}, 
       0.00046426883007315745`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881875113756, -8722.452561062186}, \
{2584.882339382586, -8722.452328927771}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452656952386}, {
       949.6410656365955, -8722.452656952386}, {
       949.6410656365955, -8722.452561062186}, {
       600.0829521210504, -8722.452561062186}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452656952386}, {
       1329.754784565061, -8722.452656952386}, {
       1329.754784565061, -8722.452561062186}, {
       1324.7735029625924`, -8722.452561062186}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452656952386}, {
       1601.2816681918825`, -8722.452656952386}, {
       1601.2816681918825`, -8722.452561062186}, {
       1601.2816681867425`, -8722.452561062186}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844926, -8722.452656952386}, {
       2635.815919192536, -8722.452656952386}, {
       2635.815919192536, -8722.452561062186}, {
       2619.400799844926, -8722.452561062186}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452656952386}, {
       2584.8838773493712`, -8722.452656952386}, {
       2584.8838773493712`, -8722.452561062186}, {
       2584.881923058856, -8722.452561062186}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.452656952386}, {
       3136.054810876317, -8722.452656952386}, {
       3136.054810876317, -8722.452561062186}, {
       3136.0548108744642`, -8722.452561062186}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452656952386}, {
       3697.5935470304903`, -8722.452656952386}, {
       3697.5935470304903`, -8722.452561062186}, {
       3071.5358367872, -8722.452561062186}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452656952386}, {
       4142.649334928727, -8722.452656952386}, {
       4142.649334928727, -8722.452561062186}, {
       4139.663629151372, -8722.452561062186}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.452656952386}, {
       4699.999999999998, -8722.452656952386}, {
       4699.999999999998, -8722.452561062186}, {
       4699.999999999997, -8722.452561062186}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.452656952386}, {
       100.00006727112228`, -8722.452656952386}, {
       100.00006727112228`, -8722.452561062186}, {
       100, -8722.452561062186}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881875113756, -8722.452585034736}, \
{2584.881923058856, -8722.452561062186}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881875113756, -8722.452585034736}, 0.00004794509983513131,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00011521622211`, -8722.452632979835}, {
       2584.881875113756, -8722.452632979835}, {
       2584.881875113756, -8722.452585034736}, {
       100.00011521622211`, -8722.452585034736}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00011521622211`, -8722.452632979835}, 
       0.00004794509983513131, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00006727112228`, -8722.452656952386}, \
{100.00011521622211`, -8722.452632979835}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.45265695344}, {
        100.00011521622211`, -8722.45265695344}, {
        100.00011521622211`, -8722.452656952386}, {
        100, -8722.452656952386}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.45265695344}, {
       949.6410656365955, -8722.45265695344}, {
       949.6410656365955, -8722.452656952386}, {
       600.0829521210504, -8722.452656952386}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.45265695344}, {
       1329.754784565061, -8722.45265695344}, {
       1329.754784565061, -8722.452656952386}, {
       1324.7735029625924`, -8722.452656952386}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.45265695344}, {
       1601.2816681913557`, -8722.45265695344}, {
       1601.2816681913557`, -8722.452656952386}, {
       1601.2816681867425`, -8722.452656952386}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.45265695344}, {
       2584.8838773493712`, -8722.45265695344}, {
       2584.8838773493712`, -8722.452656952386}, {
       2584.881923058856, -8722.452656952386}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.45265695344}, {
       3136.054810876317, -8722.45265695344}, {
       3136.054810876317, -8722.452656952386}, {
       3136.0548108744642`, -8722.452656952386}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.45265695344}, {
       3697.5935470304903`, -8722.45265695344}, {
       3697.5935470304903`, -8722.452656952386}, {
       3071.5358367872, -8722.452656952386}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.45265695344}, {
       4142.649334928727, -8722.45265695344}, {
       4142.649334928727, -8722.452656952386}, {
       4139.663629151372, -8722.452656952386}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999997, -8722.45265695344}, {
       4699.999999999998, -8722.45265695344}, {
       4699.999999999998, -8722.452656952386}, {
       4699.999999999997, -8722.452656952386}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.400799844926, -8722.45265695344}, {
      2635.815919192536, -8722.45265695344}, {
      2635.815919192536, -8722.452656952386}, {
      2619.400799844926, -8722.452656952386}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681913557`, -8722.45265695265}, \
{1601.2816681918825`, -8722.452656952386}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681918825`, -8722.45265695265}, 
       5.268098742103202*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681918825`, -8722.452656953175}, {
       2619.4007998443994`, -8722.452656953175}, {
       2619.4007998443994`, -8722.45265695265}, {
       1601.2816681918825`, -8722.45265695265}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.4007998443994`, -8722.452656953175}, 
       5.268098742103202*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.4007998443994`, -8722.45265695344}, \
{2619.400799844926, -8722.452656953175}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452656953441}, {
       949.6410656365955, -8722.452656953441}, {
       949.6410656365955, -8722.45265695344}, {
       600.0829521210504, -8722.45265695344}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452656953441}, {
       1329.754784565061, -8722.452656953441}, {
       1329.754784565061, -8722.45265695344}, {
       1324.7735029625924`, -8722.45265695344}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452656953441}, {
       1601.2816681913557`, -8722.452656953441}, {
       1601.2816681913557`, -8722.45265695344}, {
       1601.2816681867425`, -8722.45265695344}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.4007998443994`, -8722.452656953441}, {
       2635.815919192536, -8722.452656953441}, {
       2635.815919192536, -8722.45265695344}, {
       2619.4007998443994`, -8722.45265695344}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452656953441}, {
       2584.8838773493712`, -8722.452656953441}, {
       2584.8838773493712`, -8722.45265695344}, {
       2584.881923058856, -8722.45265695344}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.452656953441}, {
       3136.054810876317, -8722.452656953441}, {
       3136.054810876317, -8722.45265695344}, {
       3136.0548108744642`, -8722.45265695344}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452656953441}, {
       3697.5935470304903`, -8722.452656953441}, {
       3697.5935470304903`, -8722.45265695344}, {
       3071.5358367872, -8722.45265695344}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452656953441}, {
       4142.649334928727, -8722.452656953441}, {
       4142.649334928727, -8722.45265695344}, {
       4139.663629151372, -8722.45265695344}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452656953441}, {
       4699.999999999999, -8722.452656953441}, {
       4699.999999999999, -8722.45265695344}, {
       4699.999999999998, -8722.45265695344}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.452656953441}, {
       100.00011521622211`, -8722.452656953441}, {
       100.00011521622211`, -8722.45265695344}, {
       100, -8722.45265695344}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999997, -8722.45265695344}, \
{4699.999999999998, -8722.45265695344}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999997, -8722.45265695344}, 7.334991984143127*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00011521622284`, -8722.452656953441}, {
       4699.999999999997, -8722.452656953441}, {
       4699.999999999997, -8722.45265695344}, {
       100.00011521622284`, -8722.45265695344}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00011521622284`, -8722.452656953441}, 
       7.334991984143127*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00011521622211`, -8722.452656953441}, \
{100.00011521622284`, -8722.452656953441}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.45265695461}, {
        100.00011521622284`, -8722.45265695461}, {
        100.00011521622284`, -8722.452656953441}, {
        100, -8722.452656953441}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.45265695461}, {
       949.6410656365955, -8722.45265695461}, {
       949.6410656365955, -8722.452656953441}, {
       600.0829521210504, -8722.452656953441}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.45265695461}, {
       1329.754784565061, -8722.45265695461}, {
       1329.754784565061, -8722.452656953441}, {
       1324.7735029625924`, -8722.452656953441}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844984, -8722.45265695461}, {
       2635.815919192536, -8722.45265695461}, {
       2635.815919192536, -8722.452656953441}, {
       2619.400799844984, -8722.452656953441}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.45265695461}, {
       2584.8838773493712`, -8722.45265695461}, {
       2584.8838773493712`, -8722.452656953441}, {
       2584.881923058856, -8722.452656953441}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108744642`, -8722.45265695461}, {
       3136.054810876317, -8722.45265695461}, {
       3136.054810876317, -8722.452656953441}, {
       3136.0548108744642`, -8722.452656953441}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.45265695461}, {
       3697.5935470304903`, -8722.45265695461}, {
       3697.5935470304903`, -8722.452656953441}, {
       3071.5358367872, -8722.452656953441}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.45265695461}, {
       4142.649334928727, -8722.45265695461}, {
       4142.649334928727, -8722.452656953441}, {
       4139.663629151372, -8722.452656953441}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.45265695461}, {
       4699.999999999999, -8722.45265695461}, {
       4699.999999999999, -8722.452656953441}, {
       4699.999999999998, -8722.452656953441}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681867425`, -8722.45265695461}, {
      1601.2816681913557`, -8722.45265695461}, {
      1601.2816681913557`, -8722.452656953441}, {
      1601.2816681867425`, -8722.452656953441}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.4007998443994`, -8722.452656953734}, \
{2619.400799844984, -8722.452656953441}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.4007998443994`, -8722.452656953734}, 
       5.843634385095494*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.28166819194, -8722.452656954318}, {
       2619.4007998443994`, -8722.452656954318}, {
       2619.4007998443994`, -8722.452656953734}, {
       1601.28166819194, -8722.452656953734}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.28166819194, -8722.452656954318}, 5.843634385095494*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681913557`, -8722.45265695461}, \
{1601.28166819194, -8722.452656954318}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452656956046}, {
       949.6410656365955, -8722.452656956046}, {
       949.6410656365955, -8722.45265695461}, {
       600.0829521210504, -8722.45265695461}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452656956046}, {
       1329.754784565061, -8722.452656956046}, {
       1329.754784565061, -8722.45265695461}, {
       1324.7735029625924`, -8722.45265695461}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452656956046}, {
       1601.28166819194, -8722.452656956046}, {
       1601.28166819194, -8722.45265695461}, {
       1601.2816681867425`, -8722.45265695461}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400799844984, -8722.452656956046}, {
       2635.815919192536, -8722.452656956046}, {
       2635.815919192536, -8722.45265695461}, {
       2619.400799844984, -8722.45265695461}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452656956046}, {
       2584.8838773493712`, -8722.452656956046}, {
       2584.8838773493712`, -8722.45265695461}, {
       2584.881923058856, -8722.45265695461}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452656956046}, {
       3136.054810876317, -8722.452656956046}, {
       3136.054810876317, -8722.45265695461}, {
       3136.054810875182, -8722.45265695461}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452656956046}, {
       3697.5935470304903`, -8722.452656956046}, {
       3697.5935470304903`, -8722.45265695461}, {
       3071.5358367872, -8722.45265695461}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452656956046}, {
       4142.649334928727, -8722.452656956046}, {
       4142.649334928727, -8722.45265695461}, {
       4139.663629151372, -8722.45265695461}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452656956046}, {
       4699.999999999999, -8722.452656956046}, {
       4699.999999999999, -8722.45265695461}, {
       4699.999999999998, -8722.45265695461}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.452656956046}, {
       100.00011521622284`, -8722.452656956046}, {
       100.00011521622284`, -8722.45265695461}, {
       100, -8722.45265695461}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108744642`, -8722.452656954969}, \
{3136.054810875182, -8722.45265695461}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108744642`, -8722.452656954969}, 
       7.177866947810198*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00011521694063`, -8722.452656955687}, {
       3136.0548108744642`, -8722.452656955687}, {
       3136.0548108744642`, -8722.452656954969}, {
       100.00011521694063`, -8722.452656954969}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00011521694063`, -8722.452656955687}, 
       7.177866947810198*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00011521622284`, -8722.452656956046}, \
{100.00011521694063`, -8722.452656955687}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752441563}, {
       949.6410656365955, -8722.452752441563}, {
       949.6410656365955, -8722.452656956046}, {
       600.0829521210504, -8722.452656956046}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452752441563}, {
       1329.754784565061, -8722.452752441563}, {
       1329.754784565061, -8722.452656956046}, {
       1324.7735029625924`, -8722.452656956046}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452752441563}, {
       1601.28166819194, -8722.452752441563}, {
       1601.28166819194, -8722.452656956046}, {
       1601.2816681867425`, -8722.452656956046}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752441563}, {
       2635.815919192536, -8722.452752441563}, {
       2635.815919192536, -8722.452656956046}, {
       2619.400847587742, -8722.452656956046}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452752441563}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.8838773493712`, -8722.452656956046}, {
       2584.881923058856, -8722.452656956046}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452752441563}, {
       3136.054810876317, -8722.452752441563}, {
       3136.054810876317, -8722.452656956046}, {
       3136.054810875182, -8722.452656956046}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752441563}, {
       3697.5935470304903`, -8722.452752441563}, {
       3697.5935470304903`, -8722.452656956046}, {
       3071.5358367872, -8722.452656956046}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452752441563}, {
       4142.649334928727, -8722.452752441563}, {
       4142.649334928727, -8722.452656956046}, {
       4139.663629151372, -8722.452656956046}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752441563}, {
       4699.999999999999, -8722.452752441563}, {
       4699.999999999999, -8722.452656956046}, {
       4699.999999999998, -8722.452656956046}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.452752441563}, {
       100.00011521694063`, -8722.452752441563}, {
       100.00011521694063`, -8722.452656956046}, {
       100, -8722.452656956046}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.400799844984, -8722.452680827424}, \
{2619.400847587742, -8722.452656956046}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.400799844984, -8722.452680827424}, 0.00004774275839740043,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00016295969903`, -8722.452728570182}, {
       2619.400799844984, -8722.452728570182}, {
       2619.400799844984, -8722.452680827424}, {
       100.00016295969903`, -8722.452680827424}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00016295969903`, -8722.452728570182}, 
       0.00004774275839740043, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00011521694063`, -8722.452752441563}, \
{100.00016295969903`, -8722.452728570182}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452752441563}, {
        100.00016295969903`, -8722.452752441563}, {
        100.00016295969903`, -8722.452752441563}, {
        100, -8722.452752441563}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752441563}, {
       949.6410656365955, -8722.452752441563}, {
       949.6410656365955, -8722.452752441563}, {
       600.0829521210504, -8722.452752441563}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452752441563}, {
       1329.754784565061, -8722.452752441563}, {
       1329.754784565061, -8722.452752441563}, {
       1324.7735029625924`, -8722.452752441563}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452752441563}, {
       1601.28166819194, -8722.452752441563}, {
       1601.28166819194, -8722.452752441563}, {
       1601.2816681867425`, -8722.452752441563}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752441563}, {
       2635.815919192536, -8722.452752441563}, {
       2635.815919192536, -8722.452752441563}, {
       2619.400847587742, -8722.452752441563}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452752441563}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.881923058856, -8722.452752441563}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452752441563}, {
       3136.054810876317, -8722.452752441563}, {
       3136.054810876317, -8722.452752441563}, {
       3136.054810875182, -8722.452752441563}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752441563}, {
       3697.5935470304903`, -8722.452752441563}, {
       3697.5935470304903`, -8722.452752441563}, {
       3071.5358367872, -8722.452752441563}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752441563}, {
       4699.999999999999, -8722.452752441563}, {
       4699.999999999999, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.663629151372, -8722.452752441563}, {
      4142.649334928727, -8722.452752441563}, {
      4142.649334928727, -8722.452752441563}, {
      4139.663629151372, -8722.452752441563}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8722.452752441563}, \
{4699.999999999998, -8722.452752441563}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8722.452752441563}, 
       2.9173892157774046`*^-14, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928727, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       4142.649334928727, -8722.452752441563}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928727, -8722.452752441563}, 
       2.9173892157774046`*^-14, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928727, -8722.452752441563}, \
{4142.649334928727, -8722.452752441563}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452752441563}, {
        100.00016295969903`, -8722.452752441563}, {
        100.00016295969903`, -8722.452752441563}, {
        100, -8722.452752441563}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752441563}, {
       949.6410656365955, -8722.452752441563}, {
       949.6410656365955, -8722.452752441563}, {
       600.0829521210504, -8722.452752441563}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452752441563}, {
       1329.754784565061, -8722.452752441563}, {
       1329.754784565061, -8722.452752441563}, {
       1324.7735029625924`, -8722.452752441563}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681867425`, -8722.452752441563}, {
       1601.28166819194, -8722.452752441563}, {
       1601.28166819194, -8722.452752441563}, {
       1601.2816681867425`, -8722.452752441563}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752441563}, {
       2635.815919192536, -8722.452752441563}, {
       2635.815919192536, -8722.452752441563}, {
       2619.400847587742, -8722.452752441563}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452752441563}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.881923058856, -8722.452752441563}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752441563}, {
       3697.5935470304903`, -8722.452752441563}, {
       3697.5935470304903`, -8722.452752441563}, {
       3071.5358367872, -8722.452752441563}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452752441563}, {
       4142.649334928727, -8722.452752441563}, {
       4142.649334928727, -8722.452752441563}, {
       4139.663629151372, -8722.452752441563}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810875182, -8722.452752441563}, {
      3136.054810876317, -8722.452752441563}, {
      3136.054810876317, -8722.452752441563}, {
      3136.054810875182, -8722.452752441563}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8722.452752441563}, \
{4699.999999999998, -8722.452752441563}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8722.452752441563}, 3.478520627074364*^-13,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108763173`, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}, {
       3136.0548108763173`, -8722.452752441563}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108763173`, -8722.452752441563}, 
       3.478520627074364*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810876317, -8722.452752441563}, \
{3136.0548108763173`, -8722.452752441563}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452752444595}, {
        100.00016295969903`, -8722.452752444595}, {
        100.00016295969903`, -8722.452752441563}, {
        100, -8722.452752441563}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752444595}, {
       949.6410656365955, -8722.452752444595}, {
       949.6410656365955, -8722.452752441563}, {
       600.0829521210504, -8722.452752441563}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.452752444595}, {
       1601.28166819194, -8722.452752444595}, {
       1601.28166819194, -8722.452752441563}, {
       1601.2816681882591`, -8722.452752441563}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752444595}, {
       2635.815919192536, -8722.452752444595}, {
       2635.815919192536, -8722.452752441563}, {
       2619.400847587742, -8722.452752441563}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923058856, -8722.452752444595}, {
       2584.8838773493712`, -8722.452752444595}, {
       2584.8838773493712`, -8722.452752441563}, {
       2584.881923058856, -8722.452752441563}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452752444595}, {
       3136.0548108763173`, -8722.452752444595}, {
       3136.0548108763173`, -8722.452752441563}, {
       3136.054810875182, -8722.452752441563}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752444595}, {
       3697.5935470304903`, -8722.452752444595}, {
       3697.5935470304903`, -8722.452752441563}, {
       3071.5358367872, -8722.452752441563}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452752444595}, {
       4142.649334928727, -8722.452752444595}, {
       4142.649334928727, -8722.452752441563}, {
       4139.663629151372, -8722.452752441563}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752444595}, {
       4699.999999999998, -8722.452752444595}, {
       4699.999999999998, -8722.452752441563}, {
       4699.999999999998, -8722.452752441563}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7735029625924`, -8722.452752444595}, {
      1329.754784565061, -8722.452752444595}, {
      1329.754784565061, -8722.452752441563}, {
      1324.7735029625924`, -8722.452752441563}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681867425`, -8722.45275244232}, \
{1601.2816681882591`, -8722.452752441563}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681867425`, -8722.45275244232}, 1.516528204295767*^-9,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1329.7547845665777`, -8722.452752443836}, {
       1601.2816681867425`, -8722.452752443836}, {
       1601.2816681867425`, -8722.45275244232}, {
       1329.7547845665777`, -8722.45275244232}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1329.7547845665777`, -8722.452752443836}, 
       1.516528204295767*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.754784565061, -8722.452752444595}, \
{1329.7547845665777`, -8722.452752443836}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452752449417}, {
        100.00016295969903`, -8722.452752449417}, {
        100.00016295969903`, -8722.452752444595}, {
        100, -8722.452752444595}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752449417}, {
       949.6410656365955, -8722.452752449417}, {
       949.6410656365955, -8722.452752444595}, {
       600.0829521210504, -8722.452752444595}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452752449417}, {
       1329.7547845665777`, -8722.452752449417}, {
       1329.7547845665777`, -8722.452752444595}, {
       1324.7735029625924`, -8722.452752444595}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752449417}, {
       2635.815919192536, -8722.452752449417}, {
       2635.815919192536, -8722.452752444595}, {
       2619.400847587742, -8722.452752444595}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8722.452752449417}, {
       2584.883877349371, -8722.452752449417}, {
       2584.883877349371, -8722.452752444595}, {
       2584.881923061267, -8722.452752444595}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452752449417}, {
       3136.0548108763173`, -8722.452752449417}, {
       3136.0548108763173`, -8722.452752444595}, {
       3136.054810875182, -8722.452752444595}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752449417}, {
       3697.5935470304903`, -8722.452752449417}, {
       3697.5935470304903`, -8722.452752444595}, {
       3071.5358367872, -8722.452752444595}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452752449417}, {
       4142.649334928727, -8722.452752449417}, {
       4142.649334928727, -8722.452752444595}, {
       4139.663629151372, -8722.452752444595}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752444595}, {
       4699.999999999998, -8722.452752444595}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681882591`, -8722.452752449417}, {
      1601.28166819194, -8722.452752449417}, {
      1601.28166819194, -8722.452752444595}, {
      1601.2816681882591`, -8722.452752444595}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881923058856, -8722.4527524458}, \
{2584.881923061267, -8722.452752444595}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881923058856, -8722.4527524458}, 2.4112947586902335`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681943514`, -8722.452752448211}, {
       2584.881923058856, -8722.452752448211}, {
       2584.881923058856, -8722.4527524458}, {
       1601.2816681943514`, -8722.4527524458}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681943514`, -8722.452752448211}, 
       2.4112947586902335`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.28166819194, -8722.452752449417}, \
{1601.2816681943514`, -8722.452752448211}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.452752449417}, {
        100.00016295969903`, -8722.452752449417}, {
        100.00016295969903`, -8722.452752449417}, {
        100, -8722.452752449417}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.452752449417}, {
       949.6410656365955, -8722.452752449417}, {
       949.6410656365955, -8722.452752449417}, {
       600.0829521210504, -8722.452752449417}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.452752449417}, {
       1329.7547845665777`, -8722.452752449417}, {
       1329.7547845665777`, -8722.452752449417}, {
       1324.7735029625924`, -8722.452752449417}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.452752449417}, {
       1601.2816681943514`, -8722.452752449417}, {
       1601.2816681943514`, -8722.452752449417}, {
       1601.2816681882591`, -8722.452752449417}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.452752449417}, {
       2635.815919192536, -8722.452752449417}, {
       2635.815919192536, -8722.452752449417}, {
       2619.400847587742, -8722.452752449417}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.452752449417}, {
       3136.0548108763173`, -8722.452752449417}, {
       3136.0548108763173`, -8722.452752449417}, {
       3136.054810875182, -8722.452752449417}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.452752449417}, {
       3697.5935470304903`, -8722.452752449417}, {
       3697.5935470304903`, -8722.452752449417}, {
       3071.5358367872, -8722.452752449417}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.663629151372, -8722.452752449417}, {
       4142.649334928727, -8722.452752449417}, {
       4142.649334928727, -8722.452752449417}, {
       4139.663629151372, -8722.452752449417}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881923061267, -8722.452752449417}, {
      2584.883877349371, -8722.452752449417}, {
      2584.883877349371, -8722.452752449417}, {
      2584.881923061267, -8722.452752449417}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8722.452752449417}, \
{4699.999999999998, -8722.452752449417}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8722.452752449417}, 1.582413866396282*^-15,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883877349371, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}, {
       2584.883877349371, -8722.452752449417}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883877349371, -8722.452752449417}, 1.582413866396282*^-15,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.883877349371, -8722.452752449417}, \
{2584.883877349371, -8722.452752449417}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.456560892726}, {
        100.00016295969903`, -8722.456560892726}, {
        100.00016295969903`, -8722.452752449417}, {
        100, -8722.452752449417}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0829521210504, -8722.456560892726}, {
       949.6410656365955, -8722.456560892726}, {
       949.6410656365955, -8722.452752449417}, {
       600.0829521210504, -8722.452752449417}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.456560892726}, {
       1329.7547845665777`, -8722.456560892726}, {
       1329.7547845665777`, -8722.452752449417}, {
       1324.7735029625924`, -8722.452752449417}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.456560892726}, {
       1601.2816681943514`, -8722.456560892726}, {
       1601.2816681943514`, -8722.452752449417}, {
       1601.2816681882591`, -8722.452752449417}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.456560892726}, {
       2635.815919192536, -8722.456560892726}, {
       2635.815919192536, -8722.452752449417}, {
       2619.400847587742, -8722.452752449417}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8722.456560892726}, {
       2584.8819731277167`, -8722.456560892726}, {
       2584.8819731277167`, -8722.452752449417}, {
       2584.881923061267, -8722.452752449417}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.456560892726}, {
       3136.0548108763173`, -8722.456560892726}, {
       3136.0548108763173`, -8722.452752449417}, {
       3136.054810875182, -8722.452752449417}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.456560892726}, {
       3697.5935470304903`, -8722.456560892726}, {
       3697.5935470304903`, -8722.452752449417}, {
       3071.5358367872, -8722.452752449417}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.456560892726}, {
       4699.999999999998, -8722.456560892726}, {
       4699.999999999998, -8722.452752449417}, {
       4699.999999999998, -8722.452752449417}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.663629151372, -8722.456560892726}, {
      4142.649334928727, -8722.456560892726}, {
      4142.649334928727, -8722.452752449417}, {
      4139.663629151372, -8722.452752449417}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819731277167`, -8722.453704560245}, \
{2584.883877349371, -8722.452752449417}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.883877349371, -8722.453704560245}, 0.0019042216540826615`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.883877349371, -8722.455608781898}, {
       4139.661724929718, -8722.455608781898}, {
       4139.661724929718, -8722.453704560245}, {
       2584.883877349371, -8722.453704560245}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.661724929718, -8722.455608781898}, 
       0.0019042216540826615`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.661724929718, -8722.456560892726}, \
{4139.663629151372, -8722.455608781898}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8722.456816919284}, {
       949.6410656365955, -8722.456816919284}, {
       949.6410656365955, -8722.456560892726}, {
       600.0830801343297, -8722.456560892726}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.456816919284}, {
       1329.7547845665777`, -8722.456816919284}, {
       1329.7547845665777`, -8722.456560892726}, {
       1324.7735029625924`, -8722.456560892726}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.456816919284}, {
       1601.2816681943514`, -8722.456816919284}, {
       1601.2816681943514`, -8722.456560892726}, {
       1601.2816681882591`, -8722.456560892726}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.456816919284}, {
       2635.815919192536, -8722.456816919284}, {
       2635.815919192536, -8722.456560892726}, {
       2619.400847587742, -8722.456560892726}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8722.456816919284}, {
       2584.8819731277167`, -8722.456816919284}, {
       2584.8819731277167`, -8722.456560892726}, {
       2584.881923061267, -8722.456560892726}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810875182, -8722.456816919284}, {
       3136.0548108763173`, -8722.456816919284}, {
       3136.0548108763173`, -8722.456560892726}, {
       3136.054810875182, -8722.456560892726}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.456816919284}, {
       3697.5935470304903`, -8722.456816919284}, {
       3697.5935470304903`, -8722.456560892726}, {
       3071.5358367872, -8722.456560892726}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8722.456816919284}, {
       4142.649334928727, -8722.456816919284}, {
       4142.649334928727, -8722.456560892726}, {
       4139.661724929718, -8722.456560892726}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.456816919284}, {
       4699.999999999998, -8722.456816919284}, {
       4699.999999999998, -8722.456560892726}, {
       4699.999999999998, -8722.456560892726}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -8722.456816919284}, {
       100.00016295969903`, -8722.456816919284}, {
       100.00016295969903`, -8722.456560892726}, {
       100, -8722.456560892726}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0829521210504, -8722.456624899365}, \
{600.0830801343297, -8722.456560892726}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0829521210504, -8722.456624899365}, 
       0.00012801327933650392`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00029097297836`, -8722.456752912645}, {
       600.0829521210504, -8722.456752912645}, {
       600.0829521210504, -8722.456624899365}, {
       100.00029097297836`, -8722.456624899365}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00029097297836`, -8722.456752912645}, 
       0.00012801327933650392`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00016295969903`, -8722.456816919284}, \
{100.00029097297836`, -8722.456752912645}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.456816919766}, {
        100.0002909727376, -8722.456816919766}, {
        100.0002909727376, -8722.456816919284}, {
        100, -8722.456816919284}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8722.456816919766}, {
       949.6410656365955, -8722.456816919766}, {
       949.6410656365955, -8722.456816919284}, {
       600.0830801343297, -8722.456816919284}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.456816919766}, {
       1329.7547845665777`, -8722.456816919766}, {
       1329.7547845665777`, -8722.456816919284}, {
       1324.7735029625924`, -8722.456816919284}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.456816919766}, {
       1601.2816681943514`, -8722.456816919766}, {
       1601.2816681943514`, -8722.456816919284}, {
       1601.2816681882591`, -8722.456816919284}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.456816919766}, {
       2635.815919192536, -8722.456816919766}, {
       2635.815919192536, -8722.456816919284}, {
       2619.400847587742, -8722.456816919284}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8722.456816919766}, {
       2584.8819731277167`, -8722.456816919766}, {
       2584.8819731277167`, -8722.456816919284}, {
       2584.881923061267, -8722.456816919284}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.456816919766}, {
       3697.5935470304903`, -8722.456816919766}, {
       3697.5935470304903`, -8722.456816919284}, {
       3071.5358367872, -8722.456816919284}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8722.456816919766}, {
       4142.649334928727, -8722.456816919766}, {
       4142.649334928727, -8722.456816919284}, {
       4139.661724929718, -8722.456816919284}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919284}, {
       4699.999999999998, -8722.456816919284}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810875182, -8722.456816919766}, {
      3136.0548108763173`, -8722.456816919766}, {
      3136.0548108763173`, -8722.456816919284}, {
      3136.054810875182, -8722.456816919284}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0002909727376, -8722.456816919404}, \
{100.00029097297836`, -8722.456816919284}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00029097297836`, -8722.456816919404}, 
       2.407569317305889*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00029097297836`, -8722.456816919646}, {
       3136.0548108749413`, -8722.456816919646}, {
       3136.0548108749413`, -8722.456816919404}, {
       100.00029097297836`, -8722.456816919404}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108749413`, -8722.456816919646}, 
       2.407569317305889*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108749413`, -8722.456816919766}, \
{3136.054810875182, -8722.456816919646}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8722.456816919766}, {
        100.0002909727376, -8722.456816919766}, {
        100.0002909727376, -8722.456816919766}, {
        100, -8722.456816919766}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8722.456816919766}, {
       949.6410656365955, -8722.456816919766}, {
       949.6410656365955, -8722.456816919766}, {
       600.0830801343297, -8722.456816919766}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8722.456816919766}, {
       1329.7547845665777`, -8722.456816919766}, {
       1329.7547845665777`, -8722.456816919766}, {
       1324.7735029625924`, -8722.456816919766}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8722.456816919766}, {
       1601.2816681943514`, -8722.456816919766}, {
       1601.2816681943514`, -8722.456816919766}, {
       1601.2816681882591`, -8722.456816919766}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8722.456816919766}, {
       2635.815919192536, -8722.456816919766}, {
       2635.815919192536, -8722.456816919766}, {
       2619.400847587742, -8722.456816919766}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8722.456816919766}, {
       2584.8819731277167`, -8722.456816919766}, {
       2584.8819731277167`, -8722.456816919766}, {
       2584.881923061267, -8722.456816919766}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8722.456816919766}, {
       3136.0548108763173`, -8722.456816919766}, {
       3136.0548108763173`, -8722.456816919766}, {
       3136.0548108749413`, -8722.456816919766}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3071.5358367872, -8722.456816919766}, {
       3697.5935470304903`, -8722.456816919766}, {
       3697.5935470304903`, -8722.456816919766}, {
       3071.5358367872, -8722.456816919766}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.661724929718, -8722.456816919766}, {
      4142.649334928727, -8722.456816919766}, {
      4142.649334928727, -8722.456816919766}, {
      4139.661724929718, -8722.456816919766}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8722.456816919766}, \
{4699.999999999998, -8722.456816919766}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8722.456816919766}, 7.23483299441458*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928727, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}, {
       4142.649334928727, -8722.456816919766}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928727, -8722.456816919766}, 7.23483299441458*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928727, -8722.456816919766}, \
{4142.649334928727, -8722.456816919766}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8880.61928109852}, {
        100.0002909727376, -8880.61928109852}, {
        100.0002909727376, -8722.456816919766}, {
        100, -8722.456816919766}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8880.61928109852}, {
       870.5598335472187, -8880.61928109852}, {
       870.5598335472187, -8722.456816919766}, {
       600.0830801343297, -8722.456816919766}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8880.61928109852}, {
       1329.7547845665777`, -8880.61928109852}, {
       1329.7547845665777`, -8722.456816919766}, {
       1324.7735029625924`, -8722.456816919766}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8880.61928109852}, {
       1601.2816681943514`, -8880.61928109852}, {
       1601.2816681943514`, -8722.456816919766}, {
       1601.2816681882591`, -8722.456816919766}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8880.61928109852}, {
       2635.815919192536, -8880.61928109852}, {
       2635.815919192536, -8722.456816919766}, {
       2619.400847587742, -8722.456816919766}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8880.61928109852}, {
       2584.8819731277167`, -8880.61928109852}, {
       2584.8819731277167`, -8722.456816919766}, {
       2584.881923061267, -8722.456816919766}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8880.61928109852}, {
       3136.0548108763173`, -8880.61928109852}, {
       3136.0548108763173`, -8722.456816919766}, {
       3136.0548108749413`, -8722.456816919766}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8880.61928109852}, {
       4142.649334928727, -8880.61928109852}, {
       4142.649334928727, -8722.456816919766}, {
       4139.661724929718, -8722.456816919766}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8880.61928109852}, {
       4699.999999999998, -8880.61928109852}, {
       4699.999999999998, -8722.456816919766}, {
       4699.999999999998, -8722.456816919766}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3071.5358367872, -8880.61928109852}, {
      3697.5935470304903`, -8880.61928109852}, {
      3697.5935470304903`, -8722.456816919766}, {
      3071.5358367872, -8722.456816919766}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{870.5598335472187, -8761.997432964454}, \
{949.6410656365955, -8722.456816919766}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{949.6410656365955, -8761.997432964454}, 79.0812320893769, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{949.6410656365955, -8841.07866505383}, {
       2992.454604697823, -8841.07866505383}, {
       2992.454604697823, -8761.997432964454}, {
       949.6410656365955, -8761.997432964454}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2992.454604697823, -8841.07866505383}, 79.0812320893769, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2992.454604697823, -8880.61928109852}, \
{3071.5358367872, -8841.07866505383}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8902.217061579233}, {
        100.0002909727376, -8902.217061579233}, {
        100.0002909727376, -8880.61928109852}, {100, -8880.61928109852}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8902.217061579233}, {
       870.5598335472187, -8902.217061579233}, {
       870.5598335472187, -8880.61928109852}, {
       600.0830801343297, -8880.61928109852}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8902.217061579233}, {
       1329.7547845665777`, -8902.217061579233}, {
       1329.7547845665777`, -8880.61928109852}, {
       1324.7735029625924`, -8880.61928109852}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8902.217061579233}, {
       1601.2816681943514`, -8902.217061579233}, {
       1601.2816681943514`, -8880.61928109852}, {
       1601.2816681882591`, -8880.61928109852}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8902.217061579233}, {
       2584.8819731277167`, -8902.217061579233}, {
       2584.8819731277167`, -8880.61928109852}, {
       2584.881923061267, -8880.61928109852}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8902.217061579233}, {
       3136.0548108763173`, -8902.217061579233}, {
       3136.0548108763173`, -8880.61928109852}, {
       3136.0548108749413`, -8880.61928109852}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949381793`, -8902.217061579233}, {
       3697.59354703049, -8902.217061579233}, {
       3697.59354703049, -8880.61928109852}, {
       3003.2534949381793`, -8880.61928109852}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8902.217061579233}, {
       4142.649334928727, -8902.217061579233}, {
       4142.649334928727, -8880.61928109852}, {
       4139.661724929718, -8880.61928109852}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8902.217061579233}, {
       4699.999999999998, -8902.217061579233}, {
       4699.999999999998, -8880.61928109852}, {
       4699.999999999998, -8880.61928109852}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.400847587742, -8902.217061579233}, {
      2635.815919192536, -8902.217061579233}, {
      2635.815919192536, -8880.61928109852}, {
      2619.400847587742, -8880.61928109852}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2992.454604697823, -8886.018726218697}, \
{3003.2534949381793`, -8880.61928109852}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2992.454604697823, -8886.018726218697}, 10.798890240356474`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2646.6148094328923`, -8896.817616459055}, {
       2992.454604697823, -8896.817616459055}, {
       2992.454604697823, -8886.018726218697}, {
       2646.6148094328923`, -8886.018726218697}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.6148094328923`, -8896.817616459055}, 10.798890240356474`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2635.815919192536, -8902.217061579233}, \
{2646.6148094328923`, -8896.817616459055}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8902.217061585154}, {
        100.0002909727376, -8902.217061585154}, {
        100.0002909727376, -8902.217061579233}, {
        100, -8902.217061579233}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8902.217061585154}, {
       870.5598335472187, -8902.217061585154}, {
       870.5598335472187, -8902.217061579233}, {
       600.0830801343297, -8902.217061579233}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8902.217061585154}, {
       1329.7547845665777`, -8902.217061585154}, {
       1329.7547845665777`, -8902.217061579233}, {
       1324.7735029625924`, -8902.217061579233}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8902.217061585154}, {
       1601.2816681913914`, -8902.217061585154}, {
       1601.2816681913914`, -8902.217061579233}, {
       1601.2816681882591`, -8902.217061579233}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847587742, -8902.217061585154}, {
       2646.6148094328923`, -8902.217061585154}, {
       2646.6148094328923`, -8902.217061579233}, {
       2619.400847587742, -8902.217061579233}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8902.217061585154}, {
       2584.8819731277167`, -8902.217061585154}, {
       2584.8819731277167`, -8902.217061579233}, {
       2584.881923061267, -8902.217061579233}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8902.217061585154}, {
       3136.0548108763173`, -8902.217061585154}, {
       3136.0548108763173`, -8902.217061579233}, {
       3136.0548108749413`, -8902.217061579233}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8902.217061585154}, {
       4142.649334928727, -8902.217061585154}, {
       4142.649334928727, -8902.217061579233}, {
       4139.661724929718, -8902.217061579233}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8902.217061585154}, {
       4699.999999999998, -8902.217061585154}, {
       4699.999999999998, -8902.217061579233}, {
       4699.999999999998, -8902.217061579233}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3003.2534949381793`, -8902.217061585154}, {
      3697.59354703049, -8902.217061585154}, {
      3697.59354703049, -8902.217061579233}, {
      3003.2534949381793`, -8902.217061579233}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681913914`, -8902.217061580714}, \
{1601.2816681943514`, -8902.217061579233}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681943514`, -8902.217061580714}, 
       2.9600307911819937`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681943514`, -8902.217061583673}, {
       3003.2534949352194`, -8902.217061583673}, {
       3003.2534949352194`, -8902.217061580714}, {
       1601.2816681943514`, -8902.217061580714}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3003.2534949352194`, -8902.217061583673}, 
       2.9600307911819937`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3003.2534949352194`, -8902.217061585154}, \
{3003.2534949381793`, -8902.217061583673}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8902.217061588606}, {
        100.0002909727376, -8902.217061588606}, {
        100.0002909727376, -8902.217061585154}, {
        100, -8902.217061585154}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8902.217061588606}, {
       870.5598335472187, -8902.217061588606}, {
       870.5598335472187, -8902.217061585154}, {
       600.0830801343297, -8902.217061585154}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8902.217061588606}, {
       1329.7547845665777`, -8902.217061588606}, {
       1329.7547845665777`, -8902.217061585154}, {
       1324.7735029625924`, -8902.217061585154}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8902.217061588606}, {
       1601.2816681896652`, -8902.217061588606}, {
       1601.2816681896652`, -8902.217061585154}, {
       1601.2816681882591`, -8902.217061585154}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8902.217061588606}, {
       2584.8819731277167`, -8902.217061588606}, {
       2584.8819731277167`, -8902.217061585154}, {
       2584.881923061267, -8902.217061585154}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8902.217061588606}, {
       3136.0548108763173`, -8902.217061588606}, {
       3136.0548108763173`, -8902.217061585154}, {
       3136.0548108749413`, -8902.217061585154}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8902.217061588606}, {
       3697.59354703049, -8902.217061588606}, {
       3697.59354703049, -8902.217061585154}, {
       3003.2534949352194`, -8902.217061585154}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8902.217061588606}, {
       4142.649334928727, -8902.217061588606}, {
       4142.649334928727, -8902.217061585154}, {
       4139.661724929718, -8902.217061585154}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8902.217061588606}, {
       4699.999999999998, -8902.217061588606}, {
       4699.999999999998, -8902.217061585154}, {
       4699.999999999998, -8902.217061585154}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.400847587742, -8902.217061588606}, {
      2646.6148094328923`, -8902.217061588606}, {
      2646.6148094328923`, -8902.217061585154}, {
      2619.400847587742, -8902.217061585154}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681896652`, -8902.217061586018}, \
{1601.2816681913914`, -8902.217061585154}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681913914`, -8902.217061586018}, 
       1.726204573640156*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681913914`, -8902.217061587744}, {
       2619.400847586016, -8902.217061587744}, {
       2619.400847586016, -8902.217061586018}, {
       1601.2816681913914`, -8902.217061586018}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.400847586016, -8902.217061587744}, 
       1.726204573640156*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.400847586016, -8902.217061588606}, \
{2619.400847587742, -8902.217061587744}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8902.217061588606}, {
        100.0002909727376, -8902.217061588606}, {
        100.0002909727376, -8902.217061588606}, {
        100, -8902.217061588606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8902.217061588606}, {
       870.5598335472187, -8902.217061588606}, {
       870.5598335472187, -8902.217061588606}, {
       600.0830801343297, -8902.217061588606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8902.217061588606}, {
       1329.7547845665777`, -8902.217061588606}, {
       1329.7547845665777`, -8902.217061588606}, {
       1324.7735029625924`, -8902.217061588606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8902.217061588606}, {
       1601.2816681896652`, -8902.217061588606}, {
       1601.2816681896652`, -8902.217061588606}, {
       1601.2816681882591`, -8902.217061588606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8902.217061588606}, {
       2646.6148094328923`, -8902.217061588606}, {
       2646.6148094328923`, -8902.217061588606}, {
       2619.400847586016, -8902.217061588606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8902.217061588606}, {
       2584.8819731277167`, -8902.217061588606}, {
       2584.8819731277167`, -8902.217061588606}, {
       2584.881923061267, -8902.217061588606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8902.217061588606}, {
       3136.0548108763173`, -8902.217061588606}, {
       3136.0548108763173`, -8902.217061588606}, {
       3136.0548108749413`, -8902.217061588606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8902.217061588606}, {
       3697.59354703049, -8902.217061588606}, {
       3697.59354703049, -8902.217061588606}, {
       3003.2534949352194`, -8902.217061588606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.661724929718, -8902.217061588606}, {
       4142.649334928727, -8902.217061588606}, {
       4142.649334928727, -8902.217061588606}, {
       4139.661724929718, -8902.217061588606}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -8902.217061588606}, {
      4699.999999999998, -8902.217061588606}, {
      4699.999999999998, -8902.217061588606}, {
      4699.999999999998, -8902.217061588606}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819731277167`, -8902.217061588606}, \
{2584.8819731277167`, -8902.217061588606}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819731277167`, -8902.217061588606}, 
       7.736976773104394*^-14, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819731277167`, -8902.217061588606}, {
       4699.999999999998, -8902.217061588606}, {
       4699.999999999998, -8902.217061588606}, {
       2584.8819731277167`, -8902.217061588606}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8902.217061588606}, 
       7.736976773104394*^-14, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8902.217061588606}, \
{4699.999999999998, -8902.217061588606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8905.551191694522}, {
        100.0002909727376, -8905.551191694522}, {
        100.0002909727376, -8902.217061588606}, {
        100, -8902.217061588606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8905.551191694522}, {
       870.5598335472187, -8905.551191694522}, {
       870.5598335472187, -8902.217061588606}, {
       600.0830801343297, -8902.217061588606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8905.551191694522}, {
       1601.2816681896652`, -8905.551191694522}, {
       1601.2816681896652`, -8902.217061588606}, {
       1601.2816681882591`, -8902.217061588606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8905.551191694522}, {
       2646.6148094328923`, -8905.551191694522}, {
       2646.6148094328923`, -8902.217061588606}, {
       2619.400847586016, -8902.217061588606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8905.551191694522}, {
       2584.8819731277167`, -8905.551191694522}, {
       2584.8819731277167`, -8902.217061588606}, {
       2584.881923061267, -8902.217061588606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8905.551191694522}, {
       3136.0548108763173`, -8905.551191694522}, {
       3136.0548108763173`, -8902.217061588606}, {
       3136.0548108749413`, -8902.217061588606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8905.551191694522}, {
       3697.59354703049, -8905.551191694522}, {
       3697.59354703049, -8902.217061588606}, {
       3003.2534949352194`, -8902.217061588606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4141.3287899826755`, -8905.551191694522}, {
       4142.649334928726, -8905.551191694522}, {
       4142.649334928726, -8902.217061588606}, {
       4141.3287899826755`, -8902.217061588606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8905.551191694522}, {4699.999999999998,
        -8905.551191694522}, {4699.999999999998, -8902.217061588606}, {
       4699.999999999998, -8902.217061588606}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7735029625924`, -8905.551191694522}, {
      1329.7547845665777`, -8905.551191694522}, {
      1329.7547845665777`, -8902.217061588606}, {
      1324.7735029625924`, -8902.217061588606}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.661724929718, -8903.050594115084}, \
{4141.3287899826755`, -8902.217061588606}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.661724929718, -8903.050594115084}, 1.6670650529580415`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1331.4218496195356`, -8904.717659168042}, {
       4139.661724929718, -8904.717659168042}, {
       4139.661724929718, -8903.050594115084}, {
       1331.4218496195356`, -8903.050594115084}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1331.4218496195356`, -8904.717659168042}, 1.6670650529580415`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1329.7547845665777`, -8905.551191694522}, \
{1331.4218496195356`, -8904.717659168042}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8907.466900407626}, {
        100.0002909727376, -8907.466900407626}, {
        100.0002909727376, -8905.551191694522}, {
        100, -8905.551191694522}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8907.466900407626}, {
       870.5598335472187, -8907.466900407626}, {
       870.5598335472187, -8905.551191694522}, {
       600.0830801343297, -8905.551191694522}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8907.466900407626}, {
       1331.4218496195356`, -8907.466900407626}, {
       1331.4218496195356`, -8905.551191694522}, {
       1324.7735029625924`, -8905.551191694522}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681882591`, -8907.466900407626}, {
       1601.2816681896652`, -8907.466900407626}, {
       1601.2816681896652`, -8905.551191694522}, {
       1601.2816681882591`, -8905.551191694522}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8907.466900407626}, {
       2645.6569550763406`, -8907.466900407626}, {
       2645.6569550763406`, -8905.551191694522}, {
       2619.400847586016, -8905.551191694522}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8907.466900407626}, {
       2584.8819731277167`, -8907.466900407626}, {
       2584.8819731277167`, -8905.551191694522}, {
       2584.881923061267, -8905.551191694522}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8907.466900407626}, {
       3136.0548108763173`, -8907.466900407626}, {
       3136.0548108763173`, -8905.551191694522}, {
       3136.0548108749413`, -8905.551191694522}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8907.466900407626}, {
       3697.59354703049, -8907.466900407626}, {
       3697.59354703049, -8905.551191694522}, {
       3003.2534949352194`, -8905.551191694522}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8907.466900407626}, {
       4699.999999999998, -8907.466900407626}, {
       4699.999999999998, -8905.551191694522}, {
       4699.999999999998, -8905.551191694522}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4141.3287899826755`, -8907.466900407626}, {
      4142.649334928726, -8907.466900407626}, {
      4142.649334928726, -8905.551191694522}, {
      4141.3287899826755`, -8905.551191694522}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2645.6569550763406`, -8906.030118872797}, \
{2646.6148094328923`, -8905.551191694522}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.6148094328923`, -8906.030118872797}, 0.9578543565520095, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2646.6148094328923`, -8906.98797322935}, {
       4140.370935626123, -8906.98797322935}, {
       4140.370935626123, -8906.030118872797}, {
       2646.6148094328923`, -8906.030118872797}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.370935626123, -8906.98797322935}, 0.9578543565520095, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.370935626123, -8907.466900407626}, \
{4141.3287899826755`, -8906.98797322935}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8907.466900408632}, {
        100.00029097223441`, -8907.466900408632}, {
        100.00029097223441`, -8907.466900407626}, {
        100, -8907.466900407626}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8907.466900408632}, {
       870.5598335472187, -8907.466900408632}, {
       870.5598335472187, -8907.466900407626}, {
       600.0830801343297, -8907.466900407626}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8907.466900408632}, {
       1331.4218496195356`, -8907.466900408632}, {
       1331.4218496195356`, -8907.466900407626}, {
       1324.7735029625924`, -8907.466900407626}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8907.466900408632}, {
       2645.6569550763406`, -8907.466900408632}, {
       2645.6569550763406`, -8907.466900407626}, {
       2619.400847586016, -8907.466900407626}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8907.466900408632}, {
       2584.8819731277167`, -8907.466900408632}, {
       2584.8819731277167`, -8907.466900407626}, {
       2584.881923061267, -8907.466900407626}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8907.466900408632}, {
       3136.0548108763173`, -8907.466900408632}, {
       3136.0548108763173`, -8907.466900407626}, {
       3136.0548108749413`, -8907.466900407626}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8907.466900408632}, {
       3697.59354703049, -8907.466900408632}, {
       3697.59354703049, -8907.466900407626}, {
       3003.2534949352194`, -8907.466900407626}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.370935626123, -8907.466900408632}, {
       4142.649334928726, -8907.466900408632}, {
       4142.649334928726, -8907.466900407626}, {
       4140.370935626123, -8907.466900407626}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900407626}, {
       4699.999999999998, -8907.466900407626}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681882591`, -8907.466900408632}, {
      1601.2816681896652`, -8907.466900408632}, {
      1601.2816681896652`, -8907.466900407626}, {
      1601.2816681882591`, -8907.466900407626}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00029097223441`, -8907.466900407877}, \
{100.0002909727376, -8907.466900407626}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0002909727376, -8907.466900407877}, 5.031983520291592*^-10,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0002909727376, -8907.46690040838}, {
       1601.281668187756, -8907.46690040838}, {
       1601.281668187756, -8907.466900407877}, {
       100.0002909727376, -8907.466900407877}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668187756, -8907.46690040838}, 
       5.031983520291592*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668187756, -8907.466900408632}, \
{1601.2816681882591`, -8907.46690040838}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8907.466900408632}, {
        100.00029097223441`, -8907.466900408632}, {
        100.00029097223441`, -8907.466900408632}, {
        100, -8907.466900408632}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8907.466900408632}, {
       870.5598335472187, -8907.466900408632}, {
       870.5598335472187, -8907.466900408632}, {
       600.0830801343297, -8907.466900408632}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8907.466900408632}, {
       1331.4218496195356`, -8907.466900408632}, {
       1331.4218496195356`, -8907.466900408632}, {
       1324.7735029625924`, -8907.466900408632}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -8907.466900408632}, {
       1601.2816681896652`, -8907.466900408632}, {
       1601.2816681896652`, -8907.466900408632}, {
       1601.281668187756, -8907.466900408632}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8907.466900408632}, {
       2645.6569550763406`, -8907.466900408632}, {
       2645.6569550763406`, -8907.466900408632}, {
       2619.400847586016, -8907.466900408632}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8907.466900408632}, {
       2584.8819731277167`, -8907.466900408632}, {
       2584.8819731277167`, -8907.466900408632}, {
       2584.881923061267, -8907.466900408632}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8907.466900408632}, {
       3136.0548108763173`, -8907.466900408632}, {
       3136.0548108763173`, -8907.466900408632}, {
       3136.0548108749413`, -8907.466900408632}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3003.2534949352194`, -8907.466900408632}, {
       3697.59354703049, -8907.466900408632}, {
       3697.59354703049, -8907.466900408632}, {
       3003.2534949352194`, -8907.466900408632}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4140.370935626123, -8907.466900408632}, {
      4142.649334928726, -8907.466900408632}, {
      4142.649334928726, -8907.466900408632}, {
      4140.370935626123, -8907.466900408632}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -8907.466900408632}, \
{4699.999999999998, -8907.466900408632}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -8907.466900408632}, 1.348866640117139*^-14,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928726, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}, {
       4142.649334928726, -8907.466900408632}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928726, -8907.466900408632}, 1.348866640117139*^-14,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928726, -8907.466900408632}, \
{4142.649334928726, -8907.466900408632}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8954.508700445793}, {
        100.00029097223441`, -8954.508700445793}, {
        100.00029097223441`, -8907.466900408632}, {
        100, -8907.466900408632}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8954.508700445793}, {
       870.5598335472187, -8954.508700445793}, {
       870.5598335472187, -8907.466900408632}, {
       600.0830801343297, -8907.466900408632}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -8954.508700445793}, {
       1331.4218496195356`, -8954.508700445793}, {
       1331.4218496195356`, -8907.466900408632}, {
       1324.7735029625924`, -8907.466900408632}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -8954.508700445793}, {
       1601.2816681896652`, -8954.508700445793}, {
       1601.2816681896652`, -8907.466900408632}, {
       1601.281668187756, -8907.466900408632}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8954.508700445793}, {
       2584.8819731277167`, -8954.508700445793}, {
       2584.8819731277167`, -8907.466900408632}, {
       2584.881923061267, -8907.466900408632}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8954.508700445793}, {
       3136.0548108763173`, -8954.508700445793}, {
       3136.0548108763173`, -8907.466900408632}, {
       3136.0548108749413`, -8907.466900408632}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3026.7743949538003`, -8954.508700445793}, {
       3697.59354703049, -8954.508700445793}, {
       3697.59354703049, -8907.466900408632}, {
       3026.7743949538003`, -8907.466900408632}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.370935626123, -8954.508700445793}, {
       4142.649334928726, -8954.508700445793}, {
       4142.649334928726, -8907.466900408632}, {
       4140.370935626123, -8907.466900408632}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8954.508700445793}, {
       4699.999999999998, -8954.508700445793}, {
       4699.999999999998, -8907.466900408632}, {
       4699.999999999998, -8907.466900408632}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2619.400847586016, -8954.508700445793}, {
      2645.6569550763406`, -8954.508700445793}, {
      2645.6569550763406`, -8907.466900408632}, {
      2619.400847586016, -8907.466900408632}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3003.2534949352194`, -8919.227350417921}, \
{3026.7743949538003`, -8907.466900408632}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3003.2534949352194`, -8919.227350417921}, 23.52090001858095, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2669.1778550949216`, -8942.748250436502}, {
       3003.2534949352194`, -8942.748250436502}, {
       3003.2534949352194`, -8919.227350417921}, {
       2669.1778550949216`, -8919.227350417921}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2669.1778550949216`, -8942.748250436502}, 23.52090001858095, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2645.6569550763406`, -8954.508700445793}, \
{2669.1778550949216`, -8942.748250436502}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -8963.562868620826}, {
        100.00029097223441`, -8963.562868620826}, {
        100.00029097223441`, -8954.508700445793}, {
        100, -8954.508700445793}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -8963.562868620826}, {
       870.5598335472187, -8963.562868620826}, {
       870.5598335472187, -8954.508700445793}, {
       600.0830801343297, -8954.508700445793}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -8963.562868620826}, {
       1601.2816681896652`, -8963.562868620826}, {
       1601.2816681896652`, -8954.508700445793}, {
       1601.281668187756, -8954.508700445793}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2619.400847586016, -8963.562868620826}, {
       2669.1778550949216`, -8963.562868620826}, {
       2669.1778550949216`, -8954.508700445793}, {
       2619.400847586016, -8954.508700445793}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -8963.562868620826}, {
       2584.8819731277167`, -8963.562868620826}, {
       2584.8819731277167`, -8954.508700445793}, {
       2584.881923061267, -8954.508700445793}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -8963.562868620826}, {
       3136.0548108763173`, -8963.562868620826}, {
       3136.0548108763173`, -8954.508700445793}, {
       3136.0548108749413`, -8954.508700445793}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -8963.562868620826}, {
       3697.59354703049, -8963.562868620826}, {
       3697.59354703049, -8954.508700445793}, {
       3031.301479041317, -8954.508700445793}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.370935626123, -8963.562868620826}, {
       4142.649334928726, -8963.562868620826}, {
       4142.649334928726, -8954.508700445793}, {
       4140.370935626123, -8954.508700445793}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -8963.562868620826}, {
       4699.999999999998, -8963.562868620826}, {
       4699.999999999998, -8954.508700445793}, {
       4699.999999999998, -8954.508700445793}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7735029625924`, -8963.562868620826}, {
      1331.4218496195356`, -8963.562868620826}, {
      1331.4218496195356`, -8954.508700445793}, {
      1324.7735029625924`, -8954.508700445793}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3026.7743949538003`, -8956.772242489551}, \
{3031.301479041317, -8954.508700445793}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3026.7743949538003`, -8956.772242489551}, 4.527084087516819, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9489337070524`, -8961.299326577067}, {
       3026.7743949538003`, -8961.299326577067}, {
       3026.7743949538003`, -8956.772242489551}, {
       1335.9489337070524`, -8956.772242489551}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9489337070524`, -8961.299326577067}, 4.527084087516819, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1331.4218496195356`, -8963.562868620826}, \
{1335.9489337070524`, -8961.299326577067}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9022.529665956628}, {
        100.00029097223441`, -9022.529665956628}, {
        100.00029097223441`, -8963.562868620826}, {
        100, -8963.562868620826}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -9022.529665956628}, {
       1335.9489337070524`, -9022.529665956628}, {
       1335.9489337070524`, -8963.562868620826}, {
       1324.7735029625924`, -8963.562868620826}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9022.529665956628}, {
       1601.2816681896652`, -9022.529665956628}, {
       1601.2816681896652`, -8963.562868620826}, {
       1601.281668187756, -8963.562868620826}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9022.529665956628}, {
       2669.1778550949216`, -9022.529665956628}, {
       2669.1778550949216`, -8963.562868620826}, {
       2648.884246253918, -8963.562868620826}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -9022.529665956628}, {
       2584.8819731277167`, -9022.529665956628}, {
       2584.8819731277167`, -8963.562868620826}, {
       2584.881923061267, -8963.562868620826}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9022.529665956628}, {
       3136.0548108763173`, -9022.529665956628}, {
       3136.0548108763173`, -8963.562868620826}, {
       3136.0548108749413`, -8963.562868620826}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -9022.529665956628}, {
       3697.59354703049, -9022.529665956628}, {
       3697.59354703049, -8963.562868620826}, {
       3031.301479041317, -8963.562868620826}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.370935626123, -9022.529665956628}, {
       4142.649334928726, -9022.529665956628}, {
       4142.649334928726, -8963.562868620826}, {
       4140.370935626123, -8963.562868620826}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9022.529665956628}, {
       4699.999999999998, -9022.529665956628}, {
       4699.999999999998, -8963.562868620826}, {
       4699.999999999998, -8963.562868620826}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0830801343297, -9022.529665956628}, {
      870.5598335472187, -9022.529665956628}, {
      870.5598335472187, -8963.562868620826}, {
      600.0830801343297, -8963.562868620826}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2619.400847586016, -8978.304567954776}, \
{2648.884246253918, -8963.562868620826}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2619.400847586016, -8978.304567954776}, 29.483398667901767`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{900.0432322151204, -9007.787966622678}, {
       2619.400847586016, -9007.787966622678}, {
       2619.400847586016, -8978.304567954776}, {
       900.0432322151204, -8978.304567954776}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{900.0432322151204, -9007.787966622678}, 29.483398667901767`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{870.5598335472187, -9022.529665956628}, \
{900.0432322151204, -9007.787966622678}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9023.19223527203}, {
        100.00029097223441`, -9023.19223527203}, {
        100.00029097223441`, -9022.529665956628}, {
        100, -9022.529665956628}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9023.19223527203}, {
       900.0432322151204, -9023.19223527203}, {
       900.0432322151204, -9022.529665956628}, {
       600.0830801343297, -9022.529665956628}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -9023.19223527203}, {
       1335.9489337070524`, -9023.19223527203}, {
       1335.9489337070524`, -9022.529665956628}, {
       1324.7735029625924`, -9022.529665956628}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9023.19223527203}, {
       1601.2816681896652`, -9023.19223527203}, {
       1601.2816681896652`, -9022.529665956628}, {
       1601.281668187756, -9022.529665956628}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9023.19223527203}, {
       2668.84657043722, -9023.19223527203}, {
       2668.84657043722, -9022.529665956628}, {
       2648.884246253918, -9022.529665956628}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -9023.19223527203}, {
       2584.8819731277167`, -9023.19223527203}, {
       2584.8819731277167`, -9022.529665956628}, {
       2584.881923061267, -9022.529665956628}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9023.19223527203}, {
       3136.0548108763173`, -9023.19223527203}, {
       3136.0548108763173`, -9022.529665956628}, {
       3136.0548108749413`, -9022.529665956628}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -9023.19223527203}, {
       3697.59354703049, -9023.19223527203}, {
       3697.59354703049, -9022.529665956628}, {
       3031.301479041317, -9022.529665956628}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9023.19223527203}, {
       4699.999999999998, -9023.19223527203}, {
       4699.999999999998, -9022.529665956628}, {
       4699.999999999998, -9022.529665956628}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4140.370935626123, -9023.19223527203}, {
      4142.649334928727, -9023.19223527203}, {
      4142.649334928727, -9022.529665956628}, {
      4140.370935626123, -9022.529665956628}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2668.84657043722, -9022.695308285478}, \
{2669.1778550949216`, -9022.529665956628}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2669.1778550949216`, -9022.695308285478}, 0.3312846577013939, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2669.1778550949216`, -9023.026592943179}, {
       4140.039650968422, -9023.026592943179}, {
       4140.039650968422, -9022.695308285478}, {
       2669.1778550949216`, -9022.695308285478}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.039650968422, -9023.026592943179}, 0.3312846577013939, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.039650968422, -9023.19223527203}, \
{4140.370935626123, -9023.026592943179}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9023.19223527203}, {
        100.00029097223441`, -9023.19223527203}, {
        100.00029097223441`, -9023.19223527203}, {
        100, -9023.19223527203}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9023.19223527203}, {
       900.0432322151204, -9023.19223527203}, {
       900.0432322151204, -9023.19223527203}, {
       600.0830801343297, -9023.19223527203}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1324.7735029625924`, -9023.19223527203}, {
       1335.9489337070524`, -9023.19223527203}, {
       1335.9489337070524`, -9023.19223527203}, {
       1324.7735029625924`, -9023.19223527203}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9023.19223527203}, {
       1601.2816681896652`, -9023.19223527203}, {
       1601.2816681896652`, -9023.19223527203}, {
       1601.281668187756, -9023.19223527203}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9023.19223527203}, {
       2668.84657043722, -9023.19223527203}, {
       2668.84657043722, -9023.19223527203}, {
       2648.884246253918, -9023.19223527203}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881923061267, -9023.19223527203}, {
       2584.8819731277167`, -9023.19223527203}, {
       2584.8819731277167`, -9023.19223527203}, {
       2584.881923061267, -9023.19223527203}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9023.19223527203}, {
       3136.0548108763173`, -9023.19223527203}, {
       3136.0548108763173`, -9023.19223527203}, {
       3136.0548108749413`, -9023.19223527203}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -9023.19223527203}, {
       3697.59354703049, -9023.19223527203}, {
       3697.59354703049, -9023.19223527203}, {
       3031.301479041317, -9023.19223527203}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968422, -9023.19223527203}, {
       4142.649334928727, -9023.19223527203}, {
       4142.649334928727, -9023.19223527203}, {
       4140.039650968422, -9023.19223527203}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9023.19223527203}, {
      4699.999999999998, -9023.19223527203}, {
      4699.999999999998, -9023.19223527203}, {
      4699.999999999998, -9023.19223527203}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819731277167`, -9023.19223527203}, \
{2584.8819731277167`, -9023.19223527203}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819731277167`, -9023.19223527203}, 
       2.027695303468016*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819731277167`, -9023.19223527203}, {
       4699.999999999998, -9023.19223527203}, {
       4699.999999999998, -9023.19223527203}, {
       2584.8819731277167`, -9023.19223527203}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9023.19223527203}, 
       2.027695303468016*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9023.19223527203}, \
{4699.999999999998, -9023.19223527203}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9023.192235916596}, {
        100.00029097223441`, -9023.192235916596}, {
        100.00029097223441`, -9023.19223527203}, {
        100, -9023.19223527203}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9023.192235916596}, {
       900.0432322151204, -9023.192235916596}, {
       900.0432322151204, -9023.19223527203}, {
       600.0830801343297, -9023.19223527203}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9023.192235916596}, {
       1601.2816681896652`, -9023.192235916596}, {
       1601.2816681896652`, -9023.19223527203}, {
       1601.281668187756, -9023.19223527203}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9023.192235916596}, {
       2668.84657043722, -9023.192235916596}, {
       2668.84657043722, -9023.19223527203}, {
       2648.884246253918, -9023.19223527203}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9023.192235916596}, {
       2584.8819731277167`, -9023.192235916596}, {
       2584.8819731277167`, -9023.19223527203}, {
       2584.88192338355, -9023.19223527203}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9023.192235916596}, {
       3136.0548108763173`, -9023.192235916596}, {
       3136.0548108763173`, -9023.19223527203}, {
       3136.0548108749413`, -9023.19223527203}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -9023.192235916596}, {
       3697.59354703049, -9023.192235916596}, {
       3697.59354703049, -9023.19223527203}, {
       3031.301479041317, -9023.19223527203}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968422, -9023.192235916596}, {
       4142.649334928727, -9023.192235916596}, {
       4142.649334928727, -9023.19223527203}, {
       4140.039650968422, -9023.19223527203}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9023.192235916596}, {
       4699.999999999998, -9023.192235916596}, {
       4699.999999999998, -9023.19223527203}, {
       4699.999999999998, -9023.19223527203}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1324.7735029625924`, -9023.192235916596}, {
      1335.9489337070524`, -9023.192235916596}, {
      1335.9489337070524`, -9023.19223527203}, {
      1324.7735029625924`, -9023.19223527203}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881923061267, -9023.192235433173}, \
{2584.88192338355, -9023.19223527203}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881923061267, -9023.192235433173}, 
       3.2228290057608795`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9489340293353`, -9023.192235755456}, {
       2584.881923061267, -9023.192235755456}, {
       2584.881923061267, -9023.192235433173}, {
       1335.9489340293353`, -9023.192235433173}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9489340293353`, -9023.192235755456}, 
       3.2228290057608795`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9489337070524`, -9023.192235916596}, \
{1335.9489340293353`, -9023.192235755456}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046740076}, {
        100.00029097223441`, -9045.381046740076}, {
        100.00029097223441`, -9023.192235916596}, {
        100, -9023.192235916596}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046740076}, {
       1335.9489340293355`, -9045.381046740076}, {
       1335.9489340293355`, -9023.192235916596}, {
       1335.867908374332, -9023.192235916596}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9045.381046740076}, {
       1601.2816681896652`, -9045.381046740076}, {
       1601.2816681896652`, -9023.192235916596}, {
       1601.281668187756, -9023.192235916596}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046740076}, {
       2668.84657043722, -9045.381046740076}, {
       2668.84657043722, -9023.192235916596}, {
       2648.884246253918, -9023.192235916596}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.381046740076}, {
       2584.8819731277167`, -9045.381046740076}, {
       2584.8819731277167`, -9023.192235916596}, {
       2584.88192338355, -9023.192235916596}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9045.381046740076}, {
       3136.0548108763173`, -9045.381046740076}, {
       3136.0548108763173`, -9023.192235916596}, {
       3136.0548108749413`, -9023.192235916596}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.301479041317, -9045.381046740076}, {
       3697.59354703049, -9045.381046740076}, {
       3697.59354703049, -9023.192235916596}, {
       3031.301479041317, -9023.192235916596}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968422, -9045.381046740076}, {
       4142.649334928727, -9045.381046740076}, {
       4142.649334928727, -9023.192235916596}, {
       4140.039650968422, -9023.192235916596}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046740076}, {
       4699.999999999998, -9045.381046740076}, {
       4699.999999999998, -9023.192235916596}, {
       4699.999999999998, -9023.192235916596}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0830801343297, -9045.381046740076}, {
      900.0432322151204, -9045.381046740076}, {
      900.0432322151204, -9023.192235916596}, {
      600.0830801343297, -9023.192235916596}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1324.7735029625924`, -9028.739438622466}, \
{1335.867908374332, -9023.192235916596}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1324.7735029625924`, -9028.739438622466}, 11.094405411739626`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1376376268599, -9039.833844034207}, {
       1324.7735029625924`, -9039.833844034207}, {
       1324.7735029625924`, -9028.739438622466}, {
       911.1376376268599, -9028.739438622466}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1376376268599, -9039.833844034207}, 11.094405411739626`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{900.0432322151204, -9045.381046740076}, \
{911.1376376268599, -9039.833844034207}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.38104674168}, {
        100.00029097223441`, -9045.38104674168}, {
        100.00029097223441`, -9045.381046740076}, {
        100, -9045.381046740076}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9045.38104674168}, {
       911.1376376268599, -9045.38104674168}, {
       911.1376376268599, -9045.381046740076}, {
       600.0830801343297, -9045.381046740076}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.38104674168}, {
       1335.9489340293355`, -9045.38104674168}, {
       1335.9489340293355`, -9045.381046740076}, {
       1335.867908374332, -9045.381046740076}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9045.38104674168}, {
       1601.2816681896652`, -9045.38104674168}, {
       1601.2816681896652`, -9045.381046740076}, {
       1601.281668187756, -9045.381046740076}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.38104674168}, {
       2668.84657043722, -9045.38104674168}, {
       2668.84657043722, -9045.381046740076}, {
       2648.884246253918, -9045.381046740076}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.38104674168}, {
       2584.8819731277167`, -9045.38104674168}, {
       2584.8819731277167`, -9045.381046740076}, {
       2584.88192338355, -9045.381046740076}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9045.38104674168}, {
       3136.0548108755156`, -9045.38104674168}, {
       3136.0548108755156`, -9045.381046740076}, {
       3136.0548108749413`, -9045.381046740076}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968422, -9045.38104674168}, {
       4142.649334928727, -9045.38104674168}, {
       4142.649334928727, -9045.381046740076}, {
       4140.039650968422, -9045.381046740076}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.38104674168}, {
       4699.999999999998, -9045.38104674168}, {
       4699.999999999998, -9045.381046740076}, {
       4699.999999999998, -9045.381046740076}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3031.301479041317, -9045.38104674168}, {
      3697.5935470304903`, -9045.38104674168}, {
      3697.5935470304903`, -9045.381046740076}, {
      3031.301479041317, -9045.381046740076}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108755156`, -9045.381046740478}, \
{3136.0548108763173`, -9045.381046740076}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108763173`, -9045.381046740478}, 
       8.018584130003337*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108763173`, -9045.38104674128}, {
       3031.3014790405155`, -9045.38104674128}, {
       3031.3014790405155`, -9045.381046740478}, {
       3136.0548108763173`, -9045.381046740478}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3031.3014790405155`, -9045.38104674128}, 
       8.018584130003337*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3031.3014790405155`, -9045.38104674168}, \
{3031.301479041317, -9045.38104674128}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046742645}, {
        100.00029097223441`, -9045.381046742645}, {
        100.00029097223441`, -9045.38104674168}, {
        100, -9045.38104674168}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9045.381046742645}, {
       911.1376376268599, -9045.381046742645}, {
       911.1376376268599, -9045.38104674168}, {
       600.0830801343297, -9045.38104674168}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046742645}, {
       1335.9489340293355`, -9045.381046742645}, {
       1335.9489340293355`, -9045.38104674168}, {
       1335.867908374332, -9045.38104674168}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668187756, -9045.381046742645}, {
       1601.2816681896652`, -9045.381046742645}, {
       1601.2816681896652`, -9045.38104674168}, {
       1601.281668187756, -9045.38104674168}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046742645}, {
       2668.84657043722, -9045.381046742645}, {
       2668.84657043722, -9045.38104674168}, {
       2648.884246253918, -9045.38104674168}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.381046742645}, {
       2584.8819731277167`, -9045.381046742645}, {
       2584.8819731277167`, -9045.38104674168}, {
       2584.88192338355, -9045.38104674168}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.3014790405155`, -9045.381046742645}, {
       3697.5935470304903`, -9045.381046742645}, {
       3697.5935470304903`, -9045.38104674168}, {
       3031.3014790405155`, -9045.38104674168}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9045.381046742645}, {
       4142.649334928727, -9045.381046742645}, {
       4142.649334928727, -9045.38104674168}, {
       4140.039650968904, -9045.38104674168}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046742645}, {
       4699.999999999998, -9045.381046742645}, {
       4699.999999999998, -9045.38104674168}, {
       4699.999999999998, -9045.38104674168}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9045.381046742645}, {
      3136.0548108755156`, -9045.381046742645}, {
      3136.0548108755156`, -9045.38104674168}, {
      3136.0548108749413`, -9045.38104674168}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.039650968422, -9045.381046741923}, \
{4140.039650968904, -9045.38104674168}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.039650968422, -9045.381046741923}, 4.816567184615781*^-10,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810875997, -9045.381046742405}, {
       4140.039650968422, -9045.381046742405}, {
       4140.039650968422, -9045.381046741923}, {
       3136.054810875997, -9045.381046741923}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810875997, -9045.381046742405}, 4.816567184615781*^-10,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108755156`, -9045.381046742645}, \
{3136.054810875997, -9045.381046742405}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046742878}, {
        100.00029097223441`, -9045.381046742878}, {
        100.00029097223441`, -9045.381046742645}, {
        100, -9045.381046742645}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9045.381046742878}, {
       911.1376376267434, -9045.381046742878}, {
       911.1376376267434, -9045.381046742645}, {
       600.0830801343297, -9045.381046742645}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046742878}, {
       1335.9489340293355`, -9045.381046742878}, {
       1335.9489340293355`, -9045.381046742645}, {
       1335.867908374332, -9045.381046742645}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046742878}, {
       2668.84657043722, -9045.381046742878}, {
       2668.84657043722, -9045.381046742645}, {
       2648.884246253918, -9045.381046742645}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.381046742878}, {
       2584.8819731277167`, -9045.381046742878}, {
       2584.8819731277167`, -9045.381046742645}, {
       2584.88192338355, -9045.381046742645}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9045.381046742878}, {
       3136.054810875997, -9045.381046742878}, {
       3136.054810875997, -9045.381046742645}, {
       3136.0548108749413`, -9045.381046742645}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.3014790405155`, -9045.381046742878}, {
       3697.5935470304903`, -9045.381046742878}, {
       3697.5935470304903`, -9045.381046742645}, {
       3031.3014790405155`, -9045.381046742645}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9045.381046742878}, {
       4142.649334928727, -9045.381046742878}, {
       4142.649334928727, -9045.381046742645}, {
       4140.039650968904, -9045.381046742645}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742645}, {
       4699.999999999998, -9045.381046742645}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668187756, -9045.381046742878}, {
      1601.2816681896652`, -9045.381046742878}, {
      1601.2816681896652`, -9045.381046742645}, {
      1601.281668187756, -9045.381046742645}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1376376267434, -9045.381046742703}, \
{911.1376376268599, -9045.381046742645}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1376376268599, -9045.381046742703}, 
       1.1660475041386375`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1376376268599, -9045.38104674282}, {
       1601.2816681876393`, -9045.38104674282}, {
       1601.2816681876393`, -9045.381046742703}, {
       911.1376376268599, -9045.381046742703}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681876393`, -9045.38104674282}, 
       1.1660475041386375`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681876393`, -9045.381046742878}, \
{1601.281668187756, -9045.38104674282}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046742878}, {
        100.00029097223441`, -9045.381046742878}, {
        100.00029097223441`, -9045.381046742878}, {
        100, -9045.381046742878}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9045.381046742878}, {
       911.1376376267434, -9045.381046742878}, {
       911.1376376267434, -9045.381046742878}, {
       600.0830801343297, -9045.381046742878}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046742878}, {
       1335.9489340293355`, -9045.381046742878}, {
       1335.9489340293355`, -9045.381046742878}, {
       1335.867908374332, -9045.381046742878}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681876393`, -9045.381046742878}, {
       1601.2816681896652`, -9045.381046742878}, {
       1601.2816681896652`, -9045.381046742878}, {
       1601.2816681876393`, -9045.381046742878}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046742878}, {
       2668.84657043722, -9045.381046742878}, {
       2668.84657043722, -9045.381046742878}, {
       2648.884246253918, -9045.381046742878}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.381046742878}, {
       2584.8819731277167`, -9045.381046742878}, {
       2584.8819731277167`, -9045.381046742878}, {
       2584.88192338355, -9045.381046742878}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.3014790405155`, -9045.381046742878}, {
       3697.5935470304903`, -9045.381046742878}, {
       3697.5935470304903`, -9045.381046742878}, {
       3031.3014790405155`, -9045.381046742878}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9045.381046742878}, {
       4142.649334928727, -9045.381046742878}, {
       4142.649334928727, -9045.381046742878}, {
       4140.039650968904, -9045.381046742878}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9045.381046742878}, {
      3136.054810875997, -9045.381046742878}, {
      3136.054810875997, -9045.381046742878}, {
      3136.0548108749413`, -9045.381046742878}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9045.381046742878}, \
{4699.999999999998, -9045.381046742878}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9045.381046742878}, 6.267307929319312*^-14,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810875997, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}, {
       3136.054810875997, -9045.381046742878}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810875997, -9045.381046742878}, 6.267307929319312*^-14,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810875997, -9045.381046742878}, \
{3136.054810875997, -9045.381046742878}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046743947}, {
        100.00029097223441`, -9045.381046743947}, {
        100.00029097223441`, -9045.381046742878}, {
        100, -9045.381046742878}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046743947}, {
       1335.9489340293355`, -9045.381046743947}, {
       1335.9489340293355`, -9045.381046742878}, {
       1335.867908374332, -9045.381046742878}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9045.381046743947}, {
       1601.2816681896652`, -9045.381046743947}, {
       1601.2816681896652`, -9045.381046742878}, {
       1601.2816681881743`, -9045.381046742878}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046743947}, {
       2668.84657043722, -9045.381046743947}, {
       2668.84657043722, -9045.381046742878}, {
       2648.884246253918, -9045.381046742878}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9045.381046743947}, {
       2584.8819731277167`, -9045.381046743947}, {
       2584.8819731277167`, -9045.381046742878}, {
       2584.88192338355, -9045.381046742878}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9045.381046743947}, {
       3136.054810875997, -9045.381046743947}, {
       3136.054810875997, -9045.381046742878}, {
       3136.0548108749413`, -9045.381046742878}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.3014790405155`, -9045.381046743947}, {
       3697.5935470304903`, -9045.381046743947}, {
       3697.5935470304903`, -9045.381046742878}, {
       3031.3014790405155`, -9045.381046742878}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9045.381046743947}, {
       4142.649334928727, -9045.381046743947}, {
       4142.649334928727, -9045.381046742878}, {
       4140.039650968904, -9045.381046742878}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046742878}, {
       4699.999999999998, -9045.381046742878}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0830801343297, -9045.381046743947}, {
      911.1376376267434, -9045.381046743947}, {
      911.1376376267434, -9045.381046742878}, {
      600.0830801343297, -9045.381046742878}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681876393`, -9045.381046743145}, \
{1601.2816681881743`, -9045.381046742878}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681876393`, -9045.381046743145}, 
       5.350005054069968*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1376376272784, -9045.38104674368}, {
       1601.2816681876393`, -9045.38104674368}, {
       1601.2816681876393`, -9045.381046743145}, {
       911.1376376272784, -9045.381046743145}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1376376272784, -9045.38104674368}, 5.350005054069968*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1376376267434, -9045.381046743947}, \
{911.1376376272784, -9045.38104674368}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9045.381046743947}, {
        100.00029097223441`, -9045.381046743947}, {
        100.00029097223441`, -9045.381046743947}, {
        100, -9045.381046743947}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9045.381046743947}, {
       911.1376376272784, -9045.381046743947}, {
       911.1376376272784, -9045.381046743947}, {
       600.0830801343297, -9045.381046743947}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9045.381046743947}, {
       1335.9489340293355`, -9045.381046743947}, {
       1335.9489340293355`, -9045.381046743947}, {
       1335.867908374332, -9045.381046743947}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9045.381046743947}, {
       1601.2816681896652`, -9045.381046743947}, {
       1601.2816681896652`, -9045.381046743947}, {
       1601.2816681881743`, -9045.381046743947}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9045.381046743947}, {
       2668.84657043722, -9045.381046743947}, {
       2668.84657043722, -9045.381046743947}, {
       2648.884246253918, -9045.381046743947}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9045.381046743947}, {
       3136.054810875997, -9045.381046743947}, {
       3136.054810875997, -9045.381046743947}, {
       3136.0548108749413`, -9045.381046743947}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3031.3014790405155`, -9045.381046743947}, {
       3697.5935470304903`, -9045.381046743947}, {
       3697.5935470304903`, -9045.381046743947}, {
       3031.3014790405155`, -9045.381046743947}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9045.381046743947}, {
       4142.649334928727, -9045.381046743947}, {
       4142.649334928727, -9045.381046743947}, {
       4140.039650968904, -9045.381046743947}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88192338355, -9045.381046743947}, {
      2584.8819731277167`, -9045.381046743947}, {
      2584.8819731277167`, -9045.381046743947}, {
      2584.88192338355, -9045.381046743947}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9045.381046743947}, \
{4699.999999999998, -9045.381046743947}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9045.381046743947}, 
       3.1664280001328886`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.881973127717, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}, {
       2584.881973127717, -9045.381046743947}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881973127717, -9045.381046743947}, 
       3.1664280001328886`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819731277167`, -9045.381046743947}, \
{2584.881973127717, -9045.381046743947}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9074.63114295808}, {
        100.00029097223441`, -9074.63114295808}, {
        100.00029097223441`, -9045.381046743947}, {
        100, -9045.381046743947}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9074.63114295808}, {
       911.1376376272784, -9074.63114295808}, {
       911.1376376272784, -9045.381046743947}, {
       600.0830801343297, -9045.381046743947}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9074.63114295808}, {
       1335.9489340293355`, -9074.63114295808}, {
       1335.9489340293355`, -9045.381046743947}, {
       1335.867908374332, -9045.381046743947}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9074.63114295808}, {
       1601.2816681896652`, -9074.63114295808}, {
       1601.2816681896652`, -9045.381046743947}, {
       1601.2816681881743`, -9045.381046743947}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9074.63114295808}, {
       2654.2215223301537`, -9074.63114295808}, {
       2654.2215223301537`, -9045.381046743947}, {
       2648.884246253918, -9045.381046743947}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9074.63114295808}, {
       2584.881973127717, -9074.63114295808}, {
       2584.881973127717, -9045.381046743947}, {
       2584.88192338355, -9045.381046743947}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9074.63114295808}, {
       3136.054810875997, -9074.63114295808}, {
       3136.054810875997, -9045.381046743947}, {
       3136.0548108749413`, -9045.381046743947}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650968904, -9074.63114295808}, {
       4142.649334928727, -9074.63114295808}, {
       4142.649334928727, -9045.381046743947}, {
       4140.039650968904, -9045.381046743947}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9074.63114295808}, {
       4699.999999999998, -9074.63114295808}, {
       4699.999999999998, -9045.381046743947}, {
       4699.999999999998, -9045.381046743947}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3031.3014790405155`, -9074.63114295808}, {
      3697.5935470304903`, -9074.63114295808}, {
      3697.5935470304903`, -9045.381046743947}, {
      3031.3014790405155`, -9045.381046743947}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2654.2215223301537`, -9052.69357079748}, \
{2668.84657043722, -9045.381046743947}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2668.84657043722, -9052.69357079748}, 14.625048107066256`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2668.84657043722, -9067.318618904546}, {
       3016.6764309334494`, -9067.318618904546}, {
       3016.6764309334494`, -9052.69357079748}, {
       2668.84657043722, -9052.69357079748}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3016.6764309334494`, -9067.318618904546}, 
       14.625048107066256`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3016.6764309334494`, -9074.63114295808}, \
{3031.3014790405155`, -9067.318618904546}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9074.631142958408}, {
        100.00029097223441`, -9074.631142958408}, {
        100.00029097223441`, -9074.63114295808}, {
        100, -9074.63114295808}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9074.631142958408}, {
       911.1376376272784, -9074.631142958408}, {
       911.1376376272784, -9074.63114295808}, {
       600.0830801343297, -9074.63114295808}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9074.631142958408}, {
       1335.9489340293355`, -9074.631142958408}, {
       1335.9489340293355`, -9074.63114295808}, {
       1335.867908374332, -9074.63114295808}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9074.631142958408}, {
       1601.2816681896652`, -9074.631142958408}, {
       1601.2816681896652`, -9074.63114295808}, {
       1601.2816681881743`, -9074.63114295808}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9074.631142958408}, {
       2654.2215223301537`, -9074.631142958408}, {
       2654.2215223301537`, -9074.63114295808}, {
       2648.884246253918, -9074.63114295808}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9074.631142958408}, {
       2584.881973127717, -9074.631142958408}, {
       2584.881973127717, -9074.63114295808}, {
       2584.88192338355, -9074.63114295808}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764309334494`, -9074.631142958408}, {
       3697.5935470304903`, -9074.631142958408}, {
       3697.5935470304903`, -9074.63114295808}, {
       3016.6764309334494`, -9074.63114295808}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650969068, -9074.631142958408}, {
       4142.649334928727, -9074.631142958408}, {
       4142.649334928727, -9074.63114295808}, {
       4140.039650969068, -9074.63114295808}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9074.631142958408}, {
       4699.999999999998, -9074.631142958408}, {
       4699.999999999998, -9074.63114295808}, {
       4699.999999999998, -9074.63114295808}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9074.631142958408}, {
      3136.054810875997, -9074.631142958408}, {
      3136.054810875997, -9074.63114295808}, {
      3136.0548108749413`, -9074.63114295808}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.039650968904, -9074.631142958162}, \
{4140.039650969068, -9074.63114295808}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.039650968904, -9074.631142958162}, 
       1.6400625226352885`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108761614`, -9074.631142958326}, {
       4140.039650968904, -9074.631142958326}, {
       4140.039650968904, -9074.631142958162}, {
       3136.0548108761614`, -9074.631142958162}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108761614`, -9074.631142958326}, 
       1.6400625226352885`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810875997, -9074.631142958408}, \
{3136.0548108761614`, -9074.631142958326}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9074.631147659107}, {
        100.00029097223441`, -9074.631147659107}, {
        100.00029097223441`, -9074.631142958408}, {
        100, -9074.631142958408}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9074.631147659107}, {
       911.1376376272784, -9074.631147659107}, {
       911.1376376272784, -9074.631142958408}, {
       600.0830801343297, -9074.631142958408}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9074.631147659107}, {
       1335.9489340293355`, -9074.631147659107}, {
       1335.9489340293355`, -9074.631142958408}, {
       1335.867908374332, -9074.631142958408}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9074.631147659107}, {
       1601.2816681896652`, -9074.631147659107}, {
       1601.2816681896652`, -9074.631142958408}, {
       1601.2816681881743`, -9074.631142958408}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9074.631147659107}, {
       2654.2215223301537`, -9074.631147659107}, {
       2654.2215223301537`, -9074.631142958408}, {
       2648.884246253918, -9074.631142958408}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9074.631147659107}, {
       3136.0548108761614`, -9074.631147659107}, {
       3136.0548108761614`, -9074.631142958408}, {
       3136.0548108749413`, -9074.631142958408}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332837993`, -9074.631147659107}, {
       3697.5935470304903`, -9074.631147659107}, {
       3697.5935470304903`, -9074.631142958408}, {
       3016.6764332837993`, -9074.631142958408}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.039650969068, -9074.631147659107}, {
       4142.649334928727, -9074.631147659107}, {
       4142.649334928727, -9074.631142958408}, {
       4140.039650969068, -9074.631142958408}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9074.631147659107}, {
       4699.999999999998, -9074.631147659107}, {
       4699.999999999998, -9074.631142958408}, {
       4699.999999999998, -9074.631142958408}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88192338355, -9074.631147659107}, {
      2584.881973127717, -9074.631147659107}, {
      2584.881973127717, -9074.631142958408}, {
      2584.88192338355, -9074.631142958408}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3016.6764309334494`, -9074.631144133582}, \
{3016.6764332837993`, -9074.631142958408}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3016.6764309334494`, -9074.631144133582}, 
       2.3503500497482646`*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.881975478067, -9074.631146483933}, {
       3016.6764309334494`, -9074.631146483933}, {
       3016.6764309334494`, -9074.631144133582}, {
       2584.881975478067, -9074.631144133582}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881975478067, -9074.631146483933}, 
       2.3503500497482646`*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881973127717, -9074.631147659107}, \
{2584.881975478067, -9074.631146483933}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.14889028862}, {
        100.00029097223441`, -9076.14889028862}, {
        100.00029097223441`, -9074.631147659107}, {
        100, -9074.631147659107}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9076.14889028862}, {
       911.1376376272784, -9076.14889028862}, {
       911.1376376272784, -9074.631147659107}, {
       600.0830801343297, -9074.631147659107}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9076.14889028862}, {
       1335.9489340293355`, -9076.14889028862}, {
       1335.9489340293355`, -9074.631147659107}, {
       1335.867908374332, -9074.631147659107}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.14889028862}, {
       1601.2816681896652`, -9076.14889028862}, {
       1601.2816681896652`, -9074.631147659107}, {
       1601.2816681881743`, -9074.631147659107}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.14889028862}, {
       2654.2215223301537`, -9076.14889028862}, {
       2654.2215223301537`, -9074.631147659107}, {
       2648.884246253918, -9074.631147659107}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.14889028862}, {
       2584.881975478067, -9076.14889028862}, {
       2584.881975478067, -9074.631147659107}, {
       2584.88192338355, -9074.631147659107}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.14889028862}, {
       3136.0548108761614`, -9076.14889028862}, {
       3136.0548108761614`, -9074.631147659107}, {
       3136.0548108749413`, -9074.631147659107}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.14889028862}, {
       4142.649334928727, -9076.14889028862}, {
       4142.649334928727, -9074.631147659107}, {
       4140.798522283824, -9074.631147659107}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9074.631147659107}, {
       4699.999999999998, -9074.631147659107}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3016.6764332837993`, -9076.14889028862}, {
      3697.5935470304903`, -9076.14889028862}, {
      3697.5935470304903`, -9074.631147659107}, {
      3016.6764332837993`, -9074.631147659107}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.039650969068, -9075.010583316485}, \
{4140.798522283824, -9074.631147659107}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.039650969068, -9075.010583316485}, 0.7588713147562571, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3698.3524183452464`, -9075.769454631241}, {
       4140.039650969068, -9075.769454631241}, {
       4140.039650969068, -9075.010583316485}, {
       3698.3524183452464`, -9075.010583316485}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3698.3524183452464`, -9075.769454631241}, 0.7588713147562571, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3697.5935470304903`, -9076.14889028862}, \
{3698.3524183452464`, -9075.769454631241}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.14889028862}, {
        100.00029097223441`, -9076.14889028862}, {
        100.00029097223441`, -9076.14889028862}, {
        100, -9076.14889028862}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9076.14889028862}, {
       911.1376376272784, -9076.14889028862}, {
       911.1376376272784, -9076.14889028862}, {
       600.0830801343297, -9076.14889028862}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.867908374332, -9076.14889028862}, {
       1335.9489340293355`, -9076.14889028862}, {
       1335.9489340293355`, -9076.14889028862}, {
       1335.867908374332, -9076.14889028862}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.14889028862}, {
       1601.2816681896652`, -9076.14889028862}, {
       1601.2816681896652`, -9076.14889028862}, {
       1601.2816681881743`, -9076.14889028862}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.14889028862}, {
       2654.2215223301537`, -9076.14889028862}, {
       2654.2215223301537`, -9076.14889028862}, {
       2648.884246253918, -9076.14889028862}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.14889028862}, {
       3136.0548108761614`, -9076.14889028862}, {
       3136.0548108761614`, -9076.14889028862}, {
       3136.0548108749413`, -9076.14889028862}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332837993`, -9076.14889028862}, {
       3698.3524183452464`, -9076.14889028862}, {
       3698.3524183452464`, -9076.14889028862}, {
       3016.6764332837993`, -9076.14889028862}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.14889028862}, {
       4142.649334928727, -9076.14889028862}, {
       4142.649334928727, -9076.14889028862}, {
       4140.798522283824, -9076.14889028862}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.88192338355, -9076.14889028862}, {
      2584.881975478067, -9076.14889028862}, {
      2584.881975478067, -9076.14889028862}, {
      2584.88192338355, -9076.14889028862}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9076.14889028862}, \
{4699.999999999998, -9076.14889028862}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9076.14889028862}, 
       2.1439999208390963`*^-14, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.881975478067, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}, {
       2584.881975478067, -9076.14889028862}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881975478067, -9076.14889028862}, 
       2.1439999208390963`*^-14, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881975478067, -9076.14889028862}, \
{2584.881975478067, -9076.14889028862}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206384120846}, {
        100.00029097223441`, -9076.206384120846}, {
        100.00029097223441`, -9076.14889028862}, {
        100, -9076.14889028862}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206384120846}, {
       1335.9489340293353`, -9076.206384120846}, {
       1335.9489340293353`, -9076.14889028862}, {
       1335.8966552904453`, -9076.14889028862}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206384120846}, {
       1601.2816681896652`, -9076.206384120846}, {
       1601.2816681896652`, -9076.14889028862}, {
       1601.2816681881743`, -9076.14889028862}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.206384120846}, {
       2654.2215223301537`, -9076.206384120846}, {
       2654.2215223301537`, -9076.14889028862}, {
       2648.884246253918, -9076.14889028862}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206384120846}, {
       2584.881975478067, -9076.206384120846}, {
       2584.881975478067, -9076.14889028862}, {
       2584.88192338355, -9076.14889028862}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.206384120846}, {
       3136.0548108761614`, -9076.206384120846}, {
       3136.0548108761614`, -9076.14889028862}, {
       3136.0548108749413`, -9076.14889028862}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332837993`, -9076.206384120846}, {
       3698.3524183452464`, -9076.206384120846}, {
       3698.3524183452464`, -9076.14889028862}, {
       3016.6764332837993`, -9076.14889028862}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206384120846}, {
       4142.649334928727, -9076.206384120846}, {
       4142.649334928727, -9076.14889028862}, {
       4140.798522283824, -9076.14889028862}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.206384120846}, {
       4699.999999999998, -9076.206384120846}, {
       4699.999999999998, -9076.14889028862}, {
       4699.999999999998, -9076.14889028862}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0830801343297, -9076.206384120846}, {
      911.1376376272784, -9076.206384120846}, {
      911.1376376272784, -9076.14889028862}, {
      600.0830801343297, -9076.14889028862}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.867908374332, -9076.163263746676}, \
{1335.8966552904453`, -9076.14889028862}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.867908374332, -9076.163263746676}, 0.028746916113309873`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1663845433918, -9076.19201066279}, {
       1335.867908374332, -9076.19201066279}, {
       1335.867908374332, -9076.163263746676}, {
       911.1663845433918, -9076.163263746676}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1663845433918, -9076.19201066279}, 0.028746916113309873`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1376376272784, -9076.206384120846}, \
{911.1663845433918, -9076.19201066279}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206384122968}, {
        100.00029097223441`, -9076.206384122968}, {
        100.00029097223441`, -9076.206384120846}, {
        100, -9076.206384120846}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0830801343297, -9076.206384122968}, {
       911.1663845433918, -9076.206384122968}, {
       911.1663845433918, -9076.206384120846}, {
       600.0830801343297, -9076.206384120846}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206384122968}, {
       1335.9489340293353`, -9076.206384122968}, {
       1335.9489340293353`, -9076.206384120846}, {
       1335.8966552904453`, -9076.206384120846}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206384122968}, {
       1601.2816681896652`, -9076.206384122968}, {
       1601.2816681896652`, -9076.206384120846}, {
       1601.2816681881743`, -9076.206384120846}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.206384122968}, {
       2654.2215223301537`, -9076.206384122968}, {
       2654.2215223301537`, -9076.206384120846}, {
       2648.884246253918, -9076.206384120846}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206384122968}, {
       2584.881975478067, -9076.206384122968}, {
       2584.881975478067, -9076.206384120846}, {
       2584.88192338355, -9076.206384120846}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332848607`, -9076.206384122968}, {
       3698.3524183452464`, -9076.206384122968}, {
       3698.3524183452464`, -9076.206384120846}, {
       3016.6764332848607`, -9076.206384120846}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206384122968}, {
       4142.649334928727, -9076.206384122968}, {
       4142.649334928727, -9076.206384120846}, {
       4140.798522283824, -9076.206384120846}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.206384122968}, {
       4699.999999999998, -9076.206384122968}, {
       4699.999999999998, -9076.206384120846}, {
       4699.999999999998, -9076.206384120846}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9076.206384122968}, {
      3136.0548108761614`, -9076.206384122968}, {
      3136.0548108761614`, -9076.206384120846}, {
      3136.0548108749413`, -9076.206384120846}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3016.6764332837993`, -9076.206384121377}, \
{3016.6764332848607`, -9076.206384120846}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3016.6764332837993`, -9076.206384121377}, 
       1.0612432837173191`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108772227`, -9076.206384122437}, {
       3016.6764332837993`, -9076.206384122437}, {
       3016.6764332837993`, -9076.206384121377}, {
       3136.0548108772227`, -9076.206384121377}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108772227`, -9076.206384122437}, 
       1.0612432837173191`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108761614`, -9076.206384122968}, \
{3136.0548108772227`, -9076.206384122437}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206760203147}, {
        100.000102932145, -9076.206760203147}, {
        100.000102932145, -9076.206384122968}, {100, -9076.206384122968}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206760203147}, {
       1335.9489340293353`, -9076.206760203147}, {
       1335.9489340293353`, -9076.206384122968}, {
       1335.8966552904453`, -9076.206384122968}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206760203147}, {
       1601.2816681896652`, -9076.206760203147}, {
       1601.2816681896652`, -9076.206384122968}, {
       1601.2816681881743`, -9076.206384122968}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.206760203147}, {
       2654.2215223301537`, -9076.206760203147}, {
       2654.2215223301537`, -9076.206384122968}, {
       2648.884246253918, -9076.206384122968}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206760203147}, {
       2584.881975478067, -9076.206760203147}, {
       2584.881975478067, -9076.206384122968}, {
       2584.88192338355, -9076.206384122968}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.206760203147}, {
       3136.0548108772227`, -9076.206760203147}, {
       3136.0548108772227`, -9076.206384122968}, {
       3136.0548108749413`, -9076.206384122968}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332848607`, -9076.206760203147}, {
       3698.3524183452464`, -9076.206760203147}, {
       3698.3524183452464`, -9076.206384122968}, {
       3016.6764332848607`, -9076.206384122968}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206760203147}, {
       4142.649334928727, -9076.206760203147}, {
       4142.649334928727, -9076.206384122968}, {
       4140.798522283824, -9076.206384122968}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206384122968}, {
       4699.999999999998, -9076.206384122968}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0830801343297, -9076.206760203147}, {
      911.1663845433918, -9076.206760203147}, {
      911.1663845433918, -9076.206384122968}, {
      600.0830801343297, -9076.206384122968}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.000102932145, -9076.206478143013}, \
{100.00029097223441`, -9076.206384122968}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00029097223441`, -9076.206478143013}, 
       0.00018804008941041142`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00029097223441`, -9076.206666183103}, {
       600.0828920942404, -9076.206666183103}, {
       600.0828920942404, -9076.206478143013}, {
       100.00029097223441`, -9076.206478143013}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0828920942404, -9076.206666183103}, 
       0.00018804008941041142`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0828920942404, -9076.206760203147}, \
{600.0830801343297, -9076.206666183103}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206760203147}, {
        100.000102932145, -9076.206760203147}, {
        100.000102932145, -9076.206760203147}, {100, -9076.206760203147}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.206760203147}, {
       911.1663845433918, -9076.206760203147}, {
       911.1663845433918, -9076.206760203147}, {
       600.0828920942404, -9076.206760203147}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206760203147}, {
       1335.9489340293353`, -9076.206760203147}, {
       1335.9489340293353`, -9076.206760203147}, {
       1335.8966552904453`, -9076.206760203147}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206760203147}, {
       1601.2816681896652`, -9076.206760203147}, {
       1601.2816681896652`, -9076.206760203147}, {
       1601.2816681881743`, -9076.206760203147}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206760203147}, {
       2584.881975478067, -9076.206760203147}, {
       2584.881975478067, -9076.206760203147}, {
       2584.88192338355, -9076.206760203147}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.206760203147}, {
       3136.0548108772227`, -9076.206760203147}, {
       3136.0548108772227`, -9076.206760203147}, {
       3136.0548108749413`, -9076.206760203147}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332848607`, -9076.206760203147}, {
       3698.3524183452464`, -9076.206760203147}, {
       3698.3524183452464`, -9076.206760203147}, {
       3016.6764332848607`, -9076.206760203147}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206760203147}, {
       4142.649334928727, -9076.206760203147}, {
       4142.649334928727, -9076.206760203147}, {
       4140.798522283824, -9076.206760203147}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.884246253918, -9076.206760203147}, {
      2654.2215223301537`, -9076.206760203147}, {
      2654.2215223301537`, -9076.206760203147}, {
      2648.884246253918, -9076.206760203147}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9076.206760203147}, \
{4699.999999999998, -9076.206760203147}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9076.206760203147}, 
       5.4447949368145715`*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2654.221522330154, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}, {
       2654.221522330154, -9076.206760203147}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2654.221522330154, -9076.206760203147}, 
       5.4447949368145715`*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2654.2215223301537`, -9076.206760203147}, \
{2654.221522330154, -9076.206760203147}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206760206695}, {
        100.000102932145, -9076.206760206695}, {
        100.000102932145, -9076.206760203147}, {100, -9076.206760203147}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.206760206695}, {
       911.1663845433918, -9076.206760206695}, {
       911.1663845433918, -9076.206760203147}, {
       600.0828920942404, -9076.206760203147}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206760206695}, {
       1335.9489340293353`, -9076.206760206695}, {
       1335.9489340293353`, -9076.206760203147}, {
       1335.8966552904453`, -9076.206760203147}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206760206695}, {
       1601.2816681896652`, -9076.206760206695}, {
       1601.2816681896652`, -9076.206760203147}, {
       1601.2816681881743`, -9076.206760203147}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.206760206695}, {
       2654.221522330154, -9076.206760206695}, {
       2654.221522330154, -9076.206760203147}, {
       2648.884246253918, -9076.206760203147}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206760206695}, {
       2584.881975478067, -9076.206760206695}, {
       2584.881975478067, -9076.206760203147}, {
       2584.88192338355, -9076.206760203147}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.206760206695}, {
       3698.3524183452464`, -9076.206760206695}, {
       3698.3524183452464`, -9076.206760203147}, {
       3016.6764332866337`, -9076.206760203147}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206760206695}, {
       4142.649334928727, -9076.206760206695}, {
       4142.649334928727, -9076.206760203147}, {
       4140.798522283824, -9076.206760203147}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.206760206695}, {
       4699.999999999998, -9076.206760206695}, {
       4699.999999999998, -9076.206760203147}, {
       4699.999999999998, -9076.206760203147}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9076.206760206695}, {
      3136.0548108772227`, -9076.206760206695}, {
      3136.0548108772227`, -9076.206760203147}, {
      3136.0548108749413`, -9076.206760203147}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3016.6764332848607`, -9076.206760204035}, \
{3016.6764332866337`, -9076.206760203147}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3016.6764332848607`, -9076.206760204035}, 
       1.7732181148282845`*^-9, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810878996, -9076.206760205809}, {
       3016.6764332848607`, -9076.206760205809}, {
       3016.6764332848607`, -9076.206760204035}, {
       3136.054810878996, -9076.206760204035}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810878996, -9076.206760205809}, 
       1.7732181148282845`*^-9, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108772227`, -9076.206760206695}, \
{3136.054810878996, -9076.206760205809}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.206760206695}, {
        100.000102932145, -9076.206760206695}, {
        100.000102932145, -9076.206760206695}, {100, -9076.206760206695}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.206760206695}, {
       911.1663845433918, -9076.206760206695}, {
       911.1663845433918, -9076.206760206695}, {
       600.0828920942404, -9076.206760206695}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.206760206695}, {
       1335.9489340293353`, -9076.206760206695}, {
       1335.9489340293353`, -9076.206760206695}, {
       1335.8966552904453`, -9076.206760206695}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.206760206695}, {
       1601.2816681896652`, -9076.206760206695}, {
       1601.2816681896652`, -9076.206760206695}, {
       1601.2816681881743`, -9076.206760206695}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.206760206695}, {
       2654.221522330154, -9076.206760206695}, {
       2654.221522330154, -9076.206760206695}, {
       2648.884246253918, -9076.206760206695}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.206760206695}, {
       2584.881975478067, -9076.206760206695}, {
       2584.881975478067, -9076.206760206695}, {
       2584.88192338355, -9076.206760206695}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.206760206695}, {
       3136.054810878996, -9076.206760206695}, {
       3136.054810878996, -9076.206760206695}, {
       3136.0548108749413`, -9076.206760206695}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.206760206695}, {
       3698.3524183452464`, -9076.206760206695}, {
       3698.3524183452464`, -9076.206760206695}, {
       3016.6764332866337`, -9076.206760206695}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.798522283824, -9076.206760206695}, {
       4142.649334928727, -9076.206760206695}, {
       4142.649334928727, -9076.206760206695}, {
       4140.798522283824, -9076.206760206695}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9076.206760206695}, {
      4699.999999999998, -9076.206760206695}, {
      4699.999999999998, -9076.206760206695}, {
      4699.999999999998, -9076.206760206695}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810878996, -9076.206760206695}, \
{3136.054810878996, -9076.206760206695}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810878996, -9076.206760206695}, 
       1.3452719546044812`*^-14, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810878996, -9076.206760206695}, {
       4699.999999999998, -9076.206760206695}, {
       4699.999999999998, -9076.206760206695}, {
       3136.054810878996, -9076.206760206695}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9076.206760206695}, 
       1.3452719546044812`*^-14, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9076.206760206695}, \
{4699.999999999998, -9076.206760206695}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.267267028521}, {
        100.000102932145, -9076.267267028521}, {
        100.000102932145, -9076.206760206695}, {100, -9076.206760206695}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.267267028521}, {
       911.1663845433918, -9076.267267028521}, {
       911.1663845433918, -9076.206760206695}, {
       600.0828920942404, -9076.206760206695}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.267267028521}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.9186806184225`, -9076.206760206695}, {
       1335.8966552904453`, -9076.206760206695}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.267267028521}, {
       1601.2816681896652`, -9076.267267028521}, {
       1601.2816681896652`, -9076.206760206695}, {
       1601.2816681881743`, -9076.206760206695}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.267267028521}, {
       2654.221522330154, -9076.267267028521}, {
       2654.221522330154, -9076.206760206695}, {
       2648.884246253918, -9076.206760206695}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.267267028521}, {
       2584.881975478067, -9076.267267028521}, {
       2584.881975478067, -9076.206760206695}, {
       2584.88192338355, -9076.206760206695}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.267267028521}, {
       3136.054810878996, -9076.267267028521}, {
       3136.054810878996, -9076.206760206695}, {
       3136.0548108749413`, -9076.206760206695}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.267267028521}, {
       3698.3524183452464`, -9076.267267028521}, {
       3698.3524183452464`, -9076.206760206695}, {
       3016.6764332866337`, -9076.206760206695}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.206760206695}, {
       4699.999999999998, -9076.206760206695}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4140.798522283824, -9076.267267028521}, {
      4142.649334928726, -9076.267267028521}, {
      4142.649334928726, -9076.206760206695}, {
      4140.798522283824, -9076.206760206695}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9186806184225`, -9076.221886912152}, \
{1335.9489340293353`, -9076.206760206695}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9489340293353`, -9076.221886912152}, 
       0.030253410912972803`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9489340293353`, -9076.252140323064}, {
       4140.768268872911, -9076.252140323064}, {
       4140.768268872911, -9076.221886912152}, {
       1335.9489340293353`, -9076.221886912152}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4140.768268872911, -9076.252140323064}, 
       0.030253410912972803`, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4140.768268872911, -9076.267267028521}, \
{4140.798522283824, -9076.252140323064}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.267267028521}, {
        100.000102932145, -9076.267267028521}, {
        100.000102932145, -9076.267267028521}, {100, -9076.267267028521}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.267267028521}, {
       911.1663845433918, -9076.267267028521}, {
       911.1663845433918, -9076.267267028521}, {
       600.0828920942404, -9076.267267028521}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.267267028521}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.8966552904453`, -9076.267267028521}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.267267028521}, {
       1601.2816681896652`, -9076.267267028521}, {
       1601.2816681896652`, -9076.267267028521}, {
       1601.2816681881743`, -9076.267267028521}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.267267028521}, {
       2654.221522330154, -9076.267267028521}, {
       2654.221522330154, -9076.267267028521}, {
       2648.884246253918, -9076.267267028521}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.267267028521}, {
       2584.881975478067, -9076.267267028521}, {
       2584.881975478067, -9076.267267028521}, {
       2584.88192338355, -9076.267267028521}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.267267028521}, {
       3136.054810878996, -9076.267267028521}, {
       3136.054810878996, -9076.267267028521}, {
       3136.0548108749413`, -9076.267267028521}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.267267028521}, {
       3698.3524183452464`, -9076.267267028521}, {
       3698.3524183452464`, -9076.267267028521}, {
       3016.6764332866337`, -9076.267267028521}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.768268872911, -9076.267267028521}, {
       4142.649334928726, -9076.267267028521}, {
       4142.649334928726, -9076.267267028521}, {
       4140.768268872911, -9076.267267028521}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9076.267267028521}, {
      4699.999999999998, -9076.267267028521}, {
      4699.999999999998, -9076.267267028521}, {
      4699.999999999998, -9076.267267028521}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681896652`, -9076.267267028521}, \
{1601.2816681896652`, -9076.267267028521}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681896652`, -9076.267267028521}, 
       1.5382225434856437`*^-14, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681896652`, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       1601.2816681896652`, -9076.267267028521}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9076.267267028521}, 
       1.5382225434856437`*^-14, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9076.267267028521}, \
{4699.999999999998, -9076.267267028521}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.267267028521}, {
        100.000102932145, -9076.267267028521}, {
        100.000102932145, -9076.267267028521}, {100, -9076.267267028521}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828920942404, -9076.267267028521}, {
       911.1663845433918, -9076.267267028521}, {
       911.1663845433918, -9076.267267028521}, {
       600.0828920942404, -9076.267267028521}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.267267028521}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.8966552904453`, -9076.267267028521}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.267267028521}, {
       2654.221522330154, -9076.267267028521}, {
       2654.221522330154, -9076.267267028521}, {
       2648.884246253918, -9076.267267028521}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.88192338355, -9076.267267028521}, {
       2584.881975478067, -9076.267267028521}, {
       2584.881975478067, -9076.267267028521}, {
       2584.88192338355, -9076.267267028521}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.267267028521}, {
       3136.054810878996, -9076.267267028521}, {
       3136.054810878996, -9076.267267028521}, {
       3136.0548108749413`, -9076.267267028521}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.267267028521}, {
       3698.3524183452464`, -9076.267267028521}, {
       3698.3524183452464`, -9076.267267028521}, {
       3016.6764332866337`, -9076.267267028521}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.768268872911, -9076.267267028521}, {
       4142.649334928726, -9076.267267028521}, {
       4142.649334928726, -9076.267267028521}, {
       4140.768268872911, -9076.267267028521}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681881743`, -9076.267267028521}, {
      1601.2816681896652`, -9076.267267028521}, {
      1601.2816681896652`, -9076.267267028521}, {
      1601.2816681881743`, -9076.267267028521}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9076.267267028521}, \
{4699.999999999998, -9076.267267028521}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9076.267267028521}, 
       2.2972853132186323`*^-14, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681896652`, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}, {
       1601.2816681896652`, -9076.267267028521}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681896652`, -9076.267267028521}, 
       2.2972853132186323`*^-14, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681896652`, -9076.267267028521}, \
{1601.2816681896652`, -9076.267267028521}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.267349575844}, {
        100.000102932145, -9076.267349575844}, {
        100.000102932145, -9076.267267028521}, {100, -9076.267267028521}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8966552904453`, -9076.267349575844}, {
       1335.9186806184225`, -9076.267349575844}, {
       1335.9186806184225`, -9076.267267028521}, {
       1335.8966552904453`, -9076.267267028521}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.267349575844}, {
       1601.2816681896652`, -9076.267349575844}, {
       1601.2816681896652`, -9076.267267028521}, {
       1601.2816681881743`, -9076.267267028521}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.267349575844}, {
       2654.221522330154, -9076.267349575844}, {
       2654.221522330154, -9076.267267028521}, {
       2648.884246253918, -9076.267267028521}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881964657212, -9076.267349575844}, {
       2584.881975478067, -9076.267349575844}, {
       2584.881975478067, -9076.267267028521}, {
       2584.881964657212, -9076.267267028521}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.267349575844}, {
       3136.054810878996, -9076.267349575844}, {
       3136.054810878996, -9076.267267028521}, {
       3136.0548108749413`, -9076.267267028521}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.267349575844}, {
       3698.3524183452464`, -9076.267349575844}, {
       3698.3524183452464`, -9076.267267028521}, {
       3016.6764332866337`, -9076.267267028521}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.768268872911, -9076.267349575844}, {
       4142.649334928726, -9076.267349575844}, {
       4142.649334928726, -9076.267267028521}, {
       4140.768268872911, -9076.267267028521}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.267349575844}, {
       4699.999999999998, -9076.267349575844}, {
       4699.999999999998, -9076.267267028521}, {
       4699.999999999998, -9076.267267028521}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828920942404, -9076.267349575844}, {
      911.1663845433918, -9076.267349575844}, {
      911.1663845433918, -9076.267267028521}, {
      600.0828920942404, -9076.267267028521}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88192338355, -9076.267287665352}, \
{2584.881964657212, -9076.267267028521}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.88192338355, -9076.267287665352}, 0.00004127366164537266, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1664258170534, -9076.267328939013}, {
       2584.88192338355, -9076.267328939013}, {
       2584.88192338355, -9076.267287665352}, {
       911.1664258170534, -9076.267287665352}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1664258170534, -9076.267328939013}, 0.00004127366164537266,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1663845433918, -9076.267349575844}, \
{911.1664258170534, -9076.267328939013}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.281164517386}, {
        100.000102932145, -9076.281164517386}, {
        100.000102932145, -9076.267349575844}, {100, -9076.267349575844}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9076.281164517386}, {
       1335.9186806184223`, -9076.281164517386}, {
       1335.9186806184223`, -9076.267349575844}, {
       1335.903562761216, -9076.267349575844}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.281164517386}, {
       1601.2816681896652`, -9076.281164517386}, {
       1601.2816681896652`, -9076.267349575844}, {
       1601.2816681881743`, -9076.267349575844}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.281164517386}, {
       2654.221522330154, -9076.281164517386}, {
       2654.221522330154, -9076.267349575844}, {
       2648.884246253918, -9076.267349575844}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881964657212, -9076.281164517386}, {
       2584.881975478067, -9076.281164517386}, {
       2584.881975478067, -9076.267349575844}, {
       2584.881964657212, -9076.267349575844}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.281164517386}, {
       3136.054810878996, -9076.281164517386}, {
       3136.054810878996, -9076.267349575844}, {
       3136.0548108749413`, -9076.267349575844}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.281164517386}, {
       3698.3524183452464`, -9076.281164517386}, {
       3698.3524183452464`, -9076.267349575844}, {
       3016.6764332866337`, -9076.267349575844}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.768268872911, -9076.281164517386}, {
       4142.649334928726, -9076.281164517386}, {
       4142.649334928726, -9076.267349575844}, {
       4140.768268872911, -9076.267349575844}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.281164517386}, {
       4699.999999999998, -9076.281164517386}, {
       4699.999999999998, -9076.267349575844}, {
       4699.999999999998, -9076.267349575844}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828920942404, -9076.281164517386}, {
      911.1664258170534, -9076.281164517386}, {
      911.1664258170534, -9076.267349575844}, {
      600.0828920942404, -9076.267349575844}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.8966552904453`, -9076.27080331123}, \
{1335.903562761216, -9076.267349575844}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.8966552904453`, -9076.27080331123}, 0.00690747077088703, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1733332878243, -9076.277710782}, {
       1335.8966552904453`, -9076.277710782}, {
       1335.8966552904453`, -9076.27080331123}, {
       911.1733332878243, -9076.27080331123}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1733332878243, -9076.277710782}, 0.00690747077088703, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1664258170534, -9076.281164517386}, \
{911.1733332878243, -9076.277710782}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9076.281258942106}, {
        100.00005571978436`, -9076.281258942106}, {
        100.00005571978436`, -9076.281164517386}, {
        100, -9076.281164517386}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9076.281258942106}, {
       1335.9186806184223`, -9076.281258942106}, {
       1335.9186806184223`, -9076.281164517386}, {
       1335.903562761216, -9076.281164517386}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9076.281258942106}, {
       1601.2816681896652`, -9076.281258942106}, {
       1601.2816681896652`, -9076.281164517386}, {
       1601.2816681881743`, -9076.281164517386}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9076.281258942106}, {
       2654.221522330154, -9076.281258942106}, {
       2654.221522330154, -9076.281164517386}, {
       2648.884246253918, -9076.281164517386}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881964657212, -9076.281258942106}, {
       2584.881975478067, -9076.281258942106}, {
       2584.881975478067, -9076.281164517386}, {
       2584.881964657212, -9076.281164517386}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9076.281258942106}, {
       3136.054810878996, -9076.281258942106}, {
       3136.054810878996, -9076.281164517386}, {
       3136.0548108749413`, -9076.281164517386}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9076.281258942106}, {
       3698.3524183452464`, -9076.281258942106}, {
       3698.3524183452464`, -9076.281164517386}, {
       3016.6764332866337`, -9076.281164517386}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4140.768268872911, -9076.281258942106}, {
       4142.649334928726, -9076.281258942106}, {
       4142.649334928726, -9076.281164517386}, {
       4140.768268872911, -9076.281164517386}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9076.281258942106}, {
       4699.999999999998, -9076.281258942106}, {
       4699.999999999998, -9076.281164517386}, {
       4699.999999999998, -9076.281164517386}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828920942404, -9076.281258942106}, {
      911.1733332878243, -9076.281258942106}, {
      911.1733332878243, -9076.281164517386}, {
      600.0828920942404, -9076.281164517386}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00005571978436`, -9076.281188123565}, \
{100.000102932145, -9076.281164517386}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.000102932145, -9076.281188123565}, 0.00004721236063707631, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.000102932145, -9076.281235335926}, {
       600.0828448818797, -9076.281235335926}, {
       600.0828448818797, -9076.281188123565}, {
       100.000102932145, -9076.281188123565}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0828448818797, -9076.281235335926}, 
       0.00004721236063707631, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0828448818797, -9076.281258942106}, \
{600.0828920942404, -9076.281235335926}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9079.34543845561}, {
        100.00005571978436`, -9079.34543845561}, {
        100.00005571978436`, -9076.281258942106}, {
        100, -9076.281258942106}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9079.34543845561}, {
       911.1733332878243, -9079.34543845561}, {
       911.1733332878243, -9076.281258942106}, {
       600.0828448818797, -9076.281258942106}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9079.34543845561}, {
       1335.9186806184223`, -9079.34543845561}, {
       1335.9186806184223`, -9076.281258942106}, {
       1335.903562761216, -9076.281258942106}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9079.34543845561}, {
       1601.2816681896652`, -9079.34543845561}, {
       1601.2816681896652`, -9076.281258942106}, {
       1601.2816681881743`, -9076.281258942106}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9079.34543845561}, {
       2654.221522330154, -9079.34543845561}, {
       2654.221522330154, -9076.281258942106}, {
       2648.884246253918, -9076.281258942106}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881964657212, -9079.34543845561}, {
       2584.881975478067, -9079.34543845561}, {
       2584.881975478067, -9076.281258942106}, {
       2584.881964657212, -9076.281258942106}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9079.34543845561}, {
       3136.054810878996, -9079.34543845561}, {
       3136.054810878996, -9076.281258942106}, {
       3136.0548108749413`, -9076.281258942106}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9079.34543845561}, {
       3696.8203285884947`, -9079.34543845561}, {
       3696.8203285884947`, -9076.281258942106}, {
       3016.6764332866337`, -9076.281258942106}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9079.34543845561}, {
       4699.999999999998, -9079.34543845561}, {
       4699.999999999998, -9076.281258942106}, {
       4699.999999999998, -9076.281258942106}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4140.768268872911, -9079.34543845561}, {
      4142.649334928726, -9079.34543845561}, {
      4142.649334928726, -9076.281258942106}, {
      4140.768268872911, -9076.281258942106}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3696.8203285884947`, -9077.047303820482}, \
{3698.3524183452464`, -9076.281258942106}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3698.3524183452464`, -9077.047303820482}, 1.532089756751761, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3698.3524183452464`, -9078.579393577234}, {
       4139.236179116159, -9078.579393577234}, {
       4139.236179116159, -9077.047303820482}, {
       3698.3524183452464`, -9077.047303820482}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.236179116159, -9078.579393577234}, 1.532089756751761, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.236179116159, -9079.34543845561}, \
{4140.768268872911, -9078.579393577234}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9079.34545816806}, {
        100.00005571978436`, -9079.34545816806}, {
        100.00005571978436`, -9079.34543845561}, {
        100, -9079.34543845561}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9079.34545816806}, {
       911.1733332878243, -9079.34545816806}, {
       911.1733332878243, -9079.34543845561}, {
       600.0828448818797, -9079.34543845561}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9079.34545816806}, {
       1601.2816681896652`, -9079.34545816806}, {
       1601.2816681896652`, -9079.34543845561}, {
       1601.2816681881743`, -9079.34543845561}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9079.34545816806}, {
       2654.221522330154, -9079.34545816806}, {
       2654.221522330154, -9079.34543845561}, {
       2648.884246253918, -9079.34543845561}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9079.34545816806}, {
       2584.881975478067, -9079.34545816806}, {
       2584.881975478067, -9079.34543845561}, {
       2584.8819745134365`, -9079.34543845561}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9079.34545816806}, {
       3136.054810878996, -9079.34545816806}, {
       3136.054810878996, -9079.34543845561}, {
       3136.0548108749413`, -9079.34543845561}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3016.6764332866337`, -9079.34545816806}, {
       3696.8203285884947`, -9079.34545816806}, {
       3696.8203285884947`, -9079.34543845561}, {
       3016.6764332866337`, -9079.34543845561}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116159, -9079.34545816806}, {
       4142.649334928726, -9079.34545816806}, {
       4142.649334928726, -9079.34543845561}, {
       4139.236179116159, -9079.34543845561}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9079.34545816806}, {
       4699.999999999998, -9079.34545816806}, {
       4699.999999999998, -9079.34543845561}, {
       4699.999999999998, -9079.34543845561}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.903562761216, -9079.34545816806}, {
      1335.9186806184223`, -9079.34545816806}, {
      1335.9186806184223`, -9079.34543845561}, {
      1335.903562761216, -9079.34543845561}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881964657212, -9079.345443383723}, \
{2584.8819745134365`, -9079.34543845561}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881964657212, -9079.345443383723}, 9.856224622008942*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.918690474647, -9079.345453239948}, {
       2584.881964657212, -9079.345453239948}, {
       2584.881964657212, -9079.345443383723}, {
       1335.918690474647, -9079.345443383723}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.918690474647, -9079.345453239948}, 9.856224622008942*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9186806184223`, -9079.34545816806}, \
{1335.918690474647, -9079.345453239948}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9081.879949093105}, {
        100.00005571978436`, -9081.879949093105}, {
        100.00005571978436`, -9079.34545816806}, {
        100, -9079.34545816806}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9081.879949093105}, {
       911.1733332878243, -9081.879949093105}, {
       911.1733332878243, -9079.34545816806}, {
       600.0828448818797, -9079.34545816806}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9081.879949093105}, {
       1335.918690474647, -9081.879949093105}, {
       1335.918690474647, -9079.34545816806}, {
       1335.903562761216, -9079.34545816806}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9081.879949093105}, {
       1601.2816681896652`, -9081.879949093105}, {
       1601.2816681896652`, -9079.34545816806}, {
       1601.2816681881743`, -9079.34545816806}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9081.879949093105}, {
       2584.881975478067, -9081.879949093105}, {
       2584.881975478067, -9079.34545816806}, {
       2584.8819745134365`, -9079.34545816806}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108749413`, -9081.879949093105}, {
       3136.054810878996, -9081.879949093105}, {
       3136.054810878996, -9079.34545816806}, {
       3136.0548108749413`, -9079.34545816806}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3017.943678749157, -9081.879949093105}, {
       3696.8203285884947`, -9081.879949093105}, {
       3696.8203285884947`, -9079.34545816806}, {
       3017.943678749157, -9079.34545816806}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116159, -9081.879949093105}, {
       4142.649334928726, -9081.879949093105}, {
       4142.649334928726, -9079.34545816806}, {
       4139.236179116159, -9079.34545816806}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9081.879949093105}, {
       4699.999999999998, -9081.879949093105}, {
       4699.999999999998, -9079.34545816806}, {
       4699.999999999998, -9079.34545816806}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.884246253918, -9081.879949093105}, {
      2654.221522330154, -9081.879949093105}, {
      2654.221522330154, -9079.34545816806}, {
      2648.884246253918, -9079.34545816806}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3016.6764332866337`, -9079.97908089932}, \
{3017.943678749157, -9079.34545816806}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3016.6764332866337`, -9079.97908089932}, 1.2672454625228733`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2655.4887677926768`, -9081.246326361843}, {
       3016.6764332866337`, -9081.246326361843}, {
       3016.6764332866337`, -9079.97908089932}, {
       2655.4887677926768`, -9079.97908089932}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2655.4887677926768`, -9081.246326361843}, 1.2672454625228733`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2654.221522330154, -9081.879949093105}, 
       {2655.4887677926768`, -9081.246326361843}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9081.879949093822}, {
        100.00005571978436`, -9081.879949093822}, {
        100.00005571978436`, -9081.879949093105}, {
        100, -9081.879949093105}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9081.879949093822}, {
       911.1733332878243, -9081.879949093822}, {
       911.1733332878243, -9081.879949093105}, {
       600.0828448818797, -9081.879949093105}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9081.879949093822}, {
       1335.918690474647, -9081.879949093822}, {
       1335.918690474647, -9081.879949093105}, {
       1335.903562761216, -9081.879949093105}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9081.879949093822}, {
       1601.2816681896652`, -9081.879949093822}, {
       1601.2816681896652`, -9081.879949093105}, {
       1601.2816681881743`, -9081.879949093105}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9081.879949093822}, {
       2655.4887677926768`, -9081.879949093822}, {
       2655.4887677926768`, -9081.879949093105}, {
       2648.884246253918, -9081.879949093105}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9081.879949093822}, {
       2584.881975478067, -9081.879949093822}, {
       2584.881975478067, -9081.879949093105}, {
       2584.8819745134365`, -9081.879949093105}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3017.943678749157, -9081.879949093822}, {
       3696.8203285884947`, -9081.879949093822}, {
       3696.8203285884947`, -9081.879949093105}, {
       3017.943678749157, -9081.879949093105}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9081.879949093822}, {
       4142.649334928726, -9081.879949093822}, {
       4142.649334928726, -9081.879949093105}, {
       4139.236179116518, -9081.879949093105}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9081.879949093822}, {
       4699.999999999998, -9081.879949093822}, {
       4699.999999999998, -9081.879949093105}, {
       4699.999999999998, -9081.879949093105}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108749413`, -9081.879949093822}, {
      3136.054810878996, -9081.879949093822}, {
      3136.054810878996, -9081.879949093105}, {
      3136.0548108749413`, -9081.879949093105}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4139.236179116159, -9081.879949093283}, \
{4139.236179116518, -9081.879949093105}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4139.236179116159, -9081.879949093283}, 3.58655942680218*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108793546`, -9081.879949093642}, {
       4139.236179116159, -9081.879949093642}, {
       4139.236179116159, -9081.879949093283}, {
       3136.0548108793546`, -9081.879949093283}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108793546`, -9081.879949093642}, 
       3.58655942680218*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810878996, -9081.879949093822}, \
{3136.0548108793546`, -9081.879949093642}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9081.87994909385}, {
        100.00005571978436`, -9081.87994909385}, {
        100.00005571978436`, -9081.879949093822}, {
        100, -9081.879949093822}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9081.87994909385}, {
       1335.918690474647, -9081.87994909385}, {
       1335.918690474647, -9081.879949093822}, {
       1335.903562761216, -9081.879949093822}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9081.87994909385}, {
       1601.2816681896652`, -9081.87994909385}, {
       1601.2816681896652`, -9081.879949093822}, {
       1601.2816681881743`, -9081.879949093822}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9081.87994909385}, {
       2655.4887677926768`, -9081.87994909385}, {
       2655.4887677926768`, -9081.879949093822}, {
       2648.884246253918, -9081.879949093822}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9081.87994909385}, {
       2584.881975478067, -9081.87994909385}, {
       2584.881975478067, -9081.879949093822}, {
       2584.8819745134365`, -9081.879949093822}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810874956, -9081.87994909385}, {
       3136.0548108793546`, -9081.87994909385}, {
       3136.0548108793546`, -9081.879949093822}, {
       3136.054810874956, -9081.879949093822}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3017.943678749157, -9081.87994909385}, {
       3696.8203285884947`, -9081.87994909385}, {
       3696.8203285884947`, -9081.879949093822}, {
       3017.943678749157, -9081.879949093822}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9081.87994909385}, {
       4142.649334928726, -9081.87994909385}, {
       4142.649334928726, -9081.879949093822}, {
       4139.236179116518, -9081.879949093822}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9081.87994909385}, {
       4699.999999999998, -9081.87994909385}, {
       4699.999999999998, -9081.879949093822}, {
       4699.999999999998, -9081.879949093822}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828448818797, -9081.87994909385}, {
      911.1733332878243, -9081.87994909385}, {
      911.1733332878243, -9081.879949093822}, {
      600.0828448818797, -9081.879949093822}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108749413`, -9081.879949093829}, \
{3136.054810874956, -9081.879949093822}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108749413`, -9081.879949093829}, 
       1.4473069515140721`*^-11, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{911.1733332878389, -9081.879949093844}, {
       3136.0548108749413`, -9081.879949093844}, {
       3136.0548108749413`, -9081.879949093829}, {
       911.1733332878389, -9081.879949093829}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{911.1733332878389, -9081.879949093844}, 
       1.4473069515140721`*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1733332878243, -9081.87994909385}, \
{911.1733332878389, -9081.879949093844}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9081.883091189877}, {
        100.00005571978436`, -9081.883091189877}, {
        100.00005571978436`, -9081.87994909385}, {
        100, -9081.87994909385}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9081.883091189877}, {
       911.1733332878389, -9081.883091189877}, {
       911.1733332878389, -9081.87994909385}, {
       600.0828448818797, -9081.87994909385}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9081.883091189877}, {
       1335.9171194266337`, -9081.883091189877}, {
       1335.9171194266337`, -9081.87994909385}, {
       1335.903562761216, -9081.87994909385}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9081.883091189877}, {
       1601.2816681896652`, -9081.883091189877}, {
       1601.2816681896652`, -9081.87994909385}, {
       1601.2816681881743`, -9081.87994909385}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9081.883091189877}, {
       2655.4887677926768`, -9081.883091189877}, {
       2655.4887677926768`, -9081.87994909385}, {
       2648.884246253918, -9081.87994909385}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9081.883091189877}, {
       2584.881975478067, -9081.883091189877}, {
       2584.881975478067, -9081.87994909385}, {
       2584.8819745134365`, -9081.87994909385}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810874956, -9081.883091189877}, {
       3136.0548108793546`, -9081.883091189877}, {
       3136.0548108793546`, -9081.87994909385}, {
       3136.054810874956, -9081.87994909385}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9081.883091189877}, {
       4142.649334928726, -9081.883091189877}, {
       4142.649334928726, -9081.87994909385}, {
       4139.236179116518, -9081.87994909385}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9081.883091189877}, {
       4699.999999999998, -9081.883091189877}, {
       4699.999999999998, -9081.87994909385}, {
       4699.999999999998, -9081.87994909385}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3017.943678749157, -9081.883091189877}, {
      3696.8203285884947`, -9081.883091189877}, {
      3696.8203285884947`, -9081.87994909385}, {
      3017.943678749157, -9081.87994909385}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9171194266337`, -9081.880734617856}, \
{1335.918690474647, -9081.87994909385}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.918690474647, -9081.880734617856}, 0.0015710480132458179`,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.918690474647, -9081.88230566587}, {
       3017.9421077011434`, -9081.88230566587}, {
       3017.9421077011434`, -9081.880734617856}, {
       1335.918690474647, -9081.880734617856}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3017.9421077011434`, -9081.88230566587}, 
       0.0015710480132458179`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3017.9421077011434`, -9081.883091189877}, \
{3017.943678749157, -9081.88230566587}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493354438453}, {
        100.00005571978436`, -9136.493354438453}, {
        100.00005571978436`, -9081.883091189877}, {
        100, -9081.883091189877}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9136.493354438453}, {
       1335.9171194266337`, -9136.493354438453}, {
       1335.9171194266337`, -9081.883091189877}, {
       1335.903562761216, -9081.883091189877}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9136.493354438453}, {
       1601.2816681896652`, -9136.493354438453}, {
       1601.2816681896652`, -9081.883091189877}, {
       1601.2816681881743`, -9081.883091189877}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493354438453}, {
       2655.4887677926768`, -9136.493354438453}, {
       2655.4887677926768`, -9081.883091189877}, {
       2648.884246253918, -9081.883091189877}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493354438453}, {
       2584.881975478067, -9136.493354438453}, {
       2584.881975478067, -9081.883091189877}, {
       2584.8819745134365`, -9081.883091189877}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810874956, -9136.493354438453}, {
       3136.0548108793546`, -9136.493354438453}, {
       3136.0548108793546`, -9081.883091189877}, {
       3136.054810874956, -9081.883091189877}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493354438453}, {
       3696.8203285884947`, -9136.493354438453}, {
       3696.8203285884947`, -9081.883091189877}, {
       3045.2472393254316`, -9081.883091189877}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493354438453}, {
       4142.649334928726, -9136.493354438453}, {
       4142.649334928726, -9081.883091189877}, {
       4139.236179116518, -9081.883091189877}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493354438453}, {
       4699.999999999998, -9136.493354438453}, {
       4699.999999999998, -9081.883091189877}, {
       4699.999999999998, -9081.883091189877}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828448818797, -9136.493354438453}, {
      911.1733332878389, -9136.493354438453}, {
      911.1733332878389, -9081.883091189877}, {
      600.0828448818797, -9081.883091189877}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3017.9421077011434`, -9095.535657002021}, \
{3045.2472393254316`, -9081.883091189877}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3017.9421077011434`, -9095.535657002021}, 27.30513162428798, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{938.4784649121268, -9122.840788626308}, {
       3017.9421077011434`, -9122.840788626308}, {
       3017.9421077011434`, -9095.535657002021}, {
       938.4784649121268, -9095.535657002021}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{938.4784649121268, -9122.840788626308}, 27.30513162428798, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{911.1733332878389, -9136.493354438453}, \
{938.4784649121268, -9122.840788626308}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493354440858}, {
        100.00005571978436`, -9136.493354440858}, {
        100.00005571978436`, -9136.493354438453}, {
        100, -9136.493354438453}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493354440858}, {
       938.4784649121268, -9136.493354440858}, {
       938.4784649121268, -9136.493354438453}, {
       600.0828448818797, -9136.493354438453}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903562761216, -9136.493354440858}, {
       1335.9171194266337`, -9136.493354440858}, {
       1335.9171194266337`, -9136.493354438453}, {
       1335.903562761216, -9136.493354438453}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9136.493354440858}, {
       1601.2816681896652`, -9136.493354440858}, {
       1601.2816681896652`, -9136.493354438453}, {
       1601.2816681881743`, -9136.493354438453}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493354440858}, {
       2655.4887677914744`, -9136.493354440858}, {
       2655.4887677914744`, -9136.493354438453}, {
       2648.884246253918, -9136.493354438453}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493354440858}, {
       2584.881975478067, -9136.493354440858}, {
       2584.881975478067, -9136.493354438453}, {
       2584.8819745134365`, -9136.493354438453}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493354440858}, {
       3696.8203285884947`, -9136.493354440858}, {
       3696.8203285884947`, -9136.493354438453}, {
       3045.2472393254316`, -9136.493354438453}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493354440858}, {
       4142.649334928726, -9136.493354440858}, {
       4142.649334928726, -9136.493354438453}, {
       4139.236179116518, -9136.493354438453}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493354440858}, {
       4699.999999999998, -9136.493354440858}, {
       4699.999999999998, -9136.493354438453}, {
       4699.999999999998, -9136.493354438453}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810874956, -9136.493354440858}, {
      3136.0548108793546`, -9136.493354440858}, {
      3136.0548108793546`, -9136.493354438453}, {
      3136.054810874956, -9136.493354438453}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2655.4887677914744`, -9136.493354439053}, \
{2655.4887677926768`, -9136.493354438453}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2655.4887677926768`, -9136.493354439053}, 
       1.202411085942227*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2655.4887677926768`, -9136.493354440256}, {
       3136.0548108737535`, -9136.493354440256}, {
       3136.0548108737535`, -9136.493354439053}, {
       2655.4887677926768`, -9136.493354439053}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108737535`, -9136.493354440256}, 
       1.202411085942227*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108737535`, -9136.493354440858}, \
{3136.054810874956, -9136.493354440256}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493400614907}, {
        100.00003263276021`, -9136.493400614907}, {
        100.00003263276021`, -9136.493354440858}, {
        100, -9136.493354440858}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493400614907}, {
       938.4784649121268, -9136.493400614907}, {
       938.4784649121268, -9136.493354440858}, {
       600.0828448818797, -9136.493354440858}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9136.493400614907}, {
       1601.2816681896652`, -9136.493400614907}, {
       1601.2816681896652`, -9136.493354440858}, {
       1601.2816681881743`, -9136.493354440858}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493400614907}, {
       2655.4887677914744`, -9136.493400614907}, {
       2655.4887677914744`, -9136.493354440858}, {
       2648.884246253918, -9136.493354440858}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493400614907}, {
       2584.881975478067, -9136.493400614907}, {
       2584.881975478067, -9136.493354440858}, {
       2584.8819745134365`, -9136.493354440858}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108737535`, -9136.493400614907}, {
       3136.0548108793546`, -9136.493400614907}, {
       3136.0548108793546`, -9136.493354440858}, {
       3136.0548108737535`, -9136.493354440858}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493400614907}, {
       3696.8203285884947`, -9136.493400614907}, {
       3696.8203285884947`, -9136.493354440858}, {
       3045.2472393254316`, -9136.493354440858}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493400614907}, {
       4142.649334928726, -9136.493400614907}, {
       4142.649334928726, -9136.493354440858}, {
       4139.236179116518, -9136.493354440858}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493400614907}, {
       4699.999999999998, -9136.493400614907}, {
       4699.999999999998, -9136.493354440858}, {
       4699.999999999998, -9136.493354440858}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.903562761216, -9136.493400614907}, {
      1335.9171194266337`, -9136.493400614907}, {
      1335.9171194266337`, -9136.493354440858}, {
      1335.903562761216, -9136.493354440858}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00003263276021`, -9136.49336598437}, \
{100.00005571978436`, -9136.493354440858}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00005571978436`, -9136.49336598437}, 
       0.000023087024148101315`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00005571978436`, -9136.493389071395}, {
       1335.903539674192, -9136.493389071395}, {
       1335.903539674192, -9136.49336598437}, {
       100.00005571978436`, -9136.49336598437}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.903539674192, -9136.493389071395}, 
       0.000023087024148101315`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.903539674192, -9136.493400614907}, \
{1335.903562761216, -9136.493389071395}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493400616893}, {
        100.00003263276021`, -9136.493400616893}, {
        100.00003263276021`, -9136.493400614907}, {
        100, -9136.493400614907}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493400616893}, {
       938.4784649121268, -9136.493400616893}, {
       938.4784649121268, -9136.493400614907}, {
       600.0828448818797, -9136.493400614907}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903539674192, -9136.493400616893}, {
       1335.9171194266337`, -9136.493400616893}, {
       1335.9171194266337`, -9136.493400614907}, {
       1335.903539674192, -9136.493400614907}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681881743`, -9136.493400616893}, {
       1601.2816681896652`, -9136.493400616893}, {
       1601.2816681896652`, -9136.493400614907}, {
       1601.2816681881743`, -9136.493400614907}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493400616893}, {
       2655.488767790481, -9136.493400616893}, {
       2655.488767790481, -9136.493400614907}, {
       2648.884246253918, -9136.493400614907}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493400616893}, {
       2584.881975478067, -9136.493400616893}, {
       2584.881975478067, -9136.493400614907}, {
       2584.8819745134365`, -9136.493400614907}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493400616893}, {
       3696.8203285884947`, -9136.493400616893}, {
       3696.8203285884947`, -9136.493400614907}, {
       3045.2472393254316`, -9136.493400614907}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493400616893}, {
       4142.649334928726, -9136.493400616893}, {
       4142.649334928726, -9136.493400614907}, {
       4139.236179116518, -9136.493400614907}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400614907}, {
       4699.999999999998, -9136.493400614907}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108737535`, -9136.493400616893}, {
      3136.054810879354, -9136.493400616893}, {
      3136.054810879354, -9136.493400614907}, {
      3136.0548108737535`, -9136.493400614907}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2655.488767790481, -9136.493400615404}, \
{2655.4887677914744`, -9136.493400614907}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2655.4887677914744`, -9136.493400615404}, 
       9.934319752733627*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2655.4887677914744`, -9136.493400616397}, {
       3136.05481087276, -9136.493400616397}, {
       3136.05481087276, -9136.493400615404}, {
       2655.4887677914744`, -9136.493400615404}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05481087276, -9136.493400616397}, 
       9.934319752733627*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05481087276, -9136.493400616893}, \
{3136.0548108737535`, -9136.493400616397}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493400616893}, {
        100.00003263276021`, -9136.493400616893}, {
        100.00003263276021`, -9136.493400616893}, {
        100, -9136.493400616893}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493400616893}, {
       938.4784649121268, -9136.493400616893}, {
       938.4784649121268, -9136.493400616893}, {
       600.0828448818797, -9136.493400616893}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903539674192, -9136.493400616893}, {
       1335.9171194266337`, -9136.493400616893}, {
       1335.9171194266337`, -9136.493400616893}, {
       1335.903539674192, -9136.493400616893}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493400616893}, {
       2655.488767790481, -9136.493400616893}, {
       2655.488767790481, -9136.493400616893}, {
       2648.884246253918, -9136.493400616893}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493400616893}, {
       2584.881975478067, -9136.493400616893}, {
       2584.881975478067, -9136.493400616893}, {
       2584.8819745134365`, -9136.493400616893}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.05481087276, -9136.493400616893}, {
       3136.054810879354, -9136.493400616893}, {
       3136.054810879354, -9136.493400616893}, {
       3136.05481087276, -9136.493400616893}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493400616893}, {
       3696.8203285884947`, -9136.493400616893}, {
       3696.8203285884947`, -9136.493400616893}, {
       3045.2472393254316`, -9136.493400616893}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493400616893}, {
       4142.649334928726, -9136.493400616893}, {
       4142.649334928726, -9136.493400616893}, {
       4139.236179116518, -9136.493400616893}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681881743`, -9136.493400616893}, {
      1601.2816681896652`, -9136.493400616893}, {
      1601.2816681896652`, -9136.493400616893}, {
      1601.2816681881743`, -9136.493400616893}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9136.493400616893}, \
{4699.999999999998, -9136.493400616893}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9136.493400616893}, 5.16607668286959*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681896652`, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}, {
       1601.2816681896652`, -9136.493400616893}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681896652`, -9136.493400616893}, 
       5.16607668286959*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681896652`, -9136.493400616893}, \
{1601.2816681896652`, -9136.493400616893}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493400618607}, {
        100.00003263276021`, -9136.493400618607}, {
        100.00003263276021`, -9136.493400616893}, {
        100, -9136.493400616893}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903539674192, -9136.493400618607}, {
       1335.9171194266337`, -9136.493400618607}, {
       1335.9171194266337`, -9136.493400616893}, {
       1335.903539674192, -9136.493400616893}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9136.493400618607}, {
       1601.2816681896652`, -9136.493400618607}, {
       1601.2816681896652`, -9136.493400616893}, {
       1601.281668189031, -9136.493400616893}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493400618607}, {
       2655.488767790481, -9136.493400618607}, {
       2655.488767790481, -9136.493400616893}, {
       2648.884246253918, -9136.493400616893}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493400618607}, {
       2584.881975478067, -9136.493400618607}, {
       2584.881975478067, -9136.493400616893}, {
       2584.8819745134365`, -9136.493400616893}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.05481087276, -9136.493400618607}, {
       3136.054810879354, -9136.493400618607}, {
       3136.054810879354, -9136.493400616893}, {
       3136.05481087276, -9136.493400616893}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493400618607}, {
       3696.8203285884947`, -9136.493400618607}, {
       3696.8203285884947`, -9136.493400616893}, {
       3045.2472393254316`, -9136.493400616893}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493400618607}, {
       4142.649334928726, -9136.493400618607}, {
       4142.649334928726, -9136.493400616893}, {
       4139.236179116518, -9136.493400616893}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493400618607}, {
       4699.999999999998, -9136.493400618607}, {
       4699.999999999998, -9136.493400616893}, {
       4699.999999999998, -9136.493400616893}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828448818797, -9136.493400618607}, {
      938.4784649121268, -9136.493400618607}, {
      938.4784649121268, -9136.493400616893}, {
      600.0828448818797, -9136.493400616893}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681881743`, -9136.49340061732}, \
{1601.281668189031, -9136.493400616893}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681881743`, -9136.49340061732}, 
       8.568513626231662*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{938.4784649129837, -9136.493400618177}, {
       1601.2816681881743`, -9136.493400618177}, {
       1601.2816681881743`, -9136.49340061732}, {
       938.4784649129837, -9136.49340061732}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{938.4784649129837, -9136.493400618177}, 8.568513626231662*^-10,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{938.4784649121268, -9136.493400618607}, \
{938.4784649129837, -9136.493400618177}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9136.493400623025}, {
        100.00003263276021`, -9136.493400623025}, {
        100.00003263276021`, -9136.493400618607}, {
        100, -9136.493400618607}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493400623025}, {
       938.4784649129837, -9136.493400623025}, {
       938.4784649129837, -9136.493400618607}, {
       600.0828448818797, -9136.493400618607}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.903539674192, -9136.493400623025}, {
       1335.9171194266337`, -9136.493400623025}, {
       1335.9171194266337`, -9136.493400618607}, {
       1335.903539674192, -9136.493400618607}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9136.493400623025}, {
       1601.2816681896652`, -9136.493400623025}, {
       1601.2816681896652`, -9136.493400618607}, {
       1601.281668189031, -9136.493400618607}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493400623025}, {
       2655.488767788271, -9136.493400623025}, {
       2655.488767788271, -9136.493400618607}, {
       2648.884246253918, -9136.493400618607}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493400623025}, {
       2584.881975478067, -9136.493400623025}, {
       2584.881975478067, -9136.493400618607}, {
       2584.8819745134365`, -9136.493400618607}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493400623025}, {
       3696.8203285884947`, -9136.493400623025}, {
       3696.8203285884947`, -9136.493400618607}, {
       3045.2472393254316`, -9136.493400618607}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493400623025}, {4142.649334928726,
        -9136.493400623025}, {4142.649334928726, -9136.493400618607}, {
       4139.236179116518, -9136.493400618607}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493400623025}, {
       4699.999999999998, -9136.493400623025}, {
       4699.999999999998, -9136.493400618607}, {
       4699.999999999998, -9136.493400618607}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.05481087276, -9136.493400623025}, {
      3136.054810879354, -9136.493400623025}, {
      3136.054810879354, -9136.493400618607}, {
      3136.05481087276, -9136.493400618607}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2655.488767788271, -9136.49340061971}, \
{2655.488767790481, -9136.493400618607}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2655.488767790481, -9136.49340061971}, 2.20958763109401*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2655.488767790481, -9136.493400621921}, {
       3136.05481087055, -9136.493400621921}, {
       3136.05481087055, -9136.49340061971}, {
       2655.488767790481, -9136.49340061971}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05481087055, -9136.493400621921}, 2.20958763109401*^-9, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05481087055, -9136.493400623025}, \
{3136.05481087276, -9136.493400621921}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9136.493461732882}, {
       938.4784649129837, -9136.493461732882}, {
       938.4784649129837, -9136.493400623025}, {
       600.0828448818797, -9136.493400623025}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9136.493461732882}, {
       1335.9171194266337`, -9136.493461732882}, {
       1335.9171194266337`, -9136.493400623025}, {
       1335.9035702291205`, -9136.493400623025}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9136.493461732882}, {
       1601.2816681896652`, -9136.493461732882}, {
       1601.2816681896652`, -9136.493400623025}, {
       1601.281668189031, -9136.493400623025}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9136.493461732882}, {
       2655.488767788271, -9136.493461732882}, {
       2655.488767788271, -9136.493400623025}, {
       2648.884246253918, -9136.493400623025}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9136.493461732882}, {
       2584.881975478067, -9136.493461732882}, {
       2584.881975478067, -9136.493400623025}, {
       2584.8819745134365`, -9136.493400623025}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.05481087055, -9136.493461732882}, {
       3136.054810879354, -9136.493461732882}, {
       3136.054810879354, -9136.493400623025}, {
       3136.05481087055, -9136.493400623025}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9136.493461732882}, {
       3696.8203285884947`, -9136.493461732882}, {
       3696.8203285884947`, -9136.493400623025}, {
       3045.2472393254316`, -9136.493400623025}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4139.236179116518, -9136.493461732882}, {
       4142.649334928726, -9136.493461732882}, {
       4142.649334928726, -9136.493400623025}, {
       4139.236179116518, -9136.493400623025}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9136.493461732882}, {
       4699.999999999998, -9136.493461732882}, {
       4699.999999999998, -9136.493400623025}, {
       4699.999999999998, -9136.493400623025}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9136.493461732882}, {
       100.00003263276021`, -9136.493461732882}, {
       100.00003263276021`, -9136.493400623025}, {
       100, -9136.493400623025}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.903539674192, -9136.49341590049}, \
{1335.9035702291205`, -9136.493400623025}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.903539674192, -9136.49341590049}, 0.00003055492861774953, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006318768884`, -9136.493446455417}, {
       1335.903539674192, -9136.493446455417}, {
       1335.903539674192, -9136.49341590049}, {
       100.00006318768884`, -9136.49341590049}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006318768884`, -9136.493446455417}, 
       0.00003055492861774953, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00003263276021`, -9136.493461732882}, \
{100.00006318768884`, -9136.493446455417}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9139.509224751293}, {
        100.00006318768884`, -9139.509224751293}, {
        100.00006318768884`, -9136.493461732882}, {
        100, -9136.493461732882}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9139.509224751293}, {
       936.9705834037777, -9139.509224751293}, {
       936.9705834037777, -9136.493461732882}, {
       600.0828448818797, -9136.493461732882}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9139.509224751293}, {
       1335.9171194266337`, -9139.509224751293}, {
       1335.9171194266337`, -9136.493461732882}, {
       1335.9035702291205`, -9136.493461732882}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9139.509224751293}, {
       1601.2816681896652`, -9139.509224751293}, {
       1601.2816681896652`, -9136.493461732882}, {
       1601.281668189031, -9136.493461732882}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9139.509224751293}, {
       2655.488767788271, -9139.509224751293}, {
       2655.488767788271, -9136.493461732882}, {
       2648.884246253918, -9136.493461732882}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9139.509224751293}, {
       2584.881975478067, -9139.509224751293}, {
       2584.881975478067, -9136.493461732882}, {
       2584.8819745134365`, -9136.493461732882}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.05481087055, -9139.509224751293}, {
       3136.054810879354, -9139.509224751293}, {
       3136.054810879354, -9136.493461732882}, {
       3136.05481087055, -9136.493461732882}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9139.509224751293}, {
       3696.8203285884947`, -9139.509224751293}, {
       3696.8203285884947`, -9136.493461732882}, {
       3045.2472393254316`, -9136.493461732882}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9139.509224751293}, {
       4699.999999999998, -9139.509224751293}, {
       4699.999999999998, -9136.493461732882}, {
       4699.999999999998, -9136.493461732882}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4139.236179116518, -9139.509224751293}, {
      4142.649334928727, -9139.509224751293}, {
      4142.649334928727, -9136.493461732882}, {
      4139.236179116518, -9136.493461732882}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{936.9705834037777, -9137.247402487485}, \
{938.4784649129837, -9136.493461732882}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{938.4784649129837, -9137.247402487485}, 1.5078815092060065`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{938.4784649129837, -9138.75528399669}, {
       4137.728297607312, -9138.75528399669}, {
       4137.728297607312, -9137.247402487485}, {
       938.4784649129837, -9137.247402487485}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4137.728297607312, -9138.75528399669}, 1.5078815092060065`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4137.728297607312, -9139.509224751293}, \
{4139.236179116518, -9138.75528399669}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9139.50922475156}, {
        100.00006318768884`, -9139.50922475156}, {
        100.00006318768884`, -9139.509224751293}, {
        100, -9139.509224751293}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9139.50922475156}, {
       936.9705834037777, -9139.50922475156}, {
       936.9705834037777, -9139.509224751293}, {
       600.0828448818797, -9139.509224751293}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9139.50922475156}, {
       1335.9171194266337`, -9139.50922475156}, {
       1335.9171194266337`, -9139.509224751293}, {
       1335.9035702291205`, -9139.509224751293}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9139.50922475156}, {
       2655.488767788271, -9139.50922475156}, {
       2655.488767788271, -9139.509224751293}, {
       2648.884246253918, -9139.509224751293}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819745134365`, -9139.50922475156}, {
       2584.881975478067, -9139.50922475156}, {
       2584.881975478067, -9139.509224751293}, {
       2584.8819745134365`, -9139.509224751293}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9139.50922475156}, {
       3136.0548108793546`, -9139.50922475156}, {
       3136.0548108793546`, -9139.509224751293}, {
       3136.054810870684, -9139.509224751293}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9139.50922475156}, {
       3696.8203285884947`, -9139.50922475156}, {
       3696.8203285884947`, -9139.509224751293}, {
       3045.2472393254316`, -9139.509224751293}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4137.728297607312, -9139.50922475156}, {
       4142.649334928727, -9139.50922475156}, {
       4142.649334928727, -9139.509224751293}, {
       4137.728297607312, -9139.509224751293}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9139.50922475156}, {
       4699.999999999998, -9139.50922475156}, {
       4699.999999999998, -9139.509224751293}, {
       4699.999999999998, -9139.509224751293}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668189031, -9139.50922475156}, {
      1601.2816681896652`, -9139.50922475156}, {
      1601.2816681896652`, -9139.509224751293}, {
      1601.281668189031, -9139.509224751293}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.05481087055, -9139.50922475136}, \
{3136.054810870684, -9139.509224751293}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05481087055, -9139.50922475136}, 1.3352294707280063`*^-10,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681897987`, -9139.509224751493}, {
       3136.05481087055, -9139.509224751493}, {
       3136.05481087055, -9139.50922475136}, {
       1601.2816681897987`, -9139.50922475136}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681897987`, -9139.509224751493}, 
       1.3352294707280063`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681896652`, -9139.50922475156}, \
{1601.2816681897987`, -9139.509224751493}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9139.509225042191}, {
       936.9705834037777, -9139.509225042191}, {
       936.9705834037777, -9139.50922475156}, {
       600.0828448818797, -9139.50922475156}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9139.509225042191}, {
       1335.9171194266337`, -9139.509225042191}, {
       1335.9171194266337`, -9139.50922475156}, {
       1335.9035702291205`, -9139.50922475156}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9139.509225042191}, {
       1601.2816681897987`, -9139.509225042191}, {
       1601.2816681897987`, -9139.50922475156}, {
       1601.281668189031, -9139.50922475156}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9139.509225042191}, {
       2655.488767788271, -9139.509225042191}, {
       2655.488767788271, -9139.50922475156}, {
       2648.884246253918, -9139.50922475156}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819746587524`, -9139.509225042191}, {
       2584.881975478067, -9139.509225042191}, {
       2584.881975478067, -9139.50922475156}, {
       2584.8819746587524`, -9139.50922475156}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9139.509225042191}, {
       3136.0548108793546`, -9139.509225042191}, {
       3136.0548108793546`, -9139.50922475156}, {
       3136.054810870684, -9139.50922475156}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9139.509225042191}, {
       3696.8203285884947`, -9139.509225042191}, {
       3696.8203285884947`, -9139.50922475156}, {
       3045.2472393254316`, -9139.50922475156}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4137.728297607312, -9139.509225042191}, {
       4142.649334928727, -9139.509225042191}, {
       4142.649334928727, -9139.50922475156}, {
       4137.728297607312, -9139.50922475156}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9139.509225042191}, {
       4699.999999999998, -9139.509225042191}, {
       4699.999999999998, -9139.50922475156}, {
       4699.999999999998, -9139.50922475156}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9139.509225042191}, {
       100.00006318768884`, -9139.509225042191}, {
       100.00006318768884`, -9139.50922475156}, {
       100, -9139.50922475156}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819745134365`, -9139.509224824218}, \
{2584.8819746587524`, -9139.50922475156}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819745134365`, -9139.509224824218}, 
       1.4531578045874963`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006333300462`, -9139.509224969534}, {
       2584.8819745134365`, -9139.509224969534}, {
       2584.8819745134365`, -9139.509224824218}, {
       100.00006333300462`, -9139.509224824218}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006333300462`, -9139.509224969534}, 
       1.4531578045874963`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00006318768884`, -9139.509225042191}, \
{100.00006333300462`, -9139.509224969534}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9139.50922631578}, {
        100.00006333300462`, -9139.50922631578}, {
        100.00006333300462`, -9139.509225042191}, {
        100, -9139.509225042191}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9139.50922631578}, {
       936.9705834037777, -9139.50922631578}, {
       936.9705834037777, -9139.509225042191}, {
       600.0828448818797, -9139.509225042191}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9139.50922631578}, {
       1335.9171194266337`, -9139.50922631578}, {
       1335.9171194266337`, -9139.509225042191}, {
       1335.9035702291205`, -9139.509225042191}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9139.50922631578}, {
       1601.2816681897987`, -9139.50922631578}, {
       1601.2816681897987`, -9139.509225042191}, {
       1601.281668189031, -9139.509225042191}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9139.50922631578}, {
       2655.488767788271, -9139.50922631578}, {
       2655.488767788271, -9139.509225042191}, {
       2648.884246253918, -9139.509225042191}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9139.50922631578}, {
       3136.0548108793546`, -9139.50922631578}, {
       3136.0548108793546`, -9139.509225042191}, {
       3136.054810870684, -9139.509225042191}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9139.50922631578}, {
       3696.8203285884947`, -9139.50922631578}, {
       3696.8203285884947`, -9139.509225042191}, {
       3045.2472393254316`, -9139.509225042191}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4137.728298244107, -9139.50922631578}, {
       4142.649334928726, -9139.50922631578}, {
       4142.649334928726, -9139.509225042191}, {
       4137.728298244107, -9139.509225042191}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9139.50922631578}, {
       4699.999999999998, -9139.50922631578}, {
       4699.999999999998, -9139.509225042191}, {
       4699.999999999998, -9139.509225042191}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819746587524`, -9139.50922631578}, {
      2584.881975478067, -9139.50922631578}, {
      2584.881975478067, -9139.509225042191}, {
      2584.8819746587524`, -9139.509225042191}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4137.728297607312, -9139.509225360589}, \
{4137.728298244107, -9139.509225042191}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4137.728297607312, -9139.509225360589}, 6.36794685343387*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.881976114862, -9139.509225997383}, {
       4137.728297607312, -9139.509225997383}, {
       4137.728297607312, -9139.509225360589}, {
       2584.881976114862, -9139.509225360589}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881976114862, -9139.509225997383}, 6.36794685343387*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881975478067, -9139.50922631578}, \
{2584.881976114862, -9139.509225997383}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9146.375273232237}, {
        100.00006333300462`, -9146.375273232237}, {
        100.00006333300462`, -9139.50922631578}, {
        100, -9139.50922631578}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828448818797, -9146.375273232237}, {
       933.5375599455488, -9146.375273232237}, {
       933.5375599455488, -9139.50922631578}, {
       600.0828448818797, -9139.50922631578}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9146.375273232237}, {
       1335.9171194266337`, -9146.375273232237}, {
       1335.9171194266337`, -9139.50922631578}, {
       1335.9035702291205`, -9139.50922631578}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9146.375273232237}, {
       1601.2816681897987`, -9146.375273232237}, {
       1601.2816681897987`, -9139.50922631578}, {
       1601.281668189031, -9139.50922631578}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9146.375273232237}, {
       2655.488767788271, -9146.375273232237}, {
       2655.488767788271, -9139.50922631578}, {
       2648.884246253918, -9139.50922631578}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819746587524`, -9146.375273232237}, {
       2584.881976114862, -9146.375273232237}, {
       2584.881976114862, -9139.50922631578}, {
       2584.8819746587524`, -9139.50922631578}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9146.375273232237}, {
       3136.0548108793546`, -9146.375273232237}, {
       3136.0548108793546`, -9139.50922631578}, {
       3136.054810870684, -9139.50922631578}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9146.375273232237}, {
       3696.8203285884947`, -9146.375273232237}, {
       3696.8203285884947`, -9139.50922631578}, {
       3045.2472393254316`, -9139.50922631578}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9146.375273232237}, {
       4699.999999999998, -9146.375273232237}, {
       4699.999999999998, -9139.50922631578}, {
       4699.999999999998, -9139.50922631578}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4137.728298244107, -9146.375273232237}, {
      4142.649334928727, -9146.375273232237}, {
      4142.649334928727, -9139.50922631578}, {
      4137.728298244107, -9139.50922631578}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{933.5375599455488, -9141.225738044894}, \
{936.9705834037777, -9139.50922631578}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{936.9705834037777, -9141.225738044894}, 3.433023458228873, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{936.9705834037777, -9144.658761503122}, {
       4134.295274785878, -9144.658761503122}, {
       4134.295274785878, -9141.225738044894}, {
       936.9705834037777, -9141.225738044894}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.295274785878, -9144.658761503122}, 3.433023458228873, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.295274785878, -9146.375273232237}, \
{4137.728298244107, -9144.658761503122}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9146.375276690756}, {
        100.00006160374465`, -9146.375276690756}, {
        100.00006160374465`, -9146.375273232237}, {
        100, -9146.375273232237}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9146.375276690756}, {
       1335.9171194266337`, -9146.375276690756}, {
       1335.9171194266337`, -9146.375273232237}, {
       1335.9035702291205`, -9146.375273232237}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9146.375276690756}, {
       1601.2816681897987`, -9146.375276690756}, {
       1601.2816681897987`, -9146.375273232237}, {
       1601.281668189031, -9146.375273232237}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9146.375276690756}, {
       2655.488767788271, -9146.375276690756}, {
       2655.488767788271, -9146.375273232237}, {
       2648.884246253918, -9146.375273232237}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819746587524`, -9146.375276690756}, {
       2584.881976114862, -9146.375276690756}, {
       2584.881976114862, -9146.375273232237}, {
       2584.8819746587524`, -9146.375273232237}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9146.375276690756}, {
       3136.0548108793546`, -9146.375276690756}, {
       3136.0548108793546`, -9146.375273232237}, {
       3136.054810870684, -9146.375273232237}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9146.375276690756}, {
       3696.8203285884947`, -9146.375276690756}, {
       3696.8203285884947`, -9146.375273232237}, {
       3045.2472393254316`, -9146.375273232237}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274785878, -9146.375276690756}, {
       4142.649334928727, -9146.375276690756}, {
       4142.649334928727, -9146.375273232237}, {
       4134.295274785878, -9146.375273232237}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9146.375276690756}, {
       4699.999999999998, -9146.375276690756}, {
       4699.999999999998, -9146.375273232237}, {
       4699.999999999998, -9146.375273232237}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828448818797, -9146.375276690756}, {
      933.5375599455488, -9146.375276690756}, {
      933.5375599455488, -9146.375273232237}, {
      600.0828448818797, -9146.375273232237}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00006160374465`, -9146.375274096867}, \
{100.00006333300462`, -9146.375273232237}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006333300462`, -9146.375274096867}, 
       1.7292599608023928`*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006333300462`, -9146.375275826127}, {
       600.0828431526198, -9146.375275826127}, {
       600.0828431526198, -9146.375274096867}, {
       100.00006333300462`, -9146.375274096867}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0828431526198, -9146.375275826127}, 
       1.7292599608023928`*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0828431526198, -9146.375276690756}, \
{600.0828448818797, -9146.375275826127}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9146.375276700284}, {
        100.00006160374465`, -9146.375276700284}, {
        100.00006160374465`, -9146.375276690756}, {
        100, -9146.375276690756}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9146.375276700284}, {
       933.5375599455488, -9146.375276700284}, {
       933.5375599455488, -9146.375276690756}, {
       600.0828431526198, -9146.375276690756}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9146.375276700284}, {
       1335.9171194266337`, -9146.375276700284}, {
       1335.9171194266337`, -9146.375276690756}, {
       1335.9035702291205`, -9146.375276690756}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9146.375276700284}, {
       1601.2816681897987`, -9146.375276700284}, {
       1601.2816681897987`, -9146.375276690756}, {
       1601.281668189031, -9146.375276690756}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9146.375276700284}, {
       2655.488767788271, -9146.375276700284}, {
       2655.488767788271, -9146.375276690756}, {
       2648.884246253918, -9146.375276690756}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819746587524`, -9146.375276700284}, {
       2584.881976114862, -9146.375276700284}, {
       2584.881976114862, -9146.375276690756}, {
       2584.8819746587524`, -9146.375276690756}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9146.375276700284}, {
       3136.054810874591, -9146.375276700284}, {
       3136.054810874591, -9146.375276690756}, {
       3136.054810870684, -9146.375276690756}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9146.375276700284}, {
       3696.8203285884947`, -9146.375276700284}, {
       3696.8203285884947`, -9146.375276690756}, {
       3045.2472393254316`, -9146.375276690756}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9146.375276700284}, {
       4699.999999999998, -9146.375276700284}, {
       4699.999999999998, -9146.375276690756}, {
       4699.999999999998, -9146.375276690756}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.295274785878, -9146.375276700284}, {
      4142.649334928726, -9146.375276700284}, {
      4142.649334928726, -9146.375276690756}, {
      4134.295274785878, -9146.375276690756}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810874591, -9146.37527669314}, \
{3136.0548108793546`, -9146.375276690756}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108793546`, -9146.37527669314}, 
       4.7635383216618905`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108793546`, -9146.375276697903}, {
       4134.295274781114, -9146.375276697903}, {
       4134.295274781114, -9146.37527669314}, {
       3136.0548108793546`, -9146.37527669314}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.295274781114, -9146.375276697903}, 
       4.7635383216618905`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.295274781114, -9146.375276700284}, \
{4134.295274785878, -9146.375276697903}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9146.375277564566}, {
        100.00006117160389`, -9146.375277564566}, {
        100.00006117160389`, -9146.375276700284}, {
        100, -9146.375276700284}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9146.375277564566}, {
       933.5375599455488, -9146.375277564566}, {
       933.5375599455488, -9146.375276700284}, {
       600.0828431526198, -9146.375276700284}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9146.375277564566}, {
       1335.9171194266337`, -9146.375277564566}, {
       1335.9171194266337`, -9146.375276700284}, {
       1335.9035702291205`, -9146.375276700284}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9146.375277564566}, {
       1601.2816681897987`, -9146.375277564566}, {
       1601.2816681897987`, -9146.375276700284}, {
       1601.281668189031, -9146.375276700284}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884246253918, -9146.375277564566}, {
       2655.488767788271, -9146.375277564566}, {
       2655.488767788271, -9146.375276700284}, {
       2648.884246253918, -9146.375276700284}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9146.375277564566}, {
       3136.054810874591, -9146.375277564566}, {
       3136.054810874591, -9146.375276700284}, {
       3136.054810870684, -9146.375276700284}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9146.375277564566}, {
       3696.8203285884947`, -9146.375277564566}, {
       3696.8203285884947`, -9146.375276700284}, {
       3045.2472393254316`, -9146.375276700284}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9146.375277564566}, {
       4142.649334928726, -9146.375277564566}, {
       4142.649334928726, -9146.375276700284}, {
       4134.295274781114, -9146.375276700284}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9146.375277564566}, {
       4699.999999999998, -9146.375277564566}, {
       4699.999999999998, -9146.375276700284}, {
       4699.999999999998, -9146.375276700284}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819746587524`, -9146.375277564566}, {
      2584.8819761148616`, -9146.375277564566}, {
      2584.8819761148616`, -9146.375276700284}, {
      2584.8819746587524`, -9146.375276700284}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00006117160389`, -9146.375276916355}, \
{100.00006160374465`, -9146.375276700284}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006160374465`, -9146.375276916355}, 
       4.3214076254368706`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006160374465`, -9146.375277348496}, {
       2584.8819742266114`, -9146.375277348496}, {
       2584.8819742266114`, -9146.375276916355}, {
       100.00006160374465`, -9146.375276916355}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819742266114`, -9146.375277348496}, 
       4.3214076254368706`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819742266114`, -9146.375277564566}, \
{2584.8819746587524`, -9146.375277348496}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9146.375363349622}, {
        100.00001827907573`, -9146.375363349622}, {
        100.00001827907573`, -9146.375277564566}, {
        100, -9146.375277564566}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9146.375363349622}, {
       933.5375599455488, -9146.375363349622}, {
       933.5375599455488, -9146.375277564566}, {
       600.0828431526198, -9146.375277564566}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9146.375363349622}, {
       1335.9171194266337`, -9146.375363349622}, {
       1335.9171194266337`, -9146.375277564566}, {
       1335.9035702291205`, -9146.375277564566}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9146.375363349622}, {
       1601.2816681897987`, -9146.375363349622}, {
       1601.2816681897987`, -9146.375277564566}, {
       1601.281668189031, -9146.375277564566}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9146.375363349622}, {
       2584.8819761148616`, -9146.375363349622}, {
       2584.8819761148616`, -9146.375277564566}, {
       2584.8819742266114`, -9146.375277564566}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9146.375363349622}, {
       3136.054810874591, -9146.375363349622}, {
       3136.054810874591, -9146.375277564566}, {
       3136.054810870684, -9146.375277564566}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{3045.2472393254316`, -9146.375363349622}, {
       3696.8203285884947`, -9146.375363349622}, {
       3696.8203285884947`, -9146.375277564566}, {
       3045.2472393254316`, -9146.375277564566}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9146.375363349622}, {
       4142.649334928726, -9146.375363349622}, {
       4142.649334928726, -9146.375277564566}, {
       4134.295274781114, -9146.375277564566}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9146.375363349622}, {
       4699.999999999998, -9146.375363349622}, {
       4699.999999999998, -9146.375277564566}, {
       4699.999999999998, -9146.375277564566}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.884246253918, -9146.375363349622}, {
      2655.488767788271, -9146.375363349622}, {
      2655.488767788271, -9146.375277564566}, {
      2648.884246253918, -9146.375277564566}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001827907573`, -9146.37529901083}, \
{100.00006117160389`, -9146.375277564566}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00006117160389`, -9146.37529901083}, 
       0.000042892528150259674`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00006117160389`, -9146.375341903358}, {
       2648.8842033613896`, -9146.375341903358}, {
       2648.8842033613896`, -9146.37529901083}, {
       100.00006117160389`, -9146.37529901083}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2648.8842033613896`, -9146.375341903358}, 
       0.000042892528150259674`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.8842033613896`, -9146.375363349622}, \
{2648.884246253918, -9146.375341903358}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9152.715966143796}, {
        100.00001827907573`, -9152.715966143796}, {
        100.00001827907573`, -9146.375363349622}, {
        100, -9146.375363349622}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9152.715966143796}, {
       933.5375599455488, -9152.715966143796}, {
       933.5375599455488, -9146.375363349622}, {
       600.0828431526198, -9146.375363349622}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9152.715966143796}, {
       1335.9171194266337`, -9152.715966143796}, {
       1335.9171194266337`, -9146.375363349622}, {
       1335.9035702291205`, -9146.375363349622}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9152.715966143796}, {
       1601.2816681897987`, -9152.715966143796}, {
       1601.2816681897987`, -9146.375363349622}, {
       1601.281668189031, -9146.375363349622}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8842033613896`, -9152.715966143796}, {
       2652.318466391184, -9152.715966143796}, {
       2652.318466391184, -9146.375363349622}, {
       2648.8842033613896`, -9146.375363349622}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9152.715966143796}, {
       2584.8819761148616`, -9152.715966143796}, {
       2584.8819761148616`, -9146.375363349622}, {
       2584.8819742266114`, -9146.375363349622}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9152.715966143796}, {
       3136.054810874591, -9152.715966143796}, {
       3136.054810874591, -9146.375363349622}, {
       3136.054810870684, -9146.375363349622}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9152.715966143796}, {
       4142.649334928726, -9152.715966143796}, {
       4142.649334928726, -9146.375363349622}, {
       4134.295274781114, -9146.375363349622}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9152.715966143796}, {
       4699.999999999998, -9152.715966143796}, {
       4699.999999999998, -9146.375363349622}, {
       4699.999999999998, -9146.375363349622}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3045.2472393254316`, -9152.715966143796}, {
      3696.8203285884947`, -9152.715966143796}, {
      3696.8203285884947`, -9146.375363349622}, {
      3045.2472393254316`, -9146.375363349622}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.318466391184, -9147.960514048165}, \
{2655.488767788271, -9146.375363349622}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2655.488767788271, -9147.960514048165}, 3.1703013970875515`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2655.488767788271, -9151.130815445253}, {
       3042.076937928344, -9151.130815445253}, {
       3042.076937928344, -9147.960514048165}, {
       2655.488767788271, -9147.960514048165}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3042.076937928344, -9151.130815445253}, 3.1703013970875515`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3042.076937928344, -9152.715966143796}, \
{3045.2472393254316`, -9151.130815445253}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037385776197}, {
        100.00001827907573`, -9716.037385776197}, {
        100.00001827907573`, -9152.715966143796}, {
        100, -9152.715966143796}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037385776197}, {
       651.8768501293489, -9716.037385776197}, {
       651.8768501293489, -9152.715966143796}, {
       600.0828431526198, -9152.715966143796}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037385776197}, {
       1335.9171194266337`, -9716.037385776197}, {
       1335.9171194266337`, -9152.715966143796}, {
       1335.9035702291205`, -9152.715966143796}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037385776197}, {
       1601.2816681897987`, -9716.037385776197}, {
       1601.2816681897987`, -9152.715966143796}, {
       1601.281668189031, -9152.715966143796}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8842033613896`, -9716.037385776197}, {
       2652.318466391184, -9716.037385776197}, {
       2652.318466391184, -9152.715966143796}, {
       2648.8842033613896`, -9152.715966143796}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9716.037385776197}, {
       2584.8819761148616`, -9716.037385776197}, {
       2584.8819761148616`, -9152.715966143796}, {
       2584.8819742266114`, -9152.715966143796}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037385776197}, {
       3136.054810874591, -9716.037385776197}, {
       3136.054810874591, -9152.715966143796}, {
       3136.054810870684, -9152.715966143796}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.037385776197}, {
       4142.649334928726, -9716.037385776197}, {
       4142.649334928726, -9152.715966143796}, {
       4134.295274781114, -9152.715966143796}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037385776197}, {
       4699.999999999998, -9716.037385776197}, {
       4699.999999999998, -9152.715966143796}, {
       4699.999999999998, -9152.715966143796}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{3042.076937928344, -9716.037385776197}, {
      3696.8203285884947`, -9716.037385776197}, {
      3696.8203285884947`, -9152.715966143796}, {
      3042.076937928344, -9152.715966143796}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{651.8768501293489, -9293.546321051897}, \
{933.5375599455488, -9152.715966143796}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{933.5375599455488, -9293.546321051897}, 281.6607098161999, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{933.5375599455488, -9575.207030868098}, {
       2760.416228112144, -9575.207030868098}, {
       2760.416228112144, -9293.546321051897}, {
       933.5375599455488, -9293.546321051897}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2760.416228112144, -9575.207030868098}, 281.6607098161999, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2760.416228112144, -9716.037385776197}, \
{3042.076937928344, -9575.207030868098}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037387022989}, {
        100.00001765568021`, -9716.037387022989}, {
        100.00001765568021`, -9716.037385776197}, {
        100, -9716.037385776197}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037387022989}, {
       651.8768501293489, -9716.037387022989}, {
       651.8768501293489, -9716.037385776197}, {
       600.0828431526198, -9716.037385776197}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037387022989}, {
       1335.9171194266337`, -9716.037387022989}, {
       1335.9171194266337`, -9716.037385776197}, {
       1335.9035702291205`, -9716.037385776197}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037387022989}, {
       1601.2816681897987`, -9716.037387022989}, {
       1601.2816681897987`, -9716.037385776197}, {
       1601.281668189031, -9716.037385776197}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9716.037387022989}, {
       2584.8819761148616`, -9716.037387022989}, {
       2584.8819761148616`, -9716.037385776197}, {
       2584.8819742266114`, -9716.037385776197}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037387022989}, {
       3136.054810874591, -9716.037387022989}, {
       3136.054810874591, -9716.037385776197}, {
       3136.054810870684, -9716.037385776197}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416228112144, -9716.037387022989}, {
       3696.8203285884947`, -9716.037387022989}, {
       3696.8203285884947`, -9716.037385776197}, {
       2760.416228112144, -9716.037385776197}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.037387022989}, {
       4142.649334928726, -9716.037387022989}, {
       4142.649334928726, -9716.037385776197}, {
       4134.295274781114, -9716.037385776197}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037385776197}, {
       4699.999999999998, -9716.037385776197}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.8842033613896`, -9716.037387022989}, {
      2652.318466391184, -9716.037387022989}, {
      2652.318466391184, -9716.037385776197}, {
      2648.8842033613896`, -9716.037385776197}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001765568021`, -9716.037386087895}, \
{100.00001827907573`, -9716.037385776197}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00001827907573`, -9716.037386087895}, 6.2339552396867*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00001827907573`, -9716.03738671129}, {
       2648.884202737994, -9716.03738671129}, {
       2648.884202737994, -9716.037386087895}, {
       100.00001827907573`, -9716.037386087895}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2648.884202737994, -9716.03738671129}, 6.2339552396867*^-7, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.884202737994, -9716.037387022989}, \
{2648.8842033613896`, -9716.03738671129}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037387022989}, {
       651.8768501293489, -9716.037387022989}, {
       651.8768501293489, -9716.037387022989}, {
       600.0828431526198, -9716.037387022989}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037387022989}, {
       1335.9171194266337`, -9716.037387022989}, {
       1335.9171194266337`, -9716.037387022989}, {
       1335.9035702291205`, -9716.037387022989}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037387022989}, {
       1601.2816681897987`, -9716.037387022989}, {
       1601.2816681897987`, -9716.037387022989}, {
       1601.281668189031, -9716.037387022989}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037387022989}, {
       2652.318466391184, -9716.037387022989}, {
       2652.318466391184, -9716.037387022989}, {
       2648.884202737994, -9716.037387022989}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9716.037387022989}, {
       2584.8819761148616`, -9716.037387022989}, {
       2584.8819761148616`, -9716.037387022989}, {
       2584.8819742266114`, -9716.037387022989}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037387022989}, {
       3136.054810874591, -9716.037387022989}, {
       3136.054810874591, -9716.037387022989}, {
       3136.054810870684, -9716.037387022989}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416228112144, -9716.037387022989}, {
       3696.8203285884947`, -9716.037387022989}, {
       3696.8203285884947`, -9716.037387022989}, {
       2760.416228112144, -9716.037387022989}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.037387022989}, {
       4142.649334928726, -9716.037387022989}, {
       4142.649334928726, -9716.037387022989}, {
       4134.295274781114, -9716.037387022989}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9716.037387022989}, {
       100.00001765568021`, -9716.037387022989}, {
       100.00001765568021`, -9716.037387022989}, {
       100, -9716.037387022989}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.037387022989}, \
{4699.999999999998, -9716.037387022989}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.037387022989}, 7.161068315714499*^-16,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00001765568021`, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}, {
       100.00001765568021`, -9716.037387022989}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00001765568021`, -9716.037387022989}, 
       7.161068315714499*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001765568021`, -9716.037387022989}, \
{100.00001765568021`, -9716.037387022989}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.03738703062}, {
        100.00001765568021`, -9716.03738703062}, {
        100.00001765568021`, -9716.037387022989}, {
        100, -9716.037387022989}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.03738703062}, {
       651.8768501293489, -9716.03738703062}, {
       651.8768501293489, -9716.037387022989}, {
       600.0828431526198, -9716.037387022989}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.03738703062}, {
       1335.9171194266337`, -9716.03738703062}, {
       1335.9171194266337`, -9716.037387022989}, {
       1335.9035702291205`, -9716.037387022989}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.03738703062}, {
       1601.2816681897987`, -9716.03738703062}, {
       1601.2816681897987`, -9716.037387022989}, {
       1601.281668189031, -9716.037387022989}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.03738703062}, {
       2652.318466391184, -9716.03738703062}, {
       2652.318466391184, -9716.037387022989}, {
       2648.884202737994, -9716.037387022989}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9716.03738703062}, {
       2584.8819761148616`, -9716.03738703062}, {
       2584.8819761148616`, -9716.037387022989}, {
       2584.8819742266114`, -9716.037387022989}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.03738703062}, {
       3136.0548108707753`, -9716.03738703062}, {
       3136.0548108707753`, -9716.037387022989}, {
       3136.054810870684, -9716.037387022989}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.03738703062}, {
       4142.649334928726, -9716.03738703062}, {
       4142.649334928726, -9716.037387022989}, {
       4134.295274781114, -9716.037387022989}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.03738703062}, {
       4699.999999999998, -9716.03738703062}, {
       4699.999999999998, -9716.037387022989}, {
       4699.999999999998, -9716.037387022989}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.416228112144, -9716.03738703062}, {
      3696.8203285884942`, -9716.03738703062}, {
      3696.8203285884942`, -9716.037387022989}, {
      2760.416228112144, -9716.037387022989}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707753`, -9716.037387024895}, \
{3136.054810874591, -9716.037387022989}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810874591, -9716.037387024895}, 3.815717871971281*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810874591, -9716.037387028711}, {
       2760.416228108328, -9716.037387028711}, {
       2760.416228108328, -9716.037387024895}, {
       3136.054810874591, -9716.037387024895}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2760.416228108328, -9716.037387028711}, 
       3.815717871971281*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2760.416228108328, -9716.03738703062}, \
{2760.416228112144, -9716.037387028711}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037389454681}, {
        100.00001765568021`, -9716.037389454681}, {
        100.00001765568021`, -9716.03738703062}, {
        100, -9716.03738703062}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037389454681}, {
       651.8768501293489, -9716.037389454681}, {
       651.8768501293489, -9716.03738703062}, {
       600.0828431526198, -9716.03738703062}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037389454681}, {
       1335.9171194266337`, -9716.037389454681}, {
       1335.9171194266337`, -9716.03738703062}, {
       1335.9035702291205`, -9716.03738703062}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037389454681}, {
       1601.2816681897987`, -9716.037389454681}, {
       1601.2816681897987`, -9716.03738703062}, {
       1601.281668189031, -9716.03738703062}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037389454681}, {
       2652.318466391184, -9716.037389454681}, {
       2652.318466391184, -9716.03738703062}, {
       2648.884202737994, -9716.03738703062}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819742266114`, -9716.037389454681}, {
       2584.8819749028307`, -9716.037389454681}, {
       2584.8819749028307`, -9716.03738703062}, {
       2584.8819742266114`, -9716.03738703062}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037389454681}, {
       3136.0548108707753`, -9716.037389454681}, {
       3136.0548108707753`, -9716.03738703062}, {
       3136.054810870684, -9716.03738703062}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.037389454681}, {
       4142.649334928726, -9716.037389454681}, {
       4142.649334928726, -9716.03738703062}, {
       4134.295274781114, -9716.03738703062}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037389454681}, {
       4699.999999999998, -9716.037389454681}, {
       4699.999999999998, -9716.03738703062}, {
       4699.999999999998, -9716.03738703062}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.416228108328, -9716.037389454681}, {
      3696.8203285884942`, -9716.037389454681}, {
      3696.8203285884942`, -9716.03738703062}, {
      2760.416228108328, -9716.03738703062}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819749028307`, -9716.037387636634}, \
{2584.8819761148616`, -9716.03738703062}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819761148616`, -9716.037387636634}, 
       1.2120311340574137`*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819761148616`, -9716.037388848665}, {
       2760.416226896297, -9716.037388848665}, {
       2760.416226896297, -9716.037387636634}, {
       2584.8819761148616`, -9716.037387636634}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2760.416226896297, -9716.037388848665}, 
       1.2120311340574137`*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2760.416226896297, -9716.037389454681}, \
{2760.416228108328, -9716.037388848665}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390753723}, {
        100.00001765568021`, -9716.037390753723}, {
        100.00001765568021`, -9716.037389454681}, {
        100, -9716.037389454681}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390753723}, {
       651.8768501293489, -9716.037390753723}, {
       651.8768501293489, -9716.037389454681}, {
       600.0828431526198, -9716.037389454681}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037390753723}, {
       1335.9171194266337`, -9716.037390753723}, {
       1335.9171194266337`, -9716.037389454681}, {
       1335.9035702291205`, -9716.037389454681}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390753723}, {
       1601.2816681897987`, -9716.037390753723}, {
       1601.2816681897987`, -9716.037389454681}, {
       1601.281668189031, -9716.037389454681}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974876132, -9716.037390753723}, {
       2584.8819749028303`, -9716.037390753723}, {
       2584.8819749028303`, -9716.037389454681}, {
       2584.881974876132, -9716.037389454681}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390753723}, {
       3136.0548108707753`, -9716.037390753723}, {
       3136.0548108707753`, -9716.037389454681}, {
       3136.054810870684, -9716.037389454681}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390753723}, {
       3696.8203285884942`, -9716.037390753723}, {
       3696.8203285884942`, -9716.037389454681}, {
       2760.416226896297, -9716.037389454681}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781114, -9716.037390753723}, {
       4142.649334928726, -9716.037390753723}, {
       4142.649334928726, -9716.037389454681}, {
       4134.295274781114, -9716.037389454681}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390753723}, {
       4699.999999999998, -9716.037390753723}, {
       4699.999999999998, -9716.037389454681}, {
       4699.999999999998, -9716.037389454681}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.884202737994, -9716.037390753723}, {
      2652.318466391184, -9716.037390753723}, {
      2652.318466391184, -9716.037389454681}, {
      2648.884202737994, -9716.037389454681}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819742266114`, -9716.037389779442}, \
{2584.881974876132, -9716.037389454681}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819742266114`, -9716.037389779442}, 
       6.495207318992794*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.3184670407045`, -9716.037390428963}, {
       2584.8819742266114`, -9716.037390428963}, {
       2584.8819742266114`, -9716.037389779442}, {
       2652.3184670407045`, -9716.037389779442}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.3184670407045`, -9716.037390428963}, 
       6.495207318992794*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.318466391184, -9716.037390753723}, \
{2652.3184670407045`, -9716.037390428963}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753723}, {
        100, -9716.037390753723}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390753794}, {
       651.8768501293489, -9716.037390753794}, {
       651.8768501293489, -9716.037390753723}, {
       600.0828431526198, -9716.037390753723}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753723}, {
       1335.9035702291205`, -9716.037390753723}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753723}, {
       1601.281668189031, -9716.037390753723}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037390753794}, {
       2652.3184670407045`, -9716.037390753794}, {
       2652.3184670407045`, -9716.037390753723}, {
       2648.884202737994, -9716.037390753723}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974876132, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753723}, {
       2584.881974876132, -9716.037390753723}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753723}, {
       3136.054810870684, -9716.037390753723}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753723}, {
       2760.416226896297, -9716.037390753723}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753723}, {
       4699.999999999998, -9716.037390753723}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.295274781114, -9716.037390753794}, {
      4142.649334928727, -9716.037390753794}, {
      4142.649334928727, -9716.037390753723}, {
      4134.295274781114, -9716.037390753723}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707394`, -9716.037390753741}, \
{3136.0548108707753`, -9716.037390753723}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707753`, -9716.037390753741}, 
       3.575325494352469*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707753`, -9716.037390753776}, {
       4134.295274781079, -9716.037390753776}, {
       4134.295274781079, -9716.037390753741}, {
       3136.0548108707753`, -9716.037390753741}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.295274781079, -9716.037390753776}, 
       3.575325494352469*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.295274781079, -9716.037390753794}, \
{4134.295274781114, -9716.037390753776}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753794}, {
        100, -9716.037390753794}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390753794}, {
       651.8768501293489, -9716.037390753794}, {
       651.8768501293489, -9716.037390753794}, {
       600.0828431526198, -9716.037390753794}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753794}, {
       1335.9035702291205`, -9716.037390753794}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.281668189031, -9716.037390753794}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037390753794}, {
       2652.3184670407045`, -9716.037390753794}, {
       2652.3184670407045`, -9716.037390753794}, {
       2648.884202737994, -9716.037390753794}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974876132, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.881974876132, -9716.037390753794}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.054810870684, -9716.037390753794}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753794}, {
       2760.416226896297, -9716.037390753794}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.295274781079, -9716.037390753794}, {
      4142.649334928727, -9716.037390753794}, {
      4142.649334928727, -9716.037390753794}, {
      4134.295274781079, -9716.037390753794}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.037390753794}, \
{4699.999999999998, -9716.037390753794}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.037390753794}, 
       3.3060536512456424`*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928727, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4142.649334928727, -9716.037390753794}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928727, -9716.037390753794}, 
       3.3060536512456424`*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928727, -9716.037390753794}, \
{4142.649334928727, -9716.037390753794}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753794}, {
        100.00001765568021`, -9716.037390753794}, {
        100, -9716.037390753794}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390753794}, {
       651.8768501293489, -9716.037390753794}, {
       651.8768501293489, -9716.037390753794}, {
       600.0828431526198, -9716.037390753794}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753794}, {
       1335.9171194266337`, -9716.037390753794}, {
       1335.9035702291205`, -9716.037390753794}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.281668189031, -9716.037390753794}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974876132, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.881974876132, -9716.037390753794}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.054810870684, -9716.037390753794}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753794}, {
       3696.8203285884942`, -9716.037390753794}, {
       2760.416226896297, -9716.037390753794}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781079, -9716.037390753794}, {
       4142.649334928727, -9716.037390753794}, {
       4142.649334928727, -9716.037390753794}, {
       4134.295274781079, -9716.037390753794}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.884202737994, -9716.037390753794}, {
      2652.3184670407045`, -9716.037390753794}, {
      2652.3184670407045`, -9716.037390753794}, {
      2648.884202737994, -9716.037390753794}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.037390753794}, \
{4699.999999999998, -9716.037390753794}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.037390753794}, 5.794329006879596*^-16,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.3184670407045`, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}, {
       2652.3184670407045`, -9716.037390753794}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.3184670407045`, -9716.037390753794}, 
       5.794329006879596*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.3184670407045`, -9716.037390753794}, \
{2652.3184670407045`, -9716.037390753794}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390797968}, {
        100.00001765568021`, -9716.037390797968}, {
        100.00001765568021`, -9716.037390753794}, {
        100, -9716.037390753794}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390797968}, {
       651.8768501293489, -9716.037390797968}, {
       651.8768501293489, -9716.037390753794}, {
       600.0828431526198, -9716.037390753794}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390797968}, {
       1601.2816681897987`, -9716.037390797968}, {
       1601.2816681897987`, -9716.037390753794}, {
       1601.281668189031, -9716.037390753794}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037390797968}, {
       2652.3184670407045`, -9716.037390797968}, {
       2652.3184670407045`, -9716.037390753794}, {
       2648.884202737994, -9716.037390753794}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.037390797968}, {
       2584.8819749028303`, -9716.037390797968}, {
       2584.8819749028303`, -9716.037390753794}, {
       2584.8819748982187`, -9716.037390753794}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390797968}, {
       3136.0548108707394`, -9716.037390797968}, {
       3136.0548108707394`, -9716.037390753794}, {
       3136.054810870684, -9716.037390753794}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390797968}, {
       3696.8203285884942`, -9716.037390797968}, {
       3696.8203285884942`, -9716.037390753794}, {
       2760.416226896297, -9716.037390753794}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.295274781079, -9716.037390797968}, {
       4142.649334928727, -9716.037390797968}, {
       4142.649334928727, -9716.037390753794}, {
       4134.295274781079, -9716.037390753794}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390797968}, {
       4699.999999999998, -9716.037390797968}, {
       4699.999999999998, -9716.037390753794}, {
       4699.999999999998, -9716.037390753794}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.9035702291205`, -9716.037390797968}, {
      1335.9171194266337`, -9716.037390797968}, {
      1335.9171194266337`, -9716.037390753794}, {
      1335.9035702291205`, -9716.037390753794}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974876132, -9716.037390764837}, \
{2584.8819748982187`, -9716.037390753794}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974876132, -9716.037390764837}, 2.208681588377356*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9171194487205`, -9716.037390786925}, {
       2584.881974876132, -9716.037390786925}, {
       2584.881974876132, -9716.037390764837}, {
       1335.9171194487205`, -9716.037390764837}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9171194487205`, -9716.037390786925}, 
       2.208681588377356*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9171194266337`, -9716.037390797968}, \
{1335.9171194487205`, -9716.037390786925}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.037390802769}, {
        100.00001765568021`, -9716.037390802769}, {
        100.00001765568021`, -9716.037390797968}, {
        100, -9716.037390797968}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.037390802769}, {
       651.8768501293489, -9716.037390802769}, {
       651.8768501293489, -9716.037390797968}, {
       600.0828431526198, -9716.037390797968}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.037390802769}, {
       1335.9171194487205`, -9716.037390802769}, {
       1335.9171194487205`, -9716.037390797968}, {
       1335.9035702291205`, -9716.037390797968}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.037390802769}, {
       1601.2816681897987`, -9716.037390802769}, {
       1601.2816681897987`, -9716.037390797968}, {
       1601.281668189031, -9716.037390797968}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.037390802769}, {
       2652.3184670407045`, -9716.037390802769}, {
       2652.3184670407045`, -9716.037390797968}, {
       2648.884202737994, -9716.037390797968}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.037390802769}, {
       2584.88197490043, -9716.037390802769}, {
       2584.88197490043, -9716.037390797968}, {
       2584.8819748982187`, -9716.037390797968}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870684, -9716.037390802769}, {
       3136.0548108707394`, -9716.037390802769}, {
       3136.0548108707394`, -9716.037390797968}, {
       3136.054810870684, -9716.037390797968}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.037390802769}, {
       3696.8203285884942`, -9716.037390802769}, {
       3696.8203285884942`, -9716.037390797968}, {
       2760.416226896297, -9716.037390797968}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.037390802769}, {
       4699.999999999998, -9716.037390802769}, {
       4699.999999999998, -9716.037390797968}, {
       4699.999999999998, -9716.037390797968}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.295274781079, -9716.037390802769}, {
      4142.649334928727, -9716.037390802769}, {
      4142.649334928727, -9716.037390797968}, {
      4134.295274781079, -9716.037390797968}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.88197490043, -9716.037390799169}, \
{2584.8819749028303`, -9716.037390797968}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819749028303`, -9716.037390799169}, 
       2.4002232535374305`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819749028303`, -9716.037390801568}, {
       4134.2952747786785`, -9716.037390801568}, {
       4134.2952747786785`, -9716.037390799169}, {
       2584.8819749028303`, -9716.037390799169}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.2952747786785`, -9716.037390801568}, 
       2.4002232535374305`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.2952747786785`, -9716.037390802769}, \
{4134.295274781079, -9716.037390801568}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.03739080277}, {
        100.00001765568021`, -9716.03739080277}, {
        100.00001765568021`, -9716.037390802769}, {
        100, -9716.037390802769}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.03739080277}, {
       651.8768501293489, -9716.03739080277}, {
       651.8768501293489, -9716.037390802769}, {
       600.0828431526198, -9716.037390802769}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.03739080277}, {
       1335.9171194487205`, -9716.03739080277}, {
       1335.9171194487205`, -9716.037390802769}, {
       1335.9035702291205`, -9716.037390802769}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.884202737994, -9716.03739080277}, {
       2652.3184670407045`, -9716.03739080277}, {
       2652.3184670407045`, -9716.037390802769}, {
       2648.884202737994, -9716.037390802769}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.03739080277}, {
       2584.88197490043, -9716.03739080277}, {
       2584.88197490043, -9716.037390802769}, {
       2584.8819748982187`, -9716.037390802769}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870685, -9716.03739080277}, {
       3136.05481087074, -9716.03739080277}, {
       3136.05481087074, -9716.037390802769}, {
       3136.054810870685, -9716.037390802769}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.03739080277}, {
       3696.8203285884942`, -9716.03739080277}, {
       3696.8203285884942`, -9716.037390802769}, {
       2760.416226896297, -9716.037390802769}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.2952747786785`, -9716.03739080277}, {
       4142.649334928727, -9716.03739080277}, {
       4142.649334928727, -9716.037390802769}, {
       4134.2952747786785`, -9716.037390802769}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.03739080277}, {
       4699.999999999998, -9716.03739080277}, {
       4699.999999999998, -9716.037390802769}, {
       4699.999999999998, -9716.037390802769}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668189031, -9716.03739080277}, {
      1601.2816681897987`, -9716.03739080277}, {
      1601.2816681897987`, -9716.037390802769}, {
      1601.281668189031, -9716.037390802769}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870684, -9716.037390802769}, \
{3136.054810870685, -9716.037390802769}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810870684, -9716.037390802769}, 7.442771382263418*^-13,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681897993`, -9716.03739080277}, {
       3136.054810870684, -9716.03739080277}, {
       3136.054810870684, -9716.037390802769}, {
       1601.2816681897993`, -9716.037390802769}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681897993`, -9716.03739080277}, 
       7.442771382263418*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681897987`, -9716.03739080277}, \
{1601.2816681897993`, -9716.03739080277}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.038029861542}, {
        100.00001765568021`, -9716.038029861542}, {
        100.00001765568021`, -9716.03739080277}, {
        100, -9716.03739080277}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.038029861542}, {
       651.8768501293489, -9716.038029861542}, {
       651.8768501293489, -9716.03739080277}, {
       600.0828431526198, -9716.03739080277}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.038029861542}, {
       1601.2816681897993`, -9716.038029861542}, {
       1601.2816681897993`, -9716.03739080277}, {
       1601.281668189031, -9716.03739080277}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.038029861542}, {
       2652.3184670407045`, -9716.038029861542}, {
       2652.3184670407045`, -9716.03739080277}, {
       2648.8845222673804`, -9716.03739080277}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.038029861542}, {
       2584.88197490043, -9716.038029861542}, {
       2584.88197490043, -9716.03739080277}, {
       2584.8819748982187`, -9716.03739080277}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870685, -9716.038029861542}, {
       3136.05481087074, -9716.038029861542}, {
       3136.05481087074, -9716.03739080277}, {
       3136.054810870685, -9716.03739080277}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.038029861542}, {
       3696.8203285884942`, -9716.038029861542}, {
       3696.8203285884942`, -9716.03739080277}, {
       2760.416226896297, -9716.03739080277}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.2952747786785`, -9716.038029861542}, {
       4142.649334928727, -9716.038029861542}, {
       4142.649334928727, -9716.03739080277}, {
       4134.2952747786785`, -9716.03739080277}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.038029861542}, {
       4699.999999999998, -9716.038029861542}, {
       4699.999999999998, -9716.03739080277}, {
       4699.999999999998, -9716.03739080277}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.9035702291205`, -9716.038029861542}, {
      1335.9171194487205`, -9716.038029861542}, {
      1335.9171194487205`, -9716.03739080277}, {
      1335.9035702291205`, -9716.03739080277}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.884202737994, -9716.037550567462}, \
{2648.8845222673804`, -9716.03739080277}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2648.884202737994, -9716.037550567462}, 
       0.00031952938613925147`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9174389781067`, -9716.037870096849}, {
       2648.884202737994, -9716.037870096849}, {
       2648.884202737994, -9716.037550567462}, {
       1335.9174389781067`, -9716.037550567462}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9174389781067`, -9716.037870096849}, 
       0.00031952938613925147`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9171194487205`, -9716.038029861542}, \
{1335.9174389781067`, -9716.037870096849}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.038029861547}, {
        100.00001765567735`, -9716.038029861547}, {
        100.00001765567735`, -9716.038029861542}, {
        100, -9716.038029861542}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.038029861547}, {
       651.8768501293489, -9716.038029861547}, {
       651.8768501293489, -9716.038029861542}, {
       600.0828431526198, -9716.038029861542}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.038029861547}, {
       1335.9174389781067`, -9716.038029861547}, {
       1335.9174389781067`, -9716.038029861542}, {
       1335.9035702291205`, -9716.038029861542}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.038029861547}, {
       1601.2816681897993`, -9716.038029861547}, {
       1601.2816681897993`, -9716.038029861542}, {
       1601.281668189031, -9716.038029861542}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.038029861547}, {
       2652.3184670407045`, -9716.038029861547}, {
       2652.3184670407045`, -9716.038029861542}, {
       2648.8845222673804`, -9716.038029861542}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.038029861547}, {
       2584.88197490043, -9716.038029861547}, {
       2584.88197490043, -9716.038029861542}, {
       2584.8819748982187`, -9716.038029861542}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.416226896297, -9716.038029861547}, {
       3696.8203285884942`, -9716.038029861547}, {
       3696.8203285884942`, -9716.038029861542}, {
       2760.416226896297, -9716.038029861542}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.2952747786785`, -9716.038029861547}, {
       4142.649334928727, -9716.038029861547}, {
       4142.649334928727, -9716.038029861542}, {
       4134.2952747786785`, -9716.038029861542}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.038029861547}, {
       4699.999999999998, -9716.038029861547}, {
       4699.999999999998, -9716.038029861542}, {
       4699.999999999998, -9716.038029861542}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870685, -9716.038029861547}, {
      3136.05481087074, -9716.038029861547}, {
      3136.05481087074, -9716.038029861542}, {
      3136.054810870685, -9716.038029861542}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001765567735`, -9716.038029861544}, \
{100.00001765568021`, -9716.038029861542}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00001765568021`, -9716.038029861544}, 
       2.862906467934193*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00001765568021`, -9716.038029861546}, {
       3136.054810870682, -9716.038029861546}, {
       3136.054810870682, -9716.038029861544}, {
       100.00001765568021`, -9716.038029861544}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810870682, -9716.038029861546}, 
       2.862906467934193*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870682, -9716.038029861547}, \
{3136.054810870685, -9716.038029861546}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.038044802699}, {
        100.0000101851019, -9716.038044802699}, {
        100.0000101851019, -9716.038029861547}, {
        100, -9716.038029861547}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.038044802699}, {
       651.8768501293489, -9716.038044802699}, {
       651.8768501293489, -9716.038029861547}, {
       600.0828431526198, -9716.038029861547}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.038044802699}, {
       1335.9174389781067`, -9716.038044802699}, {
       1335.9174389781067`, -9716.038029861547}, {
       1335.9035702291205`, -9716.038029861547}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.038044802699}, {
       1601.2816681897993`, -9716.038044802699}, {
       1601.2816681897993`, -9716.038029861547}, {
       1601.281668189031, -9716.038029861547}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.038044802699}, {
       2652.3184670407045`, -9716.038044802699}, {
       2652.3184670407045`, -9716.038029861547}, {
       2648.8845222673804`, -9716.038029861547}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.038044802699}, {
       2584.88197490043, -9716.038044802699}, {
       2584.88197490043, -9716.038029861547}, {
       2584.8819748982187`, -9716.038029861547}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.038044802699}, {
       3136.05481087074, -9716.038044802699}, {
       3136.05481087074, -9716.038029861547}, {
       3136.054810870682, -9716.038029861547}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.2952747786785`, -9716.038044802699}, {
       4142.649334928727, -9716.038044802699}, {
       4142.649334928727, -9716.038029861547}, {
       4134.2952747786785`, -9716.038029861547}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038029861547}, {
       4699.999999999998, -9716.038029861547}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.416226896297, -9716.038044802699}, {
      3696.8203285884942`, -9716.038044802699}, {
      3696.8203285884942`, -9716.038029861547}, {
      2760.416226896297, -9716.038029861547}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000101851019, -9716.038033596837}, \
{100.00001765567735`, -9716.038029861547}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00001765567735`, -9716.038033596837}, 
       7.470575458915079*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00001765567735`, -9716.038041067412}, {
       2760.4162194257215`, -9716.038041067412}, {
       2760.4162194257215`, -9716.038033596837}, {
       100.00001765567735`, -9716.038033596837}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2760.4162194257215`, -9716.038041067412}, 
       7.470575458915079*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2760.4162194257215`, -9716.038044802699}, \
{2760.416226896297, -9716.038041067412}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.038044802699}, {
        100.0000101851019, -9716.038044802699}, {
        100.0000101851019, -9716.038044802699}, {
        100, -9716.038044802699}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.038044802699}, {
       651.8768501293489, -9716.038044802699}, {
       651.8768501293489, -9716.038044802699}, {
       600.0828431526198, -9716.038044802699}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.038044802699}, {
       1335.9174389781067`, -9716.038044802699}, {
       1335.9174389781067`, -9716.038044802699}, {
       1335.9035702291205`, -9716.038044802699}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.038044802699}, {
       1601.2816681897993`, -9716.038044802699}, {
       1601.2816681897993`, -9716.038044802699}, {
       1601.281668189031, -9716.038044802699}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.038044802699}, {
       2652.3184670407045`, -9716.038044802699}, {
       2652.3184670407045`, -9716.038044802699}, {
       2648.8845222673804`, -9716.038044802699}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.038044802699}, {
       2584.88197490043, -9716.038044802699}, {
       2584.88197490043, -9716.038044802699}, {
       2584.8819748982187`, -9716.038044802699}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.038044802699}, {
       3136.05481087074, -9716.038044802699}, {
       3136.05481087074, -9716.038044802699}, {
       3136.054810870682, -9716.038044802699}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.2952747786785`, -9716.038044802699}, {
       4142.649334928727, -9716.038044802699}, {
       4142.649334928727, -9716.038044802699}, {
       4134.2952747786785`, -9716.038044802699}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.4162194257215`, -9716.038044802699}, {
      3696.8203285884942`, -9716.038044802699}, {
      3696.8203285884942`, -9716.038044802699}, {
      2760.4162194257215`, -9716.038044802699}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.038044802699}, \
{4699.999999999998, -9716.038044802699}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.038044802699}, 9.327995294567965*^-15,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3696.8203285884942`, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}, {
       3696.8203285884942`, -9716.038044802699}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3696.8203285884942`, -9716.038044802699}, 
       9.327995294567965*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3696.8203285884942`, -9716.038044802699}, \
{3696.8203285884942`, -9716.038044802699}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.046011614106}, {
        100.0000101851019, -9716.046011614106}, {
        100.0000101851019, -9716.038044802699}, {
        100, -9716.038044802699}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}, {
       651.8768501293489, -9716.038044802699}, {
       600.0828431526198, -9716.038044802699}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.046011614106}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9134555724033`, -9716.038044802699}, {
       1335.9035702291205`, -9716.038044802699}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.046011614106}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.2816681897993`, -9716.038044802699}, {
       1601.281668189031, -9716.038044802699}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.046011614106}, {
       2652.3184670407045`, -9716.046011614106}, {
       2652.3184670407045`, -9716.038044802699}, {
       2648.8845222673804`, -9716.038044802699}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.046011614106}, {
       2584.88197490043, -9716.046011614106}, {
       2584.88197490043, -9716.038044802699}, {
       2584.8819748982187`, -9716.038044802699}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.046011614106}, {
       3136.05481087074, -9716.046011614106}, {
       3136.05481087074, -9716.038044802699}, {
       3136.054810870682, -9716.038044802699}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194257215`, -9716.046011614106}, {
       3696.8203285884942`, -9716.046011614106}, {
       3696.8203285884942`, -9716.038044802699}, {
       2760.4162194257215`, -9716.038044802699}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}, {
       4699.999999999998, -9716.038044802699}, {
       4699.999999999998, -9716.038044802699}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.2952747786785`, -9716.046011614106}, {
      4142.649334928727, -9716.046011614106}, {
      4142.649334928727, -9716.038044802699}, {
      4134.2952747786785`, -9716.038044802699}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9134555724033`, -9716.04003650555}, \
{1335.9174389781067`, -9716.038044802699}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9174389781067`, -9716.04003650555}, 0.003983405703397903, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9174389781067`, -9716.044019911255}, {
       4134.291291372975, -9716.044019911255}, {
       4134.291291372975, -9716.04003650555}, {
       1335.9174389781067`, -9716.04003650555}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.291291372975, -9716.044019911255}, 0.003983405703397903, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.291291372975, -9716.046011614106}, \
{4134.2952747786785`, -9716.044019911255}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.046011614106}, {
        100.0000101851019, -9716.046011614106}, {
        100.0000101851019, -9716.046011614106}, {
        100, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}, {
       600.0828431526198, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.046011614106}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9035702291205`, -9716.046011614106}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.046011614106}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.281668189031, -9716.046011614106}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.046011614106}, {
       2652.3184670407045`, -9716.046011614106}, {
       2652.3184670407045`, -9716.046011614106}, {
       2648.8845222673804`, -9716.046011614106}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.046011614106}, {
       2584.88197490043, -9716.046011614106}, {
       2584.88197490043, -9716.046011614106}, {
       2584.8819748982187`, -9716.046011614106}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.046011614106}, {
       3136.05481087074, -9716.046011614106}, {
       3136.05481087074, -9716.046011614106}, {
       3136.054810870682, -9716.046011614106}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194257215`, -9716.046011614106}, {
       3696.8203285884942`, -9716.046011614106}, {
       3696.8203285884942`, -9716.046011614106}, {
       2760.4162194257215`, -9716.046011614106}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.291291372975, -9716.046011614106}, {
       4142.649334928727, -9716.046011614106}, {
       4142.649334928727, -9716.046011614106}, {
       4134.291291372975, -9716.046011614106}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{651.8768501293489, -9716.046011614106}, \
{651.8768501293489, -9716.046011614106}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{651.8768501293489, -9716.046011614106}, 3.763214859494149*^-17,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{651.8768501293489, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.046011614106}, 
       3.763214859494149*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.046011614106}, \
{4699.999999999998, -9716.046011614106}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.046011614106}, {
        100.0000101851019, -9716.046011614106}, {
        100.0000101851019, -9716.046011614106}, {
        100, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}, {
       651.8768501293489, -9716.046011614106}, {
       600.0828431526198, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.046011614106}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9035702291205`, -9716.046011614106}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.046011614106}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.281668189031, -9716.046011614106}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.046011614106}, {
       2652.3184670407045`, -9716.046011614106}, {
       2652.3184670407045`, -9716.046011614106}, {
       2648.8845222673804`, -9716.046011614106}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.046011614106}, {
       2584.88197490043, -9716.046011614106}, {
       2584.88197490043, -9716.046011614106}, {
       2584.8819748982187`, -9716.046011614106}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.046011614106}, {
       3136.05481087074, -9716.046011614106}, {
       3136.05481087074, -9716.046011614106}, {
       3136.054810870682, -9716.046011614106}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194257215`, -9716.046011614106}, {
       3696.8203285884942`, -9716.046011614106}, {
       3696.8203285884942`, -9716.046011614106}, {
       2760.4162194257215`, -9716.046011614106}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.291291372975, -9716.046011614106}, {
       4142.649334928727, -9716.046011614106}, {
       4142.649334928727, -9716.046011614106}, {
       4134.291291372975, -9716.046011614106}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}, {
      4699.999999999998, -9716.046011614106}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000101851019, -9716.046011614106}, \
{100.0000101851019, -9716.046011614106}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000101851019, -9716.046011614106}, 6.940134214838963*^-16,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000101851019, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}, {
       100.0000101851019, -9716.046011614106}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9716.046011614106}, 
       6.940134214838963*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9716.046011614106}, \
{4699.999999999998, -9716.046011614106}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.046011614197}, {
        100.0000101851019, -9716.046011614197}, {
        100.0000101851019, -9716.046011614106}, {
        100, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.046011614197}, {
       651.8768501293489, -9716.046011614197}, {
       651.8768501293489, -9716.046011614106}, {
       600.0828431526198, -9716.046011614106}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.046011614197}, {
       1335.9134555724033`, -9716.046011614197}, {
       1335.9134555724033`, -9716.046011614106}, {
       1335.9035702291205`, -9716.046011614106}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.046011614197}, {
       1601.2816681897993`, -9716.046011614197}, {
       1601.2816681897993`, -9716.046011614106}, {
       1601.281668189031, -9716.046011614106}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.046011614197}, {
       2652.3184670407045`, -9716.046011614197}, {
       2652.3184670407045`, -9716.046011614106}, {
       2648.8845222673804`, -9716.046011614106}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748982187`, -9716.046011614197}, {
       2584.88197490043, -9716.046011614197}, {
       2584.88197490043, -9716.046011614106}, {
       2584.8819748982187`, -9716.046011614106}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.046011614197}, {
       3136.0548108706944`, -9716.046011614197}, {
       3136.0548108706944`, -9716.046011614106}, {
       3136.054810870682, -9716.046011614106}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.291291372975, -9716.046011614197}, {
       4142.649334928727, -9716.046011614197}, {
       4142.649334928727, -9716.046011614106}, {
       4134.291291372975, -9716.046011614106}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.046011614197}, {
       4699.999999999998, -9716.046011614197}, {
       4699.999999999998, -9716.046011614106}, {
       4699.999999999998, -9716.046011614106}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.4162194257215`, -9716.046011614197}, {
      3696.8203285884947`, -9716.046011614197}, {
      3696.8203285884947`, -9716.046011614106}, {
      2760.4162194257215`, -9716.046011614106}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706944`, -9716.04601161413}, \
{3136.05481087074, -9716.046011614106}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.05481087074, -9716.04601161413}, 4.5212226568459245`*^-11,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.05481087074, -9716.046011614175}, {
       2760.4162194256764`, -9716.046011614175}, {
       2760.4162194256764`, -9716.04601161413}, {
       3136.05481087074, -9716.04601161413}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2760.4162194256764`, -9716.046011614175}, 
       4.5212226568459245`*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2760.4162194256764`, -9716.046011614197}, \
{2760.4162194257215`, -9716.046011614175}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.046011614495}, {
        100.0000101851019, -9716.046011614495}, {
        100.0000101851019, -9716.046011614197}, {
        100, -9716.046011614197}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.046011614495}, {
       651.8768501293489, -9716.046011614495}, {
       651.8768501293489, -9716.046011614197}, {
       600.0828431526198, -9716.046011614197}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.046011614495}, {
       1335.9134555724033`, -9716.046011614495}, {
       1335.9134555724033`, -9716.046011614197}, {
       1335.9035702291205`, -9716.046011614197}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.8845222673804`, -9716.046011614495}, {
       2652.3184670407045`, -9716.046011614495}, {
       2652.3184670407045`, -9716.046011614197}, {
       2648.8845222673804`, -9716.046011614197}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748983674`, -9716.046011614495}, {
       2584.88197490043, -9716.046011614495}, {
       2584.88197490043, -9716.046011614197}, {
       2584.8819748983674`, -9716.046011614197}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.046011614495}, {
       3136.0548108706944`, -9716.046011614495}, {
       3136.0548108706944`, -9716.046011614197}, {
       3136.054810870682, -9716.046011614197}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9716.046011614495}, {
       3696.8203285884947`, -9716.046011614495}, {
       3696.8203285884947`, -9716.046011614197}, {
       2760.4162194256764`, -9716.046011614197}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.291291372975, -9716.046011614495}, {
       4142.649334928727, -9716.046011614495}, {
       4142.649334928727, -9716.046011614197}, {
       4134.291291372975, -9716.046011614197}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.046011614495}, {
       4699.999999999998, -9716.046011614495}, {
       4699.999999999998, -9716.046011614197}, {
       4699.999999999998, -9716.046011614197}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668189031, -9716.046011614495}, {
      1601.2816681897993`, -9716.046011614495}, {
      1601.2816681897993`, -9716.046011614197}, {
      1601.281668189031, -9716.046011614197}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748982187`, -9716.046011614271}, \
{2584.8819748983674`, -9716.046011614197}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748982187`, -9716.046011614271}, 
       1.4875606299077556`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189948, -9716.04601161442}, {
       2584.8819748982187`, -9716.04601161442}, {
       2584.8819748982187`, -9716.046011614271}, {
       1601.281668189948, -9716.046011614271}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189948, -9716.04601161442}, 
       1.4875606299077556`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681897993`, -9716.046011614495}, \
{1601.281668189948, -9716.04601161442}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9716.05928726065}, {
        100.0000101851019, -9716.05928726065}, {
        100.0000101851019, -9716.046011614495}, {
        100, -9716.046011614495}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9716.05928726065}, {
       651.8768501293489, -9716.05928726065}, {
       651.8768501293489, -9716.046011614495}, {
       600.0828431526198, -9716.046011614495}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9716.05928726065}, {
       1335.906817749326, -9716.05928726065}, {
       1335.906817749326, -9716.046011614495}, {
       1335.9035702291205`, -9716.046011614495}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9716.05928726065}, {
       1601.281668189948, -9716.05928726065}, {
       1601.281668189948, -9716.046011614495}, {
       1601.281668189031, -9716.046011614495}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748983674`, -9716.05928726065}, {
       2584.88197490043, -9716.05928726065}, {
       2584.88197490043, -9716.046011614495}, {
       2584.8819748983674`, -9716.046011614495}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9716.05928726065}, {
       3136.0548108706944`, -9716.05928726065}, {
       3136.0548108706944`, -9716.046011614495}, {
       3136.054810870682, -9716.046011614495}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9716.05928726065}, {
       3696.8203285884947`, -9716.05928726065}, {
       3696.8203285884947`, -9716.046011614495}, {
       2760.4162194256764`, -9716.046011614495}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.291291372975, -9716.05928726065}, {
       4142.649334928727, -9716.05928726065}, {
       4142.649334928727, -9716.046011614495}, {
       4134.291291372975, -9716.046011614495}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9716.05928726065}, {
       4699.999999999998, -9716.05928726065}, {
       4699.999999999998, -9716.046011614495}, {
       4699.999999999998, -9716.046011614495}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.8845222673804`, -9716.05928726065}, {
      2652.3184670407045`, -9716.05928726065}, {
      2652.3184670407045`, -9716.046011614495}, {
      2648.8845222673804`, -9716.046011614495}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.906817749326, -9716.049330526035}, \
{1335.9134555724033`, -9716.046011614495}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9134555724033`, -9716.049330526035}, 0.006637823077229276,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9134555724033`, -9716.055968349112}, {
       2648.877884444303, -9716.055968349112}, {
       2648.877884444303, -9716.049330526035}, {
       1335.9134555724033`, -9716.049330526035}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2648.877884444303, -9716.055968349112}, 0.006637823077229276, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.877884444303, -9716.05928726065}, \
{2648.8845222673804`, -9716.055968349112}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.724724022746}, {
        100.0000101851019, -9726.724724022746}, {
        100.0000101851019, -9716.05928726065}, {100, -9716.05928726065}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.724724022746}, {
       646.5441317483005, -9726.724724022746}, {
       646.5441317483005, -9716.05928726065}, {
       600.0828431526198, -9716.05928726065}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9726.724724022746}, {
       1335.906817749326, -9726.724724022746}, {
       1335.906817749326, -9716.05928726065}, {
       1335.9035702291205`, -9716.05928726065}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.724724022746}, {
       1601.281668189948, -9726.724724022746}, {
       1601.281668189948, -9716.05928726065}, {
       1601.281668189031, -9716.05928726065}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.724724022746}, {
       2652.3184670407045`, -9726.724724022746}, {
       2652.3184670407045`, -9716.05928726065}, {
       2648.877884444303, -9716.05928726065}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748983674`, -9726.724724022746}, {
       2584.88197490043, -9726.724724022746}, {
       2584.88197490043, -9716.05928726065}, {
       2584.8819748983674`, -9716.05928726065}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.724724022746}, {
       3136.0548108706944`, -9726.724724022746}, {
       3136.0548108706944`, -9716.05928726065}, {
       3136.054810870682, -9716.05928726065}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.724724022746}, {
       3696.8203285884947`, -9726.724724022746}, {
       3696.8203285884947`, -9716.05928726065}, {
       2760.4162194256764`, -9716.05928726065}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9726.724724022746}, {
       4699.999999999998, -9726.724724022746}, {
       4699.999999999998, -9716.05928726065}, {
       4699.999999999998, -9716.05928726065}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.291291372975, -9726.724724022746}, {
      4142.649334928727, -9726.724724022746}, {
      4142.649334928727, -9716.05928726065}, {
      4134.291291372975, -9716.05928726065}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{646.5441317483005, -9718.725646451174}, \
{651.8768501293489, -9716.05928726065}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{651.8768501293489, -9718.725646451174}, 5.332718381048348, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{651.8768501293489, -9724.058364832223}, {
       4128.958572991927, -9724.058364832223}, {
       4128.958572991927, -9718.725646451174}, {
       651.8768501293489, -9718.725646451174}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4128.958572991927, -9724.058364832223}, 5.332718381048348, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4128.958572991927, -9726.724724022746}, \
{4134.291291372975, -9724.058364832223}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.724724026351}, {
        100.0000101851019, -9726.724724026351}, {
        100.0000101851019, -9726.724724022746}, {
        100, -9726.724724022746}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.724724026351}, {
       646.5441317483005, -9726.724724026351}, {
       646.5441317483005, -9726.724724022746}, {
       600.0828431526198, -9726.724724022746}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9726.724724026351}, {
       1335.906817747523, -9726.724724026351}, {
       1335.906817747523, -9726.724724022746}, {
       1335.9035702291205`, -9726.724724022746}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.724724026351}, {
       1601.281668189948, -9726.724724026351}, {
       1601.281668189948, -9726.724724022746}, {
       1601.281668189031, -9726.724724022746}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.724724026351}, {
       2652.3184670407045`, -9726.724724026351}, {
       2652.3184670407045`, -9726.724724022746}, {
       2648.877884444303, -9726.724724022746}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.724724026351}, {
       3136.0548108706944`, -9726.724724026351}, {
       3136.0548108706944`, -9726.724724022746}, {
       3136.054810870682, -9726.724724022746}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.724724026351}, {
       3696.8203285884947`, -9726.724724026351}, {
       3696.8203285884947`, -9726.724724022746}, {
       2760.4162194256764`, -9726.724724022746}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.958572991927, -9726.724724026351}, {
       4142.649334928727, -9726.724724026351}, {
       4142.649334928727, -9726.724724022746}, {
       4128.958572991927, -9726.724724022746}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9726.724724026351}, {
       4699.999999999998, -9726.724724026351}, {
       4699.999999999998, -9726.724724022746}, {
       4699.999999999998, -9726.724724022746}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819748983674`, -9726.724724026351}, {
      2584.88197490043, -9726.724724026351}, {
      2584.88197490043, -9726.724724022746}, {
      2584.8819748983674`, -9726.724724022746}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.906817747523, -9726.724724023647}, \
{1335.906817749326, -9726.724724022746}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.906817749326, -9726.724724023647}, 
       1.8028270922481356`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.906817749326, -9726.72472402545}, {
       2584.8819748965648`, -9726.72472402545}, {
       2584.8819748965648`, -9726.724724023647}, {
       1335.906817749326, -9726.724724023647}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748965648`, -9726.72472402545}, 
       1.8028270922481356`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748965648`, -9726.724724026351}, \
{2584.8819748983674`, -9726.72472402545}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.724724033747}, {
        100.00001018140426`, -9726.724724033747}, {
        100.00001018140426`, -9726.724724026351}, {
        100, -9726.724724026351}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.724724033747}, {
       646.5441317483005, -9726.724724033747}, {
       646.5441317483005, -9726.724724026351}, {
       600.0828431526198, -9726.724724026351}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9726.724724033747}, {
       1335.906817747523, -9726.724724033747}, {
       1335.906817747523, -9726.724724026351}, {
       1335.9035702291205`, -9726.724724026351}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.724724033747}, {
       1601.281668189948, -9726.724724033747}, {
       1601.281668189948, -9726.724724026351}, {
       1601.281668189031, -9726.724724026351}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.724724033747}, {
       2652.3184670407045`, -9726.724724033747}, {
       2652.3184670407045`, -9726.724724026351}, {
       2648.877884444303, -9726.724724026351}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.724724033747}, {
       3136.0548108706944`, -9726.724724033747}, {
       3136.0548108706944`, -9726.724724026351}, {
       3136.054810870682, -9726.724724026351}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.724724033747}, {
       3696.8203285884947`, -9726.724724033747}, {
       3696.8203285884947`, -9726.724724026351}, {
       2760.4162194256764`, -9726.724724026351}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.958572991927, -9726.724724033747}, {
       4142.649334928727, -9726.724724033747}, {
       4142.649334928727, -9726.724724026351}, {
       4128.958572991927, -9726.724724026351}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9726.724724033747}, {
       4699.999999999998, -9726.724724033747}, {
       4699.999999999998, -9726.724724026351}, {
       4699.999999999998, -9726.724724026351}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819748965648`, -9726.724724033747}, {
      2584.88197490043, -9726.724724033747}, {
      2584.88197490043, -9726.724724026351}, {
      2584.8819748965648`, -9726.724724026351}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001018140426`, -9726.724724028201}, \
{100.0000101851019, -9726.724724026351}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000101851019, -9726.724724028201}, 
       3.6976253569201342`*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000101851019, -9726.7247240319}, {
       2584.881974892867, -9726.7247240319}, {
       2584.881974892867, -9726.724724028201}, {
       100.0000101851019, -9726.724724028201}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974892867, -9726.7247240319}, 
       3.6976253569201342`*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974892867, -9726.724724033747}, \
{2584.8819748965648`, -9726.7247240319}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.728014841949}, {
        100.00001018140426`, -9726.728014841949}, {
        100.00001018140426`, -9726.724724033747}, {
        100, -9726.724724033747}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.728014841949}, {
       646.5441317483005, -9726.728014841949}, {
       646.5441317483005, -9726.724724033747}, {
       600.0828431526198, -9726.724724033747}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.728014841949}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189948, -9726.724724033747}, {
       1601.281668189031, -9726.724724033747}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}, {
       2652.3184670407045`, -9726.724724033747}, {
       2648.877884444303, -9726.724724033747}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9726.728014841949}, {
       2584.88197490043, -9726.728014841949}, {
       2584.88197490043, -9726.724724033747}, {
       2584.881974892867, -9726.724724033747}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.728014841949}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.0548108706944`, -9726.724724033747}, {
       3136.054810870682, -9726.724724033747}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}, {
       3696.8203285884947`, -9726.724724033747}, {
       2760.4162194256764`, -9726.724724033747}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9726.728014841949}, {
       4142.649334928727, -9726.728014841949}, {
       4142.649334928727, -9726.724724033747}, {
       4128.960218396028, -9726.724724033747}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}, {
       4699.999999999998, -9726.724724033747}, {
       4699.999999999998, -9726.724724033747}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.9035702291205`, -9726.728014841949}, {
      1335.906817747523, -9726.728014841949}, {
      1335.906817747523, -9726.724724033747}, {
      1335.9035702291205`, -9726.724724033747}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4128.958572991927, -9726.725546735797}, \
{4128.960218396028, -9726.724724033747}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4128.958572991927, -9726.725546735797}, 0.0016454041009459773`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9084631516241`, -9726.727192139899}, {
       4128.958572991927, -9726.727192139899}, {
       4128.958572991927, -9726.725546735797}, {
       1335.9084631516241`, -9726.725546735797}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9084631516241`, -9726.727192139899}, 
       0.0016454041009459773`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.906817747523, -9726.728014841949}, \
{1335.9084631516241`, -9726.727192139899}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.728014841949}, {
        100.00001018140426`, -9726.728014841949}, {
        100.00001018140426`, -9726.728014841949}, {
        100, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.728014841949}, {
       646.5441317483005, -9726.728014841949}, {
       646.5441317483005, -9726.728014841949}, {
       600.0828431526198, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9726.728014841949}, {
       1335.9084631516241`, -9726.728014841949}, {
       1335.9084631516241`, -9726.728014841949}, {
       1335.9035702291205`, -9726.728014841949}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.728014841949}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189031, -9726.728014841949}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}, {
       2648.877884444303, -9726.728014841949}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9726.728014841949}, {
       2584.88197490043, -9726.728014841949}, {
       2584.88197490043, -9726.728014841949}, {
       2584.881974892867, -9726.728014841949}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.728014841949}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.054810870682, -9726.728014841949}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}, {
       2760.4162194256764`, -9726.728014841949}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9726.728014841949}, {
       4142.649334928727, -9726.728014841949}, {
       4142.649334928727, -9726.728014841949}, {
       4128.960218396028, -9726.728014841949}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2652.3184670407045`, -9726.728014841949}, \
{2652.3184670407045`, -9726.728014841949}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.3184670407045`, -9726.728014841949}, 
       1.0914339973773285`*^-15, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.3184670407045`, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9726.728014841949}, 
       1.0914339973773285`*^-15, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9726.728014841949}, \
{4699.999999999998, -9726.728014841949}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9726.728014841949}, {
        100.00001018140426`, -9726.728014841949}, {
        100.00001018140426`, -9726.728014841949}, {
        100, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9726.728014841949}, {
       646.5441317483005, -9726.728014841949}, {
       646.5441317483005, -9726.728014841949}, {
       600.0828431526198, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9726.728014841949}, {
       1335.9084631516241`, -9726.728014841949}, {
       1335.9084631516241`, -9726.728014841949}, {
       1335.9035702291205`, -9726.728014841949}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9726.728014841949}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189031, -9726.728014841949}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2648.877884444303, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}, {
       2652.3184670407045`, -9726.728014841949}, {
       2648.877884444303, -9726.728014841949}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9726.728014841949}, {
       2584.88197490043, -9726.728014841949}, {
       2584.88197490043, -9726.728014841949}, {
       2584.881974892867, -9726.728014841949}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9726.728014841949}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.054810870682, -9726.728014841949}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}, {
       2760.4162194256764`, -9726.728014841949}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9726.728014841949}, {
       4142.649334928727, -9726.728014841949}, {
       4142.649334928727, -9726.728014841949}, {
       4128.960218396028, -9726.728014841949}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}, {
      4699.999999999998, -9726.728014841949}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3696.8203285884947`, -9726.728014841949}, \
{3696.8203285884947`, -9726.728014841949}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3696.8203285884947`, -9726.728014841949}, 
       1.4253588201955115`*^-15, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3696.8203285884947`, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}, {
       3696.8203285884947`, -9726.728014841949}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9726.728014841949}, 
       1.4253588201955115`*^-15, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9726.728014841949}, \
{4699.999999999998, -9726.728014841949}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9730.357764193799}, {
        100.00001018140426`, -9730.357764193799}, {
        100.00001018140426`, -9726.728014841949}, {
        100, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9730.357764193799}, {
       644.7292570723752, -9730.357764193799}, {
       644.7292570723752, -9726.728014841949}, {
       600.0828431526198, -9726.728014841949}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9730.357764193799}, {
       1335.9084631516241`, -9730.357764193799}, {
       1335.9084631516241`, -9726.728014841949}, {
       1335.9035702291205`, -9726.728014841949}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9730.357764193799}, {
       1601.281668189948, -9730.357764193799}, {
       1601.281668189948, -9726.728014841949}, {
       1601.281668189031, -9726.728014841949}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9730.357764193799}, {
       2584.88197490043, -9730.357764193799}, {
       2584.88197490043, -9726.728014841949}, {
       2584.881974892867, -9726.728014841949}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9730.357764193799}, {
       3136.0548108706944`, -9730.357764193799}, {
       3136.0548108706944`, -9726.728014841949}, {
       3136.054810870682, -9726.728014841949}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9730.357764193799}, {
       3696.8203285884947`, -9730.357764193799}, {
       3696.8203285884947`, -9726.728014841949}, {
       2760.4162194256764`, -9726.728014841949}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9730.357764193799}, {
       4142.649334928727, -9730.357764193799}, {
       4142.649334928727, -9726.728014841949}, {
       4128.960218396028, -9726.728014841949}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9730.357764193799}, {
       4699.999999999998, -9730.357764193799}, {
       4699.999999999998, -9726.728014841949}, {
       4699.999999999998, -9726.728014841949}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2648.877884444303, -9730.357764193799}, {
      2652.318467040705, -9730.357764193799}, {
      2652.318467040705, -9726.728014841949}, {
      2648.877884444303, -9726.728014841949}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{644.7292570723752, -9727.635452179911}, \
{646.5441317483005, -9726.728014841949}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{646.5441317483005, -9727.635452179911}, 1.814874675925418, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{646.5441317483005, -9729.450326855836}, {
       2647.063009768378, -9729.450326855836}, {
       2647.063009768378, -9727.635452179911}, {
       646.5441317483005, -9727.635452179911}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2647.063009768378, -9729.450326855836}, 1.814874675925418, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2647.063009768378, -9730.357764193799}, \
{2648.877884444303, -9729.450326855836}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9730.357764193799}, {
        100.00001018140426`, -9730.357764193799}, {
        100.00001018140426`, -9730.357764193799}, {
        100, -9730.357764193799}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9730.357764193799}, {
       644.7292570723752, -9730.357764193799}, {
       644.7292570723752, -9730.357764193799}, {
       600.0828431526198, -9730.357764193799}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9730.357764193799}, {
       1335.9084631516241`, -9730.357764193799}, {
       1335.9084631516241`, -9730.357764193799}, {
       1335.9035702291205`, -9730.357764193799}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9730.357764193799}, {
       1601.281668189948, -9730.357764193799}, {
       1601.281668189948, -9730.357764193799}, {
       1601.281668189031, -9730.357764193799}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9730.357764193799}, {
       2652.318467040705, -9730.357764193799}, {
       2652.318467040705, -9730.357764193799}, {
       2647.063009768378, -9730.357764193799}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9730.357764193799}, {
       2584.88197490043, -9730.357764193799}, {
       2584.88197490043, -9730.357764193799}, {
       2584.881974892867, -9730.357764193799}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9730.357764193799}, {
       3136.0548108706944`, -9730.357764193799}, {
       3136.0548108706944`, -9730.357764193799}, {
       3136.054810870682, -9730.357764193799}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2760.4162194256764`, -9730.357764193799}, {
       3696.8203285884947`, -9730.357764193799}, {
       3696.8203285884947`, -9730.357764193799}, {
       2760.4162194256764`, -9730.357764193799}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9730.357764193799}, {
       4142.649334928727, -9730.357764193799}, {
       4142.649334928727, -9730.357764193799}, {
       4128.960218396028, -9730.357764193799}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9730.357764193799}, {
      4699.999999999998, -9730.357764193799}, {
      4699.999999999998, -9730.357764193799}, {
      4699.999999999998, -9730.357764193799}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706944`, -9730.357764193799}, \
{3136.0548108706944`, -9730.357764193799}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706944`, -9730.357764193799}, 
       1.2602861531545417`*^-15, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108706944`, -9730.357764193799}, {
       4699.999999999998, -9730.357764193799}, {
       4699.999999999998, -9730.357764193799}, {
       3136.0548108706944`, -9730.357764193799}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9730.357764193799}, 
       1.2602861531545417`*^-15, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9730.357764193799}, \
{4699.999999999998, -9730.357764193799}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9733.922709949376}, {
        100.00001018140426`, -9733.922709949376}, {
        100.00001018140426`, -9730.357764193799}, {
        100, -9730.357764193799}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9733.922709949376}, {
       644.7292570723752, -9733.922709949376}, {
       644.7292570723752, -9730.357764193799}, {
       600.0828431526198, -9730.357764193799}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9733.922709949376}, {
       1335.9084631516241`, -9733.922709949376}, {
       1335.9084631516241`, -9730.357764193799}, {
       1335.9035702291205`, -9730.357764193799}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9733.922709949376}, {
       1601.281668189948, -9733.922709949376}, {
       1601.281668189948, -9730.357764193799}, {
       1601.281668189031, -9730.357764193799}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9733.922709949376}, {
       2650.535994162916, -9733.922709949376}, {
       2650.535994162916, -9730.357764193799}, {
       2647.063009768378, -9730.357764193799}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9733.922709949376}, {
       2584.88197490043, -9733.922709949376}, {
       2584.88197490043, -9730.357764193799}, {
       2584.881974892867, -9730.357764193799}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870682, -9733.922709949376}, {
       3136.0548108706944`, -9733.922709949376}, {
       3136.0548108706944`, -9730.357764193799}, {
       3136.054810870682, -9730.357764193799}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9733.922709949376}, {
       4142.649334928727, -9733.922709949376}, {
       4142.649334928727, -9730.357764193799}, {
       4128.960218396028, -9730.357764193799}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9733.922709949376}, {
       4699.999999999998, -9733.922709949376}, {
       4699.999999999998, -9730.357764193799}, {
       4699.999999999998, -9730.357764193799}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2760.4162194256764`, -9733.922709949376}, {
      3696.8203285884947`, -9733.922709949376}, {
      3696.8203285884947`, -9730.357764193799}, {
      2760.4162194256764`, -9730.357764193799}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2650.535994162916, -9731.249000632693}, \
{2652.318467040705, -9730.357764193799}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.318467040705, -9731.249000632693}, 1.7824728777890373`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.318467040705, -9733.031473510482}, {
       2758.6337465478873`, -9733.031473510482}, {
       2758.6337465478873`, -9731.249000632693}, {
       2652.318467040705, -9731.249000632693}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2758.6337465478873`, -9733.031473510482}, 
       1.7824728777890373`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2758.6337465478873`, -9733.922709949376}, \
{2760.4162194256764`, -9733.031473510482}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9733.922709949378}, {
        100.00001018140426`, -9733.922709949378}, {
        100.00001018140426`, -9733.922709949376}, {
        100, -9733.922709949376}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9733.922709949378}, {
       644.7292570723752, -9733.922709949378}, {
       644.7292570723752, -9733.922709949376}, {
       600.0828431526198, -9733.922709949376}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9733.922709949378}, {
       1335.9084631516234`, -9733.922709949378}, {
       1335.9084631516234`, -9733.922709949376}, {
       1335.9035702291205`, -9733.922709949376}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9733.922709949378}, {
       1601.281668189948, -9733.922709949378}, {
       1601.281668189948, -9733.922709949376}, {
       1601.281668189031, -9733.922709949376}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9733.922709949378}, {
       2650.535994162916, -9733.922709949378}, {
       2650.535994162916, -9733.922709949376}, {
       2647.063009768378, -9733.922709949376}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892867, -9733.922709949378}, {
       2584.88197490043, -9733.922709949378}, {
       2584.88197490043, -9733.922709949376}, {
       2584.881974892867, -9733.922709949376}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2758.6337465478873`, -9733.922709949378}, {
       3696.8203285884947`, -9733.922709949378}, {
       3696.8203285884947`, -9733.922709949376}, {
       2758.6337465478873`, -9733.922709949376}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9733.922709949378}, {
       4142.649334928727, -9733.922709949378}, {
       4142.649334928727, -9733.922709949376}, {
       4128.960218396028, -9733.922709949376}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9733.922709949378}, {
       4699.999999999998, -9733.922709949378}, {
       4699.999999999998, -9733.922709949376}, {
       4699.999999999998, -9733.922709949376}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870682, -9733.922709949378}, {
      3136.054810870695, -9733.922709949378}, {
      3136.054810870695, -9733.922709949376}, {
      3136.054810870682, -9733.922709949376}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9084631516234`, -9733.922709949378}, \
{1335.9084631516241`, -9733.922709949376}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9084631516241`, -9733.922709949378}, 
       5.724284881511294*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9084631516241`, -9733.922709949378}, {
       3136.0548108706816`, -9733.922709949378}, {
       3136.0548108706816`, -9733.922709949378}, {
       1335.9084631516241`, -9733.922709949378}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706816`, -9733.922709949378}, 
       5.724284881511294*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706816`, -9733.922709949378}, \
{3136.054810870682, -9733.922709949378}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9733.922709951195}, {
        100.00001018140426`, -9733.922709951195}, {
        100.00001018140426`, -9733.922709949378}, {
        100, -9733.922709949378}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9733.922709951195}, {
       644.7292570723752, -9733.922709951195}, {
       644.7292570723752, -9733.922709949378}, {
       600.0828431526198, -9733.922709949378}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9733.922709951195}, {
       1335.9084631516234`, -9733.922709951195}, {
       1335.9084631516234`, -9733.922709949378}, {
       1335.9035702291205`, -9733.922709949378}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9733.922709951195}, {
       1601.2816681890392`, -9733.922709951195}, {
       1601.2816681890392`, -9733.922709949378}, {
       1601.281668189031, -9733.922709949378}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9733.922709951195}, {
       2650.535994162916, -9733.922709951195}, {
       2650.535994162916, -9733.922709949378}, {
       2647.063009768378, -9733.922709949378}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706816`, -9733.922709951195}, {
       3136.054810870695, -9733.922709951195}, {
       3136.054810870695, -9733.922709949378}, {
       3136.0548108706816`, -9733.922709949378}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2758.6337465478873`, -9733.922709951195}, {
       3696.8203285884947`, -9733.922709951195}, {
       3696.8203285884947`, -9733.922709949378}, {
       2758.6337465478873`, -9733.922709949378}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9733.922709951195}, {
       4142.649334928727, -9733.922709951195}, {
       4142.649334928727, -9733.922709949378}, {
       4128.960218396028, -9733.922709949378}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9733.922709951195}, {
       4699.999999999998, -9733.922709951195}, {
       4699.999999999998, -9733.922709949378}, {
       4699.999999999998, -9733.922709949378}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892867, -9733.922709951195}, {
      2584.88197490043, -9733.922709951195}, {
      2584.88197490043, -9733.922709949378}, {
      2584.881974892867, -9733.922709949378}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890392`, -9733.922709949831}, \
{1601.281668189948, -9733.922709949378}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189948, -9733.922709949831}, 9.089578312207291*^-10,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189948, -9733.92270995074}, {
       2584.881974891958, -9733.92270995074}, {
       2584.881974891958, -9733.922709949831}, {
       1601.281668189948, -9733.922709949831}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974891958, -9733.92270995074}, 
       9.089578312207291*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974891958, -9733.922709951195}, \
{2584.881974892867, -9733.92270995074}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9733.922709951206}, {
       644.7292570723752, -9733.922709951206}, {
       644.7292570723752, -9733.922709951195}, {
       600.0828431526198, -9733.922709951195}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9733.922709951206}, {
       1335.9084631516234`, -9733.922709951206}, {
       1335.9084631516234`, -9733.922709951195}, {
       1335.9035702291205`, -9733.922709951195}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9733.922709951206}, {
       1601.2816681890392`, -9733.922709951206}, {
       1601.2816681890392`, -9733.922709951195}, {
       1601.281668189031, -9733.922709951195}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9733.922709951206}, {
       2650.535994162916, -9733.922709951206}, {
       2650.535994162916, -9733.922709951195}, {
       2647.063009768378, -9733.922709951195}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891958, -9733.922709951206}, {
       2584.88197490043, -9733.922709951206}, {
       2584.88197490043, -9733.922709951195}, {
       2584.881974891958, -9733.922709951195}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9733.922709951206}, {
       3136.054810870695, -9733.922709951206}, {
       3136.054810870695, -9733.922709951195}, {
       3136.054810870687, -9733.922709951195}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2758.6337465478873`, -9733.922709951206}, {
       3696.8203285884947`, -9733.922709951206}, {
       3696.8203285884947`, -9733.922709951195}, {
       2758.6337465478873`, -9733.922709951195}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9733.922709951206}, {
       4142.649334928727, -9733.922709951206}, {
       4142.649334928727, -9733.922709951195}, {
       4128.960218396028, -9733.922709951195}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9733.922709951206}, {
       4699.999999999998, -9733.922709951206}, {
       4699.999999999998, -9733.922709951195}, {
       4699.999999999998, -9733.922709951195}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9733.922709951206}, {
       100.00001018140426`, -9733.922709951206}, {
       100.00001018140426`, -9733.922709951195}, {
       100, -9733.922709951195}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706816`, -9733.922709951199}, \
{3136.054810870687, -9733.922709951195}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706816`, -9733.922709951199}, 
       5.3356405227281605`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000101814096, -9733.922709951205}, {
       3136.0548108706816`, -9733.922709951205}, {
       3136.0548108706816`, -9733.922709951199}, {
       100.0000101814096, -9733.922709951199}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000101814096, -9733.922709951205}, 
       5.3356405227281605`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00001018140426`, -9733.922709951206}, \
{100.0000101814096, -9733.922709951205}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9733.922709951212}, {
        100.0000101814096, -9733.922709951212}, {
        100.0000101814096, -9733.922709951206}, {
        100, -9733.922709951206}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9733.922709951212}, {
       644.7292570723752, -9733.922709951212}, {
       644.7292570723752, -9733.922709951206}, {
       600.0828431526198, -9733.922709951206}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9733.922709951212}, {
       1335.9084631516234`, -9733.922709951212}, {
       1335.9084631516234`, -9733.922709951206}, {
       1335.9035702291205`, -9733.922709951206}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9733.922709951212}, {
       1601.2816681890392`, -9733.922709951212}, {
       1601.2816681890392`, -9733.922709951206}, {
       1601.281668189031, -9733.922709951206}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9733.922709951212}, {
       2650.535994162916, -9733.922709951212}, {
       2650.535994162916, -9733.922709951206}, {
       2647.063009768378, -9733.922709951206}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891958, -9733.922709951212}, {
       2584.88197490043, -9733.922709951212}, {
       2584.88197490043, -9733.922709951206}, {
       2584.881974891958, -9733.922709951206}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2758.63374654789, -9733.922709951212}, {
       3696.8203285884942`, -9733.922709951212}, {
       3696.8203285884942`, -9733.922709951206}, {
       2758.63374654789, -9733.922709951206}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9733.922709951212}, {
       4142.649334928727, -9733.922709951212}, {
       4142.649334928727, -9733.922709951206}, {
       4128.960218396028, -9733.922709951206}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9733.922709951212}, {
       4699.999999999998, -9733.922709951212}, {
       4699.999999999998, -9733.922709951206}, {
       4699.999999999998, -9733.922709951206}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870687, -9733.922709951212}, {
      3136.054810870695, -9733.922709951212}, {
      3136.054810870695, -9733.922709951206}, {
      3136.054810870687, -9733.922709951206}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2758.6337465478873`, -9733.922709951208}, \
{2758.63374654789, -9733.922709951206}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2758.6337465478873`, -9733.922709951208}, 
       2.9389305011238296`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108706976`, -9733.92270995121}, {
       2758.6337465478873`, -9733.92270995121}, {
       2758.6337465478873`, -9733.922709951208}, {
       3136.0548108706976`, -9733.922709951208}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706976`, -9733.92270995121}, 
       2.9389305011238296`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870695, -9733.922709951212}, \
{3136.0548108706976`, -9733.92270995121}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181886111824}, {
        100.0000101814096, -9792.181886111824}, {
        100.0000101814096, -9733.922709951212}, {
        100, -9733.922709951212}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181886111824}, {
       615.5996689920689, -9792.181886111824}, {
       615.5996689920689, -9733.922709951212}, {
       600.0828431526198, -9733.922709951212}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181886111824}, {
       1335.9084631516234`, -9792.181886111824}, {
       1335.9084631516234`, -9733.922709951212}, {
       1335.9035702291205`, -9733.922709951212}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181886111824}, {
       1601.2816681890392`, -9792.181886111824}, {
       1601.2816681890392`, -9733.922709951212}, {
       1601.281668189031, -9733.922709951212}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181886111824}, {
       2650.535994162916, -9792.181886111824}, {
       2650.535994162916, -9733.922709951212}, {
       2647.063009768378, -9733.922709951212}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891958, -9792.181886111824}, {
       2584.88197490043, -9792.181886111824}, {
       2584.88197490043, -9733.922709951212}, {
       2584.881974891958, -9733.922709951212}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181886111824}, {
       3136.0548108706976`, -9792.181886111824}, {
       3136.0548108706976`, -9733.922709951212}, {
       3136.054810870687, -9733.922709951212}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.960218396028, -9792.181886111824}, {
       4142.649334928727, -9792.181886111824}, {
       4142.649334928727, -9733.922709951212}, {
       4128.960218396028, -9733.922709951212}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181886111824}, {
       4699.999999999998, -9792.181886111824}, {
       4699.999999999998, -9733.922709951212}, {
       4699.999999999998, -9733.922709951212}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2758.63374654789, -9792.181886111824}, {
      3696.8203285884942`, -9792.181886111824}, {
      3696.8203285884942`, -9733.922709951212}, {
      2758.63374654789, -9733.922709951212}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{615.5996689920689, -9748.487503991366}, \
{644.7292570723752, -9733.922709951212}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{644.7292570723752, -9748.487503991366}, 29.129588080306185`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{644.7292570723752, -9777.617092071672}, {
       2729.5041584675837`, -9777.617092071672}, {
       2729.5041584675837`, -9748.487503991366}, {
       644.7292570723752, -9748.487503991366}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2729.5041584675837`, -9777.617092071672}, 
       29.129588080306185`, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2729.5041584675837`, -9792.181886111824}, \
{2758.63374654789, -9777.617092071672}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181904656887}, {
        100.00000090887823`, -9792.181904656887}, {
        100.00000090887823`, -9792.181886111824}, {
        100, -9792.181886111824}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181904656887}, {
       615.5996689920689, -9792.181904656887}, {
       615.5996689920689, -9792.181886111824}, {
       600.0828431526198, -9792.181886111824}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904656887}, {
       1335.9084631516234`, -9792.181904656887}, {
       1335.9084631516234`, -9792.181886111824}, {
       1335.9035702291205`, -9792.181886111824}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904656887}, {
       1601.2816681890392`, -9792.181904656887}, {
       1601.2816681890392`, -9792.181886111824}, {
       1601.281668189031, -9792.181886111824}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904656887}, {
       2650.535994162916, -9792.181904656887}, {
       2650.535994162916, -9792.181886111824}, {
       2647.063009768378, -9792.181886111824}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891958, -9792.181904656887}, {
       2584.88197490043, -9792.181904656887}, {
       2584.88197490043, -9792.181886111824}, {
       2584.881974891958, -9792.181886111824}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904656887}, {
       3136.0548108706976`, -9792.181904656887}, {
       3136.0548108706976`, -9792.181886111824}, {
       3136.054810870687, -9792.181886111824}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.5041584675837`, -9792.181904656887}, {
       3696.8203285884942`, -9792.181904656887}, {
       3696.8203285884942`, -9792.181886111824}, {
       2729.5041584675837`, -9792.181886111824}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181886111824}, {
       4699.999999999998, -9792.181886111824}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4128.960218396028, -9792.181904656887}, {
      4142.649334928727, -9792.181904656887}, {
      4142.649334928727, -9792.181886111824}, {
      4128.960218396028, -9792.181886111824}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000090887823`, -9792.18189074809}, \
{100.0000101814096, -9792.181886111824}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000101814096, -9792.18189074809}, 9.27253136993238*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000101814096, -9792.181900020621}, {
       4128.9602091234965`, -9792.181900020621}, {
       4128.9602091234965`, -9792.18189074809}, {
       100.0000101814096, -9792.18189074809}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4128.9602091234965`, -9792.181900020621}, 
       9.27253136993238*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4128.9602091234965`, -9792.181904656887}, \
{4128.960218396028, -9792.181900020621}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181904656887}, {
        100.00000090887823`, -9792.181904656887}, {
        100.00000090887823`, -9792.181904656887}, {
        100, -9792.181904656887}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181904656887}, {
       615.5996689920689, -9792.181904656887}, {
       615.5996689920689, -9792.181904656887}, {
       600.0828431526198, -9792.181904656887}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904656887}, {
       1335.9084631516234`, -9792.181904656887}, {
       1335.9084631516234`, -9792.181904656887}, {
       1335.9035702291205`, -9792.181904656887}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904656887}, {
       1601.2816681890392`, -9792.181904656887}, {
       1601.2816681890392`, -9792.181904656887}, {
       1601.281668189031, -9792.181904656887}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904656887}, {
       2650.535994162916, -9792.181904656887}, {
       2650.535994162916, -9792.181904656887}, {
       2647.063009768378, -9792.181904656887}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891958, -9792.181904656887}, {
       2584.88197490043, -9792.181904656887}, {
       2584.88197490043, -9792.181904656887}, {
       2584.881974891958, -9792.181904656887}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904656887}, {
       3136.0548108706976`, -9792.181904656887}, {
       3136.0548108706976`, -9792.181904656887}, {
       3136.054810870687, -9792.181904656887}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.9602091234965`, -9792.181904656887}, {
       4142.649334928727, -9792.181904656887}, {
       4142.649334928727, -9792.181904656887}, {
       4128.9602091234965`, -9792.181904656887}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2729.5041584675837`, -9792.181904656887}, {
      3696.8203285884942`, -9792.181904656887}, {
      3696.8203285884942`, -9792.181904656887}, {
      2729.5041584675837`, -9792.181904656887}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9792.181904656887}, \
{4699.999999999998, -9792.181904656887}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9792.181904656887}, 
       1.7502489368667176`*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3696.8203285884942`, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}, {
       3696.8203285884942`, -9792.181904656887}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3696.8203285884942`, -9792.181904656887}, 
       1.7502489368667176`*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3696.8203285884942`, -9792.181904656887}, \
{3696.8203285884942`, -9792.181904656887}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181904657427}, {
        100.00000090887823`, -9792.181904657427}, {
        100.00000090887823`, -9792.181904656887}, {
        100, -9792.181904656887}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904657427}, {
       1335.9084631516234`, -9792.181904657427}, {
       1335.9084631516234`, -9792.181904656887}, {
       1335.9035702291205`, -9792.181904656887}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904657427}, {
       1601.2816681890392`, -9792.181904657427}, {
       1601.2816681890392`, -9792.181904656887}, {
       1601.281668189031, -9792.181904656887}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904657427}, {
       2650.535994162916, -9792.181904657427}, {
       2650.535994162916, -9792.181904656887}, {
       2647.063009768378, -9792.181904656887}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9792.181904657427}, {
       2584.8819749004306`, -9792.181904657427}, {
       2584.8819749004306`, -9792.181904656887}, {
       2584.8819748922283`, -9792.181904656887}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904657427}, {
       3136.0548108706976`, -9792.181904657427}, {
       3136.0548108706976`, -9792.181904656887}, {
       3136.054810870687, -9792.181904656887}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.5041584675837`, -9792.181904657427}, {
       3696.8203285884942`, -9792.181904657427}, {
       3696.8203285884942`, -9792.181904656887}, {
       2729.5041584675837`, -9792.181904656887}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.9602091234965`, -9792.181904657427}, {
       4142.649334928727, -9792.181904657427}, {
       4142.649334928727, -9792.181904656887}, {
       4128.9602091234965`, -9792.181904656887}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904657427}, {
       4699.999999999998, -9792.181904657427}, {
       4699.999999999998, -9792.181904656887}, {
       4699.999999999998, -9792.181904656887}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828431526198, -9792.181904657427}, {
      615.5996689920689, -9792.181904657427}, {
      615.5996689920689, -9792.181904656887}, {
      600.0828431526198, -9792.181904656887}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974891958, -9792.181904657022}, \
{2584.8819748922283`, -9792.181904656887}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974891958, -9792.181904657022}, 2.699672051188215*^-10,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{615.5996689923389, -9792.181904657293}, {
       2584.881974891958, -9792.181904657293}, {
       2584.881974891958, -9792.181904657022}, {
       615.5996689923389, -9792.181904657022}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{615.5996689923389, -9792.181904657293}, 2.699672051188215*^-10,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{615.5996689920689, -9792.181904657427}, \
{615.5996689923389, -9792.181904657293}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181904890569}, {
       615.5996689923389, -9792.181904890569}, {
       615.5996689923389, -9792.181904657427}, {
       600.0828431526198, -9792.181904657427}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904890569}, {
       1335.9084631516234`, -9792.181904890569}, {
       1335.9084631516234`, -9792.181904657427}, {
       1335.9035702291205`, -9792.181904657427}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904890569}, {
       1601.2816681890392`, -9792.181904890569}, {
       1601.2816681890392`, -9792.181904657427}, {
       1601.281668189031, -9792.181904657427}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904890569}, {
       2650.535994162916, -9792.181904890569}, {
       2650.535994162916, -9792.181904657427}, {
       2647.063009768378, -9792.181904657427}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9792.181904890569}, {
       2584.8819749004306`, -9792.181904890569}, {
       2584.8819749004306`, -9792.181904657427}, {
       2584.8819748922283`, -9792.181904657427}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904890569}, {
       3136.0548108706976`, -9792.181904890569}, {
       3136.0548108706976`, -9792.181904657427}, {
       3136.054810870687, -9792.181904657427}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.5041585841545`, -9792.181904890569}, {
       3696.8203285884942`, -9792.181904890569}, {
       3696.8203285884942`, -9792.181904657427}, {
       2729.5041585841545`, -9792.181904657427}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.9602091234965`, -9792.181904890569}, {
       4142.649334928727, -9792.181904890569}, {
       4142.649334928727, -9792.181904657427}, {
       4128.9602091234965`, -9792.181904657427}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904890569}, {
       4699.999999999998, -9792.181904890569}, {
       4699.999999999998, -9792.181904657427}, {
       4699.999999999998, -9792.181904657427}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9792.181904890569}, {
       100.00000090887823`, -9792.181904890569}, {
       100.00000090887823`, -9792.181904657427}, {
       100, -9792.181904657427}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2729.5041584675837`, -9792.181904715713}, \
{2729.5041585841545`, -9792.181904657427}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2729.5041584675837`, -9792.181904715713}, 
       1.1657069740339031`*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000102544892`, -9792.181904832283}, {
       2729.5041584675837`, -9792.181904832283}, {
       2729.5041584675837`, -9792.181904715713}, {
       100.00000102544892`, -9792.181904715713}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000102544892`, -9792.181904832283}, 
       1.1657069740339031`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000090887823`, -9792.181904890569}, \
{100.00000102544892`, -9792.181904832283}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181904890582}, {
        100.00000102544892`, -9792.181904890582}, {
        100.00000102544892`, -9792.181904890569}, {
        100, -9792.181904890569}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181904890582}, {
       615.5996689923389, -9792.181904890582}, {
       615.5996689923389, -9792.181904890569}, {
       600.0828431526198, -9792.181904890569}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904890582}, {
       1335.9084631516234`, -9792.181904890582}, {
       1335.9084631516234`, -9792.181904890569}, {
       1335.9035702291205`, -9792.181904890569}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904890582}, {
       1601.2816681890324`, -9792.181904890582}, {
       1601.2816681890324`, -9792.181904890569}, {
       1601.281668189031, -9792.181904890569}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904890582}, {
       2650.535994162916, -9792.181904890582}, {
       2650.535994162916, -9792.181904890569}, {
       2647.063009768378, -9792.181904890569}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9792.181904890582}, {
       2584.8819749004306`, -9792.181904890582}, {
       2584.8819749004306`, -9792.181904890569}, {
       2584.8819748922283`, -9792.181904890569}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904890582}, {
       3136.0548108706976`, -9792.181904890582}, {
       3136.0548108706976`, -9792.181904890569}, {
       3136.054810870687, -9792.181904890569}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.5041585841545`, -9792.181904890582}, {
       3696.8203285884942`, -9792.181904890582}, {
       3696.8203285884942`, -9792.181904890569}, {
       2729.5041585841545`, -9792.181904890569}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904890582}, {
       4699.999999999998, -9792.181904890582}, {
       4699.999999999998, -9792.181904890569}, {
       4699.999999999998, -9792.181904890569}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4128.9602091234965`, -9792.181904890582}, {
      4142.649334928727, -9792.181904890582}, {
      4142.649334928727, -9792.181904890569}, {
      4128.9602091234965`, -9792.181904890569}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890324`, -9792.181904890573}, \
{1601.2816681890392`, -9792.181904890569}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890392`, -9792.181904890573}, 
       6.657050729186118*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890392`, -9792.181904890578}, {
       4128.96020912349, -9792.181904890578}, {
       4128.96020912349, -9792.181904890573}, {
       1601.2816681890392`, -9792.181904890573}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4128.96020912349, -9792.181904890578}, 
       6.657050729186118*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4128.96020912349, -9792.181904890582}, \
{4128.9602091234965`, -9792.181904890578}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9792.181904903668}, {
        100.00000102544892`, -9792.181904903668}, {
        100.00000102544892`, -9792.181904890582}, {
        100, -9792.181904890582}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9792.181904903668}, {
       615.5996689923389, -9792.181904903668}, {
       615.5996689923389, -9792.181904890582}, {
       600.0828431526198, -9792.181904890582}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9792.181904903668}, {
       1335.9084631516234`, -9792.181904903668}, {
       1335.9084631516234`, -9792.181904890582}, {
       1335.9035702291205`, -9792.181904890582}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9792.181904903668}, {
       1601.2816681890324`, -9792.181904903668}, {
       1601.2816681890324`, -9792.181904890582}, {
       1601.281668189031, -9792.181904890582}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9792.181904903668}, {
       2650.535994162916, -9792.181904903668}, {
       2650.535994162916, -9792.181904890582}, {
       2647.063009768378, -9792.181904890582}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9792.181904903668}, {
       2584.8819748938877`, -9792.181904903668}, {
       2584.8819748938877`, -9792.181904890582}, {
       2584.8819748922283`, -9792.181904890582}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9792.181904903668}, {
       3136.0548108706976`, -9792.181904903668}, {
       3136.0548108706976`, -9792.181904890582}, {
       3136.054810870687, -9792.181904890582}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4128.96020912349, -9792.181904903668}, {
       4142.649334928727, -9792.181904903668}, {
       4142.649334928727, -9792.181904890582}, {
       4128.96020912349, -9792.181904890582}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9792.181904903668}, {
       4699.999999999998, -9792.181904903668}, {
       4699.999999999998, -9792.181904890582}, {
       4699.999999999998, -9792.181904890582}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2729.5041585841545`, -9792.181904903668}, {
      3696.8203285884942`, -9792.181904903668}, {
      3696.8203285884942`, -9792.181904890582}, {
      2729.5041585841545`, -9792.181904890582}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748938877`, -9792.181904893854}, \
{2584.8819749004306`, -9792.181904890582}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819749004306`, -9792.181904893854}, 
       6.542535415039024*^-9, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819749004306`, -9792.181904900397}, {
       2729.504158577612, -9792.181904900397}, {
       2729.504158577612, -9792.181904893854}, {
       2584.8819749004306`, -9792.181904893854}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2729.504158577612, -9792.181904900397}, 
       6.542535415039024*^-9, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2729.504158577612, -9792.181904903668}, \
{2729.5041585841545`, -9792.181904900397}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9794.514198280809}, {
        100.00000102544892`, -9794.514198280809}, {
        100.00000102544892`, -9792.181904903668}, {
        100, -9792.181904903668}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9794.514198280809}, {
       615.5996689923389, -9794.514198280809}, {
       615.5996689923389, -9792.181904903668}, {
       600.0828431526198, -9792.181904903668}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9794.514198280809}, {
       1335.9084631516234`, -9794.514198280809}, {
       1335.9084631516234`, -9792.181904903668}, {
       1335.9035702291205`, -9792.181904903668}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9794.514198280809}, {
       1601.2816681890324`, -9794.514198280809}, {
       1601.2816681890324`, -9792.181904903668}, {
       1601.281668189031, -9792.181904903668}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9794.514198280809}, {
       2649.369847474345, -9794.514198280809}, {
       2649.369847474345, -9792.181904903668}, {
       2647.063009768378, -9792.181904903668}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9794.514198280809}, {
       2584.8819748938877`, -9794.514198280809}, {
       2584.8819748938877`, -9792.181904903668}, {
       2584.8819748922283`, -9792.181904903668}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870687, -9794.514198280809}, {
       3136.0548108706976`, -9794.514198280809}, {
       3136.0548108706976`, -9792.181904903668}, {
       3136.054810870687, -9792.181904903668}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.504158577612, -9794.514198280809}, {
       3696.8203285884942`, -9794.514198280809}, {
       3696.8203285884942`, -9792.181904903668}, {
       2729.504158577612, -9792.181904903668}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9794.514198280809}, {
       4699.999999999998, -9794.514198280809}, {
       4699.999999999998, -9792.181904903668}, {
       4699.999999999998, -9792.181904903668}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4128.96020912349, -9794.514198280809}, {
      4142.649334928727, -9794.514198280809}, {
      4142.649334928727, -9792.181904903668}, {
      4128.96020912349, -9792.181904903668}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.369847474345, -9792.764978247953}, \
{2650.535994162916, -9792.181904903668}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2650.535994162916, -9792.764978247953}, 1.1661466885706737`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2650.535994162916, -9793.931124936524}, {
       4127.794062434919, -9793.931124936524}, {
       4127.794062434919, -9792.764978247953}, {
       2650.535994162916, -9792.764978247953}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.794062434919, -9793.931124936524}, 1.1661466885706737`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.794062434919, -9794.514198280809}, \
{4128.96020912349, -9793.931124936524}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9794.514198280827}, {
        100.00000102543946`, -9794.514198280827}, {
        100.00000102543946`, -9794.514198280809}, {
        100, -9794.514198280809}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9794.514198280827}, {
       615.5996689923389, -9794.514198280827}, {
       615.5996689923389, -9794.514198280809}, {
       600.0828431526198, -9794.514198280809}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9794.514198280827}, {
       1335.9084631516234`, -9794.514198280827}, {
       1335.9084631516234`, -9794.514198280809}, {
       1335.9035702291205`, -9794.514198280809}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9794.514198280827}, {
       1601.2816681890324`, -9794.514198280827}, {
       1601.2816681890324`, -9794.514198280809}, {
       1601.281668189031, -9794.514198280809}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9794.514198280827}, {
       2649.369847474345, -9794.514198280827}, {
       2649.369847474345, -9794.514198280809}, {
       2647.063009768378, -9794.514198280809}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9794.514198280827}, {
       2584.8819748938877`, -9794.514198280827}, {
       2584.8819748938877`, -9794.514198280809}, {
       2584.8819748922283`, -9794.514198280809}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2729.504158577612, -9794.514198280827}, {
       3696.8203285884942`, -9794.514198280827}, {
       3696.8203285884942`, -9794.514198280809}, {
       2729.504158577612, -9794.514198280809}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.794062434919, -9794.514198280827}, {
       4142.649334928727, -9794.514198280827}, {
       4142.649334928727, -9794.514198280809}, {
       4127.794062434919, -9794.514198280809}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9794.514198280827}, {
       4699.999999999998, -9794.514198280827}, {
       4699.999999999998, -9794.514198280809}, {
       4699.999999999998, -9794.514198280809}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870687, -9794.514198280827}, {
      3136.0548108706976`, -9794.514198280827}, {
      3136.0548108706976`, -9794.514198280809}, {
      3136.054810870687, -9794.514198280809}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000102543946`, -9794.514198280813}, \
{100.00000102544892`, -9794.514198280809}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000102544892`, -9794.514198280813}, 
       9.476143528507335*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000102544892`, -9794.514198280822}, {
       3136.0548108706776`, -9794.514198280822}, {
       3136.0548108706776`, -9794.514198280813}, {
       100.00000102544892`, -9794.514198280813}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706776`, -9794.514198280822}, 
       9.476143528507335*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706776`, -9794.514198280827}, \
{3136.054810870687, -9794.514198280822}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9822.527796068183}, {
        100.00000102543946`, -9822.527796068183}, {
        100.00000102543946`, -9794.514198280827}, {
        100, -9794.514198280827}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9822.527796068183}, {
       601.592870098661, -9822.527796068183}, {
       601.592870098661, -9794.514198280827}, {
       600.0828431526198, -9794.514198280827}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9822.527796068183}, {
       1335.9084631516234`, -9822.527796068183}, {
       1335.9084631516234`, -9794.514198280827}, {
       1335.9035702291205`, -9794.514198280827}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9822.527796068183}, {
       1601.2816681890324`, -9822.527796068183}, {
       1601.2816681890324`, -9794.514198280827}, {
       1601.281668189031, -9794.514198280827}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9822.527796068183}, {
       2649.369847474345, -9822.527796068183}, {
       2649.369847474345, -9794.514198280827}, {
       2647.063009768378, -9794.514198280827}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9822.527796068183}, {
       2584.8819748938877`, -9822.527796068183}, {
       2584.8819748938877`, -9794.514198280827}, {
       2584.8819748922283`, -9794.514198280827}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9822.527796068183}, {
       3136.0548108706976`, -9822.527796068183}, {
       3136.0548108706976`, -9794.514198280827}, {
       3136.0548108706776`, -9794.514198280827}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.794062434919, -9822.527796068183}, {
       4142.649334928727, -9822.527796068183}, {
       4142.649334928727, -9794.514198280827}, {
       4127.794062434919, -9794.514198280827}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9822.527796068183}, {
       4699.999999999998, -9822.527796068183}, {
       4699.999999999998, -9794.514198280827}, {
       4699.999999999998, -9794.514198280827}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2729.504158577612, -9822.527796068183}, {
      3696.8203285884942`, -9822.527796068183}, {
      3696.8203285884942`, -9794.514198280827}, {
      2729.504158577612, -9794.514198280827}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.592870098661, -9801.517597727667}, \
{615.5996689923389, -9794.514198280827}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{615.5996689923389, -9801.517597727667}, 14.006798893677846`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{615.5996689923389, -9815.524396621344}, {
       2715.497359683934, -9815.524396621344}, {
       2715.497359683934, -9801.517597727667}, {
       615.5996689923389, -9801.517597727667}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2715.497359683934, -9815.524396621344}, 14.006798893677846`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2715.497359683934, -9822.527796068183}, \
{2729.504158577612, -9815.524396621344}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9822.527796068183}, {
        100.00000102543946`, -9822.527796068183}, {
        100.00000102543946`, -9822.527796068183}, {
        100, -9822.527796068183}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9822.527796068183}, {
       601.592870098661, -9822.527796068183}, {
       601.592870098661, -9822.527796068183}, {
       600.0828431526198, -9822.527796068183}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9822.527796068183}, {
       1335.9084631516234`, -9822.527796068183}, {
       1335.9084631516234`, -9822.527796068183}, {
       1335.9035702291205`, -9822.527796068183}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9822.527796068183}, {
       1601.2816681890324`, -9822.527796068183}, {
       1601.2816681890324`, -9822.527796068183}, {
       1601.281668189031, -9822.527796068183}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9822.527796068183}, {
       2649.369847474345, -9822.527796068183}, {
       2649.369847474345, -9822.527796068183}, {
       2647.063009768378, -9822.527796068183}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9822.527796068183}, {
       2584.8819748938877`, -9822.527796068183}, {
       2584.8819748938877`, -9822.527796068183}, {
       2584.8819748922283`, -9822.527796068183}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9822.527796068183}, {
       3136.0548108706976`, -9822.527796068183}, {
       3136.0548108706976`, -9822.527796068183}, {
       3136.0548108706776`, -9822.527796068183}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.497359683934, -9822.527796068183}, {
       3696.8203285884942`, -9822.527796068183}, {
       3696.8203285884942`, -9822.527796068183}, {
       2715.497359683934, -9822.527796068183}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.794062434919, -9822.527796068183}, {
       4142.649334928727, -9822.527796068183}, {
       4142.649334928727, -9822.527796068183}, {
       4127.794062434919, -9822.527796068183}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9822.527796068183}, {
      4699.999999999998, -9822.527796068183}, {
      4699.999999999998, -9822.527796068183}, {
      4699.999999999998, -9822.527796068183}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.369847474345, -9822.527796068183}, \
{2649.369847474345, -9822.527796068183}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.369847474345, -9822.527796068183}, 2.476326198799212*^-15,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.369847474345, -9822.527796068183}, {
       4699.999999999998, -9822.527796068183}, {
       4699.999999999998, -9822.527796068183}, {
       2649.369847474345, -9822.527796068183}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9822.527796068183}, 
       2.476326198799212*^-15, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9822.527796068183}, \
{4699.999999999998, -9822.527796068183}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9822.5277960682}, {
        100.00000102543946`, -9822.5277960682}, {
        100.00000102543946`, -9822.527796068183}, {
        100, -9822.527796068183}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9822.5277960682}, {
       601.592870098661, -9822.5277960682}, {
       601.592870098661, -9822.527796068183}, {
       600.0828431526198, -9822.527796068183}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9822.5277960682}, {
       1335.9084631516234`, -9822.5277960682}, {
       1335.9084631516234`, -9822.527796068183}, {
       1335.9035702291205`, -9822.527796068183}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9822.5277960682}, {
       1601.2816681890324`, -9822.5277960682}, {
       1601.2816681890324`, -9822.527796068183}, {
       1601.281668189031, -9822.527796068183}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9822.5277960682}, {
       2649.369847474345, -9822.5277960682}, {
       2649.369847474345, -9822.527796068183}, {
       2647.063009768378, -9822.527796068183}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9822.5277960682}, {
       2584.8819748938877`, -9822.5277960682}, {
       2584.8819748938877`, -9822.527796068183}, {
       2584.8819748922283`, -9822.527796068183}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.497359683934, -9822.5277960682}, {
       3696.8203285884942`, -9822.5277960682}, {
       3696.8203285884942`, -9822.527796068183}, {
       2715.497359683934, -9822.527796068183}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.794062434928, -9822.5277960682}, {
       4142.649334928727, -9822.5277960682}, {
       4142.649334928727, -9822.527796068183}, {
       4127.794062434928, -9822.527796068183}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9822.5277960682}, {
       4699.999999999998, -9822.5277960682}, {
       4699.999999999998, -9822.527796068183}, {
       4699.999999999998, -9822.527796068183}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108706776`, -9822.5277960682}, {
      3136.0548108706976`, -9822.5277960682}, {
      3136.0548108706976`, -9822.527796068183}, {
      3136.0548108706776`, -9822.527796068183}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.794062434919, -9822.527796068187}, \
{4127.794062434928, -9822.527796068183}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.794062434919, -9822.527796068187}, 8.228903984343026*^-12,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707058`, -9822.527796068196}, {
       4127.794062434919, -9822.527796068196}, {
       4127.794062434919, -9822.527796068187}, {
       3136.0548108707058`, -9822.527796068187}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707058`, -9822.527796068196}, 
       8.228903984343026*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706976`, -9822.5277960682}, \
{3136.0548108707058`, -9822.527796068196}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9822.527796069726}, {
        100.00000102543946`, -9822.527796069726}, {
        100.00000102543946`, -9822.5277960682}, {100, -9822.5277960682}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9822.527796069726}, {
       601.592870098661, -9822.527796069726}, {
       601.592870098661, -9822.5277960682}, {
       600.0828431526198, -9822.5277960682}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9822.527796069726}, {
       1335.9084631516234`, -9822.527796069726}, {
       1335.9084631516234`, -9822.5277960682}, {
       1335.9035702291205`, -9822.5277960682}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9822.527796069726}, {
       1601.2816681890324`, -9822.527796069726}, {
       1601.2816681890324`, -9822.5277960682}, {
       1601.281668189031, -9822.5277960682}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9822.527796069726}, {
       2649.369847474345, -9822.527796069726}, {
       2649.369847474345, -9822.5277960682}, {
       2647.063009768378, -9822.5277960682}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748922283`, -9822.527796069726}, {
       2584.881974893124, -9822.527796069726}, {
       2584.881974893124, -9822.5277960682}, {
       2584.8819748922283`, -9822.5277960682}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9822.527796069726}, {
       3136.0548108707058`, -9822.527796069726}, {
       3136.0548108707058`, -9822.5277960682}, {
       3136.0548108706776`, -9822.5277960682}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.497359683934, -9822.527796069726}, {
       3696.8203285884942`, -9822.527796069726}, {
       3696.8203285884942`, -9822.5277960682}, {
       2715.497359683934, -9822.5277960682}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9822.527796069726}, {
       4699.999999999998, -9822.527796069726}, {
       4699.999999999998, -9822.5277960682}, {
       4699.999999999998, -9822.5277960682}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4127.794062434928, -9822.527796069726}, {
      4142.6493349287275`, -9822.527796069726}, {
      4142.6493349287275`, -9822.5277960682}, {
      4127.794062434928, -9822.5277960682}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974893124, -9822.52779606858}, \
{2584.8819748938877`, -9822.5277960682}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748938877`, -9822.52779606858}, 
       7.634828783821215*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819748938877`, -9822.527796069344}, {
       4127.7940624341645`, -9822.527796069344}, {
       4127.7940624341645`, -9822.52779606858}, {
       2584.8819748938877`, -9822.52779606858}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.7940624341645`, -9822.527796069344}, 
       7.634828783821215*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.7940624341645`, -9822.527796069726}, \
{4127.794062434928, -9822.527796069344}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9822.527796070688}, {
       601.592870098661, -9822.527796070688}, {
       601.592870098661, -9822.527796069726}, {
       600.0828431526198, -9822.527796069726}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9822.527796070688}, {
       1335.9084631516234`, -9822.527796070688}, {
       1335.9084631516234`, -9822.527796069726}, {
       1335.9035702291205`, -9822.527796069726}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9822.527796070688}, {
       1601.2816681890324`, -9822.527796070688}, {
       1601.2816681890324`, -9822.527796069726}, {
       1601.281668189031, -9822.527796069726}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2647.063009768378, -9822.527796070688}, {
       2649.369847474345, -9822.527796070688}, {
       2649.369847474345, -9822.527796069726}, {
       2647.063009768378, -9822.527796069726}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927094`, -9822.527796070688}, {
       2584.881974893124, -9822.527796070688}, {
       2584.881974893124, -9822.527796069726}, {
       2584.8819748927094`, -9822.527796069726}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9822.527796070688}, {
       3136.0548108707058`, -9822.527796070688}, {
       3136.0548108707058`, -9822.527796069726}, {
       3136.0548108706776`, -9822.527796069726}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.497359683934, -9822.527796070688}, {
       3696.8203285884942`, -9822.527796070688}, {
       3696.8203285884942`, -9822.527796069726}, {
       2715.497359683934, -9822.527796069726}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9822.527796070688}, {
       4142.6493349287275`, -9822.527796070688}, {
       4142.6493349287275`, -9822.527796069726}, {
       4127.7940624341645`, -9822.527796069726}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9822.527796070688}, {
       4699.999999999998, -9822.527796070688}, {
       4699.999999999998, -9822.527796069726}, {
       4699.999999999998, -9822.527796069726}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9822.527796070688}, {
       100.00000102543946`, -9822.527796070688}, {
       100.00000102543946`, -9822.527796069726}, {
       100, -9822.527796069726}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748922283`, -9822.527796069966}, \
{2584.8819748927094`, -9822.527796069726}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748922283`, -9822.527796069966}, 
       4.812467128264582*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000010259207, -9822.527796070448}, {
       2584.8819748922283`, -9822.527796070448}, {
       2584.8819748922283`, -9822.527796069966}, {
       100.0000010259207, -9822.527796069966}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000010259207, -9822.527796070448}, 4.812467128264582*^-10,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000102543946`, -9822.527796070688}, \
{100.0000010259207, -9822.527796070448}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.155170926115}, {
        100.0000010259207, -9823.155170926115}, {
        100.0000010259207, -9822.527796070688}, {
        100, -9822.527796070688}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.155170926115}, {
       601.2791826709474, -9823.155170926115}, {
       601.2791826709474, -9822.527796070688}, {
       600.0828431526198, -9822.527796070688}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.155170926115}, {
       1335.9084631516234`, -9823.155170926115}, {
       1335.9084631516234`, -9822.527796070688}, {
       1335.9035702291205`, -9822.527796070688}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.155170926115}, {
       1601.2816681890324`, -9823.155170926115}, {
       1601.2816681890324`, -9822.527796070688}, {
       1601.281668189031, -9822.527796070688}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927094`, -9823.155170926115}, {
       2584.881974893124, -9823.155170926115}, {
       2584.881974893124, -9822.527796070688}, {
       2584.8819748927094`, -9822.527796070688}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.155170926115}, {
       3136.0548108707058`, -9823.155170926115}, {
       3136.0548108707058`, -9822.527796070688}, {
       3136.0548108706776`, -9822.527796070688}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.497359683934, -9823.155170926115}, {
       3696.8203285884942`, -9823.155170926115}, {
       3696.8203285884942`, -9822.527796070688}, {
       2715.497359683934, -9822.527796070688}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.155170926115}, {
       4142.6493349287275`, -9823.155170926115}, {
       4142.6493349287275`, -9822.527796070688}, {
       4127.7940624341645`, -9822.527796070688}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.155170926115}, {
       4699.999999999998, -9823.155170926115}, {
       4699.999999999998, -9822.527796070688}, {
       4699.999999999998, -9822.527796070688}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2647.063009768378, -9823.155170926115}, {
      2649.369847474345, -9823.155170926115}, {
      2649.369847474345, -9822.527796070688}, {
      2647.063009768378, -9822.527796070688}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.2791826709474, -9822.684639784544}, \
{601.592870098661, -9822.527796070688}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.592870098661, -9822.684639784544}, 0.31368742771366365`, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{601.592870098661, -9822.998327212257}, {
       2646.749322340664, -9822.998327212257}, {
       2646.749322340664, -9822.684639784544}, {
       601.592870098661, -9822.684639784544}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.749322340664, -9822.998327212257}, 0.31368742771366365`, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.749322340664, -9823.155170926115}, \
{2647.063009768378, -9822.998327212257}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.630112966051}, {
        100.0000010259207, -9823.630112966051}, {
        100.0000010259207, -9823.155170926115}, {
        100, -9823.155170926115}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112966051}, {
       1335.9084631516234`, -9823.630112966051}, {
       1335.9084631516234`, -9823.155170926115}, {
       1335.9035702291205`, -9823.155170926115}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.630112966051}, {
       1601.2816681890324`, -9823.630112966051}, {
       1601.2816681890324`, -9823.155170926115}, {
       1601.281668189031, -9823.155170926115}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112966051}, {
       2649.369847474345, -9823.630112966051}, {
       2649.369847474345, -9823.155170926115}, {
       2646.749322340664, -9823.155170926115}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927094`, -9823.630112966051}, {
       2584.881974893124, -9823.630112966051}, {
       2584.881974893124, -9823.155170926115}, {
       2584.8819748927094`, -9823.155170926115}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.630112966051}, {
       3136.0548108707058`, -9823.630112966051}, {
       3136.0548108707058`, -9823.155170926115}, {
       3136.0548108706776`, -9823.155170926115}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039024`, -9823.630112966051}, {
       3696.820328588494, -9823.630112966051}, {
       3696.820328588494, -9823.155170926115}, {
       2715.7348307039024`, -9823.155170926115}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112966051}, {
       4142.6493349287275`, -9823.630112966051}, {
       4142.6493349287275`, -9823.155170926115}, {
       4127.7940624341645`, -9823.155170926115}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.630112966051}, {
       4699.999999999998, -9823.630112966051}, {
       4699.999999999998, -9823.155170926115}, {
       4699.999999999998, -9823.155170926115}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828431526198, -9823.630112966051}, {
      601.2791826709474, -9823.630112966051}, {
      601.2791826709474, -9823.155170926115}, {
      600.0828431526198, -9823.155170926115}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2715.497359683934, -9823.2739064361}, \
{2715.7348307039024`, -9823.155170926115}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2715.497359683934, -9823.2739064361}, 0.2374710199684662, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{601.5166536909159, -9823.511377456067}, {
       2715.497359683934, -9823.511377456067}, {
       2715.497359683934, -9823.2739064361}, {
       601.5166536909159, -9823.2739064361}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.5166536909159, -9823.511377456067}, 0.2374710199684662, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.2791826709474, -9823.630112966051}, \
{601.5166536909159, -9823.511377456067}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.63011296684}, {
        100.0000010259207, -9823.63011296684}, {
        100.0000010259207, -9823.630112966051}, {
        100, -9823.630112966051}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.63011296684}, {
       601.5166536909159, -9823.63011296684}, {
       601.5166536909159, -9823.630112966051}, {
       600.0828431526198, -9823.630112966051}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.63011296684}, {
       1335.9084631516234`, -9823.63011296684}, {
       1335.9084631516234`, -9823.630112966051}, {
       1335.9035702291205`, -9823.630112966051}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.63011296684}, {
       1601.2816681890324`, -9823.63011296684}, {
       1601.2816681890324`, -9823.630112966051}, {
       1601.281668189031, -9823.630112966051}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.63011296684}, {
       2649.369847474345, -9823.63011296684}, {
       2649.369847474345, -9823.630112966051}, {
       2646.749322340664, -9823.630112966051}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.63011296684}, {
       3136.0548108707058`, -9823.63011296684}, {
       3136.0548108707058`, -9823.630112966051}, {
       3136.0548108706776`, -9823.630112966051}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307042976`, -9823.63011296684}, {
       3696.8203285884942`, -9823.63011296684}, {
       3696.8203285884942`, -9823.630112966051}, {
       2715.7348307042976`, -9823.630112966051}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.63011296684}, {
       4142.6493349287275`, -9823.63011296684}, {
       4142.6493349287275`, -9823.630112966051}, {
       4127.7940624341645`, -9823.630112966051}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.63011296684}, {
       4699.999999999998, -9823.63011296684}, {
       4699.999999999998, -9823.630112966051}, {
       4699.999999999998, -9823.630112966051}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819748927094`, -9823.63011296684}, {
      2584.881974893124, -9823.63011296684}, {
      2584.881974893124, -9823.630112966051}, {
      2584.8819748927094`, -9823.630112966051}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2715.7348307039024`, -9823.630112966248}, \
{2715.7348307042976`, -9823.630112966051}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2715.7348307039024`, -9823.630112966248}, 
       3.9503922501174077`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819748935193`, -9823.630112966643}, {
       2715.7348307039024`, -9823.630112966643}, {
       2715.7348307039024`, -9823.630112966248}, {
       2584.8819748935193`, -9823.630112966248}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748935193`, -9823.630112966643}, 
       3.9503922501174077`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974893124, -9823.63011296684}, \
{2584.8819748935193`, -9823.630112966643}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.630112967083}, {
       601.5166536909159, -9823.630112967083}, {
       601.5166536909159, -9823.63011296684}, {
       600.0828431526198, -9823.63011296684}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112967083}, {
       1335.9084631516234`, -9823.630112967083}, {
       1335.9084631516234`, -9823.63011296684}, {
       1335.9035702291205`, -9823.63011296684}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.630112967083}, {
       1601.2816681890324`, -9823.630112967083}, {
       1601.2816681890324`, -9823.63011296684}, {
       1601.281668189031, -9823.63011296684}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112967083}, {
       2649.369847474345, -9823.630112967083}, {
       2649.369847474345, -9823.63011296684}, {
       2646.749322340664, -9823.63011296684}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.630112967083}, {
       2584.8819748935193`, -9823.630112967083}, {
       2584.8819748935193`, -9823.63011296684}, {
       2584.8819748928304`, -9823.63011296684}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.630112967083}, {
       3136.0548108707058`, -9823.630112967083}, {
       3136.0548108707058`, -9823.63011296684}, {
       3136.0548108706776`, -9823.63011296684}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307042976`, -9823.630112967083}, {
       3696.8203285884942`, -9823.630112967083}, {
       3696.8203285884942`, -9823.63011296684}, {
       2715.7348307042976`, -9823.63011296684}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112967083}, {
       4142.6493349287275`, -9823.630112967083}, {
       4142.6493349287275`, -9823.63011296684}, {
       4127.7940624341645`, -9823.63011296684}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.630112967083}, {
       4699.999999999998, -9823.630112967083}, {
       4699.999999999998, -9823.63011296684}, {
       4699.999999999998, -9823.63011296684}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9823.630112967083}, {
       100.0000010259207, -9823.630112967083}, {
       100.0000010259207, -9823.63011296684}, {100, -9823.63011296684}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748927094`, -9823.630112966901}, \
{2584.8819748928304`, -9823.63011296684}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748927094`, -9823.630112966901}, 
       1.208054606700297*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000010260415, -9823.630112967023}, {
       2584.8819748927094`, -9823.630112967023}, {
       2584.8819748927094`, -9823.630112966901}, {
       100.0000010260415, -9823.630112966901}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000010260415, -9823.630112967023}, 1.208054606700297*^-10,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000010259207, -9823.630112967083}, \
{100.0000010260415, -9823.630112967023}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100.0000010260415, -9823.630112967083}, {
        100, -9823.630112967083}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       601.5166536909159, -9823.630112967083}, {
       600.0828431526198, -9823.630112967083}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967083}, {
       1335.9035702291205`, -9823.630112967083}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967083}, {
       1601.281668189031, -9823.630112967083}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2649.369847474345, -9823.630112967083}, {
       2646.749322340664, -9823.630112967083}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.881974893138, -9823.630112967083}, {
       2584.8819748928304`, -9823.630112967083}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967083}, {
       3136.0548108706776`, -9823.630112967083}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967083}, {
       4127.7940624341645`, -9823.630112967083}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967083}, {
       4699.999999999998, -9823.630112967083}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2715.7348307042976`, -9823.630112967847}, {
      3696.820328588494, -9823.630112967847}, {
      3696.820328588494, -9823.630112967083}, {
      2715.7348307042976`, -9823.630112967083}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974893138, -9823.630112967274}, \
{2584.8819748935193`, -9823.630112967083}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748935193`, -9823.630112967274}, 
       3.8180464989873324`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819748935193`, -9823.630112967656}, {
       2715.7348307039156`, -9823.630112967656}, {
       2715.7348307039156`, -9823.630112967274}, {
       2584.8819748935193`, -9823.630112967274}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2715.7348307039156`, -9823.630112967656}, 
       3.8180464989873324`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2715.7348307039156`, -9823.630112967847}, \
{2715.7348307042976`, -9823.630112967656}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       600.0828431526198, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9035702291205`, -9823.630112967847}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2646.749322340664, -9823.630112967847}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.8819748928304`, -9823.630112967847}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108706776`, -9823.630112967847}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       2715.7348307039156`, -9823.630112967847}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4127.7940624341645`, -9823.630112967847}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668189031, -9823.630112967847}, {
      1601.2816681890324`, -9823.630112967847}, {
      1601.2816681890324`, -9823.630112967847}, {
      1601.281668189031, -9823.630112967847}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.630112967847}, \
{4699.999999999998, -9823.630112967847}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.630112967847}, 2.306440203506107*^-15,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890324`, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890324`, -9823.630112967847}, 
       2.306440203506107*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890324`, -9823.630112967847}, \
{1601.2816681890324`, -9823.630112967847}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       600.0828431526198, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9035702291205`, -9823.630112967847}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.281668189031, -9823.630112967847}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2646.749322340664, -9823.630112967847}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.8819748928304`, -9823.630112967847}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       2715.7348307039156`, -9823.630112967847}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4127.7940624341645`, -9823.630112967847}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108706776`, -9823.630112967847}, {
      3136.0548108707058`, -9823.630112967847}, {
      3136.0548108707058`, -9823.630112967847}, {
      3136.0548108706776`, -9823.630112967847}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.630112967847}, \
{4699.999999999998, -9823.630112967847}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.630112967847}, 
       3.4606899756660667`*^-15, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707058`, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707058`, -9823.630112967847}, 
       3.4606899756660667`*^-15, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707058`, -9823.630112967847}, \
{3136.0548108707058`, -9823.630112967847}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100.0000010260415, -9823.630112967847}, {
        100, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       601.5166536909159, -9823.630112967847}, {
       600.0828431526198, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9084631516234`, -9823.630112967847}, {
       1335.9035702291205`, -9823.630112967847}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.281668189031, -9823.630112967847}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2649.369847474345, -9823.630112967847}, {
       2646.749322340664, -9823.630112967847}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.881974893138, -9823.630112967847}, {
       2584.8819748928304`, -9823.630112967847}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108706776`, -9823.630112967847}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       3696.820328588494, -9823.630112967847}, {
       2715.7348307039156`, -9823.630112967847}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.7940624341645`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4142.6493349287275`, -9823.630112967847}, {
       4127.7940624341645`, -9823.630112967847}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9823.630112967847}, {
      4699.999999999998, -9823.630112967847}, {
      4699.999999999998, -9823.630112967847}, {
      4699.999999999998, -9823.630112967847}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707058`, -9823.630112967847}, \
{3136.0548108707058`, -9823.630112967847}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707058`, -9823.630112967847}, 
       1.6196619391890167`*^-17, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707058`, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}, {
       3136.0548108707058`, -9823.630112967847}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.630112967847}, 
       1.6196619391890167`*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.630112967847}, \
{4699.999999999998, -9823.630112967847}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097344}, {
        100.0000010260415, -9823.639084097344}, {
        100.0000010260415, -9823.630112967847}, {
        100, -9823.630112967847}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097344}, {
       601.5166536909159, -9823.639084097344}, {
       601.5166536909159, -9823.630112967847}, {
       600.0828431526198, -9823.630112967847}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097344}, {
       1601.2816681890324`, -9823.639084097344}, {
       1601.2816681890324`, -9823.630112967847}, {
       1601.281668189031, -9823.630112967847}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097344}, {
       2649.369847474345, -9823.639084097344}, {
       2649.369847474345, -9823.630112967847}, {
       2646.749322340664, -9823.630112967847}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.639084097344}, {
       2584.881974893138, -9823.639084097344}, {
       2584.881974893138, -9823.630112967847}, {
       2584.8819748928304`, -9823.630112967847}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097344}, {
       3136.0548108707058`, -9823.639084097344}, {
       3136.0548108707058`, -9823.630112967847}, {
       3136.0548108706776`, -9823.630112967847}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097344}, {
       3696.820328588494, -9823.639084097344}, {
       3696.820328588494, -9823.630112967847}, {
       2715.7348307039156`, -9823.630112967847}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998913, -9823.639084097344}, {
       4142.649334928727, -9823.639084097344}, {
       4142.649334928727, -9823.630112967847}, {
       4127.798547998913, -9823.630112967847}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097344}, {
       4699.999999999998, -9823.639084097344}, {
       4699.999999999998, -9823.630112967847}, {
       4699.999999999998, -9823.630112967847}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.9035702291205`, -9823.639084097344}, {
      1335.9084631516234`, -9823.639084097344}, {
      1335.9084631516234`, -9823.630112967847}, {
      1335.9035702291205`, -9823.630112967847}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.7940624341645`, -9823.63235575022}, \
{4127.798547998913, -9823.630112967847}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.7940624341645`, -9823.63235575022}, 0.00448556474866222, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9129487163723`, -9823.636841314968}, {
       4127.7940624341645`, -9823.636841314968}, {
       4127.7940624341645`, -9823.63235575022}, {
       1335.9129487163723`, -9823.63235575022}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9129487163723`, -9823.636841314968}, 0.00448556474866222, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9084631516234`, -9823.639084097344}, \
{1335.9129487163723`, -9823.636841314968}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097354}, {
        100.0000010260415, -9823.639084097354}, {
        100.0000010260415, -9823.639084097344}, {
        100, -9823.639084097344}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097354}, {
       601.5166536909159, -9823.639084097354}, {
       601.5166536909159, -9823.639084097344}, {
       600.0828431526198, -9823.639084097344}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097354}, {
       1335.9129487163723`, -9823.639084097354}, {
       1335.9129487163723`, -9823.639084097344}, {
       1335.9035702291205`, -9823.639084097344}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097354}, {
       1601.2816681890324`, -9823.639084097354}, {
       1601.2816681890324`, -9823.639084097344}, {
       1601.281668189031, -9823.639084097344}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097354}, {
       2649.369847474345, -9823.639084097354}, {
       2649.369847474345, -9823.639084097344}, {
       2646.749322340664, -9823.639084097344}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.639084097354}, {
       2584.881974893138, -9823.639084097354}, {
       2584.881974893138, -9823.639084097344}, {
       2584.8819748928304`, -9823.639084097344}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097354}, {
       3136.0548108707007`, -9823.639084097354}, {
       3136.0548108707007`, -9823.639084097344}, {
       3136.0548108706776`, -9823.639084097344}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097354}, {
       3696.820328588494, -9823.639084097354}, {
       3696.820328588494, -9823.639084097344}, {
       2715.7348307039156`, -9823.639084097344}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097354}, {
       4699.999999999998, -9823.639084097354}, {
       4699.999999999998, -9823.639084097344}, {
       4699.999999999998, -9823.639084097344}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4127.798547998913, -9823.639084097354}, {
      4142.649334928727, -9823.639084097354}, {
      4142.649334928727, -9823.639084097344}, {
      4127.798547998913, -9823.639084097344}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707007`, -9823.639084097347}, \
{3136.0548108707058`, -9823.639084097344}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707058`, -9823.639084097347}, 
       5.213975669971655*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707058`, -9823.639084097353}, {
       4127.798547998907, -9823.639084097353}, {
       4127.798547998907, -9823.639084097347}, {
       3136.0548108707058`, -9823.639084097347}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.798547998907, -9823.639084097353}, 
       5.213975669971655*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.798547998907, -9823.639084097354}, \
{4127.798547998913, -9823.639084097353}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097354}, {
        100.0000010260415, -9823.639084097354}, {
        100.0000010260415, -9823.639084097354}, {
        100, -9823.639084097354}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097354}, {
       601.5166536909159, -9823.639084097354}, {
       601.5166536909159, -9823.639084097354}, {
       600.0828431526198, -9823.639084097354}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097354}, {
       1335.9129487163723`, -9823.639084097354}, {
       1335.9129487163723`, -9823.639084097354}, {
       1335.9035702291205`, -9823.639084097354}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097354}, {
       1601.2816681890324`, -9823.639084097354}, {
       1601.2816681890324`, -9823.639084097354}, {
       1601.281668189031, -9823.639084097354}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097354}, {
       2649.369847474345, -9823.639084097354}, {
       2649.369847474345, -9823.639084097354}, {
       2646.749322340664, -9823.639084097354}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748928304`, -9823.639084097354}, {
       2584.881974893138, -9823.639084097354}, {
       2584.881974893138, -9823.639084097354}, {
       2584.8819748928304`, -9823.639084097354}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097354}, {
       3136.0548108707007`, -9823.639084097354}, {
       3136.0548108707007`, -9823.639084097354}, {
       3136.0548108706776`, -9823.639084097354}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097354}, {
       3696.820328588494, -9823.639084097354}, {
       3696.820328588494, -9823.639084097354}, {
       2715.7348307039156`, -9823.639084097354}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.639084097354}, {
       4142.649334928727, -9823.639084097354}, {
       4142.649334928727, -9823.639084097354}, {
       4127.798547998907, -9823.639084097354}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9823.639084097354}, {
      4699.999999999998, -9823.639084097354}, {
      4699.999999999998, -9823.639084097354}, {
      4699.999999999998, -9823.639084097354}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890324`, -9823.639084097354}, \
{1601.2816681890324`, -9823.639084097354}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890324`, -9823.639084097354}, 
       1.5568742331793535`*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890324`, -9823.639084097354}, {
       4699.999999999998, -9823.639084097354}, {
       4699.999999999998, -9823.639084097354}, {
       1601.2816681890324`, -9823.639084097354}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.639084097354}, 
       1.5568742331793535`*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.639084097354}, \
{4699.999999999998, -9823.639084097354}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097558}, {
        100.0000010260415, -9823.639084097558}, {
        100.0000010260415, -9823.639084097354}, {
        100, -9823.639084097354}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097558}, {
       1335.9129487163723`, -9823.639084097558}, {
       1335.9129487163723`, -9823.639084097354}, {
       1335.9035702291205`, -9823.639084097354}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097558}, {
       1601.2816681890324`, -9823.639084097558}, {
       1601.2816681890324`, -9823.639084097354}, {
       1601.281668189031, -9823.639084097354}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097558}, {
       2649.369847474345, -9823.639084097558}, {
       2649.369847474345, -9823.639084097354}, {
       2646.749322340664, -9823.639084097354}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892932, -9823.639084097558}, {
       2584.881974893138, -9823.639084097558}, {
       2584.881974893138, -9823.639084097354}, {
       2584.881974892932, -9823.639084097354}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097558}, {
       3136.0548108707007`, -9823.639084097558}, {
       3136.0548108707007`, -9823.639084097354}, {
       3136.0548108706776`, -9823.639084097354}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097558}, {
       3696.820328588494, -9823.639084097558}, {
       3696.820328588494, -9823.639084097354}, {
       2715.7348307039156`, -9823.639084097354}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.639084097558}, {
       4142.649334928727, -9823.639084097558}, {
       4142.649334928727, -9823.639084097354}, {
       4127.798547998907, -9823.639084097354}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097354}, {
       4699.999999999998, -9823.639084097354}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828431526198, -9823.639084097558}, {
      601.5166536909159, -9823.639084097558}, {
      601.5166536909159, -9823.639084097354}, {
      600.0828431526198, -9823.639084097354}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748928304`, -9823.639084097405}, \
{2584.881974892932, -9823.639084097354}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748928304`, -9823.639084097405}, 
       1.0146073730931358`*^-10, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{601.5166536910174, -9823.639084097507}, {
       2584.8819748928304`, -9823.639084097507}, {
       2584.8819748928304`, -9823.639084097405}, {
       601.5166536910174, -9823.639084097405}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.5166536910174, -9823.639084097507}, 
       1.0146073730931358`*^-10, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.5166536909159, -9823.639084097558}, \
{601.5166536910174, -9823.639084097507}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097558}, {
        100.0000010260415, -9823.639084097558}, {
        100.0000010260415, -9823.639084097558}, {
        100, -9823.639084097558}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097558}, {
       601.5166536910174, -9823.639084097558}, {
       601.5166536910174, -9823.639084097558}, {
       600.0828431526198, -9823.639084097558}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097558}, {
       1335.9129487163723`, -9823.639084097558}, {
       1335.9129487163723`, -9823.639084097558}, {
       1335.9035702291205`, -9823.639084097558}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097558}, {
       1601.2816681890324`, -9823.639084097558}, {
       1601.2816681890324`, -9823.639084097558}, {
       1601.281668189031, -9823.639084097558}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097558}, {
       2649.369847474345, -9823.639084097558}, {
       2649.369847474345, -9823.639084097558}, {
       2646.749322340664, -9823.639084097558}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097558}, {
       3136.0548108707007`, -9823.639084097558}, {
       3136.0548108707007`, -9823.639084097558}, {
       3136.0548108706776`, -9823.639084097558}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097558}, {
       3696.820328588494, -9823.639084097558}, {
       3696.820328588494, -9823.639084097558}, {
       2715.7348307039156`, -9823.639084097558}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.639084097558}, {
       4142.649334928727, -9823.639084097558}, {
       4142.649334928727, -9823.639084097558}, {
       4127.798547998907, -9823.639084097558}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892932, -9823.639084097558}, {
      2584.881974893138, -9823.639084097558}, {
      2584.881974893138, -9823.639084097558}, {
      2584.881974892932, -9823.639084097558}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.639084097558}, \
{4699.999999999998, -9823.639084097558}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.639084097558}, 
       1.4939506942858448`*^-17, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.881974893138, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}, {
       2584.881974893138, -9823.639084097558}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974893138, -9823.639084097558}, 
       1.4939506942858448`*^-17, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974893138, -9823.639084097558}, \
{2584.881974893138, -9823.639084097558}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097895}, {
        100.00000102587343`, -9823.639084097895}, {
        100.00000102587343`, -9823.639084097558}, {
        100, -9823.639084097558}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097895}, {
       601.5166536910174, -9823.639084097895}, {
       601.5166536910174, -9823.639084097558}, {
       600.0828431526198, -9823.639084097558}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097895}, {
       1335.9129487163723`, -9823.639084097895}, {
       1335.9129487163723`, -9823.639084097558}, {
       1335.9035702291205`, -9823.639084097558}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097895}, {
       1601.2816681890324`, -9823.639084097895}, {
       1601.2816681890324`, -9823.639084097558}, {
       1601.281668189031, -9823.639084097558}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097895}, {
       2649.369847474345, -9823.639084097895}, {
       2649.369847474345, -9823.639084097558}, {
       2646.749322340664, -9823.639084097558}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097895}, {
       3136.0548108707007`, -9823.639084097895}, {
       3136.0548108707007`, -9823.639084097558}, {
       3136.0548108706776`, -9823.639084097558}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097895}, {
       3696.820328588494, -9823.639084097895}, {
       3696.820328588494, -9823.639084097558}, {
       2715.7348307039156`, -9823.639084097558}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.639084097895}, {
       4142.649334928727, -9823.639084097895}, {
       4142.649334928727, -9823.639084097558}, {
       4127.798547998907, -9823.639084097558}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097558}, {
       4699.999999999998, -9823.639084097558}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892932, -9823.639084097895}, {
      2584.8819748931373`, -9823.639084097895}, {
      2584.8819748931373`, -9823.639084097558}, {
      2584.881974892932, -9823.639084097558}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000102587343`, -9823.639084097642}, \
{100.0000010260415, -9823.639084097558}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000010260415, -9823.639084097642}, 
       1.6808148311928856`*^-10, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000010260415, -9823.639084097811}, {
       2584.8819748927635`, -9823.639084097811}, {
       2584.8819748927635`, -9823.639084097642}, {
       100.0000010260415, -9823.639084097642}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748927635`, -9823.639084097811}, 
       1.6808148311928856`*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748927635`, -9823.639084097895}, \
{2584.881974892932, -9823.639084097811}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.639084097895}, {
        100.00000102587343`, -9823.639084097895}, {
        100.00000102587343`, -9823.639084097895}, {
        100, -9823.639084097895}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.639084097895}, {
       601.5166536910174, -9823.639084097895}, {
       601.5166536910174, -9823.639084097895}, {
       600.0828431526198, -9823.639084097895}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.9035702291205`, -9823.639084097895}, {
       1335.9129487163723`, -9823.639084097895}, {
       1335.9129487163723`, -9823.639084097895}, {
       1335.9035702291205`, -9823.639084097895}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.639084097895}, {
       1601.2816681890324`, -9823.639084097895}, {
       1601.2816681890324`, -9823.639084097895}, {
       1601.281668189031, -9823.639084097895}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.639084097895}, {
       2649.369847474345, -9823.639084097895}, {
       2649.369847474345, -9823.639084097895}, {
       2646.749322340664, -9823.639084097895}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927635`, -9823.639084097895}, {
       2584.8819748931373`, -9823.639084097895}, {
       2584.8819748931373`, -9823.639084097895}, {
       2584.8819748927635`, -9823.639084097895}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.639084097895}, {
       3136.0548108707007`, -9823.639084097895}, {
       3136.0548108707007`, -9823.639084097895}, {
       3136.0548108706776`, -9823.639084097895}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.639084097895}, {
       3696.820328588494, -9823.639084097895}, {
       3696.820328588494, -9823.639084097895}, {
       2715.7348307039156`, -9823.639084097895}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4127.798547998907, -9823.639084097895}, {
      4142.649334928727, -9823.639084097895}, {
      4142.649334928727, -9823.639084097895}, {
      4127.798547998907, -9823.639084097895}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.639084097895}, \
{4699.999999999998, -9823.639084097895}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.639084097895}, 
       2.3477957999021854`*^-16, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928727, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}, {
       4142.649334928727, -9823.639084097895}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928727, -9823.639084097895}, 
       2.3477957999021854`*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928727, -9823.639084097895}, \
{4142.649334928727, -9823.639084097895}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.653989551347}, {
        100.00000102587343`, -9823.653989551347}, {
        100.00000102587343`, -9823.639084097895}, {
        100, -9823.639084097895}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.653989551347}, {
       601.5092009642916, -9823.653989551347}, {
       601.5092009642916, -9823.639084097895}, {
       600.0828431526198, -9823.639084097895}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.653989551347}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.2816681890324`, -9823.639084097895}, {
       1601.281668189031, -9823.639084097895}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}, {
       2649.369847474345, -9823.639084097895}, {
       2646.749322340664, -9823.639084097895}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927635`, -9823.653989551347}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748931373`, -9823.639084097895}, {
       2584.8819748927635`, -9823.639084097895}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.653989551347}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108707007`, -9823.639084097895}, {
       3136.0548108706776`, -9823.639084097895}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.653989551347}, {
       3696.820328588494, -9823.653989551347}, {
       3696.820328588494, -9823.639084097895}, {
       2715.7348307039156`, -9823.639084097895}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}, {
       4142.649334928727, -9823.639084097895}, {
       4127.798547998907, -9823.639084097895}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}, {
       4699.999999999998, -9823.639084097895}, {
       4699.999999999998, -9823.639084097895}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.9035702291205`, -9823.653989551347}, {
      1335.9129487163723`, -9823.653989551347}, {
      1335.9129487163723`, -9823.639084097895}, {
      1335.9035702291205`, -9823.639084097895}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{601.5092009642916, -9823.642810461259}, \
{601.5166536910174, -9823.639084097895}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.5166536910174, -9823.642810461259}, 0.007452726725761416, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{601.5166536910174, -9823.650263187985}, {
       1335.8961175023949`, -9823.650263187985}, {
       1335.8961175023949`, -9823.642810461259}, {
       601.5166536910174, -9823.642810461259}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.8961175023949`, -9823.650263187985}, 
       0.007452726725761416, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.8961175023949`, -9823.653989551347}, \
{1335.9035702291205`, -9823.650263187985}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.653989551347}, {
        100.00000102587343`, -9823.653989551347}, {
        100.00000102587343`, -9823.653989551347}, {
        100, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.653989551347}, {
       601.5092009642916, -9823.653989551347}, {
       601.5092009642916, -9823.653989551347}, {
       600.0828431526198, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9823.653989551347}, {
       1335.9129487163723`, -9823.653989551347}, {
       1335.9129487163723`, -9823.653989551347}, {
       1335.8961175023949`, -9823.653989551347}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.653989551347}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.281668189031, -9823.653989551347}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}, {
       2646.749322340664, -9823.653989551347}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927635`, -9823.653989551347}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748927635`, -9823.653989551347}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.653989551347}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108706776`, -9823.653989551347}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.653989551347}, {
       3696.820328588494, -9823.653989551347}, {
       3696.820328588494, -9823.653989551347}, {
       2715.7348307039156`, -9823.653989551347}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}, {
       4127.798547998907, -9823.653989551347}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.369847474345, -9823.653989551347}, \
{2649.369847474345, -9823.653989551347}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.369847474345, -9823.653989551347}, 6.588818562815525*^-17,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.369847474345, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.653989551347}, 
       6.588818562815525*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.653989551347}, \
{4699.999999999998, -9823.653989551347}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9823.653989551347}, {
        100.00000102587343`, -9823.653989551347}, {
        100.00000102587343`, -9823.653989551347}, {
        100, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9823.653989551347}, {
       601.5092009642916, -9823.653989551347}, {
       601.5092009642916, -9823.653989551347}, {
       600.0828431526198, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9823.653989551347}, {
       1335.9129487163723`, -9823.653989551347}, {
       1335.9129487163723`, -9823.653989551347}, {
       1335.8961175023949`, -9823.653989551347}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9823.653989551347}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.281668189031, -9823.653989551347}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}, {
       2649.369847474345, -9823.653989551347}, {
       2646.749322340664, -9823.653989551347}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927635`, -9823.653989551347}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748927635`, -9823.653989551347}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9823.653989551347}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108706776`, -9823.653989551347}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2715.7348307039156`, -9823.653989551347}, {
       3696.820328588494, -9823.653989551347}, {
       3696.820328588494, -9823.653989551347}, {
       2715.7348307039156`, -9823.653989551347}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}, {
       4127.798547998907, -9823.653989551347}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}, {
      4699.999999999998, -9823.653989551347}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.649334928727, -9823.653989551347}, \
{4142.649334928727, -9823.653989551347}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.649334928727, -9823.653989551347}, 
       1.4051740879931765`*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.649334928727, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}, {
       4142.649334928727, -9823.653989551347}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9823.653989551347}, 
       1.4051740879931765`*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9823.653989551347}, \
{4699.999999999998, -9823.653989551347}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9825.30220588011}, {
        100.00000102587343`, -9825.30220588011}, {
        100.00000102587343`, -9823.653989551347}, {
        100, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9825.30220588011}, {
       600.6850927999097, -9825.30220588011}, {
       600.6850927999097, -9823.653989551347}, {
       600.0828431526198, -9823.653989551347}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9825.30220588011}, {
       1335.9129487163723`, -9825.30220588011}, {
       1335.9129487163723`, -9823.653989551347}, {
       1335.8961175023949`, -9823.653989551347}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9825.30220588011}, {
       1601.2816681890324`, -9825.30220588011}, {
       1601.2816681890324`, -9823.653989551347}, {
       1601.281668189031, -9823.653989551347}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9825.30220588011}, {
       2649.369847474345, -9825.30220588011}, {
       2649.369847474345, -9823.653989551347}, {
       2646.749322340664, -9823.653989551347}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927635`, -9825.30220588011}, {
       2584.8819748931373`, -9825.30220588011}, {
       2584.8819748931373`, -9823.653989551347}, {
       2584.8819748927635`, -9823.653989551347}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9825.30220588011}, {
       3136.0548108707007`, -9825.30220588011}, {
       3136.0548108707007`, -9823.653989551347}, {
       3136.0548108706776`, -9823.653989551347}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9825.30220588011}, {
       4142.649334928727, -9825.30220588011}, {
       4142.649334928727, -9823.653989551347}, {
       4127.798547998907, -9823.653989551347}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9825.30220588011}, {
       4699.999999999998, -9825.30220588011}, {
       4699.999999999998, -9823.653989551347}, {
       4699.999999999998, -9823.653989551347}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2715.7348307039156`, -9825.30220588011}, {3696.820328588494,
       -9825.30220588011}, {3696.820328588494, -9823.653989551347}, {
      2715.7348307039156`, -9823.653989551347}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.6850927999097, -9824.066043633538}, \
{601.5092009642916, -9823.653989551347}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{601.5092009642916, -9824.066043633538}, 0.8241081643818433, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{601.5092009642916, -9824.89015179792}, {
       2714.9107225395337`, -9824.89015179792}, {
       2714.9107225395337`, -9824.066043633538}, {
       601.5092009642916, -9824.066043633538}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2714.9107225395337`, -9824.89015179792}, 0.8241081643818433, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2714.9107225395337`, -9825.30220588011}, \
{2715.7348307039156`, -9824.89015179792}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9825.302205880156}, {
        100.00000102587343`, -9825.302205880156}, {
        100.00000102587343`, -9825.30220588011}, {
        100, -9825.30220588011}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9825.302205880156}, {
       600.6850927999097, -9825.302205880156}, {
       600.6850927999097, -9825.30220588011}, {
       600.0828431526198, -9825.30220588011}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9825.302205880156}, {
       1335.9129487163723`, -9825.302205880156}, {
       1335.9129487163723`, -9825.30220588011}, {
       1335.8961175023949`, -9825.30220588011}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9825.302205880156}, {
       1601.2816681890324`, -9825.302205880156}, {
       1601.2816681890324`, -9825.30220588011}, {
       1601.281668189031, -9825.30220588011}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9825.302205880156}, {
       2584.8819748931373`, -9825.302205880156}, {
       2584.8819748931373`, -9825.30220588011}, {
       2584.881974892786, -9825.30220588011}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9825.302205880156}, {
       3136.0548108707007`, -9825.302205880156}, {
       3136.0548108707007`, -9825.30220588011}, {
       3136.0548108706776`, -9825.30220588011}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395337`, -9825.302205880156}, {
       3696.820328588494, -9825.302205880156}, {
       3696.820328588494, -9825.30220588011}, {
       2714.9107225395337`, -9825.30220588011}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998907, -9825.302205880156}, {
       4142.649334928727, -9825.302205880156}, {
       4142.649334928727, -9825.30220588011}, {
       4127.798547998907, -9825.30220588011}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9825.302205880156}, {
       4699.999999999998, -9825.302205880156}, {
       4699.999999999998, -9825.30220588011}, {
       4699.999999999998, -9825.30220588011}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.749322340664, -9825.302205880156}, {
      2649.369847474345, -9825.302205880156}, {
      2649.369847474345, -9825.30220588011}, {
      2646.749322340664, -9825.30220588011}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748927635`, -9825.302205880122}, \
{2584.881974892786, -9825.30220588011}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748927635`, -9825.302205880122}, 
       2.24913670694122*^-11, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.3698474743674`, -9825.302205880145}, {
       2584.8819748927635`, -9825.302205880145}, {
       2584.8819748927635`, -9825.302205880122}, {
       2649.3698474743674`, -9825.302205880122}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.3698474743674`, -9825.302205880145}, 
       2.24913670694122*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.369847474345, -9825.302205880156}, \
{2649.3698474743674`, -9825.302205880145}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9825.302205880158}, {
        100.00000102587343`, -9825.302205880158}, {
        100.00000102587343`, -9825.302205880156}, {
        100, -9825.302205880156}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9825.302205880158}, {
       600.6850927999097, -9825.302205880158}, {
       600.6850927999097, -9825.302205880156}, {
       600.0828431526198, -9825.302205880156}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9825.302205880158}, {
       1335.9129487163723`, -9825.302205880158}, {
       1335.9129487163723`, -9825.302205880156}, {
       1335.8961175023949`, -9825.302205880156}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9825.302205880158}, {
       2649.3698474743674`, -9825.302205880158}, {
       2649.3698474743674`, -9825.302205880156}, {
       2646.749322340664, -9825.302205880156}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9825.302205880158}, {
       2584.8819748931373`, -9825.302205880158}, {
       2584.8819748931373`, -9825.302205880156}, {
       2584.881974892786, -9825.302205880156}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9825.302205880158}, {
       3136.0548108707007`, -9825.302205880158}, {
       3136.0548108707007`, -9825.302205880156}, {
       3136.0548108706776`, -9825.302205880156}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395337`, -9825.302205880158}, {
       3696.820328588494, -9825.302205880158}, {
       3696.820328588494, -9825.302205880156}, {
       2714.9107225395337`, -9825.302205880156}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998908, -9825.302205880158}, {
       4142.649334928727, -9825.302205880158}, {
       4142.649334928727, -9825.302205880156}, {
       4127.798547998908, -9825.302205880156}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9825.302205880158}, {
       4699.999999999998, -9825.302205880158}, {
       4699.999999999998, -9825.302205880156}, {
       4699.999999999998, -9825.302205880156}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.281668189031, -9825.302205880158}, {
      1601.2816681890324`, -9825.302205880158}, {
      1601.2816681890324`, -9825.302205880156}, {
      1601.281668189031, -9825.302205880156}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.798547998907, -9825.302205880156}, \
{4127.798547998908, -9825.302205880156}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.798547998907, -9825.302205880156}, 9.494344034219927*^-13,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890336`, -9825.302205880158}, {
       4127.798547998907, -9825.302205880158}, {
       4127.798547998907, -9825.302205880156}, {
       1601.2816681890336`, -9825.302205880156}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890336`, -9825.302205880158}, 
       9.494344034219927*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890324`, -9825.302205880158}, \
{1601.2816681890336`, -9825.302205880158}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9825.302205880158}, {
        100.00000102587343`, -9825.302205880158}, {
        100.00000102587343`, -9825.302205880158}, {
        100, -9825.302205880158}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9825.302205880158}, {
       600.6850927999097, -9825.302205880158}, {
       600.6850927999097, -9825.302205880158}, {
       600.0828431526198, -9825.302205880158}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9825.302205880158}, {
       1335.9129487163723`, -9825.302205880158}, {
       1335.9129487163723`, -9825.302205880158}, {
       1335.8961175023949`, -9825.302205880158}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9825.302205880158}, {
       1601.2816681890336`, -9825.302205880158}, {
       1601.2816681890336`, -9825.302205880158}, {
       1601.281668189031, -9825.302205880158}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9825.302205880158}, {
       2649.3698474743674`, -9825.302205880158}, {
       2649.3698474743674`, -9825.302205880158}, {
       2646.749322340664, -9825.302205880158}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9825.302205880158}, {
       2584.8819748931373`, -9825.302205880158}, {
       2584.8819748931373`, -9825.302205880158}, {
       2584.881974892786, -9825.302205880158}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9825.302205880158}, {
       3136.0548108707007`, -9825.302205880158}, {
       3136.0548108707007`, -9825.302205880158}, {
       3136.0548108706776`, -9825.302205880158}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395337`, -9825.302205880158}, {
       3696.820328588494, -9825.302205880158}, {
       3696.820328588494, -9825.302205880158}, {
       2714.9107225395337`, -9825.302205880158}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4127.798547998908, -9825.302205880158}, {
       4142.649334928727, -9825.302205880158}, {
       4142.649334928727, -9825.302205880158}, {
       4127.798547998908, -9825.302205880158}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9825.302205880158}, {
      4699.999999999998, -9825.302205880158}, {
      4699.999999999998, -9825.302205880158}, {
      4699.999999999998, -9825.302205880158}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890336`, -9825.302205880158}, \
{1601.2816681890336`, -9825.302205880158}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890336`, -9825.302205880158}, 
       3.467654042282731*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890336`, -9825.302205880158}, {
       4699.999999999998, -9825.302205880158}, {
       4699.999999999998, -9825.302205880158}, {
       1601.2816681890336`, -9825.302205880158}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9825.302205880158}, 
       3.467654042282731*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9825.302205880158}, \
{4699.999999999998, -9825.302205880158}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.364234993704}, {
        100.00000102587343`, -9840.364234993704}, {
        100.00000102587343`, -9825.302205880158}, {
        100, -9825.302205880158}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.364234993704}, {
       600.6850927999097, -9840.364234993704}, {
       600.6850927999097, -9825.302205880158}, {
       600.0828431526198, -9825.302205880158}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.364234993704}, {
       1335.9129487163723`, -9840.364234993704}, {
       1335.9129487163723`, -9825.302205880158}, {
       1335.8961175023949`, -9825.302205880158}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.364234993704}, {
       1601.2816681890336`, -9840.364234993704}, {
       1601.2816681890336`, -9825.302205880158}, {
       1601.281668189031, -9825.302205880158}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.749322340664, -9840.364234993704}, {
       2649.3698474743674`, -9840.364234993704}, {
       2649.3698474743674`, -9825.302205880158}, {
       2646.749322340664, -9825.302205880158}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.364234993704}, {
       2584.8819748931373`, -9840.364234993704}, {
       2584.8819748931373`, -9825.302205880158}, {
       2584.881974892786, -9825.302205880158}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.364234993704}, {
       3136.0548108707007`, -9840.364234993704}, {
       3136.0548108707007`, -9825.302205880158}, {
       3136.0548108706776`, -9825.302205880158}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329562555681, -9840.364234993704}, {
       4142.649334928727, -9840.364234993704}, {
       4142.649334928727, -9825.302205880158}, {
       4135.329562555681, -9825.302205880158}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.364234993704}, {
       4699.999999999998, -9840.364234993704}, {
       4699.999999999998, -9825.302205880158}, {
       4699.999999999998, -9825.302205880158}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2714.9107225395337`, -9840.364234993704}, {
      3696.820328588494, -9840.364234993704}, {
      3696.820328588494, -9825.302205880158}, {
      2714.9107225395337`, -9825.302205880158}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4127.798547998908, -9829.067713158545}, \
{4135.329562555681, -9825.302205880158}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4127.798547998908, -9829.067713158545}, 7.531014556772526, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3704.3513431452666`, -9836.598727715318}, {
       4127.798547998908, -9836.598727715318}, {
       4127.798547998908, -9829.067713158545}, {
       3704.3513431452666`, -9829.067713158545}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3704.3513431452666`, -9836.598727715318}, 7.531014556772526, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3696.820328588494, -9840.364234993704}, \
{3704.3513431452666`, -9836.598727715318}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.364234993705}, {
        100.00000102587343`, -9840.364234993705}, {
        100.00000102587343`, -9840.364234993704}, {
        100, -9840.364234993704}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.364234993705}, {
       600.6850927999097, -9840.364234993705}, {
       600.6850927999097, -9840.364234993704}, {
       600.0828431526198, -9840.364234993704}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.364234993705}, {
       1335.9129487163723`, -9840.364234993705}, {
       1335.9129487163723`, -9840.364234993704}, {
       1335.8961175023949`, -9840.364234993704}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.364234993705}, {
       1601.2816681890322`, -9840.364234993705}, {
       1601.2816681890322`, -9840.364234993704}, {
       1601.281668189031, -9840.364234993704}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.364234993705}, {
       2584.8819748931373`, -9840.364234993705}, {
       2584.8819748931373`, -9840.364234993704}, {
       2584.881974892786, -9840.364234993704}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.364234993705}, {
       3136.0548108707007`, -9840.364234993705}, {
       3136.0548108707007`, -9840.364234993704}, {
       3136.0548108706776`, -9840.364234993704}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395337`, -9840.364234993705}, {
       3704.3513431452666`, -9840.364234993705}, {
       3704.3513431452666`, -9840.364234993704}, {
       2714.9107225395337`, -9840.364234993704}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329562555681, -9840.364234993705}, {
       4142.649334928727, -9840.364234993705}, {
       4142.649334928727, -9840.364234993704}, {
       4135.329562555681, -9840.364234993704}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.364234993705}, {
       4699.999999999998, -9840.364234993705}, {
       4699.999999999998, -9840.364234993704}, {
       4699.999999999998, -9840.364234993704}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.749322340664, -9840.364234993705}, {
      2649.3698474743674`, -9840.364234993705}, {
      2649.3698474743674`, -9840.364234993704}, {
      2646.749322340664, -9840.364234993704}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890322`, -9840.364234993704}, \
{1601.2816681890336`, -9840.364234993704}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890336`, -9840.364234993704}, 
       1.1836299161068518`*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890336`, -9840.364234993705}, {
       2646.7493223406627`, -9840.364234993705}, {
       2646.7493223406627`, -9840.364234993704}, {
       1601.2816681890336`, -9840.364234993704}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.7493223406627`, -9840.364234993705}, 
       1.1836299161068518`*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.7493223406627`, -9840.364234993705}, \
{2646.749322340664, -9840.364234993705}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.364234993736}, {
        100.00000102587343`, -9840.364234993736}, {
        100.00000102587343`, -9840.364234993705}, {
        100, -9840.364234993705}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.364234993736}, {
       600.6850927999097, -9840.364234993736}, {
       600.6850927999097, -9840.364234993705}, {
       600.0828431526198, -9840.364234993705}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.364234993736}, {
       1335.9129487163723`, -9840.364234993736}, {
       1335.9129487163723`, -9840.364234993705}, {
       1335.8961175023949`, -9840.364234993705}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.364234993736}, {
       1601.2816681890322`, -9840.364234993736}, {
       1601.2816681890322`, -9840.364234993705}, {
       1601.281668189031, -9840.364234993705}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7493223406627`, -9840.364234993736}, {
       2649.3698474743674`, -9840.364234993736}, {
       2649.3698474743674`, -9840.364234993705}, {
       2646.7493223406627`, -9840.364234993705}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.364234993736}, {
       2584.8819748931373`, -9840.364234993736}, {
       2584.8819748931373`, -9840.364234993705}, {
       2584.881974892786, -9840.364234993705}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.364234993736}, {
       3704.3513431452666`, -9840.364234993736}, {
       3704.3513431452666`, -9840.364234993705}, {
       2714.9107225395496`, -9840.364234993705}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329562555681, -9840.364234993736}, {
       4142.649334928727, -9840.364234993736}, {
       4142.649334928727, -9840.364234993705}, {
       4135.329562555681, -9840.364234993705}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.364234993736}, {
       4699.999999999998, -9840.364234993736}, {
       4699.999999999998, -9840.364234993705}, {
       4699.999999999998, -9840.364234993705}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108706776`, -9840.364234993736}, {
      3136.0548108707007`, -9840.364234993736}, {
      3136.0548108707007`, -9840.364234993705}, {
      3136.0548108706776`, -9840.364234993705}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2714.9107225395337`, -9840.364234993713}, \
{2714.9107225395496`, -9840.364234993705}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2714.9107225395337`, -9840.364234993713}, 
       1.5865410906331612`*^-11, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707167`, -9840.364234993729}, {
       2714.9107225395337`, -9840.364234993729}, {
       2714.9107225395337`, -9840.364234993713}, {
       3136.0548108707167`, -9840.364234993713}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707167`, -9840.364234993729}, 
       1.5865410906331612`*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707007`, -9840.364234993736}, \
{3136.0548108707167`, -9840.364234993729}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.364234993736}, {
        100.00000102587343`, -9840.364234993736}, {
        100.00000102587343`, -9840.364234993736}, {
        100, -9840.364234993736}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.364234993736}, {
       600.6850927999097, -9840.364234993736}, {
       600.6850927999097, -9840.364234993736}, {
       600.0828431526198, -9840.364234993736}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.364234993736}, {
       1335.9129487163723`, -9840.364234993736}, {
       1335.9129487163723`, -9840.364234993736}, {
       1335.8961175023949`, -9840.364234993736}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.364234993736}, {
       1601.2816681890322`, -9840.364234993736}, {
       1601.2816681890322`, -9840.364234993736}, {
       1601.281668189031, -9840.364234993736}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7493223406627`, -9840.364234993736}, {
       2649.3698474743674`, -9840.364234993736}, {
       2649.3698474743674`, -9840.364234993736}, {
       2646.7493223406627`, -9840.364234993736}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.364234993736}, {
       2584.8819748931373`, -9840.364234993736}, {
       2584.8819748931373`, -9840.364234993736}, {
       2584.881974892786, -9840.364234993736}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.364234993736}, {
       3136.0548108707167`, -9840.364234993736}, {
       3136.0548108707167`, -9840.364234993736}, {
       3136.0548108706776`, -9840.364234993736}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.364234993736}, {
       3704.3513431452666`, -9840.364234993736}, {
       3704.3513431452666`, -9840.364234993736}, {
       2714.9107225395496`, -9840.364234993736}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329562555681, -9840.364234993736}, {
       4142.649334928727, -9840.364234993736}, {
       4142.649334928727, -9840.364234993736}, {
       4135.329562555681, -9840.364234993736}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9840.364234993736}, {
      4699.999999999998, -9840.364234993736}, {
      4699.999999999998, -9840.364234993736}, {
      4699.999999999998, -9840.364234993736}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.3698474743674`, -9840.364234993736}, \
{2649.3698474743674`, -9840.364234993736}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.3698474743674`, -9840.364234993736}, 
       2.424391912474157*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.3698474743674`, -9840.364234993736}, {
       4699.999999999998, -9840.364234993736}, {
       4699.999999999998, -9840.364234993736}, {
       2649.3698474743674`, -9840.364234993736}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.364234993736}, 
       2.424391912474157*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.364234993736}, \
{4699.999999999998, -9840.364234993736}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.418584459354}, {
        100.00000102587343`, -9840.418584459354}, {
        100.00000102587343`, -9840.364234993736}, {
        100, -9840.364234993736}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.418584459354}, {
       1335.9129487163723`, -9840.418584459354}, {
       1335.9129487163723`, -9840.364234993736}, {
       1335.8961175023949`, -9840.364234993736}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.418584459354}, {
       1601.2816681890322`, -9840.418584459354}, {
       1601.2816681890322`, -9840.364234993736}, {
       1601.281668189031, -9840.364234993736}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.776497073471, -9840.418584459354}, {
       2649.369847474367, -9840.418584459354}, {
       2649.369847474367, -9840.364234993736}, {
       2646.776497073471, -9840.364234993736}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.418584459354}, {
       2584.8819748931373`, -9840.418584459354}, {
       2584.8819748931373`, -9840.364234993736}, {
       2584.881974892786, -9840.364234993736}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418584459354}, {
       3136.0548108707167`, -9840.418584459354}, {
       3136.0548108707167`, -9840.364234993736}, {
       3136.0548108706776`, -9840.364234993736}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418584459354}, {
       3704.3513431452666`, -9840.418584459354}, {
       3704.3513431452666`, -9840.364234993736}, {
       2714.9107225395496`, -9840.364234993736}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329562555681, -9840.418584459354}, {
       4142.649334928727, -9840.418584459354}, {
       4142.649334928727, -9840.364234993736}, {
       4135.329562555681, -9840.364234993736}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418584459354}, {
       4699.999999999998, -9840.418584459354}, {
       4699.999999999998, -9840.364234993736}, {
       4699.999999999998, -9840.364234993736}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828431526198, -9840.418584459354}, {
      600.6850927999097, -9840.418584459354}, {
      600.6850927999097, -9840.364234993736}, {
      600.0828431526198, -9840.364234993736}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.7493223406627`, -9840.37782236014}, \
{2646.776497073471, -9840.364234993736}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.7493223406627`, -9840.37782236014}, 0.027174732808532442`,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{600.7122675327182, -9840.40499709295}, {
       2646.7493223406627`, -9840.40499709295}, {
       2646.7493223406627`, -9840.37782236014}, {
       600.7122675327182, -9840.37782236014}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.7122675327182, -9840.40499709295}, 0.027174732808532442`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.6850927999097, -9840.418584459354}, \
{600.7122675327182, -9840.40499709295}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.418584755536}, {
        100.000000877782, -9840.418584755536}, {
        100.000000877782, -9840.418584459354}, {100, -9840.418584459354}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.418584755536}, {
       600.7122675327182, -9840.418584755536}, {
       600.7122675327182, -9840.418584459354}, {
       600.0828431526198, -9840.418584459354}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.8961175023949`, -9840.418584755536}, {
       1335.9129487163723`, -9840.418584755536}, {
       1335.9129487163723`, -9840.418584459354}, {
       1335.8961175023949`, -9840.418584459354}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.418584755536}, {
       1601.2816681890322`, -9840.418584755536}, {
       1601.2816681890322`, -9840.418584459354}, {
       1601.281668189031, -9840.418584459354}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.776497073471, -9840.418584755536}, {
       2649.369847474367, -9840.418584755536}, {
       2649.369847474367, -9840.418584459354}, {
       2646.776497073471, -9840.418584459354}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.418584755536}, {
       2584.8819748931373`, -9840.418584755536}, {
       2584.8819748931373`, -9840.418584459354}, {
       2584.881974892786, -9840.418584459354}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418584755536}, {
       3136.0548108707167`, -9840.418584755536}, {
       3136.0548108707167`, -9840.418584459354}, {
       3136.0548108706776`, -9840.418584459354}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418584755536}, {
       3704.3513431452666`, -9840.418584755536}, {
       3704.3513431452666`, -9840.418584459354}, {
       2714.9107225395496`, -9840.418584459354}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418584755536}, {
       4699.999999999998, -9840.418584755536}, {
       4699.999999999998, -9840.418584459354}, {
       4699.999999999998, -9840.418584459354}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4135.329562555681, -9840.418584755536}, {
      4142.6493349287275`, -9840.418584755536}, {
      4142.6493349287275`, -9840.418584459354}, {
      4135.329562555681, -9840.418584459354}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.000000877782, -9840.4185845334}, \
{100.00000102587343`, -9840.418584459354}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000102587343`, -9840.4185845334}, 
       1.4809142598336145`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000102587343`, -9840.41858468149}, {
       4135.32956240759, -9840.41858468149}, {
       4135.32956240759, -9840.4185845334}, {
       100.00000102587343`, -9840.4185845334}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4135.32956240759, -9840.41858468149}, 
       1.4809142598336145`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4135.32956240759, -9840.418584755536}, \
{4135.329562555681, -9840.41858468149}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.418584895158}, {
       600.7122675327182, -9840.418584895158}, {
       600.7122675327182, -9840.418584755536}, {
       600.0828431526198, -9840.418584755536}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896117572206, -9840.418584895158}, {
       1335.9129487163723`, -9840.418584895158}, {
       1335.9129487163723`, -9840.418584755536}, {
       1335.896117572206, -9840.418584755536}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.418584895158}, {
       1601.2816681890322`, -9840.418584895158}, {
       1601.2816681890322`, -9840.418584755536}, {
       1601.281668189031, -9840.418584755536}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.776497073471, -9840.418584895158}, {
       2649.369847474367, -9840.418584895158}, {
       2649.369847474367, -9840.418584755536}, {
       2646.776497073471, -9840.418584755536}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.418584895158}, {
       2584.8819748931373`, -9840.418584895158}, {
       2584.8819748931373`, -9840.418584755536}, {
       2584.881974892786, -9840.418584755536}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418584895158}, {
       3136.0548108707167`, -9840.418584895158}, {
       3136.0548108707167`, -9840.418584755536}, {
       3136.0548108706776`, -9840.418584755536}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418584895158}, {
       3704.3513431452666`, -9840.418584895158}, {
       3704.3513431452666`, -9840.418584755536}, {
       2714.9107225395496`, -9840.418584755536}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.418584895158}, {
       4142.6493349287275`, -9840.418584895158}, {
       4142.6493349287275`, -9840.418584755536}, {
       4135.32956240759, -9840.418584755536}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584755536}, {
       4699.999999999998, -9840.418584755536}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9840.418584895158}, {
       100.000000877782, -9840.418584895158}, {
       100.000000877782, -9840.418584755536}, {100, -9840.418584755536}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.8961175023949`, -9840.418584790441}, \
{1335.896117572206, -9840.418584755536}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.8961175023949`, -9840.418584790441}, 
       6.981119395975747*^-8, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000009475932, -9840.418584860252}, {
       1335.8961175023949`, -9840.418584860252}, {
       1335.8961175023949`, -9840.418584790441}, {
       100.0000009475932, -9840.418584790441}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000009475932, -9840.418584860252}, 6.981119395975747*^-8, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.000000877782, -9840.418584895158}, \
{100.0000009475932, -9840.418584860252}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.418584895158}, {
        100.0000009475932, -9840.418584895158}, {
        100.0000009475932, -9840.418584895158}, {
        100, -9840.418584895158}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.418584895158}, {
       600.7122675327182, -9840.418584895158}, {
       600.7122675327182, -9840.418584895158}, {
       600.0828431526198, -9840.418584895158}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896117572206, -9840.418584895158}, {
       1335.9129487163723`, -9840.418584895158}, {
       1335.9129487163723`, -9840.418584895158}, {
       1335.896117572206, -9840.418584895158}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.281668189031, -9840.418584895158}, {
       1601.281668189032, -9840.418584895158}, {
       1601.281668189032, -9840.418584895158}, {
       1601.281668189031, -9840.418584895158}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.418584895158}, {
       2584.8819748931373`, -9840.418584895158}, {
       2584.8819748931373`, -9840.418584895158}, {
       2584.881974892786, -9840.418584895158}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418584895158}, {
       3136.0548108707167`, -9840.418584895158}, {
       3136.0548108707167`, -9840.418584895158}, {
       3136.0548108706776`, -9840.418584895158}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418584895158}, {
       3704.3513431452666`, -9840.418584895158}, {
       3704.3513431452666`, -9840.418584895158}, {
       2714.9107225395496`, -9840.418584895158}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.418584895158}, {
       4142.6493349287275`, -9840.418584895158}, {
       4142.6493349287275`, -9840.418584895158}, {
       4135.32956240759, -9840.418584895158}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584895158}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.776497073471, -9840.418584895158}, {
      2649.369847474367, -9840.418584895158}, {
      2649.369847474367, -9840.418584895158}, {
      2646.776497073471, -9840.418584895158}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189032, -9840.418584895158}, \
{1601.2816681890322`, -9840.418584895158}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9840.418584895158}, 
       2.486580758016129*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9840.418584895158}, {
       2646.7764970734706`, -9840.418584895158}, {
       2646.7764970734706`, -9840.418584895158}, {
       1601.2816681890322`, -9840.418584895158}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.7764970734706`, -9840.418584895158}, 
       2.486580758016129*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.7764970734706`, -9840.418584895158}, \
{2646.776497073471, -9840.418584895158}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.41858489516}, {
       600.7122675327182, -9840.41858489516}, {
       600.7122675327182, -9840.418584895158}, {
       600.0828431526198, -9840.418584895158}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896117572206, -9840.41858489516}, {
       1335.9129487163723`, -9840.41858489516}, {
       1335.9129487163723`, -9840.418584895158}, {
       1335.896117572206, -9840.418584895158}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.41858489516}, {
       1601.2816681890322`, -9840.41858489516}, {
       1601.2816681890322`, -9840.418584895158}, {
       1601.2816681890317`, -9840.418584895158}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.41858489516}, {
       2649.369847474367, -9840.41858489516}, {
       2649.369847474367, -9840.418584895158}, {
       2646.7764970734706`, -9840.418584895158}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.41858489516}, {
       2584.8819748931373`, -9840.41858489516}, {
       2584.8819748931373`, -9840.418584895158}, {
       2584.881974892786, -9840.418584895158}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.41858489516}, {
       3136.0548108707167`, -9840.41858489516}, {
       3136.0548108707167`, -9840.418584895158}, {
       3136.0548108706776`, -9840.418584895158}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.41858489516}, {
       3704.3513431452666`, -9840.41858489516}, {
       3704.3513431452666`, -9840.418584895158}, {
       2714.9107225395496`, -9840.418584895158}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.41858489516}, {
       4142.6493349287275`, -9840.41858489516}, {
       4142.6493349287275`, -9840.418584895158}, {
       4135.32956240759, -9840.418584895158}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.41858489516}, {
       4699.999999999998, -9840.41858489516}, {
       4699.999999999998, -9840.418584895158}, {
       4699.999999999998, -9840.418584895158}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9840.41858489516}, {
       100.0000009475932, -9840.41858489516}, {
       100.0000009475932, -9840.418584895158}, {
       100, -9840.418584895158}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189031, -9840.41858489516}, \
{1601.2816681890317`, -9840.418584895158}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189031, -9840.41858489516}, 5.857126220577477*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000094759378`, -9840.41858489516}, {
       1601.281668189031, -9840.41858489516}, {
       1601.281668189031, -9840.41858489516}, {
       100.00000094759378`, -9840.41858489516}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000094759378`, -9840.41858489516}, 
       5.857126220577477*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000009475932, -9840.41858489516}, \
{100.00000094759378`, -9840.41858489516}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.41858489516}, {
        100.00000094759378`, -9840.41858489516}, {
        100.00000094759378`, -9840.41858489516}, {
        100, -9840.41858489516}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.41858489516}, {
       600.7122675327182, -9840.41858489516}, {
       600.7122675327182, -9840.41858489516}, {
       600.0828431526198, -9840.41858489516}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896117572206, -9840.41858489516}, {
       1335.9129487163723`, -9840.41858489516}, {
       1335.9129487163723`, -9840.41858489516}, {
       1335.896117572206, -9840.41858489516}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.41858489516}, {
       1601.2816681890322`, -9840.41858489516}, {
       1601.2816681890322`, -9840.41858489516}, {
       1601.2816681890317`, -9840.41858489516}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.41858489516}, {
       2649.369847474367, -9840.41858489516}, {
       2649.369847474367, -9840.41858489516}, {
       2646.7764970734706`, -9840.41858489516}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892786, -9840.41858489516}, {
       2584.8819748931373`, -9840.41858489516}, {
       2584.8819748931373`, -9840.41858489516}, {
       2584.881974892786, -9840.41858489516}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.41858489516}, {
       3136.0548108707167`, -9840.41858489516}, {
       3136.0548108707167`, -9840.41858489516}, {
       3136.0548108706776`, -9840.41858489516}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.41858489516}, {
       3704.3513431452666`, -9840.41858489516}, {
       3704.3513431452666`, -9840.41858489516}, {
       2714.9107225395496`, -9840.41858489516}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.41858489516}, {
       4142.6493349287275`, -9840.41858489516}, {
       4142.6493349287275`, -9840.41858489516}, {
       4135.32956240759, -9840.41858489516}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9840.41858489516}, {
      4699.999999999998, -9840.41858489516}, {
      4699.999999999998, -9840.41858489516}, {
      4699.999999999998, -9840.41858489516}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9129487163723`, -9840.41858489516}, \
{1335.9129487163723`, -9840.41858489516}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9129487163723`, -9840.41858489516}, 
       6.902256666490332*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9129487163723`, -9840.41858489516}, {
       4699.999999999998, -9840.41858489516}, {
       4699.999999999998, -9840.41858489516}, {
       1335.9129487163723`, -9840.41858489516}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.41858489516}, 
       6.902256666490332*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.41858489516}, \
{4699.999999999998, -9840.41858489516}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.418584895207}, {
        100.00000094759378`, -9840.418584895207}, {
        100.00000094759378`, -9840.41858489516}, {
        100, -9840.41858489516}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.418584895207}, {
       600.7122675326942, -9840.418584895207}, {
       600.7122675326942, -9840.41858489516}, {
       600.0828431526198, -9840.41858489516}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896117572206, -9840.418584895207}, {
       1335.9129487163723`, -9840.418584895207}, {
       1335.9129487163723`, -9840.41858489516}, {
       1335.896117572206, -9840.41858489516}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.418584895207}, {
       1601.2816681890322`, -9840.418584895207}, {
       1601.2816681890322`, -9840.41858489516}, {
       1601.2816681890317`, -9840.41858489516}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.418584895207}, {
       2649.369847474367, -9840.418584895207}, {
       2649.369847474367, -9840.41858489516}, {
       2646.7764970734706`, -9840.41858489516}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418584895207}, {
       3136.0548108707167`, -9840.418584895207}, {
       3136.0548108707167`, -9840.41858489516}, {
       3136.0548108706776`, -9840.41858489516}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418584895207}, {
       3704.3513431452666`, -9840.418584895207}, {
       3704.3513431452666`, -9840.41858489516}, {
       2714.9107225395496`, -9840.41858489516}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.418584895207}, {
       4142.6493349287275`, -9840.418584895207}, {
       4142.6493349287275`, -9840.41858489516}, {
       4135.32956240759, -9840.41858489516}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418584895207}, {
       4699.999999999998, -9840.418584895207}, {
       4699.999999999998, -9840.41858489516}, {
       4699.999999999998, -9840.41858489516}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892786, -9840.418584895207}, {
      2584.8819748931373`, -9840.418584895207}, {
      2584.8819748931373`, -9840.41858489516}, {
      2584.881974892786, -9840.41858489516}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.7122675326942, -9840.418584895171}, \
{600.7122675327182, -9840.41858489516}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.7122675327182, -9840.418584895171}, 
       2.4032087611374144`*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{600.7122675327182, -9840.418584895195}, {
       2584.8819748927617`, -9840.418584895195}, {
       2584.8819748927617`, -9840.418584895171}, {
       600.7122675327182, -9840.418584895171}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748927617`, -9840.418584895195}, 
       2.4032087611374144`*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748927617`, -9840.418584895207}, \
{2584.881974892786, -9840.418584895195}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.418586499129}, {
       600.7122675326942, -9840.418586499129}, {
       600.7122675326942, -9840.418584895207}, {
       600.0828431526198, -9840.418584895207}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.418586499129}, {
       1335.9129487163723`, -9840.418586499129}, {
       1335.9129487163723`, -9840.418584895207}, {
       1335.896118374167, -9840.418584895207}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.418586499129}, {
       1601.2816681890322`, -9840.418586499129}, {
       1601.2816681890322`, -9840.418584895207}, {
       1601.2816681890317`, -9840.418584895207}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.418586499129}, {
       2649.369847474367, -9840.418586499129}, {
       2649.369847474367, -9840.418584895207}, {
       2646.7764970734706`, -9840.418584895207}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.418586499129}, {
       2584.8819748931373`, -9840.418586499129}, {
       2584.8819748931373`, -9840.418584895207}, {
       2584.8819748927617`, -9840.418584895207}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.418586499129}, {
       3136.0548108707167`, -9840.418586499129}, {
       3136.0548108707167`, -9840.418584895207}, {
       3136.0548108706776`, -9840.418584895207}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.9107225395496`, -9840.418586499129}, {
       3704.3513431452666`, -9840.418586499129}, {
       3704.3513431452666`, -9840.418584895207}, {
       2714.9107225395496`, -9840.418584895207}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.418586499129}, {
       4142.6493349287275`, -9840.418586499129}, {
       4142.6493349287275`, -9840.418584895207}, {
       4135.32956240759, -9840.418584895207}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.418586499129}, {
       4699.999999999998, -9840.418586499129}, {
       4699.999999999998, -9840.418584895207}, {
       4699.999999999998, -9840.418584895207}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9840.418586499129}, {
       100.00000094759378`, -9840.418586499129}, {
       100.00000094759378`, -9840.418584895207}, {
       100, -9840.418584895207}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.896117572206, -9840.418585296187}, \
{1335.896118374167, -9840.418584895207}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.896117572206, -9840.418585296187}, 8.019608614753541*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000174955464`, -9840.418586098149}, {
       1335.896117572206, -9840.418586098149}, {
       1335.896117572206, -9840.418585296187}, {
       100.00000174955464`, -9840.418585296187}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000174955464`, -9840.418586098149}, 
       8.019608614753541*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000094759378`, -9840.418586499129}, \
{100.00000174955464`, -9840.418586098149}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.418586499129}, {
        100, -9840.418586499129}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.418586499129}, {
       600.0828431526198, -9840.418586499129}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890322`, -9840.426409346606}, {
       1601.2816681890322`, -9840.418586499129}, {
       1601.2816681890317`, -9840.418586499129}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2649.369847474367, -9840.418586499129}, {
       2646.7764970734706`, -9840.418586499129}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.418586499129}, {
       2584.8819748927617`, -9840.418586499129}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.418586499129}, {
       3136.0548108706776`, -9840.418586499129}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       3704.3513431452666`, -9840.418586499129}, {
       2714.914633963288, -9840.418586499129}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4142.6493349287275`, -9840.418586499129}, {
       4135.32956240759, -9840.418586499129}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.418586499129}, {
       4699.999999999998, -9840.418586499129}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.896118374167, -9840.426409346606}, {
      1335.9129487163723`, -9840.426409346606}, {
      1335.9129487163723`, -9840.418586499129}, {
      1335.896118374167, -9840.418586499129}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2714.9107225395496`, -9840.420542210999}, \
{2714.914633963288, -9840.418586499129}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2714.9107225395496`, -9840.420542210999}, 0.003911423738495408,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9168601401109`, -9840.424453634738}, {
       2714.9107225395496`, -9840.424453634738}, {
       2714.9107225395496`, -9840.420542210999}, {
       1335.9168601401109`, -9840.420542210999}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9168601401109`, -9840.424453634738}, 0.003911423738495408,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9129487163723`, -9840.426409346606}, \
{1335.9168601401109`, -9840.424453634738}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426409346606}, {
       1335.9168601401109`, -9840.426409346606}, {
       1335.9168601401109`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.426409346606}, {
       1601.281668189032, -9840.426409346606}, {
       1601.281668189032, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       2714.914633963288, -9840.426409346606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
      2649.369847474367, -9840.426409346606}, {
      2649.369847474367, -9840.426409346606}, {
      2646.7764970734706`, -9840.426409346606}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189032, -9840.426409346606}, \
{1601.2816681890322`, -9840.426409346606}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9840.426409346606}, 
       1.3010920281953153`*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}, {
       1601.2816681890322`, -9840.426409346606}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.7764970734706`, -9840.426409346606}, 
       1.3010920281953153`*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.7764970734706`, -9840.426409346606}, \
{2646.7764970734706`, -9840.426409346606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426409346606}, {
       1335.9168601401109`, -9840.426409346606}, {
       1335.9168601401109`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890317`, -9840.426409346606}, {
       1601.281668189032, -9840.426409346606}, {
       1601.281668189032, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2714.914633963288, -9840.426409346606}, {
      3704.3513431452666`, -9840.426409346606}, {
      3704.3513431452666`, -9840.426409346606}, {
      2714.914633963288, -9840.426409346606}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.426409346606}, \
{4699.999999999998, -9840.426409346606}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.426409346606}, 7.412695800949191*^-16,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3704.3513431452666`, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3704.3513431452666`, -9840.426409346606}, 
       7.412695800949191*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3704.3513431452666`, -9840.426409346606}, \
{3704.3513431452666`, -9840.426409346606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       2714.914633963288, -9840.426409346606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890317`, -9840.426409346606}, {
      1601.281668189032, -9840.426409346606}, {
      1601.281668189032, -9840.426409346606}, {
      1601.2816681890317`, -9840.426409346606}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9168601401107`, -9840.426409346606}, \
{1335.9168601401109`, -9840.426409346606}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9168601401109`, -9840.426409346606}, 
       1.3142513498147166`*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9168601401109`, -9840.426409346606}, {
       1601.2816681890315`, -9840.426409346606}, {
       1601.2816681890315`, -9840.426409346606}, {
       1335.9168601401109`, -9840.426409346606}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890315`, -9840.426409346606}, 
       1.3142513498147166`*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890315`, -9840.426409346606}, \
{1601.2816681890317`, -9840.426409346606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890315`, -9840.426409346606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}, {
       2714.914633963288, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4135.32956240759, -9840.426409346606}, {
      4142.6493349287275`, -9840.426409346606}, {
      4142.6493349287275`, -9840.426409346606}, {
      4135.32956240759, -9840.426409346606}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890317`, -9840.426409346606}, \
{1601.281668189032, -9840.426409346606}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189032, -9840.426409346606}, 
       1.0221084169069828`*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189032, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}, {
       1601.281668189032, -9840.426409346606}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4135.32956240759, -9840.426409346606}, 
       1.0221084169069828`*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4135.32956240759, -9840.426409346606}, \
{4135.32956240759, -9840.426409346606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100.00000174955464`, -9840.426409346606}, {
        100, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890315`, -9840.426409346606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2649.369847474367, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.32956240759, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4142.6493349287275`, -9840.426409346606}, {
       4135.32956240759, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2714.914633963288, -9840.426409346606}, {
      3704.3513431452666`, -9840.426409346606}, {
      3704.3513431452666`, -9840.426409346606}, {
      2714.914633963288, -9840.426409346606}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.426409346606}, \
{4699.999999999998, -9840.426409346606}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.426409346606}, 7.330882028988808*^-16,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3704.3513431452666`, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}, {
       3704.3513431452666`, -9840.426409346606}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3704.3513431452666`, -9840.426409346606}, 
       7.330882028988808*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3704.3513431452666`, -9840.426409346606}, \
{3704.3513431452666`, -9840.426409346606}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426411604978}, {
       600.7122675326942, -9840.426411604978}, {
       600.7122675326942, -9840.426409346606}, {
       600.0828431526198, -9840.426409346606}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426411604978}, {
       1335.9168601401107`, -9840.426411604978}, {
       1335.9168601401107`, -9840.426409346606}, {
       1335.896118374167, -9840.426409346606}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.426411604978}, {
       1601.2816681890317`, -9840.426411604978}, {
       1601.2816681890317`, -9840.426409346606}, {
       1601.2816681890315`, -9840.426409346606}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764970734706`, -9840.426411604978}, {
       2649.369847474367, -9840.426411604978}, {
       2649.369847474367, -9840.426409346606}, {
       2646.7764970734706`, -9840.426409346606}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426411604978}, {
       2584.8819748931373`, -9840.426411604978}, {
       2584.8819748931373`, -9840.426409346606}, {
       2584.8819748927617`, -9840.426409346606}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426411604978}, {
       3136.0548108707167`, -9840.426411604978}, {
       3136.0548108707167`, -9840.426409346606}, {
       3136.0548108706776`, -9840.426409346606}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426411604978}, {
       3704.3513431452666`, -9840.426411604978}, {
       3704.3513431452666`, -9840.426409346606}, {
       2714.914633963288, -9840.426409346606}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329563536776, -9840.426411604978}, {
       4142.6493349287275`, -9840.426411604978}, {
       4142.6493349287275`, -9840.426409346606}, {
       4135.329563536776, -9840.426409346606}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426411604978}, {
       4699.999999999998, -9840.426411604978}, {
       4699.999999999998, -9840.426409346606}, {
       4699.999999999998, -9840.426409346606}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9840.426411604978}, {
       100.00000174955464`, -9840.426411604978}, {
       100.00000174955464`, -9840.426409346606}, {
       100, -9840.426409346606}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4135.32956240759, -9840.426409911199}, \
{4135.329563536776, -9840.426409346606}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4135.32956240759, -9840.426409911199}, 1.129185828141424*^-6, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000287874047`, -9840.426411040386}, {
       4135.32956240759, -9840.426411040386}, {
       4135.32956240759, -9840.426409911199}, {
       100.00000287874047`, -9840.426409911199}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000287874047`, -9840.426411040386}, 
       1.129185828141424*^-6, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000174955464`, -9840.426411604978}, \
{100.00000287874047`, -9840.426411040386}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.426416174561}, {
        100.00000059394924`, -9840.426416174561}, {
        100.00000059394924`, -9840.426411604978}, {
        100, -9840.426411604978}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.426416174561}, {
       600.7122675326942, -9840.426416174561}, {
       600.7122675326942, -9840.426411604978}, {
       600.0828431526198, -9840.426411604978}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.426416174561}, {
       1335.9168601401107`, -9840.426416174561}, {
       1335.9168601401107`, -9840.426411604978}, {
       1335.896118374167, -9840.426411604978}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.426416174561}, {
       1601.2816681890317`, -9840.426416174561}, {
       1601.2816681890317`, -9840.426411604978}, {
       1601.2816681890315`, -9840.426411604978}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.8819748927617`, -9840.426416174561}, {
       2584.8819748931373`, -9840.426416174561}, {
       2584.8819748931373`, -9840.426411604978}, {
       2584.8819748927617`, -9840.426411604978}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.426416174561}, {
       3136.0548108707167`, -9840.426416174561}, {
       3136.0548108707167`, -9840.426411604978}, {
       3136.0548108706776`, -9840.426411604978}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.426416174561}, {
       3704.3513431452666`, -9840.426416174561}, {
       3704.3513431452666`, -9840.426411604978}, {
       2714.914633963288, -9840.426411604978}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329563536776, -9840.426416174561}, {
       4142.6493349287275`, -9840.426416174561}, {
       4142.6493349287275`, -9840.426411604978}, {
       4135.329563536776, -9840.426411604978}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.426416174561}, {
       4699.999999999998, -9840.426416174561}, {
       4699.999999999998, -9840.426411604978}, {
       4699.999999999998, -9840.426411604978}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.7764970734706`, -9840.426416174561}, {
      2649.369847474367, -9840.426416174561}, {
      2649.369847474367, -9840.426411604978}, {
      2646.7764970734706`, -9840.426411604978}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000059394924`, -9840.426412747374}, \
{100.00000287874047`, -9840.426411604978}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000287874047`, -9840.426412747374}, 
       2.2847912367417397`*^-6, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000287874047`, -9840.426415032165}, {
       2646.7764947886794`, -9840.426415032165}, {
       2646.7764947886794`, -9840.426412747374}, {
       100.00000287874047`, -9840.426412747374}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2646.7764947886794`, -9840.426415032165}, 
       2.2847912367417397`*^-6, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2646.7764947886794`, -9840.426416174561}, \
{2646.7764970734706`, -9840.426415032165}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.42641617515}, {
        100.00000059394924`, -9840.42641617515}, {
        100.00000059394924`, -9840.426416174561}, {
        100, -9840.426416174561}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.42641617515}, {
       600.7122675326942, -9840.42641617515}, {
       600.7122675326942, -9840.426416174561}, {
       600.0828431526198, -9840.426416174561}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.42641617515}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.9168601401107`, -9840.426416174561}, {
       1335.896118374167, -9840.426416174561}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.42641617515}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890317`, -9840.426416174561}, {
       1601.2816681890315`, -9840.426416174561}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9840.42641617515}, {
       2649.3698474740722`, -9840.42641617515}, {
       2649.3698474740722`, -9840.426416174561}, {
       2646.7764947886794`, -9840.426416174561}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108707167`, -9840.426416174561}, {
       3136.0548108706776`, -9840.426416174561}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}, {
       3704.3513431452666`, -9840.426416174561}, {
       2714.914633963288, -9840.426416174561}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329563536776, -9840.42641617515}, {
       4142.6493349287275`, -9840.42641617515}, {
       4142.6493349287275`, -9840.426416174561}, {
       4135.329563536776, -9840.426416174561}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}, {
       4699.999999999998, -9840.426416174561}, {
       4699.999999999998, -9840.426416174561}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.8819748927617`, -9840.42641617515}, {
      2584.8819748931373`, -9840.42641617515}, {
      2584.8819748931373`, -9840.426416174561}, {
      2584.8819748927617`, -9840.426416174561}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2649.3698474740722`, -9840.426416174709}, \
{2649.369847474367, -9840.426416174561}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.369847474367, -9840.426416174709}, 2.948329708689284*^-10,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.369847474367, -9840.426416175003}, {
       2584.881974892467, -9840.426416175003}, {
       2584.881974892467, -9840.426416174709}, {
       2649.369847474367, -9840.426416174709}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974892467, -9840.426416175003}, 
       2.948329708689284*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974892467, -9840.42641617515}, \
{2584.8819748927617`, -9840.426416175003}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.42641617515}, {
        100.00000059394924`, -9840.42641617515}, {
        100.00000059394924`, -9840.42641617515}, {
        100, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.42641617515}, {
       600.7122675326942, -9840.42641617515}, {
       600.7122675326942, -9840.42641617515}, {
       600.0828431526198, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.42641617515}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.896118374167, -9840.42641617515}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.42641617515}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890315`, -9840.42641617515}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9840.42641617515}, {
       2649.3698474740722`, -9840.42641617515}, {
       2649.3698474740722`, -9840.42641617515}, {
       2646.7764947886794`, -9840.42641617515}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9840.42641617515}, {
       2584.8819748931373`, -9840.42641617515}, {
       2584.8819748931373`, -9840.42641617515}, {
       2584.881974892467, -9840.42641617515}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108706776`, -9840.42641617515}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}, {
       2714.914633963288, -9840.42641617515}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329563536776, -9840.42641617515}, {
       4142.6493349287275`, -9840.42641617515}, {
       4142.6493349287275`, -9840.42641617515}, {
       4135.329563536776, -9840.42641617515}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707167`, -9840.42641617515}, \
{3136.0548108707167`, -9840.42641617515}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707167`, -9840.42641617515}, 
       1.083444320014961*^-17, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707167`, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.42641617515}, 
       1.083444320014961*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.42641617515}, \
{4699.999999999998, -9840.42641617515}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9840.42641617515}, {
        100.00000059394924`, -9840.42641617515}, {
        100.00000059394924`, -9840.42641617515}, {
        100, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9840.42641617515}, {
       600.7122675326942, -9840.42641617515}, {
       600.7122675326942, -9840.42641617515}, {
       600.0828431526198, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9840.42641617515}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.896118374167, -9840.42641617515}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9840.42641617515}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890315`, -9840.42641617515}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9840.42641617515}, {
       2649.3698474740722`, -9840.42641617515}, {
       2649.3698474740722`, -9840.42641617515}, {
       2646.7764947886794`, -9840.42641617515}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9840.42641617515}, {
       2584.8819748931373`, -9840.42641617515}, {
       2584.8819748931373`, -9840.42641617515}, {
       2584.881974892467, -9840.42641617515}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108706776`, -9840.42641617515}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}, {
       2714.914633963288, -9840.42641617515}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4135.329563536776, -9840.42641617515}, {
       4142.6493349287275`, -9840.42641617515}, {
       4142.6493349287275`, -9840.42641617515}, {
       4135.329563536776, -9840.42641617515}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}, {
      4699.999999999998, -9840.42641617515}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{3704.3513431452666`, -9840.42641617515}, \
{3704.3513431452666`, -9840.42641617515}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{3704.3513431452666`, -9840.42641617515}, 
       1.5304994279868868`*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3704.3513431452666`, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}, {
       3704.3513431452666`, -9840.42641617515}},
       VertexColors->{
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9840.42641617515}, 
       1.5304994279868868`*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9840.42641617515}, \
{4699.999999999998, -9840.42641617515}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9841.168085980833}, {
        100.00000059394924`, -9841.168085980833}, {
        100.00000059394924`, -9840.42641617515}, {
        100, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9841.168085980833}, {
       600.3414326298531, -9841.168085980833}, {
       600.3414326298531, -9840.42641617515}, {
       600.0828431526198, -9840.42641617515}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9841.168085980833}, {
       1335.9168601401107`, -9841.168085980833}, {
       1335.9168601401107`, -9840.42641617515}, {
       1335.896118374167, -9840.42641617515}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9841.168085980833}, {
       1601.2816681890317`, -9841.168085980833}, {
       1601.2816681890317`, -9840.42641617515}, {
       1601.2816681890315`, -9840.42641617515}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9841.168085980833}, {
       2649.3698474740722`, -9841.168085980833}, {
       2649.3698474740722`, -9840.42641617515}, {
       2646.7764947886794`, -9840.42641617515}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9841.168085980833}, {
       2584.8819748931373`, -9841.168085980833}, {
       2584.8819748931373`, -9840.42641617515}, {
       2584.881974892467, -9840.42641617515}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9841.168085980833}, {
       3136.0548108707167`, -9841.168085980833}, {
       3136.0548108707167`, -9840.42641617515}, {
       3136.0548108706776`, -9840.42641617515}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9841.168085980833}, {
       3704.3513431452666`, -9841.168085980833}, {
       3704.3513431452666`, -9840.42641617515}, {
       2714.914633963288, -9840.42641617515}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9840.42641617515}, {
       4699.999999999998, -9840.42641617515}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4135.329563536776, -9841.168085980833}, {
      4142.6493349287275`, -9841.168085980833}, {
      4142.6493349287275`, -9840.42641617515}, {
      4135.329563536776, -9840.42641617515}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.3414326298531, -9840.611833626572}, \
{600.7122675326942, -9840.42641617515}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.7122675326942, -9840.611833626572}, 0.3708349028411103, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{600.7122675326942, -9840.982668529412}, {
       4134.958728633935, -9840.982668529412}, {
       4134.958728633935, -9840.611833626572}, {
       600.7122675326942, -9840.611833626572}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.958728633935, -9840.982668529412}, 0.3708349028411103, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.958728633935, -9841.168085980833}, \
{4135.329563536776, -9840.982668529412}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9841.168085980833}, {
        100.00000059394924`, -9841.168085980833}, {
        100.00000059394924`, -9841.168085980833}, {
        100, -9841.168085980833}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9841.168085980833}, {
       600.3414326298531, -9841.168085980833}, {
       600.3414326298531, -9841.168085980833}, {
       600.0828431526198, -9841.168085980833}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9841.168085980833}, {
       1335.9168601401107`, -9841.168085980833}, {
       1335.9168601401107`, -9841.168085980833}, {
       1335.896118374167, -9841.168085980833}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9841.168085980833}, {
       2649.3698474740722`, -9841.168085980833}, {
       2649.3698474740722`, -9841.168085980833}, {
       2646.7764947886794`, -9841.168085980833}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9841.168085980833}, {
       2584.8819748931373`, -9841.168085980833}, {
       2584.8819748931373`, -9841.168085980833}, {
       2584.881974892467, -9841.168085980833}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706776`, -9841.168085980833}, {
       3136.0548108707167`, -9841.168085980833}, {
       3136.0548108707167`, -9841.168085980833}, {
       3136.0548108706776`, -9841.168085980833}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9841.168085980833}, {
       3704.3513431452666`, -9841.168085980833}, {
       3704.3513431452666`, -9841.168085980833}, {
       2714.914633963288, -9841.168085980833}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.958728633935, -9841.168085980833}, {
       4142.6493349287275`, -9841.168085980833}, {
       4142.6493349287275`, -9841.168085980833}, {
       4134.958728633935, -9841.168085980833}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9841.168085980833}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890315`, -9841.168085980833}, {
      1601.2816681890317`, -9841.168085980833}, {
      1601.2816681890317`, -9841.168085980833}, {
      1601.2816681890315`, -9841.168085980833}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974892467, -9841.168085980833}, \
{2584.881974892467, -9841.168085980833}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974892467, -9841.168085980833}, 
       1.2052571068497302`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189032, -9841.168085980833}, {
       2584.881974892467, -9841.168085980833}, {
       2584.881974892467, -9841.168085980833}, {
       1601.281668189032, -9841.168085980833}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189032, -9841.168085980833}, 
       1.2052571068497302`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890317`, -9841.168085980833}, \
{1601.281668189032, -9841.168085980833}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9841.168085980842}, {
        100.00000059394924`, -9841.168085980842}, {
        100.00000059394924`, -9841.168085980833}, {
        100, -9841.168085980833}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9841.168085980842}, {
       600.3414326298531, -9841.168085980842}, {
       600.3414326298531, -9841.168085980833}, {
       600.0828431526198, -9841.168085980833}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890315`, -9841.168085980842}, {
       1601.281668189032, -9841.168085980842}, {
       1601.281668189032, -9841.168085980833}, {
       1601.2816681890315`, -9841.168085980833}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9841.168085980842}, {
       2649.3698474740722`, -9841.168085980842}, {
       2649.3698474740722`, -9841.168085980833}, {
       2646.7764947886794`, -9841.168085980833}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9841.168085980842}, {
       2584.8819748931373`, -9841.168085980842}, {
       2584.8819748931373`, -9841.168085980833}, {
       2584.881974892467, -9841.168085980833}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706816`, -9841.168085980842}, {
       3136.0548108707167`, -9841.168085980842}, {
       3136.0548108707167`, -9841.168085980833}, {
       3136.0548108706816`, -9841.168085980833}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9841.168085980842}, {
       3704.3513431452666`, -9841.168085980842}, {
       3704.3513431452666`, -9841.168085980833}, {
       2714.914633963288, -9841.168085980833}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.958728633935, -9841.168085980842}, {
       4142.6493349287275`, -9841.168085980842}, {
       4142.6493349287275`, -9841.168085980833}, {
       4134.958728633935, -9841.168085980833}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980833}, {
       4699.999999999998, -9841.168085980833}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.896118374167, -9841.168085980842}, {
      1335.9168601401107`, -9841.168085980842}, {
      1335.9168601401107`, -9841.168085980833}, {
      1335.896118374167, -9841.168085980833}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706776`, -9841.168085980837}, \
{3136.0548108706816`, -9841.168085980833}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706776`, -9841.168085980837}, 
       4.184752945955647*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9168601401147`, -9841.16808598084}, {
       3136.0548108706776`, -9841.16808598084}, {
       3136.0548108706776`, -9841.168085980837}, {
       1335.9168601401147`, -9841.168085980837}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9168601401147`, -9841.16808598084}, 
       4.184752945955647*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9168601401107`, -9841.168085980842}, \
{1335.9168601401147`, -9841.16808598084}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9841.168085980842}, {
        100.00000059394907`, -9841.168085980842}, {
        100.00000059394907`, -9841.168085980842}, {
        100, -9841.168085980842}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9841.168085980842}, {
       600.3414326298531, -9841.168085980842}, {
       600.3414326298531, -9841.168085980842}, {
       600.0828431526198, -9841.168085980842}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9841.168085980842}, {
       1335.9168601401147`, -9841.168085980842}, {
       1335.9168601401147`, -9841.168085980842}, {
       1335.896118374167, -9841.168085980842}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9841.168085980842}, {
       2649.3698474740722`, -9841.168085980842}, {
       2649.3698474740722`, -9841.168085980842}, {
       2646.7764947886794`, -9841.168085980842}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9841.168085980842}, {
       2584.8819748931373`, -9841.168085980842}, {
       2584.8819748931373`, -9841.168085980842}, {
       2584.881974892467, -9841.168085980842}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706816`, -9841.168085980842}, {
       3136.0548108707167`, -9841.168085980842}, {
       3136.0548108707167`, -9841.168085980842}, {
       3136.0548108706816`, -9841.168085980842}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9841.168085980842}, {
       3704.3513431452666`, -9841.168085980842}, {
       3704.3513431452666`, -9841.168085980842}, {
       2714.914633963288, -9841.168085980842}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.958728633935, -9841.168085980842}, {
       4142.6493349287275`, -9841.168085980842}, {
       4142.6493349287275`, -9841.168085980842}, {
       4134.958728633935, -9841.168085980842}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980842}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890315`, -9841.168085980842}, {
      1601.281668189032, -9841.168085980842}, {
      1601.281668189032, -9841.168085980842}, {
      1601.2816681890315`, -9841.168085980842}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000059394907`, -9841.168085980842}, \
{100.00000059394924`, -9841.168085980842}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000059394924`, -9841.168085980842}, 
       1.710255124860841*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000059394924`, -9841.168085980842}, {
       1601.2816681890313`, -9841.168085980842}, {
       1601.2816681890313`, -9841.168085980842}, {
       100.00000059394924`, -9841.168085980842}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890313`, -9841.168085980842}, 
       1.710255124860841*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890313`, -9841.168085980842}, \
{1601.2816681890315`, -9841.168085980842}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.201572024986}, {
        100.00000059394907`, -9842.201572024986}, {
        100.00000059394907`, -9841.168085980842}, {
        100, -9841.168085980842}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.201572024986}, {
       600.3414326298531, -9842.201572024986}, {
       600.3414326298531, -9841.168085980842}, {
       600.0828431526198, -9841.168085980842}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.201572024986}, {
       1335.9168601401147`, -9842.201572024986}, {
       1335.9168601401147`, -9841.168085980842}, {
       1335.896118374167, -9841.168085980842}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.201572024986}, {
       1601.281668189032, -9842.201572024986}, {
       1601.281668189032, -9841.168085980842}, {
       1601.2816681890313`, -9841.168085980842}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.201572024986}, {
       2648.8531044520005`, -9842.201572024986}, {
       2648.8531044520005`, -9841.168085980842}, {
       2646.7764947886794`, -9841.168085980842}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.201572024986}, {
       2584.8819748931373`, -9842.201572024986}, {
       2584.8819748931373`, -9841.168085980842}, {
       2584.881974892467, -9841.168085980842}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706816`, -9842.201572024986}, {
       3136.0548108707167`, -9842.201572024986}, {
       3136.0548108707167`, -9841.168085980842}, {
       3136.0548108706816`, -9841.168085980842}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.201572024986}, {
       3704.3513431452666`, -9842.201572024986}, {
       3704.3513431452666`, -9841.168085980842}, {
       2714.914633963288, -9841.168085980842}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.201572024986}, {
       4699.999999999998, -9842.201572024986}, {
       4699.999999999998, -9841.168085980842}, {
       4699.999999999998, -9841.168085980842}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.958728633935, -9842.201572024986}, {
      4142.6493349287275`, -9842.201572024986}, {
      4142.6493349287275`, -9841.168085980842}, {
      4134.958728633935, -9841.168085980842}}]}, {
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.8531044520005`, -9841.426457491878}, \
{2649.3698474740722`, -9841.168085980842}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2649.3698474740722`, -9841.426457491878}, 0.5167430220718123, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2649.3698474740722`, -9841.94320051395}, {
       4134.441985611863, -9841.94320051395}, {
       4134.441985611863, -9841.426457491878}, {
       2649.3698474740722`, -9841.426457491878}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.441985611863, -9841.94320051395}, 0.5167430220718123, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.441985611863, -9842.201572024986}, \
{4134.958728633935, -9841.94320051395}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.201572024991}, {
        100.00000059394907`, -9842.201572024991}, {
        100.00000059394907`, -9842.201572024986}, {
        100, -9842.201572024986}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.201572024991}, {
       600.3414326298531, -9842.201572024991}, {
       600.3414326298531, -9842.201572024986}, {
       600.0828431526198, -9842.201572024986}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.201572024991}, {
       1335.9168601401147`, -9842.201572024991}, {
       1335.9168601401147`, -9842.201572024986}, {
       1335.896118374167, -9842.201572024986}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.201572024991}, {
       1601.281668189032, -9842.201572024991}, {
       1601.281668189032, -9842.201572024986}, {
       1601.2816681890313`, -9842.201572024986}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.201572024991}, {
       2648.8531044520005`, -9842.201572024991}, {
       2648.8531044520005`, -9842.201572024986}, {
       2646.7764947886794`, -9842.201572024986}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.201572024991}, {
       2584.8819748931373`, -9842.201572024991}, {
       2584.8819748931373`, -9842.201572024986}, {
       2584.881974892467, -9842.201572024986}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108706816`, -9842.201572024991}, {
       3136.054810870714, -9842.201572024991}, {
       3136.054810870714, -9842.201572024986}, {
       3136.0548108706816`, -9842.201572024986}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.201572024991}, {
       3704.3513431452666`, -9842.201572024991}, {
       3704.3513431452666`, -9842.201572024986}, {
       2714.914633963288, -9842.201572024986}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.201572024991}, {
       4699.999999999998, -9842.201572024991}, {
       4699.999999999998, -9842.201572024986}, {
       4699.999999999998, -9842.201572024986}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.441985611863, -9842.201572024991}, {
      4142.6493349287275`, -9842.201572024991}, {
      4142.6493349287275`, -9842.201572024986}, {
      4134.441985611863, -9842.201572024986}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870714, -9842.201572024987}, \
{3136.0548108707167`, -9842.201572024986}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707167`, -9842.201572024987}, 
       2.5901189639633193`*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707167`, -9842.20157202499}, {
       4134.44198561186, -9842.20157202499}, {
       4134.44198561186, -9842.201572024987}, {
       3136.0548108707167`, -9842.201572024987}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.44198561186, -9842.20157202499}, 
       2.5901189639633193`*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.44198561186, -9842.201572024991}, \
{4134.441985611863, -9842.20157202499}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.201572025037}, {
       600.3414326298531, -9842.201572025037}, {
       600.3414326298531, -9842.201572024991}, {
       600.0828431526198, -9842.201572024991}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.201572025037}, {
       1335.9168601401147`, -9842.201572025037}, {
       1335.9168601401147`, -9842.201572024991}, {
       1335.896118374167, -9842.201572024991}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.201572025037}, {
       1601.281668189032, -9842.201572025037}, {
       1601.281668189032, -9842.201572024991}, {
       1601.2816681890313`, -9842.201572024991}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.201572025037}, {
       2648.8531044520005`, -9842.201572025037}, {
       2648.8531044520005`, -9842.201572024991}, {
       2646.7764947886794`, -9842.201572024991}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.201572025037}, {
       2584.8819748931373`, -9842.201572025037}, {
       2584.8819748931373`, -9842.201572024991}, {
       2584.881974892467, -9842.201572024991}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.201572025037}, {
       3136.054810870714, -9842.201572025037}, {
       3136.054810870714, -9842.201572024991}, {
       3136.054810870705, -9842.201572024991}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.201572025037}, {
       3704.3513431452666`, -9842.201572025037}, {
       3704.3513431452666`, -9842.201572024991}, {
       2714.914633963288, -9842.201572024991}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.44198561186, -9842.201572025037}, {
       4142.6493349287275`, -9842.201572025037}, {
       4142.6493349287275`, -9842.201572024991}, {
       4134.44198561186, -9842.201572024991}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.201572025037}, {
       4699.999999999998, -9842.201572025037}, {
       4699.999999999998, -9842.201572024991}, {
       4699.999999999998, -9842.201572024991}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9842.201572025037}, {
       100.00000059394907`, -9842.201572025037}, {
       100.00000059394907`, -9842.201572024991}, {
       100, -9842.201572024991}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108706816`, -9842.201572025002}, \
{3136.054810870705, -9842.201572024991}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108706816`, -9842.201572025002}, 
       2.3148492742009296`*^-11, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.0000005939722, -9842.201572025026}, {
       3136.0548108706816`, -9842.201572025026}, {
       3136.0548108706816`, -9842.201572025002}, {
       100.0000005939722, -9842.201572025002}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.0000005939722, -9842.201572025026}, 
       2.3148492742009296`*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000059394907`, -9842.201572025037}, \
{100.0000005939722, -9842.201572025026}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.201572960508}, {
       600.3414326298531, -9842.201572960508}, {
       600.3414326298531, -9842.201572025037}, {
       600.0828431526198, -9842.201572025037}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.201572960508}, {
       1335.9168601401147`, -9842.201572960508}, {
       1335.9168601401147`, -9842.201572025037}, {
       1335.896118374167, -9842.201572025037}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.201572960508}, {
       1601.281668189032, -9842.201572960508}, {
       1601.281668189032, -9842.201572025037}, {
       1601.2816681890313`, -9842.201572025037}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.201572960508}, {
       2648.8531044520005`, -9842.201572960508}, {
       2648.8531044520005`, -9842.201572025037}, {
       2646.7764947886794`, -9842.201572025037}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.201572960508}, {
       2584.8819748931373`, -9842.201572960508}, {
       2584.8819748931373`, -9842.201572025037}, {
       2584.881974892467, -9842.201572025037}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.201572960508}, {
       3136.054810870714, -9842.201572960508}, {
       3136.054810870714, -9842.201572025037}, {
       3136.054810870705, -9842.201572025037}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.201572960508}, {
       3704.3513431452666`, -9842.201572960508}, {
       3704.3513431452666`, -9842.201572025037}, {
       2714.914633963288, -9842.201572025037}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.441986079596, -9842.201572960508}, {
       4142.6493349287275`, -9842.201572960508}, {
       4142.6493349287275`, -9842.201572025037}, {
       4134.441986079596, -9842.201572025037}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.201572960508}, {
       4699.999999999998, -9842.201572960508}, {
       4699.999999999998, -9842.201572025037}, {
       4699.999999999998, -9842.201572025037}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9842.201572960508}, {
       100.0000005939722, -9842.201572960508}, {
       100.0000005939722, -9842.201572025037}, {
       100, -9842.201572025037}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.44198561186, -9842.201572258906}, \
{4134.441986079596, -9842.201572025037}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.44198561186, -9842.201572258906}, 4.6773546252148757`*^-7,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000106170768`, -9842.20157272664}, {
       4134.44198561186, -9842.20157272664}, {
       4134.44198561186, -9842.201572258906}, {
       100.00000106170768`, -9842.201572258906}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000106170768`, -9842.20157272664}, 
       4.6773546252148757`*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.0000005939722, -9842.201572960508}, \
{100.00000106170768`, -9842.20157272664}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.201572960508}, {
        100.00000106170768`, -9842.201572960508}, {
        100.00000106170768`, -9842.201572960508}, {
        100, -9842.201572960508}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.201572960508}, {
       600.3414326298531, -9842.201572960508}, {
       600.3414326298531, -9842.201572960508}, {
       600.0828431526198, -9842.201572960508}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.201572960508}, {
       1335.9168601401147`, -9842.201572960508}, {
       1335.9168601401147`, -9842.201572960508}, {
       1335.896118374167, -9842.201572960508}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.201572960508}, {
       1601.281668189032, -9842.201572960508}, {
       1601.281668189032, -9842.201572960508}, {
       1601.2816681890313`, -9842.201572960508}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.201572960508}, {
       2648.8531044520005`, -9842.201572960508}, {
       2648.8531044520005`, -9842.201572960508}, {
       2646.7764947886794`, -9842.201572960508}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.201572960508}, {
       2584.8819748931373`, -9842.201572960508}, {
       2584.8819748931373`, -9842.201572960508}, {
       2584.881974892467, -9842.201572960508}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.201572960508}, {
       3136.054810870714, -9842.201572960508}, {
       3136.054810870714, -9842.201572960508}, {
       3136.054810870705, -9842.201572960508}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.201572960508}, {
       3704.3513431452666`, -9842.201572960508}, {
       3704.3513431452666`, -9842.201572960508}, {
       2714.914633963288, -9842.201572960508}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.441986079596, -9842.201572960508}, {
       4142.6493349287275`, -9842.201572960508}, {
       4142.6493349287275`, -9842.201572960508}, {
       4134.441986079596, -9842.201572960508}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9842.201572960508}, {
      4699.999999999998, -9842.201572960508}, {
      4699.999999999998, -9842.201572960508}, {
      4699.999999999998, -9842.201572960508}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189032, -9842.201572960508}, \
{1601.281668189032, -9842.201572960508}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189032, -9842.201572960508}, 7.028413946472107*^-17,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189032, -9842.201572960508}, {
       4699.999999999998, -9842.201572960508}, {
       4699.999999999998, -9842.201572960508}, {
       1601.281668189032, -9842.201572960508}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9842.201572960508}, 
       7.028413946472107*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9842.201572960508}, \
{4699.999999999998, -9842.201572960508}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.379373194697}, {
        100.00000106170768`, -9842.379373194697}, {
        100.00000106170768`, -9842.201572960508}, {
        100, -9842.201572960508}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.379373194697}, {
       600.2525325127585, -9842.379373194697}, {
       600.2525325127585, -9842.201572960508}, {
       600.0828431526198, -9842.201572960508}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.379373194697}, {
       1335.9168601401147`, -9842.379373194697}, {
       1335.9168601401147`, -9842.201572960508}, {
       1335.896118374167, -9842.201572960508}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.379373194697}, {
       1601.281668189032, -9842.379373194697}, {
       1601.281668189032, -9842.201572960508}, {
       1601.2816681890313`, -9842.201572960508}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.379373194697}, {
       2648.8531044520005`, -9842.379373194697}, {
       2648.8531044520005`, -9842.201572960508}, {
       2646.7764947886794`, -9842.201572960508}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.379373194697}, {
       2584.8819748931373`, -9842.379373194697}, {
       2584.8819748931373`, -9842.201572960508}, {
       2584.881974892467, -9842.201572960508}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.379373194697}, {
       3136.054810870714, -9842.379373194697}, {
       3136.054810870714, -9842.201572960508}, {
       3136.054810870705, -9842.201572960508}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963288, -9842.379373194697}, {
       3704.3513431452666`, -9842.379373194697}, {
       3704.3513431452666`, -9842.201572960508}, {
       2714.914633963288, -9842.201572960508}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.379373194697}, {
       4699.999999999998, -9842.379373194697}, {
       4699.999999999998, -9842.201572960508}, {
       4699.999999999998, -9842.201572960508}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.441986079596, -9842.379373194697}, {
      4142.6493349287275`, -9842.379373194697}, {
      4142.6493349287275`, -9842.201572960508}, {
      4134.441986079596, -9842.201572960508}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.2525325127585, -9842.246023019055}, \
{600.3414326298531, -9842.201572960508}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.3414326298531, -9842.246023019055}, 0.08890011709452666, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{600.3414326298531, -9842.33492313615}, {
       4134.353085962502, -9842.33492313615}, {
       4134.353085962502, -9842.246023019055}, {
       600.3414326298531, -9842.246023019055}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.353085962502, -9842.33492313615}, 0.08890011709452666, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.353085962502, -9842.379373194697}, \
{4134.441986079596, -9842.33492313615}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.379373194703}, {
        100.00000106170768`, -9842.379373194703}, {
        100.00000106170768`, -9842.379373194697}, {
        100, -9842.379373194697}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.379373194703}, {
       600.2525325127585, -9842.379373194703}, {
       600.2525325127585, -9842.379373194697}, {
       600.0828431526198, -9842.379373194697}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.379373194703}, {
       1335.9168601401147`, -9842.379373194703}, {
       1335.9168601401147`, -9842.379373194697}, {
       1335.896118374167, -9842.379373194697}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.379373194703}, {
       1601.281668189032, -9842.379373194703}, {
       1601.281668189032, -9842.379373194697}, {
       1601.2816681890313`, -9842.379373194697}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.379373194703}, {
       2648.8531044520005`, -9842.379373194703}, {
       2648.8531044520005`, -9842.379373194697}, {
       2646.7764947886794`, -9842.379373194697}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892467, -9842.379373194703}, {
       2584.8819748931373`, -9842.379373194703}, {
       2584.8819748931373`, -9842.379373194697}, {
       2584.881974892467, -9842.379373194697}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963291, -9842.379373194703}, {
       3704.3513431452666`, -9842.379373194703}, {
       3704.3513431452666`, -9842.379373194697}, {
       2714.914633963291, -9842.379373194697}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353085962502, -9842.379373194703}, {
       4142.6493349287275`, -9842.379373194703}, {
       4142.6493349287275`, -9842.379373194697}, {
       4134.353085962502, -9842.379373194697}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.379373194703}, {
       4699.999999999998, -9842.379373194703}, {
       4699.999999999998, -9842.379373194697}, {
       4699.999999999998, -9842.379373194697}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870705, -9842.379373194703}, {
      3136.054810870714, -9842.379373194703}, {
      3136.054810870714, -9842.379373194697}, {
      3136.054810870705, -9842.379373194697}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2714.914633963288, -9842.379373194697}, \
{2714.914633963291, -9842.379373194697}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2714.914633963288, -9842.379373194697}, 
       3.1002887389876795`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.054810870717, -9842.3793731947}, {
       2714.914633963288, -9842.3793731947}, {
       2714.914633963288, -9842.379373194697}, {
       3136.054810870717, -9842.379373194697}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810870717, -9842.3793731947}, 3.1002887389876795`*^-12,
        NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870714, -9842.379373194703}, \
{3136.054810870717, -9842.3793731947}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.379373194834}, {
        100.00000106164248`, -9842.379373194834}, {
        100.00000106164248`, -9842.379373194703}, {
        100, -9842.379373194703}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.379373194834}, {
       600.2525325127585, -9842.379373194834}, {
       600.2525325127585, -9842.379373194703}, {
       600.0828431526198, -9842.379373194703}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.379373194834}, {
       1335.9168601401147`, -9842.379373194834}, {
       1335.9168601401147`, -9842.379373194703}, {
       1335.896118374167, -9842.379373194703}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.379373194834}, {
       1601.281668189032, -9842.379373194834}, {
       1601.281668189032, -9842.379373194703}, {
       1601.2816681890313`, -9842.379373194703}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.379373194834}, {
       2648.8531044520005`, -9842.379373194834}, {
       2648.8531044520005`, -9842.379373194703}, {
       2646.7764947886794`, -9842.379373194703}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.379373194834}, {
       3136.054810870717, -9842.379373194834}, {
       3136.054810870717, -9842.379373194703}, {
       3136.054810870705, -9842.379373194703}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963291, -9842.379373194834}, {
       3704.3513431452666`, -9842.379373194834}, {
       3704.3513431452666`, -9842.379373194703}, {
       2714.914633963291, -9842.379373194703}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353085962502, -9842.379373194834}, {
       4142.6493349287275`, -9842.379373194834}, {
       4142.6493349287275`, -9842.379373194703}, {
       4134.353085962502, -9842.379373194703}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.379373194834}, {
       4699.999999999998, -9842.379373194834}, {
       4699.999999999998, -9842.379373194703}, {
       4699.999999999998, -9842.379373194703}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892467, -9842.379373194834}, {
      2584.8819748931373`, -9842.379373194834}, {
      2584.8819748931373`, -9842.379373194703}, {
      2584.881974892467, -9842.379373194703}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000106164248`, -9842.379373194735}, \
{100.00000106170768`, -9842.379373194703}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000106170768`, -9842.379373194735}, 
       6.519012978445598*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000106170768`, -9842.3793731948}, {
       2584.881974892402, -9842.3793731948}, {
       2584.881974892402, -9842.379373194735}, {
       100.00000106170768`, -9842.379373194735}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974892402, -9842.3793731948}, 6.519012978445598*^-11, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974892402, -9842.379373194834}, \
{2584.881974892467, -9842.3793731948}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9842.379373194872}, {
        100.00000106164248`, -9842.379373194872}, {
        100.00000106164248`, -9842.379373194834}, {
        100, -9842.379373194834}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9842.379373194872}, {
       600.2525325127585, -9842.379373194872}, {
       600.2525325127585, -9842.379373194834}, {
       600.0828431526198, -9842.379373194834}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9842.379373194872}, {
       1335.9168601401147`, -9842.379373194872}, {
       1335.9168601401147`, -9842.379373194834}, {
       1335.896118374167, -9842.379373194834}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9842.379373194872}, {
       1601.281668189032, -9842.379373194872}, {
       1601.281668189032, -9842.379373194834}, {
       1601.2816681890313`, -9842.379373194834}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9842.379373194872}, {
       2648.8531044520005`, -9842.379373194872}, {
       2648.8531044520005`, -9842.379373194834}, {
       2646.7764947886794`, -9842.379373194834}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9842.379373194872}, {
       2584.881974893118, -9842.379373194872}, {
       2584.881974893118, -9842.379373194834}, {
       2584.881974892402, -9842.379373194834}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9842.379373194872}, {
       3136.054810870717, -9842.379373194872}, {
       3136.054810870717, -9842.379373194834}, {
       3136.054810870705, -9842.379373194834}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2714.914633963291, -9842.379373194872}, {
       3704.3513431452666`, -9842.379373194872}, {
       3704.3513431452666`, -9842.379373194834}, {
       2714.914633963291, -9842.379373194834}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9842.379373194872}, {
       4699.999999999998, -9842.379373194872}, {
       4699.999999999998, -9842.379373194834}, {
       4699.999999999998, -9842.379373194834}}]}}, 
    {RGBColor[
     0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{4134.353085962502, -9842.379373194872}, {
      4142.6493349287275`, -9842.379373194872}, {
      4142.6493349287275`, -9842.379373194834}, {
      4134.353085962502, -9842.379373194834}}]}, {
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974893118, -9842.379373194843}, \
{2584.8819748931373`, -9842.379373194834}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748931373`, -9842.379373194843}, 
       1.9342434327934414`*^-11, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819748931373`, -9842.379373194863}, {
       4134.3530859624825`, -9842.379373194863}, {
       4134.3530859624825`, -9842.379373194843}, {
       2584.8819748931373`, -9842.379373194843}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.3530859624825`, -9842.379373194863}, 
       1.9342434327934414`*^-11, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.3530859624825`, -9842.379373194872}, \
{4134.353085962502, -9842.379373194863}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9845.676473050984}, {
        100.00000106164248`, -9845.676473050984}, {
        100.00000106164248`, -9842.379373194872}, {
        100, -9842.379373194872}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9845.676473050984}, {
       600.2525325127585, -9845.676473050984}, {
       600.2525325127585, -9842.379373194872}, {
       600.0828431526198, -9842.379373194872}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9845.676473050984}, {
       1335.9168601401147`, -9845.676473050984}, {
       1335.9168601401147`, -9842.379373194872}, {
       1335.896118374167, -9842.379373194872}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9845.676473050984}, {
       1601.281668189032, -9845.676473050984}, {
       1601.281668189032, -9842.379373194872}, {
       1601.2816681890313`, -9842.379373194872}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9845.676473050984}, {
       2584.881974893118, -9845.676473050984}, {
       2584.881974893118, -9842.379373194872}, {
       2584.881974892402, -9842.379373194872}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9845.676473050984}, {
       3136.054810870717, -9845.676473050984}, {
       3136.054810870717, -9842.379373194872}, {
       3136.054810870705, -9842.379373194872}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2716.563183891347, -9845.676473050984}, {
       3704.3513431452666`, -9845.676473050984}, {
       3704.3513431452666`, -9842.379373194872}, {
       2716.563183891347, -9842.379373194872}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9845.676473050984}, {
       4142.6493349287275`, -9845.676473050984}, {
       4142.6493349287275`, -9842.379373194872}, {
       4134.3530859624825`, -9842.379373194872}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9845.676473050984}, {
       4699.999999999998, -9845.676473050984}, {
       4699.999999999998, -9842.379373194872}, {
       4699.999999999998, -9842.379373194872}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.7764947886794`, -9845.676473050984}, {
      2648.8531044520005`, -9845.676473050984}, {
      2648.8531044520005`, -9842.379373194872}, {
      2646.7764947886794`, -9842.379373194872}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2714.914633963291, -9843.2036481589}, \
{2716.563183891347, -9842.379373194872}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2714.914633963291, -9843.2036481589}, 1.6485499280557465`, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2650.501654380056, -9844.852198086955}, {
       2714.914633963291, -9844.852198086955}, {
       2714.914633963291, -9843.2036481589}, {
       2650.501654380056, -9843.2036481589}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2650.501654380056, -9844.852198086955}, 1.6485499280557465`, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2648.8531044520005`, -9845.676473050984}, \
{2650.501654380056, -9844.852198086955}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9845.676473051}, {
        100.00000106164248`, -9845.676473051}, {
        100.00000106164248`, -9845.676473050984}, {
        100, -9845.676473050984}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9845.676473051}, {
       600.2525325127585, -9845.676473051}, {
       600.2525325127585, -9845.676473050984}, {
       600.0828431526198, -9845.676473050984}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.9168601401147`, -9845.676473050984}, {
       1335.896118374167, -9845.676473050984}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9845.676473051}, {
       1601.281668189032, -9845.676473051}, {
       1601.281668189032, -9845.676473050984}, {
       1601.2816681890313`, -9845.676473050984}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9845.676473051}, {
       2650.501654380056, -9845.676473051}, {
       2650.501654380056, -9845.676473050984}, {
       2646.7764947886794`, -9845.676473050984}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9845.676473051}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974893118, -9845.676473050984}, {
       2584.881974892402, -9845.676473050984}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2716.5631838913555`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473050984}, {
       2716.5631838913555`, -9845.676473050984}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473050984}, {
       4134.3530859624825`, -9845.676473050984}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473050984}, {
       4699.999999999998, -9845.676473050984}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.054810870705, -9845.676473051}, {
      3136.054810870717, -9845.676473051}, {
      3136.054810870717, -9845.676473050984}, {
      3136.054810870705, -9845.676473050984}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2716.563183891347, -9845.676473050988}, \
{2716.5631838913555`, -9845.676473050984}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2716.563183891347, -9845.676473050988}, 8.60945295585345*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707258`, -9845.676473050997}, {
       2716.563183891347, -9845.676473050997}, {
       2716.563183891347, -9845.676473050988}, {
       3136.0548108707258`, -9845.676473050988}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707258`, -9845.676473050997}, 
       8.60945295585345*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870717, -9845.676473051}, \
{3136.0548108707258`, -9845.676473050997}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9845.676473051}, {
        100.00000106164248`, -9845.676473051}, {
        100.00000106164248`, -9845.676473051}, {100, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9845.676473051}, {
       600.2525325127585, -9845.676473051}, {
       600.2525325127585, -9845.676473051}, {
       600.0828431526198, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.896118374167, -9845.676473051}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9845.676473051}, {
       1601.281668189032, -9845.676473051}, {
       1601.281668189032, -9845.676473051}, {
       1601.2816681890313`, -9845.676473051}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9845.676473051}, {
       2650.501654380056, -9845.676473051}, {
       2650.501654380056, -9845.676473051}, {
       2646.7764947886794`, -9845.676473051}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9845.676473051}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974892402, -9845.676473051}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9845.676473051}, {
       3136.0548108707258`, -9845.676473051}, {
       3136.0548108707258`, -9845.676473051}, {
       3136.054810870705, -9845.676473051}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2716.5631838913555`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473051}, {
       2716.5631838913555`, -9845.676473051}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473051}, {
       4134.3530859624825`, -9845.676473051}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9845.676473051}, {
      4699.999999999998, -9845.676473051}, {
      4699.999999999998, -9845.676473051}, {
      4699.999999999998, -9845.676473051}}]}, {
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9168601401147`, -9845.676473051}, \
{1335.9168601401147`, -9845.676473051}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9168601401147`, -9845.676473051}, 6.736000446882078*^-18, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9168601401147`, -9845.676473051}, {
       4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9845.676473051}, 6.736000446882078*^-18, {
       0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9845.676473051}, \
{4699.999999999998, -9845.676473051}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9845.676473051}, {
        100.00000106164248`, -9845.676473051}, {
        100.00000106164248`, -9845.676473051}, {100, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9845.676473051}, {
       600.2525325127585, -9845.676473051}, {
       600.2525325127585, -9845.676473051}, {
       600.0828431526198, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.896118374167, -9845.676473051}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9845.676473051}, {
       2650.501654380056, -9845.676473051}, {
       2650.501654380056, -9845.676473051}, {
       2646.7764947886794`, -9845.676473051}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9845.676473051}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974892402, -9845.676473051}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9845.676473051}, {
       3136.0548108707258`, -9845.676473051}, {
       3136.0548108707258`, -9845.676473051}, {
       3136.054810870705, -9845.676473051}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2716.5631838913555`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473051}, {
       3704.3513431452666`, -9845.676473051}, {
       2716.5631838913555`, -9845.676473051}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473051}, {
       4142.6493349287275`, -9845.676473051}, {
       4134.3530859624825`, -9845.676473051}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890313`, -9845.676473051}, {
      1601.281668189032, -9845.676473051}, {
      1601.281668189032, -9845.676473051}, {
      1601.2816681890313`, -9845.676473051}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.3530859624825`, -9845.676473051}, \
{4134.3530859624825`, -9845.676473051}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.3530859624825`, -9845.676473051}, 
       2.0715106185887675`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.281668189032, -9845.676473051}, {
       4134.3530859624825`, -9845.676473051}, {
       4134.3530859624825`, -9845.676473051}, {
       1601.281668189032, -9845.676473051}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.281668189032, -9845.676473051}, 2.0715106185887675`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189032, -9845.676473051}, \
{1601.281668189032, -9845.676473051}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.70893442245}, {
        100.00000106164248`, -9849.70893442245}, {
        100.00000106164248`, -9845.676473051}, {100, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.70893442245}, {
       600.2525325127585, -9849.70893442245}, {
       600.2525325127585, -9845.676473051}, {
       600.0828431526198, -9845.676473051}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.70893442245}, {
       1335.9168601401147`, -9849.70893442245}, {
       1335.9168601401147`, -9845.676473051}, {
       1335.896118374167, -9845.676473051}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9849.70893442245}, {
       1601.281668189032, -9849.70893442245}, {
       1601.281668189032, -9845.676473051}, {
       1601.2816681890313`, -9845.676473051}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9849.70893442245}, {
       2584.881974893118, -9849.70893442245}, {
       2584.881974893118, -9845.676473051}, {
       2584.881974892402, -9845.676473051}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.70893442245}, {
       3136.0548108707258`, -9849.70893442245}, {
       3136.0548108707258`, -9845.676473051}, {
       3136.054810870705, -9845.676473051}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.70893442245}, {
       3704.351343145266, -9849.70893442245}, {
       3704.351343145266, -9845.676473051}, {
       2718.5794145770797`, -9845.676473051}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.70893442245}, {
       4142.6493349287275`, -9849.70893442245}, {
       4142.6493349287275`, -9845.676473051}, {
       4134.3530859624825`, -9845.676473051}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9845.676473051}, {
       4699.999999999998, -9845.676473051}}]}}, 
    {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2646.7764947886794`, -9849.70893442245}, {
      2650.501654380056, -9849.70893442245}, {
      2650.501654380056, -9845.676473051}, {
      2646.7764947886794`, -9845.676473051}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2716.5631838913555`, -9846.684588393864}, \
{2718.5794145770797`, -9845.676473051}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2716.5631838913555`, -9846.684588393864}, 2.016230685724311, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2652.5178850657803`, -9848.700819079588}, {
       2716.5631838913555`, -9848.700819079588}, {
       2716.5631838913555`, -9846.684588393864}, {
       2652.5178850657803`, -9846.684588393864}},
       VertexColors->{
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.1450980392156863, 0.43529411764705883`, 0.3843137254901961]}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      DiskBox[{2652.5178850657803`, -9848.700819079588}, 2.016230685724311, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2650.501654380056, -9849.70893442245}, \
{2652.5178850657803`, -9848.700819079588}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.70893442245}, {
        100.00000106164248`, -9849.70893442245}, {
        100.00000106164248`, -9849.70893442245}, {
        100, -9849.70893442245}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.70893442245}, {
       600.2525325127585, -9849.70893442245}, {
       600.2525325127585, -9849.70893442245}, {
       600.0828431526198, -9849.70893442245}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.70893442245}, {
       1335.9168601401147`, -9849.70893442245}, {
       1335.9168601401147`, -9849.70893442245}, {
       1335.896118374167, -9849.70893442245}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.70893442245}, {
       2652.5178850657803`, -9849.70893442245}, {
       2652.5178850657803`, -9849.70893442245}, {
       2646.7764947886794`, -9849.70893442245}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974892402, -9849.70893442245}, {
       2584.881974893118, -9849.70893442245}, {
       2584.881974893118, -9849.70893442245}, {
       2584.881974892402, -9849.70893442245}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.70893442245}, {
       3136.0548108707258`, -9849.70893442245}, {
       3136.0548108707258`, -9849.70893442245}, {
       3136.054810870705, -9849.70893442245}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.70893442245}, {
       3704.351343145266, -9849.70893442245}, {
       3704.351343145266, -9849.70893442245}, {
       2718.5794145770797`, -9849.70893442245}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.70893442245}, {
       4142.6493349287275`, -9849.70893442245}, {
       4142.6493349287275`, -9849.70893442245}, {
       4134.3530859624825`, -9849.70893442245}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9849.70893442245}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890313`, -9849.70893442245}, {
      1601.281668189032, -9849.70893442245}, {
      1601.281668189032, -9849.70893442245}, {
      1601.2816681890313`, -9849.70893442245}}]}, {
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2718.5794145770797`, -9849.70893442245}, \
{2718.5794145770797`, -9849.70893442245}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2718.5794145770797`, -9849.70893442245}, 
       2.1803089166154812`*^-13, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9849.70893442245}, {
       2718.5794145770797`, -9849.70893442245}, {
       2718.5794145770797`, -9849.70893442245}, {
       1601.2816681890322`, -9849.70893442245}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9849.70893442245}, 
       2.1803089166154812`*^-13, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.281668189032, -9849.70893442245}, \
{1601.2816681890322`, -9849.70893442245}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708934423446}, {
        100.00000106164248`, -9849.708934423446}, {
        100.00000106164248`, -9849.70893442245}, {
        100, -9849.70893442245}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.708934423446}, {
       600.2525325122605, -9849.708934423446}, {
       600.2525325122605, -9849.70893442245}, {
       600.0828431526198, -9849.70893442245}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708934423446}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.9168601401147`, -9849.70893442245}, {
       1335.896118374167, -9849.70893442245}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}, {
       1601.2816681890322`, -9849.70893442245}, {
       1601.2816681890313`, -9849.70893442245}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708934423446}, {
       2652.5178850657803`, -9849.708934423446}, {
       2652.5178850657803`, -9849.70893442245}, {
       2646.7764947886794`, -9849.70893442245}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.0548108707258`, -9849.70893442245}, {
       3136.054810870705, -9849.70893442245}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708934423446}, {
       3704.351343145266, -9849.708934423446}, {
       3704.351343145266, -9849.70893442245}, {
       2718.5794145770797`, -9849.70893442245}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708934423446}, {
       4142.6493349287275`, -9849.708934423446}, {
       4142.6493349287275`, -9849.70893442245}, {
       4134.3530859624825`, -9849.70893442245}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}, {
       4699.999999999998, -9849.70893442245}, {
       4699.999999999998, -9849.70893442245}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974892402, -9849.708934423446}, {
      2584.8819748931182`, -9849.708934423446}, {
      2584.8819748931182`, -9849.70893442245}, {
      2584.881974892402, -9849.70893442245}}]}, {
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.2525325122605, -9849.708934422699}, \
{600.2525325127585, -9849.70893442245}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.2525325127585, -9849.708934422699}, 4.981233654089525*^-10,
        NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{600.2525325127585, -9849.708934423197}, {
       2584.881974891904, -9849.708934423197}, {
       2584.881974891904, -9849.708934422699}, {
       600.2525325127585, -9849.708934422699}},
       VertexColors->{
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.881974891904, -9849.708934423197}, 
       4.981233654089525*^-10, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.881974891904, -9849.708934423446}, \
{2584.881974892402, -9849.708934423197}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708934423446}, {
        100.00000106164248`, -9849.708934423446}, {
        100.00000106164248`, -9849.708934423446}, {
        100, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.708934423446}, {
       600.2525325122605, -9849.708934423446}, {
       600.2525325122605, -9849.708934423446}, {
       600.0828431526198, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708934423446}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.896118374167, -9849.708934423446}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}, {
       1601.2816681890313`, -9849.708934423446}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708934423446}, {
       2652.5178850657803`, -9849.708934423446}, {
       2652.5178850657803`, -9849.708934423446}, {
       2646.7764947886794`, -9849.708934423446}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708934423446}, {
       2584.8819748931182`, -9849.708934423446}, {
       2584.8819748931182`, -9849.708934423446}, {
       2584.881974891904, -9849.708934423446}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.054810870705, -9849.708934423446}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708934423446}, {
       3704.351343145266, -9849.708934423446}, {
       3704.351343145266, -9849.708934423446}, {
       2718.5794145770797`, -9849.708934423446}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708934423446}, {
       4142.6493349287275`, -9849.708934423446}, {
       4142.6493349287275`, -9849.708934423446}, {
       4134.3530859624825`, -9849.708934423446}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890322`, -9849.708934423446}, \
{1601.2816681890322`, -9849.708934423446}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9849.708934423446}, 
       7.814895263562184*^-17, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9849.708934423446}, 
       7.814895263562184*^-17, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9849.708934423446}, \
{4699.999999999998, -9849.708934423446}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708934423446}, {
        100.00000106164248`, -9849.708934423446}, {
        100.00000106164248`, -9849.708934423446}, {
        100, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.708934423446}, {
       600.2525325122605, -9849.708934423446}, {
       600.2525325122605, -9849.708934423446}, {
       600.0828431526198, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708934423446}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.896118374167, -9849.708934423446}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890313`, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}, {
       1601.2816681890322`, -9849.708934423446}, {
       1601.2816681890313`, -9849.708934423446}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708934423446}, {
       2652.5178850657803`, -9849.708934423446}, {
       2652.5178850657803`, -9849.708934423446}, {
       2646.7764947886794`, -9849.708934423446}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708934423446}, {
       2584.8819748931182`, -9849.708934423446}, {
       2584.8819748931182`, -9849.708934423446}, {
       2584.881974891904, -9849.708934423446}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.054810870705, -9849.708934423446}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708934423446}, {
       3704.351343145266, -9849.708934423446}, {
       3704.351343145266, -9849.708934423446}, {
       2718.5794145770797`, -9849.708934423446}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708934423446}, {
       4142.6493349287275`, -9849.708934423446}, {
       4142.6493349287275`, -9849.708934423446}, {
       4134.3530859624825`, -9849.708934423446}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}, {
      4699.999999999998, -9849.708934423446}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707258`, -9849.708934423446}, \
{3136.0548108707258`, -9849.708934423446}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707258`, -9849.708934423446}, 
       3.9468569177377346`*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707258`, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}, {
       3136.0548108707258`, -9849.708934423446}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9849.708934423446}, 
       3.9468569177377346`*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9849.708934423446}, \
{4699.999999999998, -9849.708934423446}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708934423448}, {
        100.00000106164161`, -9849.708934423448}, {
        100.00000106164161`, -9849.708934423446}, {
        100, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.708934423448}, {
       600.2525325122605, -9849.708934423448}, {
       600.2525325122605, -9849.708934423446}, {
       600.0828431526198, -9849.708934423446}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708934423448}, {
       1335.9168601401147`, -9849.708934423448}, {
       1335.9168601401147`, -9849.708934423446}, {
       1335.896118374167, -9849.708934423446}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708934423448}, {
       2652.5178850657803`, -9849.708934423448}, {
       2652.5178850657803`, -9849.708934423446}, {
       2646.7764947886794`, -9849.708934423446}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708934423448}, {
       2584.8819748931182`, -9849.708934423448}, {
       2584.8819748931182`, -9849.708934423446}, {
       2584.881974891904, -9849.708934423446}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.708934423448}, {
       3136.0548108707258`, -9849.708934423448}, {
       3136.0548108707258`, -9849.708934423446}, {
       3136.054810870705, -9849.708934423446}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708934423448}, {
       3704.351343145266, -9849.708934423448}, {
       3704.351343145266, -9849.708934423446}, {
       2718.5794145770797`, -9849.708934423446}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708934423448}, {
       4142.6493349287275`, -9849.708934423448}, {
       4142.6493349287275`, -9849.708934423446}, {
       4134.3530859624825`, -9849.708934423446}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708934423448}, {
       4699.999999999998, -9849.708934423448}, {
       4699.999999999998, -9849.708934423446}, {
       4699.999999999998, -9849.708934423446}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890313`, -9849.708934423448}, {
      1601.2816681890322`, -9849.708934423448}, {
      1601.2816681890322`, -9849.708934423446}, {
      1601.2816681890313`, -9849.708934423446}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000106164161`, -9849.708934423446}, \
{100.00000106164248`, -9849.708934423446}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000106164248`, -9849.708934423446}, 
       8.643207181026733*^-13, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000106164248`, -9849.708934423448}, {
       1601.2816681890304`, -9849.708934423448}, {
       1601.2816681890304`, -9849.708934423446}, {
       100.00000106164248`, -9849.708934423446}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890304`, -9849.708934423448}, 
       8.643207181026733*^-13, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890304`, -9849.708934423448}, \
{1601.2816681890313`, -9849.708934423448}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708934423448}, {
        100.00000106164161`, -9849.708934423448}, {
        100.00000106164161`, -9849.708934423448}, {
        100, -9849.708934423448}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.708934423448}, {
       600.2525325122605, -9849.708934423448}, {
       600.2525325122605, -9849.708934423448}, {
       600.0828431526198, -9849.708934423448}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708934423448}, {
       1335.9168601401147`, -9849.708934423448}, {
       1335.9168601401147`, -9849.708934423448}, {
       1335.896118374167, -9849.708934423448}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708934423448}, {
       1601.2816681890322`, -9849.708934423448}, {
       1601.2816681890322`, -9849.708934423448}, {
       1601.2816681890304`, -9849.708934423448}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708934423448}, {
       2652.5178850657803`, -9849.708934423448}, {
       2652.5178850657803`, -9849.708934423448}, {
       2646.7764947886794`, -9849.708934423448}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708934423448}, {
       2584.8819748931182`, -9849.708934423448}, {
       2584.8819748931182`, -9849.708934423448}, {
       2584.881974891904, -9849.708934423448}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.054810870705, -9849.708934423448}, {
       3136.0548108707258`, -9849.708934423448}, {
       3136.0548108707258`, -9849.708934423448}, {
       3136.054810870705, -9849.708934423448}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708934423448}, {
       3704.351343145266, -9849.708934423448}, {
       3704.351343145266, -9849.708934423448}, {
       2718.5794145770797`, -9849.708934423448}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708934423448}, {
       4142.6493349287275`, -9849.708934423448}, {
       4142.6493349287275`, -9849.708934423448}, {
       4134.3530859624825`, -9849.708934423448}}]}}, 
    {RGBColor[
     0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
     Opacity[0.9], 
     PolygonBox[{{4699.999999999998, -9849.708934423448}, {
      4699.999999999998, -9849.708934423448}, {
      4699.999999999998, -9849.708934423448}, {
      4699.999999999998, -9849.708934423448}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4142.6493349287275`, -9849.708934423448}, \
{4142.6493349287275`, -9849.708934423448}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4142.6493349287275`, -9849.708934423448}, 
       7.838061576470736*^-16, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{4142.6493349287275`, -9849.708934423448}, {
       4699.999999999998, -9849.708934423448}, {
       4699.999999999998, -9849.708934423448}, {
       4142.6493349287275`, -9849.708934423448}},
       VertexColors->{
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9849.708934423448}, 
       7.838061576470736*^-16, {0, 1.5707963267948966`}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9849.708934423448}, \
{4699.999999999998, -9849.708934423448}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.70893442348}, {
        100.00000106164161`, -9849.70893442348}, {
        100.00000106164161`, -9849.708934423448}, {
        100, -9849.708934423448}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828431526198, -9849.70893442348}, {
       600.2525325122605, -9849.70893442348}, {
       600.2525325122605, -9849.708934423448}, {
       600.0828431526198, -9849.708934423448}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.70893442348}, {
       1601.2816681890322`, -9849.70893442348}, {
       1601.2816681890322`, -9849.708934423448}, {
       1601.2816681890304`, -9849.708934423448}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.70893442348}, {
       2652.5178850657803`, -9849.70893442348}, {
       2652.5178850657803`, -9849.708934423448}, {
       2646.7764947886794`, -9849.708934423448}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.70893442348}, {
       2584.8819748931182`, -9849.70893442348}, {
       2584.8819748931182`, -9849.708934423448}, {
       2584.881974891904, -9849.708934423448}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707203`, -9849.70893442348}, {
       3136.0548108707258`, -9849.70893442348}, {
       3136.0548108707258`, -9849.708934423448}, {
       3136.0548108707203`, -9849.708934423448}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.70893442348}, {
       3704.351343145266, -9849.70893442348}, {
       3704.351343145266, -9849.708934423448}, {
       2718.5794145770797`, -9849.708934423448}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.70893442348}, {
       4142.6493349287275`, -9849.70893442348}, {
       4142.6493349287275`, -9849.708934423448}, {
       4134.3530859624825`, -9849.708934423448}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.70893442348}, {
       4699.999999999998, -9849.70893442348}, {
       4699.999999999998, -9849.708934423448}, {
       4699.999999999998, -9849.708934423448}}]}}, 
    {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
     Opacity[0.9], 
     PolygonBox[{{1335.896118374167, -9849.70893442348}, {
      1335.9168601401147`, -9849.70893442348}, {
      1335.9168601401147`, -9849.708934423448}, {
      1335.896118374167, -9849.708934423448}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.054810870705, -9849.708934423456}, \
{3136.0548108707203`, -9849.708934423448}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.054810870705, -9849.708934423456}, 
       1.5469333844765027`*^-11, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1335.9168601401302`, -9849.708934423472}, {
       3136.054810870705, -9849.708934423472}, {
       3136.054810870705, -9849.708934423456}, {
       1335.9168601401302`, -9849.708934423456}},
       VertexColors->{
         RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882],
          
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.996078431372549, 0.9882352941176471, 0.03529411764705882]}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      DiskBox[{1335.9168601401302`, -9849.708934423472}, 
       1.5469333844765027`*^-11, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      Opacity[0.9], 
      RectangleBox[{1335.9168601401147`, -9849.70893442348}, \
{1335.9168601401302`, -9849.708934423472}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935004526}, {
        100.00000077111767`, -9849.708935004526}, {
        100.00000077111767`, -9849.70893442348}, {
        100, -9849.70893442348}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935004526}, {
       1335.9168601401302`, -9849.708935004526}, {
       1335.9168601401302`, -9849.70893442348}, {
       1335.896118374167, -9849.70893442348}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708935004526}, {
       1601.2816681890322`, -9849.708935004526}, {
       1601.2816681890322`, -9849.70893442348}, {
       1601.2816681890304`, -9849.70893442348}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935004526}, {
       2652.5178850657803`, -9849.708935004526}, {
       2652.5178850657803`, -9849.70893442348}, {
       2646.7764947886794`, -9849.70893442348}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708935004526}, {
       2584.8819748931182`, -9849.708935004526}, {
       2584.8819748931182`, -9849.70893442348}, {
       2584.881974891904, -9849.70893442348}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707203`, -9849.708935004526}, {
       3136.0548108707258`, -9849.708935004526}, {
       3136.0548108707258`, -9849.70893442348}, {
       3136.0548108707203`, -9849.70893442348}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708935004526}, {
       3704.351343145266, -9849.708935004526}, {
       3704.351343145266, -9849.70893442348}, {
       2718.5794145770797`, -9849.70893442348}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708935004526}, {
       4142.6493349287275`, -9849.708935004526}, {
       4142.6493349287275`, -9849.70893442348}, {
       4134.3530859624825`, -9849.70893442348}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.70893442348}, {
       4699.999999999998, -9849.70893442348}}]}}, 
    {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{600.0828431526198, -9849.708935004526}, {
      600.2525325122605, -9849.708935004526}, {
      600.2525325122605, -9849.70893442348}, {
      600.0828431526198, -9849.70893442348}}]}, {
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000077111767`, -9849.70893456874}, \
{100.00000106164161`, -9849.70893442348}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000106164161`, -9849.70893456874}, 
       2.9052394126281266`*^-7, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000106164161`, -9849.708934859264}, {
       600.0828428620958, -9849.708934859264}, {
       600.0828428620958, -9849.70893456874}, {
       100.00000106164161`, -9849.70893456874}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[
         0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      DiskBox[{600.0828428620958, -9849.708934859264}, 
       2.9052394126281266`*^-7, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      Opacity[0.9], 
      RectangleBox[{600.0828428620958, -9849.708935004526}, \
{600.0828431526198, -9849.708934859264}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935004526}, {
        100.00000077111767`, -9849.708935004526}, {
        100.00000077111767`, -9849.708935004526}, {
        100, -9849.708935004526}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.708935004526}, {
       600.2525325122605, -9849.708935004526}, {
       600.2525325122605, -9849.708935004526}, {
       600.0828428620958, -9849.708935004526}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935004526}, {
       1335.9168601401302`, -9849.708935004526}, {
       1335.9168601401302`, -9849.708935004526}, {
       1335.896118374167, -9849.708935004526}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708935004526}, {
       1601.2816681890322`, -9849.708935004526}, {
       1601.2816681890322`, -9849.708935004526}, {
       1601.2816681890304`, -9849.708935004526}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935004526}, {
       2652.5178850657803`, -9849.708935004526}, {
       2652.5178850657803`, -9849.708935004526}, {
       2646.7764947886794`, -9849.708935004526}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708935004526}, {
       2584.8819748931182`, -9849.708935004526}, {
       2584.8819748931182`, -9849.708935004526}, {
       2584.881974891904, -9849.708935004526}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708935004526}, {
       3704.351343145266, -9849.708935004526}, {
       3704.351343145266, -9849.708935004526}, {
       2718.5794145770797`, -9849.708935004526}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708935004526}, {
       4142.6493349287275`, -9849.708935004526}, {
       4142.6493349287275`, -9849.708935004526}, {
       4134.3530859624825`, -9849.708935004526}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108707203`, -9849.708935004526}, {
      3136.0548108707258`, -9849.708935004526}, {
      3136.0548108707258`, -9849.708935004526}, {
      3136.0548108707203`, -9849.708935004526}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9849.708935004526}, \
{4699.999999999998, -9849.708935004526}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9849.708935004526}, 9.975895126914467*^-16,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707258`, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}, {
       3136.0548108707258`, -9849.708935004526}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707258`, -9849.708935004526}, 
       9.975895126914467*^-16, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707258`, -9849.708935004526}, \
{3136.0548108707258`, -9849.708935004526}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935004532}, {
        100.00000077111767`, -9849.708935004532}, {
        100.00000077111767`, -9849.708935004526}, {
        100, -9849.708935004526}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.708935004532}, {
       600.2525325122605, -9849.708935004532}, {
       600.2525325122605, -9849.708935004526}, {
       600.0828428620958, -9849.708935004526}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935004532}, {
       1335.9168601401302`, -9849.708935004532}, {
       1335.9168601401302`, -9849.708935004526}, {
       1335.896118374167, -9849.708935004526}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708935004532}, {
       1601.2816681890322`, -9849.708935004532}, {
       1601.2816681890322`, -9849.708935004526}, {
       1601.2816681890304`, -9849.708935004526}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935004532}, {
       2652.5178850657803`, -9849.708935004532}, {
       2652.5178850657803`, -9849.708935004526}, {
       2646.7764947886794`, -9849.708935004526}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707226`, -9849.708935004532}, {
       3136.0548108707253`, -9849.708935004532}, {
       3136.0548108707253`, -9849.708935004526}, {
       3136.0548108707226`, -9849.708935004526}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708935004532}, {
       3704.351343145266, -9849.708935004532}, {
       3704.351343145266, -9849.708935004526}, {
       2718.5794145770797`, -9849.708935004526}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.3530859624825`, -9849.708935004532}, {
       4142.6493349287275`, -9849.708935004532}, {
       4142.6493349287275`, -9849.708935004526}, {
       4134.3530859624825`, -9849.708935004526}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935004532}, {
       4699.999999999998, -9849.708935004532}, {
       4699.999999999998, -9849.708935004526}, {
       4699.999999999998, -9849.708935004526}}]}}, 
    {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
     Opacity[0.9], 
     PolygonBox[{{2584.881974891904, -9849.708935004532}, {
      2584.8819748931182`, -9849.708935004532}, {
      2584.8819748931182`, -9849.708935004526}, {
      2584.881974891904, -9849.708935004526}}]}, {
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707203`, -9849.708935004528}, \
{3136.0548108707226`, -9849.708935004526}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707203`, -9849.708935004528}, 
       2.3588147203819674`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{2584.8819748931205`, -9849.70893500453}, {
       3136.0548108707203`, -9849.70893500453}, {
       3136.0548108707203`, -9849.708935004528}, {
       2584.8819748931205`, -9849.708935004528}},
       VertexColors->{
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.00784313725490196, 0.5098039215686274, 0.9294117647058824]}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      DiskBox[{2584.8819748931205`, -9849.70893500453}, 
       2.3588147203819674`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      Opacity[0.9], 
      RectangleBox[{2584.8819748931182`, -9849.708935004532}, \
{2584.8819748931205`, -9849.70893500453}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935004533}, {
        100.00000077111767`, -9849.708935004533}, {
        100.00000077111767`, -9849.708935004532}, {
        100, -9849.708935004532}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.708935004533}, {
       600.2525325122605, -9849.708935004533}, {
       600.2525325122605, -9849.708935004532}, {
       600.0828428620958, -9849.708935004532}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935004533}, {
       1335.9168601401302`, -9849.708935004533}, {
       1335.9168601401302`, -9849.708935004532}, {
       1335.896118374167, -9849.708935004532}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708935004533}, {
       1601.2816681890322`, -9849.708935004533}, {
       1601.2816681890322`, -9849.708935004532}, {
       1601.2816681890304`, -9849.708935004532}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935004533}, {
       2652.5178850657803`, -9849.708935004533}, {
       2652.5178850657803`, -9849.708935004532}, {
       2646.7764947886794`, -9849.708935004532}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708935004533}, {
       2584.8819748931205`, -9849.708935004533}, {
       2584.8819748931205`, -9849.708935004532}, {
       2584.881974891904, -9849.708935004532}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708935004533}, {
       3704.351343145266, -9849.708935004533}, {
       3704.351343145266, -9849.708935004532}, {
       2718.5794145770797`, -9849.708935004532}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353085962483, -9849.708935004533}, {
       4142.6493349287275`, -9849.708935004533}, {
       4142.6493349287275`, -9849.708935004532}, {
       4134.353085962483, -9849.708935004532}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004532}, {
       4699.999999999998, -9849.708935004532}}]}}, 
    {RGBColor[
     0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
     Opacity[0.9], 
     PolygonBox[{{3136.0548108707226`, -9849.708935004533}, {
      3136.0548108707253`, -9849.708935004533}, {
      3136.0548108707253`, -9849.708935004532}, {
      3136.0548108707226`, -9849.708935004532}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.3530859624825`, -9849.708935004532}, \
{4134.353085962483, -9849.708935004532}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.3530859624825`, -9849.708935004532}, 
       1.1719106460418878`*^-12, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{3136.0548108707267`, -9849.708935004533}, {
       4134.3530859624825`, -9849.708935004533}, {
       4134.3530859624825`, -9849.708935004532}, {
       3136.0548108707267`, -9849.708935004532}},
       VertexColors->{
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.15294117647058825`, 0.11372549019607843`, 
          0.49019607843137253`]}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{3136.0548108707267`, -9849.708935004533}, 
       1.1719106460418878`*^-12, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{3136.0548108707253`, -9849.708935004533}, \
{3136.0548108707267`, -9849.708935004533}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935004533}, {
        100.00000077111767`, -9849.708935004533}, {
        100.00000077111767`, -9849.708935004533}, {
        100, -9849.708935004533}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.708935004533}, {
       600.2525325122605, -9849.708935004533}, {
       600.2525325122605, -9849.708935004533}, {
       600.0828428620958, -9849.708935004533}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935004533}, {
       1335.9168601401302`, -9849.708935004533}, {
       1335.9168601401302`, -9849.708935004533}, {
       1335.896118374167, -9849.708935004533}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935004533}, {
       2652.5178850657803`, -9849.708935004533}, {
       2652.5178850657803`, -9849.708935004533}, {
       2646.7764947886794`, -9849.708935004533}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708935004533}, {
       2584.8819748931205`, -9849.708935004533}, {
       2584.8819748931205`, -9849.708935004533}, {
       2584.881974891904, -9849.708935004533}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707226`, -9849.708935004533}, {
       3136.0548108707267`, -9849.708935004533}, {
       3136.0548108707267`, -9849.708935004533}, {
       3136.0548108707226`, -9849.708935004533}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.708935004533}, {
       3704.351343145266, -9849.708935004533}, {
       3704.351343145266, -9849.708935004533}, {
       2718.5794145770797`, -9849.708935004533}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353085962483, -9849.708935004533}, {
       4142.6493349287275`, -9849.708935004533}, {
       4142.6493349287275`, -9849.708935004533}, {
       4134.353085962483, -9849.708935004533}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}}]}}, 
    {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
     Opacity[0.9], 
     PolygonBox[{{1601.2816681890304`, -9849.708935004533}, {
      1601.2816681890322`, -9849.708935004533}, {
      1601.2816681890322`, -9849.708935004533}, {
      1601.2816681890304`, -9849.708935004533}}]}, {
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      RectangleBox[{4699.999999999998, -9849.708935004533}, 
       {4699.999999999998, -9849.708935004533}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      Opacity[0.9], 
      DiskBox[{4699.999999999998, -9849.708935004533}, 9.743905531705102*^-17,
        NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}, {
       1601.2816681890322`, -9849.708935004533}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9849.708935004533}, 
       9.743905531705102*^-17, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890322`, -9849.708935004533}, \
{1601.2816681890322`, -9849.708935004533}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.70893570352}, {
       600.2525325122605, -9849.70893570352}, {
       600.2525325122605, -9849.708935004533}, {
       600.0828428620958, -9849.708935004533}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.70893570352}, {
       1335.9168601401302`, -9849.70893570352}, {
       1335.9168601401302`, -9849.708935004533}, {
       1335.896118374167, -9849.708935004533}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.70893570352}, {
       1601.2816681890322`, -9849.70893570352}, {
       1601.2816681890322`, -9849.708935004533}, {
       1601.2816681890304`, -9849.708935004533}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.70893570352}, {
       2652.5178850657803`, -9849.70893570352}, {
       2652.5178850657803`, -9849.708935004533}, {
       2646.7764947886794`, -9849.708935004533}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.70893570352}, {
       2584.8819748931205`, -9849.70893570352}, {
       2584.8819748931205`, -9849.708935004533}, {
       2584.881974891904, -9849.708935004533}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707226`, -9849.70893570352}, {
       3136.0548108707267`, -9849.70893570352}, {
       3136.0548108707267`, -9849.708935004533}, {
       3136.0548108707226`, -9849.708935004533}}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      PolygonBox[{{2718.5794145770797`, -9849.70893570352}, {
       3704.351343145266, -9849.70893570352}, {
       3704.351343145266, -9849.708935004533}, {
       2718.5794145770797`, -9849.708935004533}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353086311977, -9849.70893570352}, {
       4142.649334928727, -9849.70893570352}, {
       4142.649334928727, -9849.708935004533}, {
       4134.353086311977, -9849.708935004533}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.70893570352}, {
       4699.999999999998, -9849.70893570352}, {
       4699.999999999998, -9849.708935004533}, {
       4699.999999999998, -9849.708935004533}}]}}, 
    {RGBColor[0., 0., 0.], Opacity[0.9], 
     PolygonBox[{{100, -9849.70893570352}, {
       100.00000077111767`, -9849.70893570352}, {
       100.00000077111767`, -9849.708935004533}, {
       100, -9849.708935004533}}]}, {
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      RectangleBox[{4134.353085962483, -9849.70893517928}, \
{4134.353086311977, -9849.708935004533}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      Opacity[0.9], 
      DiskBox[{4134.353085962483, -9849.70893517928}, 3.494937851875687*^-7, 
       NCache[{4.71238898038469, 2 Pi}, {4.71238898038469, 
        6.283185307179586}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{100.00000112061146`, -9849.708935528774}, {
       4134.353085962483, -9849.708935528774}, {
       4134.353085962483, -9849.70893517928}, {
       100.00000112061146`, -9849.70893517928}},
       VertexColors->{
         RGBColor[0., 0., 0.], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[
         0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
         RGBColor[0., 0., 0.]}]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      DiskBox[{100.00000112061146`, -9849.708935528774}, 
       3.494937851875687*^-7, 
       NCache[{1.5707963267948966`, Pi}, {1.5707963267948966`, 
        3.141592653589793}]]}, 
     {RGBColor[0., 0., 0.], Opacity[0.9], 
      RectangleBox[{100.00000077111767`, -9849.70893570352}, \
{100.00000112061146`, -9849.708935528774}]}}}, {
    {Opacity[0.9], 
     {RGBColor[0., 0., 0.], 
      PolygonBox[{{100, -9849.708935703524}, {
        100.00000112061146`, -9849.708935703524}, {
        100.00000112061146`, -9849.70893570352}, {
        100, -9849.70893570352}}]}, 
     {RGBColor[0.996078431372549, 0.3607843137254902, 0.027450980392156862`], 
      PolygonBox[{{600.0828428620958, -9849.708935703524}, {
       600.2525325122605, -9849.708935703524}, {
       600.2525325122605, -9849.70893570352}, {
       600.0828428620958, -9849.70893570352}}]}, 
     {RGBColor[0.996078431372549, 0.9882352941176471, 0.03529411764705882], 
      PolygonBox[{{1335.896118374167, -9849.708935703524}, {
       1335.9168601401302`, -9849.708935703524}, {
       1335.9168601401302`, -9849.70893570352}, {
       1335.896118374167, -9849.70893570352}}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       PolygonBox[{{1601.2816681890304`, -9849.708935703524}, {
       1601.2816681890304`, -9849.708935703524}, {
       1601.2816681890304`, -9849.70893570352}, {
       1601.2816681890304`, -9849.70893570352}}]}, 
     {RGBColor[0.1450980392156863, 0.43529411764705883`, 0.3843137254901961], 
      PolygonBox[{{2646.7764947886794`, -9849.708935703524}, {
       2652.5178850657803`, -9849.708935703524}, {
       2652.5178850657803`, -9849.70893570352}, {
       2646.7764947886794`, -9849.70893570352}}]}, 
     {RGBColor[0.00784313725490196, 0.5098039215686274, 0.9294117647058824], 
      PolygonBox[{{2584.881974891904, -9849.708935703524}, {
       2584.8819748931205`, -9849.708935703524}, {
       2584.8819748931205`, -9849.70893570352}, {
       2584.881974891904, -9849.70893570352}}]}, 
     {RGBColor[
      0.15294117647058825`, 0.11372549019607843`, 0.49019607843137253`], 
      PolygonBox[{{3136.0548108707226`, -9849.708935703524}, {
       3136.0548108707267`, -9849.708935703524}, {
       3136.0548108707267`, -9849.70893570352}, {
       3136.0548108707226`, -9849.70893570352}}]}, 
     {RGBColor[
      0.8901960784313725, 0.011764705882352941`, 0.49019607843137253`], 
      PolygonBox[{{4134.353086311977, -9849.708935703524}, {
       4142.649334928727, -9849.708935703524}, {
       4142.649334928727, -9849.70893570352}, {
       4134.353086311977, -9849.70893570352}}]}, 
     {RGBColor[
      0.9058823529411765, 0.027450980392156862`, 0.12941176470588237`], 
      PolygonBox[{{4699.999999999998, -9849.708935703524}, {
       4699.999999999998, -9849.708935703524}, {
       4699.999999999998, -9849.70893570352}, {
       4699.999999999998, -9849.70893570352}}]}}, 
    {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
     Opacity[0.9], 
     PolygonBox[{{2718.5794145770797`, -9849.708935703524}, {
      3704.351343145266, -9849.708935703524}, {
      3704.351343145266, -9849.70893570352}, {
      2718.5794145770797`, -9849.70893570352}}]}, {
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      RectangleBox[{1601.2816681890304`, -9849.708935703522}, \
{1601.2816681890322`, -9849.70893570352}]}, 
     {RGBColor[0.5411764705882353, 0.7137254901960784, 0.027450980392156862`],
       Opacity[0.9], 
      DiskBox[{1601.2816681890322`, -9849.708935703522}, 
       1.8058470367252193`*^-12, 
       NCache[{Pi, 4.71238898038469}, {3.141592653589793, 
        4.71238898038469}]]}, 
     {Opacity[0.9], 
      PolygonBox[{{1601.2816681890322`, -9849.708935703524}, {
       2718.579414577078, -9849.708935703524}, {
       2718.579414577078, -9849.708935703522}, {
       1601.2816681890322`, -9849.708935703522}},
       VertexColors->{
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
         RGBColor[
         0.5411764705882353, 0.7137254901960784, 0.027450980392156862`]}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      DiskBox[{2718.579414577078, -9849.708935703524}, 
       1.8058470367252193`*^-12, {0, 1.5707963267948966`}]}, 
     {RGBColor[0.47058823529411764`, 0.2627450980392157, 0.5843137254901961], 
      Opacity[0.9], 
      RectangleBox[{2718.579414577078, -9849.708935703524}, \
{2718.5794145770797`, -9849.708935703524}]}}}},
  AspectRatio->Automatic,
  Background->RGBColor[0.752907, 0.752907, 0.752907],
  ImageSize->{618.8270123806944, Automatic}]], "Output",
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1676, 1006},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 35, 0, 76, "Title"],
Cell[628, 25, 657, 23, 41, "Text"],
Cell[CellGroupData[{
Cell[1310, 52, 27, 0, 34, "Subsection"],
Cell[1340, 54, 3184, 89, 208, "Input",
 InitializationCell->True],
Cell[4527, 145, 1195, 35, 73, "Input",
 InitializationCell->True],
Cell[5725, 182, 17468, 460, 748, "Input",
 InitializationCell->True],
Cell[23196, 644, 572, 14, 73, "Input",
 InitializationCell->True],
Cell[23771, 660, 2599, 73, 193, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[26407, 738, 27, 0, 26, "Subsection"],
Cell[26437, 740, 954, 29, 73, "Input"],
Cell[CellGroupData[{
Cell[27416, 773, 212, 5, 27, "Input"],
Cell[27631, 780, 2753435, 53754, 1310, 2653918, 52121, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
