(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   5733744,      75875]
NotebookOptionsPosition[   5732767,      75836]
NotebookOutlinePosition[   5733132,      75852]
CellTagsIndexPosition[   5733089,      75849]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Optimal Local Alignments via Smith-Waterman", "Title"],

Cell[CellGroupData[{

Cell["Inits", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "InputOnly",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HD", "=", 
   RowBox[{"ImportFASTA", "[", "\"\<HD_3-31-2006.txt\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hdh", "=", 
   RowBox[{"ImportFASTA", "[", "\"\<Hdh.txt\>\"", "]"}]}], ";"}]}], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols", "=", 
   RowBox[{"SmithWaterman", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{"HD", ",", 
       RowBox[{"{", 
        RowBox[{"200", ",", "500"}], "}"}]}], "]"}], ",", 
     RowBox[{"Take", "[", 
      RowBox[{"Hdh", ",", 
       RowBox[{"{", 
        RowBox[{"200", ",", "500"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Each optimal local alignment has score = \"\>", 
   "\[InvisibleSpace]", "131"}],
  SequenceForm["Each optimal local alignment has score = ", 131],
  Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols5520", "=", 
   RowBox[{"Cases", "[", 
    RowBox[{"sols", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"55", ",", "20"}], "}"}], ",", "___"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Play:", "Subsection"],

Cell["\<\
Look at a stretch of 300 base-pairs on both Human and Mouse DNA. In \
particular, we look at the gene responsible for Huntington's disease. The \
genes are very similar. Here is a particular stretch where there are over \
1940 \"optimal\" alignments:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DisplayAlignment", "[", 
    RowBox[{
     RowBox[{"sols5520", "[", 
      RowBox[{"[", "k", "]"}], "]"}], ",", 
     RowBox[{"GapStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}]}], "}"}]}], ",", 
     RowBox[{"RowLength", "\[Rule]", "51"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "1940", ",", "1"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 883, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`k$$], 1, 1940, 1}}, Typeset`size$$ = {
    1179., {202.4375, 209.5625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`k$257372$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`k$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$257372$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> RMCPackages`DNA`DisplayAlignment[
        Part[$CellContext`sols5520, $CellContext`k$$], 
        RMCPackages`DNA`GapStyle -> {
         Graphics`Colors`Red, FontWeight -> "Bold"}, 
        RMCPackages`DNA`RowLength -> 51], 
      "Specifications" :> {{$CellContext`k$$, 1, 1940, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1221., {247.875, 253.125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`sols5520 = {{{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "-", "C", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "-", "-", "C", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "-", "G", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "-", "C", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "-", "T", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "-", "G", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "-", "G", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "-", "C", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "-", "T", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "-", "C", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "-", "T", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "-", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "-", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "-", "G", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "C", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "-", "-", "A", "C", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "-", "-", "C", "G", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "-", "-", "-", "C", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "-", 
           "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "-", "G", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "-", "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "-", "C", 
           "G", "C", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "-", "C", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "-", "G", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "-", 
           "C", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "-", "-", "C", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "-", "-", "-", "G", "C", "C", "G", "C", "C", "T", "C", "C", 
           "G", "C", "C", "T", "-", "C", "A", "-", "A", "C", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "-", "C", "C", "C", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "-", "C", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "-", "-", "A", "C", "C", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "-", "A", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "-", "C", "-", "C", "-", "-", "C", "C", "-", 
           "C", "T", "-", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", 
           "C", "T", "C", "A", "G", "G", "G", "G", "C", "A", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", 
           "C", "C", "G", "C", "C", "G", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "-", "-", "C", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "-", "T", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "-", "T", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "-", "C", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "-", "T", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "-", "-", "-", "-", "G", "-", "C", "C", 
           "A", "G", "G", "-", "T", "C", "C", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "-", "-", "G", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "-", "G", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "-", "T", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "-", 
           "C", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "-", "-", "-", "C", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "-", "-", "-", "G", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "-", "-", "G", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "-", "G", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "-", "-", "-", "G", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "-", "-", "-", "-", "-", "-", "C", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "-", "A", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "-", "A", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "-", "A", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "-", "-", "-", "G", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "-", "A", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "-", "G", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "-", "A", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "-", "A", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "-", "-", "G", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "-", "-", "-", "-", "-", "A", 
           "G", "G", "A", "A", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "-", "A", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "-", "G", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "-", "-", "-", "G", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "-", "C", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "-", "C", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "-", "C", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "-", "C", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "-", "C", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "-", "C", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "-", "-", "-", 
           "G", "C", "C", "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", 
           "C", "C", "G", "C", "T", "G", "C", "C", "A", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", 
           "A"}}, {{55, 20}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", "C", "C", "G", 
           "C", "C", "T", "C", "C", "T", "C", "A", "G", "C", "T", "T", "C", 
           "C", "T", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "A", "G", "G", "C", "A", "C", "A", "G", "C", "C", "G", 
           "C", "T", "G", "C", "T", "G", "C", "C", "T", "C", "A", "G", "C", 
           "C", "G", "C", "A", "G", "C", "C", "G", "C", "C", "C", "C", "C", 
           "G", "C", "C", "G", "C", "C", "G", "C", "C", "C", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "C", "G", "G", "C", "C", 
           "C", "G", "G", "C", "T", "G", "T", "G", "G", "C", "T", "G", "A", 
           "G", "G", "A", "G", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "A", "G", 
           "A", "A", "C", "T", "T", "T", "C", "A", "G", "C", "T", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "G", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "A", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "G", "T", "C", "A", "G", "A", "A"}, {
          "C", "A", "G", "C", "A", "G", "C", "A", "A", "C", "A", "G", "C", 
           "A", "G", "C", "A", "G", "C", "A", "G", "C", "C", "A", "C", "C", 
           "G", "C", "C", "G", "C", "A", "G", "G", "C", "G", "C", "C", "G", 
           "C", "C", "G", "C", "C", "A", "C", "C", "G", "C", "C", "G", "C", 
           "C", "G", "C", "C", "G", "C", "C", "T", "C", "C", "G", "C", "C", 
           "T", "C", "A", "A", "C", "C", "C", "C", "C", "T", "C", "A", "G", 
           "C", "C", "G", "C", "C", "G", "C", "C", "T", "C", "A", "G", "G", 
           "G", "G", "C", "A", "G", "C", "C", "G", "C", "C", "G", "C", "C", 
           "G", "C", "C", "A", "C", "C", "A", "C", "C", "G", "C", "C", "G", 
           "C", "T", "G", "C", "C", "A", "-", "-", "-", "G", "G", "T", "C", 
           "C", "G", "G", "C", "A", "G", "A", "G", "G", "-", "-", "-", "A", 
           "-", "-", "A", "-", "C", "C", "G", "C", "T", "G", "C", "A", "C", 
           "C", "G", "A", "C", "C", "A", "A", "A", "G", "A", "A", "G", "G", 
           "A", "A", "C", "T", "C", "T", "C", "A", "G", "C", "C", "A", "C", 
           "C", "A", "A", "G", "A", "A", "A", "G", "A", "C", "C", "G", "T", 
           "G", "T", "G", "A", "A", "T", "C", "A", "T", "T", "G", "T", "C", 
           "T", "A", "A", "C", "A", "A", "T", "A", "T", "G", "T", "G", "A", 
           "A", "A", "A", "C", "A", "T", "T", "G", "T", "G", "G", "C", "A", 
           "C", "A", "G", "T", "C", "T", "C", "T", "C", "A", "G", "A", "A"}}},
        
       TagSet[RMCPackages`DNA`GapStyle, 
        MessageName[RMCPackages`DNA`GapStyle, "usage"], 
        "GapStyle is an option for DisplayAlignment. It is used to set the \
style for the gap character. It may be set to a single directive (such as \
Red), or to a list of such."], Graphics`Colors`Red = RGBColor[1., 0., 0.], 
       TagSet[Graphics`Colors`Red, 
        MessageName[Graphics`Colors`Red, "usage"], 
        "Red is a color given in the RGBColor system."], 
       TagSet[RMCPackages`DNA`RowLength, 
        MessageName[RMCPackages`DNA`RowLength, "usage"], 
        "RowLength is an option for DisplayAlignment that is used to set the \
maximum row length in the output. The default setting is 25."]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x sequence starts at position \"\>", "\[InvisibleSpace]", "55",
    "\[InvisibleSpace]", "\<\" and y sequence starts at position \"\>", 
   "\[InvisibleSpace]", "20"}],
  SequenceForm[
  "x sequence starts at position ", 55, " and y sequence starts at position ",
    20],
  Editable->False]], "Print"]
}, {2}]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{910, 839},
WindowMargins->{{Automatic, 349}, {Automatic, 6}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 60, 0, 76, "Title"],
Cell[CellGroupData[{
Cell[675, 27, 27, 0, 34, "Subsection"],
Cell[705, 29, 154, 4, 26, "InputOnly",
 InitializationCell->True],
Cell[862, 35, 285, 8, 43, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1172, 47, 413, 14, 27, "Input",
 InitializationCell->True],
Cell[1588, 63, 226, 5, 70, "Print"]
}, Open  ]],
Cell[1829, 71, 279, 10, 27, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[2145, 86, 27, 0, 26, "Subsection"],
Cell[2175, 88, 274, 5, 41, "Text"],
Cell[CellGroupData[{
Cell[2474, 97, 551, 14, 43, "Input"],
Cell[3028, 113, 5729348, 75708, 519, "Output"],
Cell[5732379, 75823, 351, 8, 20, "Print"]
}, {2}]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
