(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18019,        401]
NotebookOptionsPosition[     17302,        373]
NotebookOutlinePosition[     17641,        388]
CellTagsIndexPosition[     17598,        385]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Alignment Display: 
Enter two sequences of the same length to display the alignment\
\>", "Section"],

Cell[TextData[StyleBox["Instructions:",
 FontWeight->"Bold"]], "Text"],

Cell[TextData[{
 "1. Click on the following link to navigate to the Genographic Project \
website: ",
 ButtonBox["http://www3.nationalgeographic.com/genographic",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www3.nationalgeographic.com/genographic"], None}]
}], "Text"],

Cell["\<\
2. Navigate to \"Your Genetic Journey\" and \"See Your Results,\" and click \
on the \"View Non-Flash Version\" tab. \
\>", "Text"],

Cell["\<\
3. Scroll down to your sequence, highlight it  (be sure to get every \
character and no extra spaces), and then right click and copy it.\
\>", "Text"],

Cell["\<\
4. Paste it into the \"x sequence\" input field below, and put your name in \
the field above.\
\>", "Text"],

Cell["\<\
5. Repeat steps 1 - 4 with one of your group member's sequence; paste this \
sequence into the \"y sequence\" input field. In a moment you will see the \
two sequences aligned.\
\>", "Text"],

Cell["\<\
6. Before moving on, click on the \"Plus\" symbol in the upper right corner \
of the panel below, and select \"Paste Snapshot\" from the popup menu. This \
will produce some ugly code that will appear under the panel below. It \
essentially keeps a record of the alignment in case you need to see it again \
later, or in case you would like to print it out. Just be sure to paste a \
snapshot of each alignment your group produces.\
\>", "Text"],

Cell["\<\
7. Repeat the entire process for each pair of members in your group. You will \
count the number of positions where a mismatch appears for each pairing in \
your group; This is the distance measure between you and each of your group \
members. Once you have all the distances for your group, you can set about \
building an unrooted tree.\
\>", "Text"],

Cell["\<\
8. Perform a \"Save As\" (in the File menu) to save this notebook to the \
local hard drive, or to your U-drive. After saving, email it to Professor \
Torrence.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"s1", "=", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"Characters", "[", "seq1", "]"}], ",", 
          RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"s2", "=", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"Characters", "[", "seq2", "]"}], ",", 
          RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "s1", "]"}], "\[Equal]", 
          RowBox[{"Length", "[", "s2", "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"Labeled", "[", 
          RowBox[{
           RowBox[{"DisplayAlignment", "[", 
            RowBox[{"s1", ",", "s2", ",", 
             RowBox[{"FontStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], ",", 
                "6"}], "}"}]}], ",", 
             RowBox[{"RowLength", "\[Rule]", "50"}], ",", 
             RowBox[{"MismatchStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"12", ",", "Red", ",", "Bold"}], "}"}]}]}], "]"}], ",",
            
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"\"\<x = \>\"", "~~", 
              RowBox[{"ToString", "[", "name1", "]"}], "~~", 
              "\"\<, and y = \>\"", "~~", 
              RowBox[{"ToString", "[", "name2", "]"}]}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "]"}]}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{
          "\"\<Sequences currently have unequal length\>\"", ",", "Gray"}], 
          "]"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "name1", ",", "Falls", ",", "\"\<name of person with x sequence\>\""}],
        "}"}], ",", 
      RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "seq1", ",", 
        "\"\<ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTG\
ACTCACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACT\
TGACCACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCCCCCCATGCTTACAAGCAAGTACAGCAATCAAC\
CCTCAACTATCACACATCAACTGCAACTCCAAAGCCACCCCTCACCCACTAGGATACCAACAAACCTACCCACCCTTA\
ACAGTACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGTCCCCATGGATGACCC\
CCCTCAGATAGGGGTCCCTTGACCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCG\
GGCCCATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGCCATAAAGCCTAAAT\
AGCCCACACGTTCCCCTTAAATAAGACATCACGATG\>\"", ",", "\"\<x sequence\>\""}], "}"}],
       ",", 
      RowBox[{
       RowBox[{"InputField", "[", 
        RowBox[{"#", ",", "String", ",", 
         RowBox[{"FieldSize", "\[Rule]", "50"}]}], "]"}], "&"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "name2", ",", "Torrence", ",", 
        "\"\<name of person with y sequence\>\""}], "}"}], ",", 
      RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "seq2", ",", 
        "\"\<ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTG\
ACTCACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACT\
TGACCACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCTCCCCATGCTTACAAGCAAGTACAGCAATCAAC\
CCTCAACTATCACACATCAACTGCAACTCCAAAGTCACCCCTCACCCATTAGGATACCAACAAACCTACCCACCCTTA\
ACAGTACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGCCCCCATGGATGACCC\
CCCTCAGATAGGGGTCCCTTGGCCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCG\
GGCCCATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGTCATAAAGCCTAAAT\
AGCCCACACGTTCCCCTTAAATAAGACATCACGATG\>\"", ",", "\"\<y sequence\>\""}], "}"}],
       ",", 
      RowBox[{
       RowBox[{"InputField", "[", 
        RowBox[{"#", ",", "String", ",", 
         RowBox[{"FieldSize", "\[Rule]", "50"}]}], "]"}], "&"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"paste", ",", "0", ",", "\"\<\>\""}], "}"}], ",", 
       RowBox[{
        RowBox[{"Button", "[", 
         RowBox[{"\"\<paste alignment\>\"", ",", 
          RowBox[{
           RowBox[{"Print", "@", 
            RowBox[{"Cases", "[", 
             RowBox[{
              RowBox[{"Characters", "[", "seq1", "]"}], ",", 
              RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}]}], "]"}]}], ";", 
           RowBox[{"Print", "@", 
            RowBox[{"Labeled", "[", 
             RowBox[{
              RowBox[{"DisplayAlignment", "[", 
               RowBox[{
                RowBox[{"Cases", "[", 
                 RowBox[{
                  RowBox[{"Characters", "[", "seq1", "]"}], ",", 
                  RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}]}], "]"}], ",", 
                RowBox[{"Cases", "[", 
                 RowBox[{
                  RowBox[{"Characters", "[", "seq2", "]"}], ",", 
                  RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}]}], "]"}], ",", 
                RowBox[{"FontStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], ",", 
                   "6"}], "}"}]}], ",", 
                RowBox[{"RowLength", "\[Rule]", "50"}], ",", 
                RowBox[{"MismatchStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"12", ",", "Red", ",", "Bold"}], "}"}]}]}], "]"}], 
              ",", 
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"\"\<x = \>\"", "~~", 
                 RowBox[{"ToString", "[", "name1", "]"}], "~~", 
                 "\"\<, and y = \>\"", "~~", 
                 RowBox[{"ToString", "[", "name2", "]"}]}], ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}]}], "]"}]}],
              "]"}]}]}]}], "]"}], "&"}]}], "}"}]}], "\[IndentingNewLine]", 
    "*)"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`name1$$ = $CellContext`Falls, \
$CellContext`name2$$ = $CellContext`Torrence, $CellContext`seq1$$ = 
    "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTCACCC\
ATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGACCACC\
TGTAGTACATAAAAACCCAATCCACATCAAAACCCCCCCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTCAACT\
ATCACACATCAACTGCAACTCCAAAGCCACCCCTCACCCACTAGGATACCAACAAACCTACCCACCCTTAACAGTACA\
TAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGTCCCCATGGATGACCCCCCTCAGA\
TAGGGGTCCCTTGACCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCCCATA\
ACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGCCATAAAGCCTAAATAGCCCACA\
CGTTCCCCTTAAATAAGACATCACGATG", $CellContext`seq2$$ = 
    "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTCACCC\
ATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGACCACC\
TGTAGTACATAAAAACCCAATCCACATCAAAACCCCCTCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTCAACT\
ATCACACATCAACTGCAACTCCAAAGTCACCCCTCACCCATTAGGATACCAACAAACCTACCCACCCTTAACAGTACA\
TAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGCCCCCATGGATGACCCCCCTCAGA\
TAGGGGTCCCTTGGCCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCCCATA\
ACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGTCATAAAGCCTAAATAGCCCACA\
CGTTCCCCTTAAATAAGACATCACGATG", Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`name1$$], $CellContext`Falls, 
       "name of person with x sequence"}}, {{
       Hold[$CellContext`seq1$$], 
       "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTCA\
CCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGACC\
ACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCCCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTCA\
ACTATCACACATCAACTGCAACTCCAAAGCCACCCCTCACCCACTAGGATACCAACAAACCTACCCACCCTTAACAGT\
ACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGTCCCCATGGATGACCCCCCTC\
AGATAGGGGTCCCTTGACCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCCC\
ATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGCCATAAAGCCTAAATAGCCC\
ACACGTTCCCCTTAAATAAGACATCACGATG", "x sequence"}, 
      InputField[#, String, FieldSize -> 50]& }, {{
       Hold[$CellContext`name2$$], $CellContext`Torrence, 
       "name of person with y sequence"}}, {{
       Hold[$CellContext`seq2$$], 
       "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTCA\
CCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGACC\
ACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCTCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTCA\
ACTATCACACATCAACTGCAACTCCAAAGTCACCCCTCACCCATTAGGATACCAACAAACCTACCCACCCTTAACAGT\
ACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGCCCCCATGGATGACCCCCCTC\
AGATAGGGGTCCCTTGGCCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCCC\
ATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGTCATAAAGCCTAAATAGCCC\
ACACGTTCCCCTTAAATAAGACATCACGATG", "y sequence"}, 
      InputField[#, String, FieldSize -> 50]& }}, Typeset`size$$ = {
    404., {255., 241.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`name1$$ = $CellContext`Falls, \
$CellContext`name2$$ = $CellContext`Torrence, $CellContext`seq1$$ = 
        "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTC\
ACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGAC\
CACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCCCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTC\
AACTATCACACATCAACTGCAACTCCAAAGCCACCCCTCACCCACTAGGATACCAACAAACCTACCCACCCTTAACAG\
TACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGTCCCCATGGATGACCCCCCT\
CAGATAGGGGTCCCTTGACCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCC\
CATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGCCATAAAGCCTAAATAGCC\
CACACGTTCCCCTTAAATAAGACATCACGATG", $CellContext`seq2$$ = 
        "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGACTC\
ACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTGAC\
CACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCTCCCCATGCTTACAAGCAAGTACAGCAATCAACCCTC\
AACTATCACACATCAACTGCAACTCCAAAGTCACCCCTCACCCATTAGGATACCAACAAACCTACCCACCCTTAACAG\
TACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGCCCCCATGGATGACCCCCCT\
CAGATAGGGGTCCCTTGGCCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGGCC\
CATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGTCATAAAGCCTAAATAGCC\
CACACGTTCCCCTTAAATAAGACATCACGATG"}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`s1$, $CellContext`s2$}, $CellContext`s1$ = Cases[
           Characters[$CellContext`seq1$$], 
           Except["\n"]]; $CellContext`s2$ = Cases[
           Characters[$CellContext`seq2$$], 
           Except["\n"]]; 
        If[Length[$CellContext`s1$] == Length[$CellContext`s2$], 
          Labeled[
           
           RMCPackages`DNA`DisplayAlignment[$CellContext`s1$, \
$CellContext`s2$, RMCPackages`DNA`FontStyle -> {FontFamily -> "Arial", 6}, 
            RMCPackages`DNA`RowLength -> 50, 
            RMCPackages`DNA`MismatchStyle -> {12, Graphics`Colors`Red, Bold}],
            
           Style[
            StringExpression["x = ", 
             ToString[$CellContext`name1$$], ", and y = ", 
             ToString[$CellContext`name2$$]], FontFamily -> "Arial"]], 
          Style[
          "Sequences currently have unequal length", Graphics`Colors`Gray]]], 
      "Specifications" :> {{{$CellContext`name1$$, $CellContext`Falls, 
          "name of person with x sequence"}, ControlType -> 
         InputField}, {{$CellContext`seq1$$, 
          "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGAC\
TCACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTG\
ACCACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCCCCCCATGCTTACAAGCAAGTACAGCAATCAACCC\
TCAACTATCACACATCAACTGCAACTCCAAAGCCACCCCTCACCCACTAGGATACCAACAAACCTACCCACCCTTAAC\
AGTACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGTCCCCATGGATGACCCCC\
CTCAGATAGGGGTCCCTTGACCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGG\
CCCATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGCCATAAAGCCTAAATAG\
CCCACACGTTCCCCTTAAATAAGACATCACGATG", "x sequence"}, 
         InputField[#, String, FieldSize -> 
          50]& }, {{$CellContext`name2$$, $CellContext`Torrence, 
          "name of person with y sequence"}, ControlType -> 
         InputField}, {{$CellContext`seq2$$, 
          "ATTCTAATTTAAACTATTCTCTGTTCTTTCATGGGGAAGCAGATTTGGGTACCACCCAAGTATTGAC\
TCACCCATCAACAACCGCTATGTATTTCGTACATTACTGCCAGCCACCATGAATATTGTACGGTACCATAAATACTTG\
ACCACCTGTAGTACATAAAAACCCAATCCACATCAAAACCCCCTCCCCATGCTTACAAGCAAGTACAGCAATCAACCC\
TCAACTATCACACATCAACTGCAACTCCAAAGTCACCCCTCACCCATTAGGATACCAACAAACCTACCCACCCTTAAC\
AGTACATAGTACATAAAGCCATTTACCGTACATAGCACATTACAGTCAAATCCCTTCTCGCCCCCATGGATGACCCCC\
CTCAGATAGGGGTCCCTTGGCCACCATCCTCCGTGAAATCAATATCCCGCACAAGAGTGCTACTCTCCTCGCTCCGGG\
CCCATAACACTTGGGGGTAGCTAAAGTGAACTGTATCCGACATCTGGTTCCTACTTCAGGGTCATAAAGCCTAAATAG\
CCCACACGTTCCCCTTAAATAAGACATCACGATG", "y sequence"}, 
         InputField[#, String, FieldSize -> 50]& }}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{564., {442.875, 448.125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, {2}]]
}, Open  ]]
},
WindowSize->{834, 938},
WindowMargins->{{27, Automatic}, {6, Automatic}},
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 110, 3, 89, "Section"],
Cell[703, 28, 70, 1, 26, "Text"],
Cell[776, 31, 282, 7, 29, "Text"],
Cell[1061, 40, 141, 3, 26, "Text"],
Cell[1205, 45, 160, 3, 26, "Text"],
Cell[1368, 50, 118, 3, 26, "Text"],
Cell[1489, 55, 200, 4, 41, "Text"],
Cell[1692, 61, 455, 7, 56, "Text"],
Cell[2150, 70, 362, 6, 56, "Text"],
Cell[2515, 78, 184, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[2724, 86, 6524, 153, 553, "Input"],
Cell[9251, 241, 8026, 128, 909, "Output"]
}, {2}]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
